       PROGRAM HTDP

**************************************************************
*  NAME:       HTDP (Horizontal Time-Dependent Positioning)
*
*  WRITTEN BY: Richard A. Snay
*
*  PURPOSE:    Predict crustal motion quantities 
*
****************************************************************
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      IMPLICIT INTEGER*4 (I-N)
      COMMON /CONST/ A,F,E2,EPS,AF,PI,TWOPI,RHOSEC
      COMMON /FILES/ LUIN, LUOUT, I1, I2, I3, I4, I5
      CHARACTER*1 OPTION
      character*5 cont

*** Introduce variables for file id's

      LUIN = 5
*       interactive input
      LUOUT = 6
*       interactive output
      I1 = 11
*       input of velocity grid in GETVEL      
*       input of earthquake parameters in GETEQ
*       input of blue-book BFILE in DLACE, VELOC, and UPDATE
*       input of blue-book GFILE in UPDATE
      I2 = 12
*       output of predicted displacements in DLACE
*       output of predicted velocities in VELOC
*       output of updated blue-book BFILE in UPDATE
*       output of updated blue-book GFILE in UPDATE
*       output of updated coordinates in UPDATE
      I3 = 13
*       output of point-velocity records in VELOC
      I4 = 14
*       storage of reference latitude & longitude & region
      I5 = 15
*       storage of earthquake parameters
C     OPEN(I5, FILE='TEMPQK' , ACCESS = 'DIRECT', RECL = 72,
C    1      FORM='UNFORMATTED')

*** Obtain parameters defining crustal motion model
      CALL MODEL
       
*** Initialize transformation parameters between reference frames
      CALL settp 

*** Initialize conversion table between reference frame identifiers
      CALL SETRF

      WRITE(LUOUT,5)
    5 FORMAT(
     1 ' **************************************************'/
     1 ' *  HTDP (Horizontal Time-Dependent Positioning)  *'/
     1 ' *  SOFTWARE VERSION 3.0 (May 1, 2008)           *'/
     1 ' *                                                *'/
     1 ' *  AUTHOR:  Richard A. Snay                      *'/
     1 ' *           NOAA / National Geodetic Survey      *'/
     1 ' *           1315 East-West Highway, Room 8813    *'/
     1 ' *           Silver Spring, Maryland 20910        *'/
     1 ' *           phone: 301-713-3191 (ext. 103)       *'/
     1 ' *           fax:   301-713-4324                  *'/
     1 ' *           Email: Richard.Snay@noaa.gov         *'/
     1 ' **************************************************'/)
      WRITE(LUOUT,10)
   10 FORMAT( 
     1 ' This software incorporates numerical models that',/
     3 ' characterize continuous crustal motion as well as ',/
     3 ' the episodic motion associated with earthquakes.'/)
      WRITE(LUOUT,11)
   11 FORMAT(
     5 ' The User Guide contains additional information and a set'/
     5 ' of exercises to familiarize users with the software.'//
     5 ' Hit ENTER or RETURN to continue.  ')
      read(luin, '(a5)') cont

   25 WRITE(LUOUT,26)
   26 FORMAT(' ***************************************'/
     1 ' MAIN MENU:',/
     6 '    0... Exit software.',/
     7 '    1... Predict displacements between two dates.'/
     8 '    2... Predict velocities.'/
     9 '    3... Update positions and/or observations '
     &           ,'to a specified date.'/
     & '    4... Transform positions between reference frames.  '/
     & '    5... Transform velocities between reference frames. ')
   30 READ(LUIN,35) OPTION
   35 FORMAT(A1)
      IF(OPTION .EQ. '0') THEN
            GO TO 50                   
      ELSEIF(OPTION .EQ. '1') THEN
	    CALL DPLACE
      ELSEIF(OPTION .EQ. '2') THEN
	    CALL VELOC
      ELSEIF(OPTION .EQ. '3') THEN
	    CALL UPDATE
      elseif(option .eq. '4') then
            call TRFPOS
      elseif(option .eq. '5') then
	    call TRFVEL
      ELSE
	    WRITE(LUOUT,40)
   40       FORMAT(' Improper entry--select again  ')
	    GO TO 30
      ENDIF
      GO TO 25
   50 CONTINUE
C     CLOSE(I5, STATUS = 'DELETE')
      STOP
      END
*****************************************************************************
      SUBROUTINE MODEL

*** Obtain parameters defining crustal motion model

      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      IMPLICIT INTEGER*4 (I-N)
      COMMON /CONST/ A,F,E2,EPS,AF,PI,TWOPI,RHOSEC
      COMMON /TIMREF/ ITREF

      A = 6.378137D06
      F = 1.D0 / 298.257222101D0
      E2 = 0.6694380022903146D-2
      AF = A / (1.D0 -F)
      EPS = F*(2.D0 - F) / ((1.D0 -F)**2)
      PI = 4.D0 * DATAN(1.D0)
      RHOSEC = (180.D0 * 3600.D0) / PI
      TWOPI = PI + PI

C*** Set default reference epoch to May 7, 1991
C     IYRREF = 1991
C     IMOREF = 5
C     IDYREF = 7
C*** Set default reference epoch to Jan. 1, 2006
      IYRREF = 2006
      IMOREF = 1
      IDYREF = 1
      CALL TOTIME (IYRREF, IMOREF, IDYREF, ITREF)

      CALL GETBDY

      RETURN
      END

*******************************************************************
      SUBROUTINE GETBDY

*** Obtain coordinates for vertices that form the polygons
*** that correspond to the boundaries for the regions.                
*** Region 1 is southern California
*** Region 2 is Northern California
*** Region 3 is the Pacific Noerthwest
*** Region 4 is western CONUS
*** Region 5 is Alaska
*** Region 6 is the North American plate 
*** Region 7 is the Caribbean plate
*** Region 8 is the western Pacific plate
*** Region 9 is the Juan de Fuca plate
*** Region 10 is the Cocos plate
*** Region 11 is the Mariana plate

      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      IMPLICIT INTEGER*4 (I-N)
      parameter (NMREGN = 11)
      COMMON /CONST/ A,F,E2,EPS,AF,PI,TWOPI,RHOSEC
      COMMON /BNDRY/ X(40,NMREGN), Y(40,NMREGN), NPOINT(NMREGN)
 
      DO 20 I = 1, NMREGN
         DO 10 J = 1, NPOINT(I)
           X(J,I) = (X(J,I) * 3600.D0)/RHOSEC
           Y(J,I) = (Y(J,I) * 3600.D0)/RHOSEC
   10    CONTINUE
   20 CONTINUE
      RETURN
      END
*******************************************************************
      SUBROUTINE GETREG(X0,Y0,JREGN)

*** Determine the region containing a given point.

      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
      IMPLICIT INTEGER*4 (I-N)
      parameter (NMREGN = 11)
      COMMON /BNDRY/ X(40,NMREGN), Y(40,NMREGN), NPOINT(NMREGN)
      COMMON /FILES/ LUIN, LUOUT, I1, I2, I3, I4, I5

      IR = 0     
    1 IR = IR + 1
      IF(IR .GT. NMREGN) THEN
         JREGN = 0
         RETURN
      ENDIF
      CALL POLYIN(X0,Y0,X(1,IR),Y(1,IR), NPOINT(IR), NTEST)
      IF(NTEST .EQ. 0) GO TO 1
      JREGN = IR       

      RETURN
      END
********************************************************
      SUBROUTINE  POLYIN (X0,Y0,X,Y,N,NPC)
C     SUBROUTINE TO DETERMINE IF A POINT AT (X0,Y0) IS INSIDE OR
C     OUTSIDE OF A CLOSED FIGURE DESCRIBED BY A SEQUENCE OF CONNECTED
C     STRAIGHT LINE SEGMENTS WITH VERTICES AT X, Y.
C
C     INPUT -
C         X0, Y0    COORDINATES OF A POINT TO BE TESTED
C         X, Y      ARRAYS CONTAINING THE VERTICES, IN ORDER, OF A
C                   CLOSED FIGURE DESCRIBED BY STRAIGHT LINE SEGMNENTS.
C                   FOR EACH 'I', THE STRAIGHT LINE FROM (XI),Y(I)) TO
C                   TO (X(I+1),Y(I+1)), IS AN EDGE OF THE FIGURE.
C         N         DIMENSION OF X AND Y, NUMBER OF VERTICES, AND NUMBER
C                   OF STRAIGHT LINE SEGMENTS IN FIGURE.
C     OUTPUT -
C         NPC       NPC=0 WHEN X0,Y0 IS OUTSIDE OF FIGURE DESCRIBED
C                   BY X,Y
C                   NPC=1 WHEN X0,Y0 IS INSIDE FIGURE
C                   NPC=2 WHEN X0,Y0 IS ON BORDER OF FIGURE
C     METHOD -
C     A COUNT IS MADE OF THE NUMBER OF TIMES THE LINE FROM (X0,Y(0)) TO
C     (X0,+ INFINITY) CROSSES THE BORDER OF THE FIGURE. IF THE COUNT
C     IS ODD, THE POINT IS INSIDE; IF THE COUNT IS EVEN THE POINT
C     IS OUTSIDE.
C     LIMITATIONS -
C     NONE. THE PROGRAM LOGIC IS VALID FOR ALL CLOSED FIGURES,
C     NO MATTER HOW COMPLEX.
C     ACCURACY -
C     MAINTAINS FULL ACCURACY OF INPUT COORDINATES.
C
      IMPLICIT INTEGER*4 (I-N)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      DIMENSION X(N),Y(N)
      DATA I6/6/
      IS=0
      NPC=0
C
C     FIND STARTING POINT WHERE X(I).NE.X0
      IP=0
   10 IP=IP+1
      IF(X(IP)-X0) 15,12,16
   12 IF(IP.LE.N) GO TO 10
      WRITE(I6,6001)
 6001 FORMAT('0  POLYGON INPUT ERROR - ALL POINTS ON LINE X = X0')
      STOP
   15 IL=-1
      GO TO 20
   16 IL=1
   20 XL=X(IP)
      YL=Y(IP)
C
C     SET UP SEARCH LOOP
C
      IP1=IP+1
      IPN=IP+N
      DO 100 II=IP1,IPN
      I=II
      IF(I.GT.N) I=I-N
      IF(IL) 30,50,40
   30 IF(X(I)-X0) 90,32,34
   32 IS=-1
      GO TO 60
   34 IL=1
      GO TO 80
   40 IF(X(I)-X0) 42,44,90
   42 IL=-1
      GO TO 80
   44 IS=1
      GO TO 60
   50 IF(X(I)-X0) 52,55,54
   52 IL=-1
      IF(IS) 90,140,80
   54 IL=1
      IF(IS) 80,140,90
   55 IF(Y(I)-Y0) 57,120,58
   57 IF(YL-Y0) 90,120,120
   58 IF(YL-Y0) 120,120,90
C
   60 IL=0
      IF(Y(I)-Y0) 90,120,90
   80 IF(YL-Y0+(Y(I)-YL)*(X0-XL)/(X(I)-XL)) 90,120,85
   85 NPC=NPC+1
   90 XL=X(I)
      YL=Y(I)
  100 CONTINUE
      NPC=MOD(NPC,2)
      RETURN
  120 NPC=2
      RETURN
 140  WRITE(I6,6002)
 6002 FORMAT('0  POLYGON LOGIC ERROR - PROGRAM SHOULD NOT REACH THIS',
     .              ' POINT')
      RETURN
      END
*****************************************************************
      SUBROUTINE RADR8T (YLAT,VN,VE,VNR,VER)

C Convert horizontal velocities from mm/yr to rad/yr

      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      IMPLICIT INTEGER*4 (I-N)

      CALL RADII (YLAT,RADMER,RADPAR)
      VNR = VN / (1000.D0 * RADMER)
      VER = VE / (1000.D0 * RADPAR)

      RETURN
      END
*****************************************************************
      SUBROUTINE COMVEL(YLAT,YLON,JREGN,VN,VE,VU)
C
C Compute the NAD_83(CORS96) velocity at a point in mm/yr
C
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      IMPLICIT INTEGER*4 (I-N)
      parameter (NUMGRD = 5)
      parameter (NMREGN = 11)
      COMMON /CONST/ A,F,E2,EPS,AF,PI,TWOPI,RHOSEC
      COMMON /FILES/ LUIN, LUOUT, I1,I2,I3,I4,I5
      COMMON /VGRID/ B(93000)
      DIMENSION WEI(2,2), VEL(2,2,3)

c     WRITE (6, 1001) JREGN
c1001 FORMAT( 'JREGN = ', I6)

      IF(JREGN .GT. NUMGRD .AND. JREGN .LE. NMREGN) THEN
*** Use tectonic plate model to compute velocity relative
***    to ITRF2005
        IPLATE = JREGN - NUMGRD
        ELON = - YLON
        HT = 0.D0
        CALL TOXYZ(YLAT, ELON, HT, X, Y, Z)
***     CALL NUVELA(IPLATE, X, Y, Z, VX, VY, VZ)
***     CALL NUVELA( 1, X, Y, Z, VX1, VY1, VZ1)
***     VX = VX - VX1
***     VY = VY - VY1
***     VZ = VZ - VZ1
        CALL PLATVL(IPLATE, X, Y, Z, VX, VY, VZ)
        VX = VX * 1000.D0
        VY = VY * 1000.D0
        VZ = VZ * 1000.D0
*** Convert ITRF2005 velocity to NAD_83(CORS96) velocity
        CALL VTRANF(X, Y, Z, VX, VY, VZ, 14, 1)
        CALL TOVNEU(YLAT, ELON, VX, VY, VZ, VN, VE, VU)

      ELSEIF(JREGN .GE. 1 .AND. JREGN .LE. NUMGRD) THEN

C*** Get indices for the lower left hand corner of the grid
C*** and get the weights for the four corners
        CALL GRDWEI (YLON, YLAT, JREGN, I, J, WEI)

C*** Get the velocity vectors at the four corners
        CALL GRDVEC (JREGN, I, J, VEL, B)

        VN = WEI(1,1) * VEL(1,1,1) + WEI(1,2) * VEL(1,2,1)
     *     + WEI(2,1) * VEL(2,1,1) + WEI(2,2) * VEL(2,2,1)

        VE = WEI(1,1) * VEL(1,1,2) + WEI(1,2) * VEL(1,2,2)
     *     + WEI(2,1) * VEL(2,1,2) + WEI(2,2) * VEL(2,2,2)
  
        VU = WEI(1,1) * VEL(1,1,3) + WEI(1,2) * VEL(1,2,3)
     *     + WEI(2,1) * VEL(2,1,3) + WEI(2,2) * VEL(2,2,3)
C*** If the point is in one of the first four regions, then
c*** the velocity grids contain the ITRF2005 velocity.
c*** Hence, the following code transforms this ITRF2005 velocity
c*** to the corresponding NAD 83 (CORS96) velocity. 
C
        IF(JREGN .LE. 4) THEN
           ELON = - YLON
           HT = 0.D0
           CALL TOXYZ(YLAT, ELON, HT, X, Y, Z)
           CALL TOVXYZ(YLAT, ELON, VN, VE, VU, VX, VY, VZ)
           CALL VTRANF( X, Y, Z, VX, VY, VZ, 14, 1)
           CALL TOVNEU(YLAT, ELON, VX, VY, VZ, VN, VE, VU)
        ENDIF

      ELSE
        WRITE(LUOUT,100) JREGN
  100   FORMAT(' Improper region identifier ',I4,'in COMVEL.')
        STOP
      ENDIF
      RETURN
      END
*********************************************************************
***   SUBROUTINE NUVELA(IPLATE, X, Y, Z, VX, VY, VZ)
*** Compute the NNR-NUVEL1A velocity at point on plate = IPLATE
***    with coordinates X, Y, Z
***    Reference = IERS Technical Note 21 (IERS Conventions), July 1996

***   IMPLICIT DOUBLE PRECISION (A-H, O-Z)
***   IMPLICIT INTEGER*4 (I-N)
***   DIMENSION WX(6), WY(6), WZ(6)
***   COMMON /FILES/ LUIN, LUOUT, I1, I2, I3, I4, I5

*** IPLATE = 1 --> North America
***          2 --> Caribbean
***          3 --> Pacific 
***          4 --> Juan de Fuca
***          5 --> Cocos
***          6 --> Mariana (from Snay, 2003)
c     DATA WX /0.258D-9, -0.178D-9, -1.510D-9, 
c    1         5.200D-9, -10.425D-9, -.099D-9/
c     DATA WY /-3.599D-9, -3.385D-9, 4.840D-9,
c    1          8.610D-9, -21.605D-9,  .511D-9/
c     DATA WZ /-0.153D-9, 1.581D-9, -9.970D-9, 
c    1         -5.820D-9, 10.925D-9,-1.684D-9/
c     IF (IPLATE .LE. 0 .OR. IPLATE .GT. 6) THEN
c         WRITE (LUOUT, 1) IPLATE
c   1     FORMAT(' Improper plate ID in NUVELA = ', I6)
c         STOP
c     ENDIF
c     VX = -WZ(IPLATE) * Y + WY(IPLATE) * Z
c     VY =  WZ(IPLATE) * X - WX(IPLATE) * Z
c     VZ = -WY(IPLATE) * X + WX(IPLATE) * Y
c     RETURN
c     END
****************************************
      SUBROUTINE PLATVL(IPLATE, X, Y, Z, VX, VY, VZ)
*** Compute the ITRF2005 velocity at point on plate = IPLATE
***    with coordinates X, Y, Z (in meters)
***    The resulting velocities--VX, VY, and VZ--will be in meters/yr
***    References 
***     NUVEL-1A = IERS Technical Note 21 (IERS Conventions), July 1996
***     Altamimi 2007 = JGR, Vol 112 B09401 (Paper on ITRF2003)
***     Snay 2003 = SALIS, Vol 63, No 1 (Paper on Frames for Pacific)

      IMPLICIT DOUBLE PRECISION (A-H, O-Z)
      IMPLICIT INTEGER*4 (I-N)
      DIMENSION WX(6), WY(6), WZ(6)
      COMMON /FILES/ LUIN, LUOUT, I1, I2, I3, I4, I5

*** IPLATE = 1 --> North America (from Altamimi 2007)
***          2 --> Caribbean (from NUVEL-1A)
***          3 --> Pacific (from Snay 2003)
***          4 --> Juan de Fuca (from NUVEL-1A)
***          5 --> Cocos (from NUVEL-1A)
***          6 --> Mariana (from Snay, 2003)
      DATA WX /0.152D-9, -0.178D-9, -1.862D-9, 
     1         5.200D-9, -10.425D-9, -.099D-9/
      DATA WY /-3.338D-9, -3.385D-9, 4.882D-9,
     1          8.610D-9, -21.605D-9,  .511D-9/
      DATA WZ /-0.251D-9, 1.581D-9,-10.598D-9, 
     1         -5.820D-9, 10.925D-9,-1.684D-9/

      IF (IPLATE .LE. 0 .OR. IPLATE .GT. 6) THEN
          WRITE (LUOUT, 1) IPLATE
    1     FORMAT(' Improper plate ID in PLATVL = ', I6)
          STOP
      ENDIF

      VX = -WZ(IPLATE) * Y + WY(IPLATE) * Z
      VY =  WZ(IPLATE) * X - WX(IPLATE) * Z
      VZ = -WY(IPLATE) * X + WX(IPLATE) * Y

*** The parameters--WX, WY, and WZ--refer to ITRF2000
*** for the Pacific Plate and the Mariana Plate (Snay, 2003). Hence,
*** for these two plates, VX, VY, and VZ, correspond to ITRF2000.
*** The following code converts VX, VY, and VZ to ITRF2005 for
*** these two plates.
      IF (IPLATE .EQ. 3 .OR. IPLATE .EQ. 6) THEN
         VX = .0002 -0.08D-9*X + VX
         VY = -.0001 -0.08D-9*Y + VY
         VZ = .0018 -0.08D-9*Z + VZ
      ENDIF

      RETURN
      END
**********************************************************************
      SUBROUTINE PVPRNT(LATD,LATM,SLAT,LOND,LONM,SLON,VN,VE)

***  Print out a point-velocity (PV) record

      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      IMPLICIT INTEGER*4 (I-N)
      COMMON /FILES/ LUIN,LUOUT,I1,I2,I3,I4,I5

      LATS = IDINT(SLAT*100.D0 + 0.5D0)
      LONS = IDINT(SLON*100.D0 + 0.5D0)
      IVN  = IDINT(  VN*100.D0 + 0.5D0)
      IVE  = IDINT(  VE*100.D0 + 0.5D0)
      IVU  = 0
      JVN  = 300 
      JVE  = 300 
      JVU  = 500

      WRITE(I3,10) LATD,LATM,LATS,LOND,LONM,LONS,
     1             IVN,JVN,IVE,JVE,IVU,JVU
   10 FORMAT('PV',I3,I2.2,I4.4,'N',I3,I2.2,I4.4,'W',6I6)
      RETURN
      END
****************************************************************************
      SUBROUTINE DSDA(LOCISN, LOCJSN, MIN1, MIN2, DS, DA)

** Compute change in distance and change in azimuth.

      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      IMPLICIT INTEGER*4 (I-N)
      COMMON /CONST/ A,F,E2,EPS,AF,PI,TWOPI,RHOSEC
      COMMON /FILES/ LUIN, LUOUT, I1, I2, I3, I4, I5

      HTF = 0.0D0
      HTT = 0.0D0

      READ(I4, REC = LOCISN) YLATF, YLONF, VNF, VEF, VUF
      READ(I4, REC = LOCJSN) YLATT, YLONT, VNT, VET, VUT

      CALL COMPSN(YLATF1,YLONF1,HTF1,YLATF,YLONF,HTF,
     1            MIN1, VNF, VEF, VUF)
      CALL COMPSN(YLATF2,YLONF2,HTF2,YLATF,YLONF,HTF,
     1            MIN2, VNF, VEF, VUF)
      CALL COMPSN(YLATT1,YLONT1,HTT1,YLATT,YLONT,HTT,
     1            MIN1, VNT, VET, VUT)
      CALL COMPSN(YLATT2,YLONT2,HTT2,YLATT,YLONT,HTT,
     1            MIN2, VNT, VET, VUT)

      CALL HELINV(YLATF1,YLONF1,YLATT1,YLONT1,FAZ1,BAZ1,S1)
      CALL HELINV(YLATF2,YLONF2,YLATT2,YLONT2,FAZ2,BAZ2,S2)
      DS = S2 - S1
      DA = FAZ2 - FAZ1
      RETURN
      END
*********************************************************************
      SUBROUTINE HELINV(GLAT1,GLON1,GLAT2,GLON2,FAZ,BAZ,S)               
C                                                                       
C *** SOLUTION OF THE GEODETIC INVERSE PROBLEM AFTER T.VINCENTY.       
C *** MODIFIED RAINSFORD WITH HELMERT ELLIPTICAL TERMS.                 
C *** EFFECTIVE IN ANY AZIMUTH AND AT ANY DISTANCE SHORT OF ANTIPODAL. 
C *** STANDPOINT/FOREPOINT MUST NOT BE THE GEOGRAPHIC POLE .           
C
C   INPUT
C      GLAT1 = Latitude of from point (radians, positive north)
C      GLON1 = Longitude of from point (radians, positive west)
C      GLAT2 = Latitude of to point (radians, positive north)
C      GLON2 = Longitude of to point (radians, positive west)
C                        
C   OUTPUT
C      FAZ = Foward azimuth (radians, clockwise from north)
C      BAZ = Back azimuth   (radians, clockwise from north)
C      S   = Distance (meters)
C                                               
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)                               
      IMPLICIT INTEGER*4 (I-N)
      COMMON/CONST/A,F,EPS2,EPS,AF,PI,TWOPI,RHOSEC                      
      DATA TOL/0.5D-14/                                                 
      R = 1.0D0-F                                                       
      TU1 = R*DSIN(GLAT1)/DCOS(GLAT1)                                   
      TU2 = R*DSIN(GLAT2)/DCOS(GLAT2)                                   
      CU1 = 1.0D0/DSQRT(TU1*TU1+1.0D0)                                  
      SU1 = CU1*TU1                                                     
      CU2 = 1.0D0/DSQRT(TU2*TU2+1.0D0)                                  
      S = CU1*CU2                                                       
      BAZ = S*TU2                                                       
      FAZ = BAZ*TU1                                                     
      X = GLON1-GLON2                                                   
  100 SX = DSIN(X)                                                      
      CX = DCOS(X)                                                      
      TU1 = CU2*SX                                                      
      TU2 = SU1*CU2*CX-BAZ                                              
      SY = DSQRT(TU1*TU1+TU2*TU2)                                       
      CY = S*CX+FAZ                                                     
      Y = DATAN2(SY,CY)                                                 
      SA = S*SX/SY                                                      
      C2A = -SA*SA+1.0D0                                                
      CZ = FAZ+FAZ                                                      
      IF(C2A .GT. 0.0D0)CZ = -CZ/C2A+CY                                 
      E = CZ*CZ*2.0D0-1.0D0                                             
      C = ((-3.0D0*C2A+4.0D0)*F+4.0D0)*C2A*F/16.0D0                     
      D = X                                                             
      X = ((E*CY*C+CZ)*SY*C+Y)*SA                                       
      X = (1.0D0-C)*X*F+GLON1-GLON2                                     
      IF(DABS(D-X) .GT. TOL)GO TO 100                                   
      FAZ = DATAN2(-TU1,TU2)                                            
      BAZ = DATAN2(CU1*SX,BAZ*CX-SU1*CU2)     
      FAZ = FAZ + PI
      BAZ = BAZ + PI                      
      IF(FAZ .LT. 0.0D0)FAZ = FAZ+TWOPI                             
      IF(BAZ .LT. 0.0D0)BAZ = BAZ+TWOPI   
      IF(FAZ .GT. TWOPI)FAZ = FAZ - TWOPI
      IF(BAZ .GT. TWOPI)BAZ = BAZ - TWOPI                            
      X = DSQRT((1.0D0/R/R-1.0D0)*C2A+1.0D0)+1.0D0                      
      X = (X-2.0D0)/X                                                   
      C = 1.0D0-X                                                       
      C = (X*X/4.0D0+1.0D0)/C                                           
      D = (0.375D0*X*X-1.0D0)*X                                         
      X = E*CY                                                          
      S = 1.0D0-E-E                                                     
      S = ((((SY*SY*4.0D0-3.0D0)*S*CZ*D/6.0D0-X)*D/4.0D0+CZ)*SY*D+Y)    
     1    *C*A*R                                                        
      RETURN                                                            
      END
*************************************************************************

c     SUBROUTINE TODMSA(val,id,im,s)
 
*** convert position radians to deg,min,sec
*** range is [-twopi to +twopi]
 
c     implicit double precision(a-h,o-z)
c     IMPLICIT INTEGER*4 (I-N)
c     common/CONST/A,F,E2,EP2,AF,PI,TWOPI,RHOSEC
 
c   1 if(val.gt.twopi) then
c       val=val-twopi
c       go to 1
c     endif
 
c   2 if(val.lt.-twopi) then
c       val=val+twopi
c       go to 2
c     endif
 
c     if(val.lt.0.d0) then
c       isign=-1
c     else
c       isign=+1
c     endif
 
c     s=dabs(val*RHOSEC/3600.D0)
c     id=idint(s)
c     s=(s-id)*60.d0
c     im=idint(s)
c     s=(s-im)*60.d0
 
*** account for rounding error
 
c     is=idnint(s*1.d5)
c     if(is.ge.6000000) then
c       s=0.d0
c       im=im+1
c     endif
c     if(im.ge.60) then
c       im=0
c       id=id+1
c     endif
 
c     id = isign*id
c     im = isign*im
c     s  = isign*s

c     return
c     end
*********************************************************
      SUBROUTINE TRFDAT(CARD,DATE,IREC12,IYEAR1,IYEAR2,MINS)

C Convert blue-book date to time in minutes

      IMPLICIT DOUBLE PRECISION (A-H, O-Z)
      IMPLICIT INTEGER*4 (I-N)
      CHARACTER*80 CARD
      CHARACTER*6 DATE
      COMMON /FILES/ LUIN,LUOUT, I1, I2, I3, I4, I5

      IF (IREC12 .EQ. 0) THEN
         WRITE (LUOUT, 5)
    5    FORMAT(' ABORT: The blue-book needs a valid *12* record.')
         STOP
      ENDIF

      READ (DATE, 10) IYEAR, MONTH, IDAY
   10 FORMAT (3I2)

      IF ( IYEAR1 .LE. (1900 + IYEAR) .AND.
     1     (1900 + IYEAR) .LE. IYEAR2) THEN
         IYEAR = 1900 + IYEAR
      ELSEIF ( IYEAR1 .LE. (2000 + IYEAR) .AND.
     1     (2000 + IYEAR) .LE. IYEAR2) THEN
         IYEAR = 2000 + IYEAR
      ELSEIF ( IYEAR1 .LE. (1800 + IYEAR) .AND.
     1     (1800 + IYEAR) .LE. IYEAR2) THEN
         IYEAR = 1800 + IYEAR
      ELSE
         WRITE (LUOUT, 20) CARD
   20    FORMAT(' ABORT: The following record has a date'/
     1          ' which is inconsistent with the *12* record'/
     1          3x, A80)
      ENDIF

      IF (IYEAR .LE. 1906) THEN
         WRITE (LUOUT, 30)
   30    FORMAT(' ***WARNING***'/
     1   ' The blue-book file contains an observation that'/
     1   ' predates 1906.  The TDP model may not be valid'/
     1   ' and the computed corrections may be erroneous.')
      ENDIF
   
      IF (IDAY .EQ. 0) IDAY = 15

      IF (MONTH .EQ. 0) THEN
         MONTH = 7
         IDAY = 1
      ENDIF

      CALL TOTIME(IYEAR,MONTH,IDAY, MINS)
      RETURN
      END
*********************************************************
      SUBROUTINE TNFDAT(DATE,MINS)

C Convert blue-book date to time in years

      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      IMPLICIT INTEGER*4 (I-N)
      CHARACTER*8 DATE
      COMMON /FILES/ LUIN,LUOUT, I1, I2, I3, I4, I5
      READ(DATE,10) IYEAR,MONTH,IDAY
   10 FORMAT(I4,I2,I2)
      IF(IYEAR .LE. 1906) THEN
	  WRITE(LUOUT,20)
   20     FORMAT(' ***WARNING***'/
     1    ' The blue-book file contains an observation that'/
     2    ' predates 1906.  The TDP model is not valid and the'/
     3    ' computed correction may be erroneous.')
      ENDIF
      IF(IDAY .EQ. 0) IDAY = 15
      IF(MONTH .EQ. 0) THEN
         MONTH = 7
         IDAY = 1
      ENDIF
      CALL TOTIME(IYEAR,MONTH,IDAY,MINS)
      RETURN
      END
***************************************************************
      SUBROUTINE GETTIM(MONTH, IDAY, IYEAR, DATE, MINS, TEST)

*** Read month-day-year and convert to decimal years
*** and Julian time in minutes      
***    MONTH      input - number from 1 to 12
***    IDAY       input - number from 1 to 31
***    IYEAR      input - must be after 1906
***    DATE       output - corresponding time in decimal years
***    MINS       output - corresponding julian time in minutes
***    TEST       output - if (true) then there is an error

      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      IMPLICIT INTEGER*4 (I-N)
      LOGICAL TEST
      COMMON /FILES/ LUIN, LUOUT, I1, I2, I3, I4, I5

      READ(LUIN,*) MONTH,IDAY,IYEAR
    
      IF(IYEAR .le. 1906) THEN
          WRITE(LUOUT,10)
   10     FORMAT(' The model is not valid for dates prior ',
     1           'to 1906.'/)
          TEST = .TRUE.
          RETURN
      ENDIF

      IF(MONTH .le. 0 .or. MONTH .gt. 12) THEN
          WRITE(LUOUT,20)
   20     FORMAT(' Improper month specified.'/)
          TEST = .TRUE.
          RETURN
      ENDIF

      IF(IDAY .le. 0 .or. IDAY .gt. 31) THEN
          WRITE(LUOUT,30)
   30     FORMAT(' Improper day specified.'/)
          TEST = .TRUE.
          RETURN
      ENDIF

      CALL TOTIME(IYEAR, MONTH, IDAY, MINS)
      CALL TOTIME(IYEAR, 1, 1, MIN00)
      DATE = DBLE(IYEAR) + DBLE(MINS - MIN00)/525600.D0
      TEST = .FALSE.
      RETURN
      END

************************************************************************
      SUBROUTINE TOXYZ(glat,glon,eht,x,y,z)
 
*** compute x,y,z
*** ref p.17 geometric geodesy notes vol 1, osu, rapp
 
      implicit double precision(a-h,o-z)
      common/CONST/ a,f,e2,ep2,af,pi,twopi,rhosec
 
      slat=dsin(glat)
      clat=dcos(glat)
      w=dsqrt(1.d0-e2*slat*slat)
      en=a/w
 
      x=(en+eht)*clat*dcos(glon)
      y=(en+eht)*clat*dsin(glon)
      z=(en*(1.d0-e2)+eht)*slat
 
      return
      end
      logical function FRMXYZ(x,y,z,glat,glon,eht)
 
*** convert x,y,z into geodetic lat, lon, and ellip. ht
*** ref: eq a.4b, p. 132, appendix a, osu #370
*** ref: geom geod notes gs 658, rapp
 
      implicit double precision(a-h,o-z)
      parameter(maxint=10,tol=1.d-13)
      common/CONST/ a,f,e2,ep2,af,pi,twopi,rhosec
 
      ae2=a*e2
 
*** compute initial estimate of reduced latitude  (eht=0)
 
      p=dsqrt(x*x+y*y)
      icount=0
      tgla=z/p/(1.d0-e2)
 
*** iterate to convergence, or to max # iterations
 
    1 if(icount.le.maxint) then
        tglax=tgla
        tgla=z/(p-(ae2/dsqrt(1.d0+(1.d0-e2)*tgla*tgla)))
        icount=icount+1
        if(dabs(tgla-tglax).gt.tol) go to 1
 
*** convergence achieved
 
        frmxyz=.true.
        glat=datan(tgla)
        slat=dsin(glat)
        clat=dcos(glat)
        glon=datan2(y,x)
        w=dsqrt(1.d0-e2*slat*slat)
        en=a/w
        if(dabs(glat).le.0.7854d0) then
          eht=p/clat-en
        else
          eht=z/slat-en+e2*en
        endif
        glon=datan2(y,x)
 
*** too many iterations
 
      else
        frmxyz=.false.
        glat=0.d0
        glon=0.d0
        eht=0.d0
      endif
 
      return
      end
*********************************************************************
      SUBROUTINE RADII(YLAT,RADMER,RADPAR)
C
C  Computes the radius of curvature in the meridian
C  and the radius of curvature in a parallel of latitude
C
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      COMMON /CONST/ A,F,E2,EPS,AF,PI,TWOPI,RHOSEC
      COSLAT = DCOS(YLAT)
      DENOM = DSQRT(1.D0 + EPS*COSLAT*COSLAT)
      RADMER = AF/(DENOM**3)
      RADPAR = AF*COSLAT/DENOM
      RETURN
      END
*********************************************************************
      SUBROUTINE GETGRD(NAMEG,MINLAT,MAXLAT,ILAT,MINLON,MAXLON,ILON)

*** Interactively obtain specifications for a grid.

      IMPLICIT INTEGER*4 (I-N)
      COMMON /FILES/ LUIN,LUOUT, I1, I2, I3, I4, I5
      CHARACTER*10 NAMEG
	  WRITE(LUOUT,200)
  200     FORMAT(' Enter name for grid (10 character max).  ')
	  READ(LUIN,210) NAMEG
  210     FORMAT(A10)
	  WRITE(LUOUT,220)
  220     FORMAT(' Enter minimum latitude for grid in deg-min-sec'/
     1           ' in free format (integer values only).  ')
	  READ(LUIN,*) ID1, IM1, IS1
	  WRITE(LUOUT,230)
  230     FORMAT(' Enter maximum latitude in same format.  ')
	  READ(LUIN,*) ID2, IM2, IS2
	  WRITE(LUOUT,240)
  240     FORMAT(' Enter latitude increment in seconds ',
     1           ' (integer value).  ')
	  READ(LUIN,*) ILAT
	  WRITE(LUOUT,250)
  250     FORMAT(' Enter minimum longitude with positive being west.  ')
	  READ(LUIN,*) JD1, JM1, JS1
          WRITE(LUOUT,260)
  260     FORMAT(' Enter maximum longitude.  ')
	  READ(LUIN,*) JD2, JM2, JS2
	  WRITE(LUOUT,270)
  270     FORMAT(' Enter longitude increment in seconds ',
     1           ' (integer value).  ')
	  READ(LUIN,*) ILON
	  MINLAT = 3600*ID1 + 60*IM1 + IS1
	  MAXLAT = 3600*ID2 + 60*IM2 + IS2
	  MINLON = 3600*JD1 + 60*JM1 + JS1
	  MAXLON = 3600*JD2 + 60*JM2 + JS2
	  RETURN
	  END
*********************************************************************
      SUBROUTINE GETLYN(NAMEG,XLAT,XLON,FAZ,BAZ,XMIN,XMAX,XINC)

*** Interactively obtain the specifications for a line.

      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      IMPLICIT INTEGER*4 (I-N)
      COMMON /FILES/ LUIN,LUOUT,I1,I2,I3,I4,I5
      COMMON /CONST/ A,F,E2,EPS,AF,PI,TWOPI,RHOSEC
      CHARACTER*10 NAMEG

      WRITE(LUOUT,100)
  100 FORMAT(' Enter name for line (10 character max.)  ')
      READ(LUIN,110) NAMEG
  110 FORMAT(A10)
      WRITE(LUOUT,120)
  120 Format(' Specify the latitude for the origin of the line'/
     1       ' in deg-min-sec in free format. For example'/
     2       '         35 17 28.3'/
     3       ' Positive is north.  ')
      READ(LUIN,*) LATD,LATM,SLAT
      XLAT = (DBLE(3600*LATD + 60*LATM)+SLAT)/RHOSEC
      WRITE(LUOUT,130)
  130 FORMAT(' Specify the longitude for the origin of the line'/
     1       ' in free format with west being positive.  ')
      READ(LUIN,*) LOND,LONM,SLON
      XLON = (DBLE(3600*LOND+60*LONM)+SLON)/RHOSEC
      WRITE(LUOUT,140)
  140 FORMAT(' Specify the orientation of the line clockwise from'/
     1       ' north in decimal degrees, eg., 43.7.  ')
      READ(LUIN,*) FAZ
      FAZ = 3600.D0*FAZ/RHOSEC
      BAZ = FAZ + PI
      IF(BAZ .GT. TWOPI) BAZ = BAZ - TWOPI
      WRITE(LUOUT,150)
  150 FORMAT(' Specify minimum and maximum distance from origin in'/
     1       ' meters, eg., -40000. 30000. '/
     2       ' NOTE: negative distance corresponds to distance in'/
     3       '       the opposite direction.  ')
      READ(LUIN,*) XMIN,XMAX
      WRITE(LUOUT,160)
  160 FORMAT(' Specify distance increment in meters.  ')
      READ(LUIN,*) XINC
      RETURN
      END
*******************************************************************
      SUBROUTINE DIRCT1(GLAT1,GLON1,GLAT2,GLON2,FAZ,BAZ,S)
C
C *** SOLUTION OF THE GEODETIC DIRECT PROBLEM AFTER T.VINCENTY
C *** MODIFIED RAINSFORD'S METHOD WITH HELMERT'S ELLIPTICAL TERMS
C *** EFFECTIVE IN ANY AZIMUTH AND AT ANY DISTANCE SHORT OF ANTIPODAL
C
C *** A IS THE SEMI-MAJOR AXIS OF THE REFERENCE ELLIPSOID
C *** FINV IS THE FLATTENING OF THE REFERENCE ELLIPSOID
C *** LATITUDES AND LONGITUDES IN RADIANS POSITIVE NORTH AND EAST
C *** AZIMUTHS IN RADIANS CLOCKWISE FROM NORTH
C *** GEODESIC DISTANCE S ASSUMED IN UNITS OF SEMI-MAJOR AXIS A
C
C *** PROGRAMMED FOR CDC-6600 BY LCDR L.PFEIFER NGS ROCKVILLE MD 20FEB75
C *** MODIFIED FOR SYSTEM 360 BY JOHN G GERGEN NGS ROCKVILLE MD 750608
C
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      IMPLICIT INTEGER*4 (I-N)
      COMMON /CONST/ A,FINV,E2,EPI,AF,PI,TWOPI,RHOSEC
      DATA EPS/0.5D-13/
      R=1.D0-FINV
      TU=R*DSIN(GLAT1)/DCOS(GLAT1)
      SF=DSIN(FAZ)
      CF=DCOS(FAZ)
      BAZ=0.D0
      IF(CF.NE.0.D0) BAZ=DATAN2(TU,CF)*2.D0
      CU=1.D0/DSQRT(TU*TU+1.D0)
      SU=TU*CU
      SA=CU*SF
      C2A=-SA*SA+1.D0
      X=DSQRT((1.D0/R/R-1.D0)*C2A+1.D0)+1.D0
      X=(X-2.D0)/X
      C=1.D0-X
      C=(X*X/4.D0+1.D0)/C
      D=(0.375D0*X*X-1.D0)*X
      TU=S/R/A/C
      Y=TU
  100 SY=DSIN(Y)
      CY=DCOS(Y)
      CZ=DCOS(BAZ+Y)
      E=CZ*CZ*2.D0-1.D0
      C=Y
      X=E*CY
      Y=E+E-1.D0
      Y=(((SY*SY*4.D0-3.D0)*Y*CZ*D/6.D0+X)*D/4.D0-CZ)*SY*D+TU
      IF(DABS(Y-C).GT.EPS)GO TO 100
      BAZ=CU*CY*CF-SU*SY
      C=R*DSQRT(SA*SA+BAZ*BAZ)
      D=SU*CY+CU*SY*CF
      GLAT2=DATAN2(D,C)
      C=CU*CY-SU*SY*CF
      X=DATAN2(SY*SF,C)
      C=((-3.D0*C2A+4.D0)*FINV+4.D0)*C2A*FINV/16.D0
      D=((E*CY*C+CZ)*SY*C+Y)*SA
      GLON2=GLON1+X-(1.D0-C)*D*FINV
      IF (GLON2.GE.TWOPI) GLON2=GLON2-TWOPI
      IF(GLON2.LT.0.D0) GLON2=GLON2+TWOPI
      BAZ=DATAN2(SA,BAZ)+PI
      IF (BAZ.GE.TWOPI) BAZ=BAZ-TWOPI
      IF (BAZ.LT.0.D0) BAZ=BAZ+TWOPI
      RETURN
      END
***********************************************************
      SUBROUTINE TOCHAR(ORIG,CHAR14)

*** Convert double precision real number to character*14

      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      IMPLICIT INTEGER*4 (I-N)
      CHARACTER*14 CHAR14

      ORIG = ORIG*10000.D0
      WRITE(CHAR14,10) ORIG
   10 FORMAT(F14.0)
      RETURN
      END
*********************************************************

      SUBROUTINE DDXYZ(ISN, JSN, MIN1, MIN2, 
     1                 DDX, DDY, DDZ)

** Compute change in DX,DY,DZ-vector from time MIN1 to MIN2.

      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      IMPLICIT INTEGER*4 (I-N)
      parameter (nbbdim = 100000)
      COMMON /ARRAYS/ HT(nbbdim), LOC(nbbdim)
      COMMON /FILES/ LUIN, LUOUT, I1, I2, I3, I4, I5

      READ(I4, REC = LOC(ISN)) GLATI, GLONI, VNI, VEI, VUI
      READ(I4, REC = LOC(JSN)) GLATJ, GLONJ, VNJ, VEJ, VUJ

      CALL COMPSN(YLATI1,YLONI1,HTI1,GLATI,GLONI,HT(ISN),
     1            MIN1,VNI, VEI, VUI)
      CALL COMPSN(YLATI2,YLONI2,HTI2,GLATI,GLONI,HT(ISN),
     1            MIN2, VNI, VEI, VUI)
      CALL COMPSN(YLATJ1,YLONJ1,HTJ1,GLATJ,GLONJ,HT(JSN),
     1            MIN1, VNJ, VEJ, VUJ)
      CALL COMPSN(YLATJ2,YLONJ2,HTJ2,GLATJ,GLONJ,HT(JSN),
     1            MIN2, VNJ, VEJ, VUJ)

      XLONI1 = -YLONI1
      XLONI2 = -YLONI2
      XLONJ1 = -YLONJ1
      XLONJ2 = -YLONJ2

      CALL TOXYZ(YLATI1,XLONI1,HTI1,XI1,YI1,ZI1)
      CALL TOXYZ(YLATI2,XLONI2,HTI2,XI2,YI2,ZI2)
      CALL TOXYZ(YLATJ1,XLONJ1,HTJ1,XJ1,YJ1,ZJ1)
      CALL TOXYZ(YLATJ2,XLONJ2,HTJ2,XJ2,YJ2,ZJ2)

      DDX = (XJ2 - XI2) - (XJ1 - XI1)
      DDY = (YJ2 - YI2) - (YJ1 - YI1)
      DDZ = (ZJ2 - ZI2) - (ZJ1 - ZI1)

      RETURN
      END
*************************************************************
      SUBROUTINE DISLOC (YLAT,YLON,STRIKE,HL,EQLAT,EQLON,
     &          SS,DS,DIP,DEPTH,WIDTH,DNORTH,DWEST,DUP)

*** Compute 3-dimensional earthquake displacement at point
*** using dislocation theory
*
*   INPUT:
*         YLAT = Latitude in radians (positive north)
*         YLON = Longitude in radians (positive west)
*         STRIKE = strike in radians clockwise from north such
*                  that the direction of dip is pi/2 radians
*                  counterclockwise from the direction of strike
*         HL   = Half-length in meters
*         EQLAT = Latitude in radians of midpoint of the
*                 rectangle's upper edge (positive north)
*         EQLON = Longitude in radians of midpoint of the
*                 rectangle's upper edge (positive west)
*         SS = strike slip in meters (positive = right lateral)
*         DS = dip slip  in meters (positive = normal faulting)
*         DIP = dip in radians
*         DEPTH = Vertical depth of rectangle's upper edge
*                 in meters
*         WIDTH = width of rectangle in meters
*
*   OUTPUT:
*         DNORTH = northward displacement in radians
*         DWEST = westward displacement in radians
*         DUP = upward displacement in meters
************** 
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      IMPLICIT INTEGER*4 (I-N)

*** Compute radii of curvature at fault center
      CALL RADII (EQLAT, RMER, RPAR)

*** Compute planar coordinates in meters
      DLAT = (YLAT - EQLAT) * RMER
      DLON = (YLON - EQLON) * RPAR
      COSSTR = DCOS(STRIKE)
      SINSTR = DSIN(STRIKE)
      X1 = COSSTR*DLAT - SINSTR*DLON
      X2 = SINSTR*DLAT + COSSTR*DLON

*** Compute displacements in fault-oriented coordinates
      CALL OKADA(X1,X2,HL,DEPTH,WIDTH,DIP,U1SS,U2SS,
     &      U3SS,U1DS,U2DS,U3DS)
      U1 = U1SS*SS + U1DS*DS
      U2 = U2SS*SS + U2DS*DS
      DUP = U3SS*SS + U3DS*DS

*** Convert horizontal displacements to radians
*** in north-west coordinate system
      DNORTH = ( COSSTR*U1 + SINSTR*U2) / RMER
      DWEST  = (-SINSTR*U1 + COSSTR*U2) / RPAR

      RETURN
      END
****************************************************
      SUBROUTINE OKADA(X1,X2,XL,DU,W,DIP,
     1     U1SS,U2SS,U3SS,U1DS,U2DS,U3DS)

************************************************************
*  This subroutine computes displacements at the point X1,X2
*  on the Earth's surface due to 1.0 meter of right-lateral 
*  strike slip (SS) and 1.0 meter of normal dip slip (DS) 
*  along a rectangular fault.
*
*  The rectangular fault dips in the direction of the positive
*  X2-axis.  The rectangle's strike parallels the X1-axis.
*  With the X3-axis directed upward out of the Earth, the X1-,
*  X2-, and X3-axes form a right-handed system.
*
*  The equations of dislocation theory are employed whereby
*  Earth is represented an a homogeneous, isotropic half-space
*  with a Poisson ratio of PNU.
*
*  REFERENCE: Okada, Y., Surface deformation due to shear and
*    tensile faults in a half-space, Bulletin of the 
*    Seismological Society of America, vol. 75, pp. 1135-1154 (1985)
*
*  The X3 = 0 plane corresponds to the Earth's surface. The plane's
*  origin is located directly above the midpoint of the rectangle's
*  upper edge.
*
*  INPUT:
*    X1,X2 - Location in meters
*    XL    - Rectangle's half-length in meters
*    DU    - Vertical depth to rectangle's upper edge in meters
*            (always positive or zero)
*    W     - Rectangle's width in meters
*    DIP   - Rectangle's dip in radians (always between 0 and PI/2
*
*  OUTPUT
*    U1SS  - Displacement in X1-direction due to 1.0 meters
*            of right-lateral strike slip
*    U2SS  - Displacement in X2-direction due to 1.0 meters
*            of right-lateral strike slip
*    U3SS  - Displacement in X3-direction due to 1.0 meters
*            of right-lateral strike slip
*    U1DS  - Displacement in X1-direction due to 1.0 meters
*            of normal dip slip
*    U2DS  - Displacement in X2-direction due to 1.0 meters
*            of normal dip slip
*    U3DS  - Displacement in X3-direction due to 1.0 meters
*            of normal dip slip
*******************************************************************
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      IMPLICIT INTEGER*4 (I-N)
      LOGICAL VERT   
      PI = 3.141593D0
      TWOPI = PI + PI
      PNU = 0.25D0
      RATIO = 1.D0 - 2.D0*PNU

      IF(DABS(PI/2.D0 - DIP) .LT. .01D0)THEN
               DIPK = -PI/2.D0
               VERT = .TRUE.
      ELSE
               DIPK = -DIP
               VERT = .FALSE.
      ENDIF

      SDIP = DSIN(DIPK)
      CDIP = DCOS(DIPK)
      P = X2*CDIP + DU*SDIP
      Q = X2*SDIP - DU*CDIP

      PSI = X1 + XL
      ETA = P
      CALL OKADAW(PSI,ETA,Q,SDIP,CDIP,RATIO,TWOPI,
     1    VERT,U1SS,U2SS,U3SS,U1DS,U2DS,U3DS)

      PSI = X1 + XL
      ETA = P - W
      CALL OKADAW(PSI,ETA,Q,SDIP,CDIP,RATIO,TWOPI,
     1     VERT,C1SS,C2SS,C3SS,C1DS,C2DS,C3DS)
      U1SS = U1SS - C1SS
      U2SS = U2SS - C2SS
      U3SS = U3SS - C3SS
      U1DS = U1DS - C1DS 
      U2DS = U2DS - C2DS
      U3DS = U3DS - C3DS

      PSI = X1 - XL
      ETA = P
      CALL OKADAW(PSI,ETA,Q,SDIP,CDIP,RATIO,TWOPI,
     1     VERT,C1SS,C2SS,C3SS,C1DS,C2DS,C3DS)
      U1SS = U1SS - C1SS
      U2SS = U2SS - C2SS
      U3SS = U3SS - C3SS
      U1DS = U1DS - C1DS
      U2DS = U2DS - C2DS
      U3DS = U3DS - C3DS

      PSI = X1 - XL
      ETA = P - W
      CALL OKADAW(PSI,ETA,Q,SDIP,CDIP,RATIO,TWOPI,
     1     VERT,C1SS,C2SS,C3SS,C1DS,C2DS,C3DS)
      U1SS = U1SS + C1SS
      U2SS = U2SS + C2SS
      U3SS = U3SS + C3SS
      U1DS = U1DS + C1DS
      U2DS = U2DS + C2DS
      U3DS = U3DS + C3DS
      RETURN
      END
*************************************************************
      SUBROUTINE OKADAW(PSI,ETA,Q,SDIP,CDIP,RATIO,TWOPI,
     1           VERT,U1SS,U2SS,U3SS,U1DS,U2DS,U3DS)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      IMPLICIT INTEGER*4 (I-N)
      LOGICAL VERT   

      YBAR = ETA*CDIP + Q*SDIP
      DBAR = ETA*SDIP - Q*CDIP
      R = DSQRT(PSI*PSI + ETA*ETA + Q*Q)
      X = DSQRT(PSI*PSI + Q*Q)
      IF(DABS(Q) .LE. 0.1d0) THEN
         TERM = 0.D0
      ELSE
         TERM = DATAN(PSI*ETA/(Q*R))
      ENDIF

      IF(VERT) THEN
         F5 = -RATIO*PSI*SDIP/(R + DBAR)
         F4 = -RATIO*Q/(R + DBAR)
         F3 = 0.5D0*RATIO*(ETA/(R + DBAR)
     1          + YBAR*Q/((R + DBAR)*(R + DBAR))
     2          - DLOG(R + ETA))
         F1 = -0.5D0*RATIO*PSI*Q/
     1        ((R + DBAR)*(R + DBAR))
      ELSE
         IF(DABS(PSI) .LE. 0.1D0) then
            F5 = 0.d0
         ELSE
            F5 = 2.D0*RATIO*
     1      DATAN((ETA*(X+Q*CDIP)+X*(R+X)*SDIP)/(PSI*(R+X)*CDIP))
     2          /CDIP
         ENDIF
         F4 = RATIO*(DLOG(R+DBAR)-SDIP*DLOG(R+ETA))/CDIP
         F3 = RATIO*(YBAR/(CDIP*(R+DBAR)) - DLOG(R+ETA))
     1         + SDIP*F4/CDIP
         F1 = -RATIO*(PSI/(CDIP*(R+DBAR))) - SDIP*F5/CDIP
      ENDIF
         F2 = -RATIO*DLOG(R+ETA) - F3

      U1SS = -(PSI*Q/(R*(R+ETA))
     1         + TERM + F1*SDIP)/TWOPI
      U2SS = -(YBAR*Q/(R*(R+ETA))
     1         + Q*CDIP/(R+ETA)
     2         + F2*SDIP)/TWOPI
      U3SS = -(DBAR*Q/(R*(R+ETA))
     1         + Q*SDIP/(R+ETA)
     2         + F4*SDIP)/TWOPI
      U1DS = -(Q/R - F3*SDIP*CDIP)/TWOPI
      U2DS = -(YBAR*Q/(R*(R+PSI))
     1         + CDIP*TERM - F1*SDIP*CDIP)/TWOPI
      U3DS = -(DBAR*Q/(R*(R+PSI))
     1         + SDIP*TERM - F5*SDIP*CDIP)/TWOPI
      RETURN
      END
*******************************************************************

C     SUBROUTINE GRDCHK (POSX, POSY, INSIDE)

C
C ROUTINE CHECKS IF THE POINT HAVING COORDINATES (POSX, POSY)
C IS WITHIN THE REGION SPANNED BY THE GRID
C
C     IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C     IMPLICIT INTEGER*4 (I-N)
C     LOGICAL INSIDE
C     COMMON /CDGRID/ GRDLX, GRDUX, GRDLY, GRDUY, ICNTX, ICNTY

C     INSIDE = .TRUE.

C     IF (POSX .LT. GRDLX .OR. POSX .GT. GRDUX) THEN
C        INSIDE = .FALSE.
C     ENDIF
C     IF (POSY .LT. GRDLY .OR. POSY .GT. GRDUY) THEN
C        INSIDE = .FALSE.
C     ENDIF

C     RETURN
C     END

*******************************************************************

      SUBROUTINE GRDWEI (YLON, YLAT, JREGN, I, J, WEI)

C
C********1*********2*********3*********4*********5*********6*********7**
C
C NAME:        GRDWEI
C VERSION:     9302.01   (YYMM.DD)
C WRITTEN BY:  MR. C. RANDOLPH PHILIPP
C PURPOSE:     THIS SUBROUTINE RETURNS THE INDICES OF THE LOWER-LEFT
C              HAND CORNER OF THE GRID CELL CONTAINING THE POINT
C              AND COMPUTES NORMALIZED WEIGHTS FOR 
C              BI-LINEAR INTERPOLATION OVER A PLANE
C              
C  INPUT PARAMETERS FROM ARGUMENT LIST:
C  ------------------------------------
C YLON         LONGITUDE OF POINT IN RADIANS, POSITIVE WEST
C YLAT         LATITUDE OF POINT IN RADIANS, POSITIVE NORTH
C JREGN        ID OF GEOGRAPHIC REGION CONTAINING POINT
C
C  OUTPUT PARAMETERS FROM ARGUMENT LIST:
C  -------------------------------------
C I, J         THE COORDINATES OF LOWER LEFT CORNER OF THE GRID
C              CONTAINING THE ABOVE POSITION
C WEI          A TWO BY TWO ARRAY CONTAINING THE NORMALIZED WEIGHTS
C              FOR THE CORNER VECTORS
C
C  GLOBAL VARIABLES AND CONSTANTS:
C  -------------------------------
C NONE
C
C    THIS MODULE CALLED BY:   COMVEL
C
C    THIS MODULE CALLS:       NONE
C
C    INCLUDE FILES USED:      NONE
C
C    COMMON BLOCKS USED:      /CDGRID/, /CONST/
C
C    REFERENCES:  SEE RICHARD SNAY
C
C    COMMENTS:
C
C********1*********2*********3*********4*********5*********6*********7**
C    MOFICATION HISTORY:
C::9302.11, CRP, ORIGINAL CREATION FOR DYNAP
C::9511.09, RAS, MODIFIED FOR HTDP
C::9712.05, RAS, MODIFIED TO ACCOUNT FOR MULTIPLE GRIDS
C********1*********2*********3*********4*********5*********6*********7**
    
C**** COMPUTES THE WEIGHTS FOR AN ELEMENT IN A GRID

      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      IMPLICIT INTEGER*4 (I-N)
      parameter (NUMGRD = 5)
      DIMENSION WEI(2,2)
      COMMON /CDGRID/ GRDLX(NUMGRD), GRDUX(NUMGRD), 
     1          GRDLY(NUMGRD), GRDUY(NUMGRD),
     1          ICNTX(NUMGRD), ICNTY(NUMGRD), NBASE(NUMGRD)
      COMMON /CONST/ A,F,E2,EPS,AF,PI,TWOPI,RHOSEC

C*** Convert input coordinates to degrees
      POSX = (TWOPI - YLON) * 180.D0 / PI
      POSY = YLAT * 180.D0 / PI

C*** Obtain indices for the lower-left corner of the cell
C*** containing the point
      STEPX = (GRDUX(JREGN) - GRDLX(JREGN)) / ICNTX(JREGN)
      STEPY = (GRDUY(JREGN) - GRDLY(JREGN)) / ICNTY(JREGN)
      I = IDINT((POSX - GRDLX(JREGN))/STEPX) + 1
      J = IDINT((POSY - GRDLY(JREGN))/STEPY) + 1
c     write(6,1001) JREGN, I, J
c1001 format(1x, 'jregn = ', I5 /
c    1       1x, ' i = ', I5 /
c    1       1x, ' j = ', I5)

C*** Compute the limits of the grid cell 
      GRLX = GRDLX(JREGN) + (I - 1) * STEPX
      GRUX = GRLX + STEPX                    
      GRLY = GRDLY(JREGN) + (J - 1) * STEPY                
      GRUY = GRLY + STEPY                     

C*** Compute the normalized weights for the point               
      DENOM = (GRUX - GRLX) * (GRUY - GRLY)
      WEI(1,1) = (GRUX - POSX) * (GRUY - POSY) / DENOM
      WEI(2,1) = (POSX - GRLX) * (GRUY - POSY) / DENOM
      WEI(1,2) = (GRUX - POSX) * (POSY - GRLY) / DENOM
      WEI(2,2) = (POSX - GRLX) * (POSY - GRLY) / DENOM

      RETURN
      END

C*********************************************************************
C
      SUBROUTINE GRDVEC (JREGN, I, J, VEL, B)
C
C********1*********2*********3*********4*********5*********6*********7**
C
C NAME:        GRDVEC
C VERSION:     9302.01   (YYMM.DD)
C WRITTEN BY:  MR. C. RANDOLPH PHILIPP
C PURPOSE:     THIS SUBROUTINE RETRIEVES THE APPROXIMATE VALUES OF THE
C              GRID NODE VELOCITIES FOR GRID (I,J) 
C              
C  INPUT PARAMETERS FROM ARGUMENT LIST:
C  ------------------------------------
C JREGN        ID OF GEOGRAPHIC REGION CORRESPONDING TO GRID
C I, J         THE COORDINATES OF LOWER LEFT CORNER OF THE GRID
C              CONTAINING THE ABOVE POSITION
C B            THE ARRAY CONTAINING ALL THE APPROXIMATE VALUES
C              FOR THE ADJUSTMENT
C
C  OUTPUT PARAMETERS FROM ARGUMENT LIST:
C  -------------------------------------
C VEL          A TWO BY TWO ARRAY CONTAINING THE VELOCITY VECTORS
C              FOR THE CORNERS OF THE GRID
C
C  GLOBAL VARIABLES AND CONSTANTS:
C  -------------------------------
C NONE
C
C    THIS MODULE CALLED BY:   COMVEL
C
C    THIS MODULE CALLS:       NONE
C
C    INCLUDE FILES USED:      NONE
C
C    COMMON BLOCKS USED:      NONE     
C
C    REFERENCES:  SEE RICHARD SNAY
C
C    COMMENTS:
C
C********1*********2*********3*********4*********5*********6*********7**
C    MOFICATION HISTORY:
C::9302.11, CRP, ORIGINAL CREATION FOR DYNAP
C::9712.05, RAS, MODIFIED FOR HTDP (version 2.2)
C********1*********2*********3*********4*********5*********6*********7**


      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      IMPLICIT INTEGER*4 (I-N)
      DIMENSION VEL(2,2,3), B(*)

      DO 30 II = 0,1
         DO 20 IJ = 0,1
            DO 10 IVEC = 1, 3
               INDEX = IUNGRD(JREGN, I + II, J + IJ, IVEC)
               VEL(II + 1, IJ + 1, IVEC) = B(INDEX)
   10       CONTINUE
   20    CONTINUE
   30 CONTINUE   

      RETURN
      END

C***************************************************

      SUBROUTINE RDEG (INPUT,VAL,CNEG)

      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      IMPLICIT INTEGER*4 (I-N)

      CHARACTER*10 INPUT
      CHARACTER*1  CNEG
      INTEGER      DEG, MIN, ISEC

      DO 10 I = 1, 9
         IF (INPUT(I:I).EQ.' ') THEN
             INPUT(I:I) = '0'
         ENDIF
   10 CONTINUE

      READ (INPUT,20) DEG, MIN, ISEC

   20 FORMAT(I3,I2,I4)

      SEC = ISEC/100.D0

      VAL = (DEG + (MIN/60.D0) + (SEC/3600.D0) ) 

      IF (INPUT(10:10).EQ.CNEG) THEN
         VAL = -VAL
      ENDIF

      RETURN
      END

C***************************************************

      INTEGER FUNCTION IUNGRD(IREGN, I, J, IVEC)

      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      IMPLICIT INTEGER*4 (I-N)
      parameter (NUMGRD = 5)
      COMMON /CDGRID/ GRDLX(NUMGRD), GRDUX(NUMGRD),
     1          GRDLY(NUMGRD), GRDUY(NUMGRD),
     1          ICNTX(NUMGRD), ICNTY(NUMGRD), NBASE(NUMGRD)

      IUNGRD = NBASE(IREGN) +
     1      3 * ((J - 1) * (ICNTX(IREGN) + 1) +  (I - 1)) + IVEC

      RETURN
      END
     
C*************************************************************

C     SUBROUTINE GRDLOC (I, J, POSX, POSY)

*** DETERMINE LOCATION OF I,J-GRID NODE

C     IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C     IMPLICIT INTEGER*4 (I-N)
C     COMMON /CDGRID/ GRDLX, GRDUX, GRDLY, GRDUY, ICNTX, ICNTY

C     STEPX = (GRDUX - GRDLX) / ICNTX
C     STEPY = (GRDUY - GRDLY) / ICNTY

C     POSX = GRDLX + (I - 1)*STEPX
C     POSY = GRDLY + (J - 1)*STEPY

C     RETURN
C     END

C********************************************************* 
      SUBROUTINE TOTIME (IYR, IMON, IDAY, MINS)
      IMPLICIT INTEGER*4 (I-N)
     
      IHR = 0
      IMN = 0
      CALL TOMNT( IYR, IMON, IDAY, IHR, IMN, MINS)
      RETURN
      END

C*********************************************************
C
      SUBROUTINE TOMNT( IYR, IMON, IDAY, IHR, IMN, MINS )
C
C********1*********2*********3*********4*********5*********6*********7**
C
C NAME:       TOMNT (ORIGINALLY IYMDMJ)
C VERSION:    9004.17
C WRITTEN BY: M. SCHENEWERK
C PURPOSE:    CONVERT DATE TO MODIFIED JULIAN DATE PLUS UT
C
C INPUT PARAMETERS FROM THE ARGUEMENT LIST:
C -----------------------------------------
C IDAY              DAY
C IMON              MONTH
C IYR               YEAR
C
C OUTPUT PARAMETERS FROM ARGUEMENT LIST:
C --------------------------------------
C MINS              MODIFIED JULIAN DATE IN MINUTES
C
C
C LOCAL VARIABLES AND CONSTANTS:
C ------------------------------
C A                 TEMPORARY STORAGE
C B                 TEMPORARY STORAGE
C C                 TEMPORARY STORAGE
C D                 TEMPORARY STORAGE
C IMOP              TEMPORARY STORAGE
C IYRP              TEMPORARY STORAGE
C
C GLOBAL VARIABLES AND CONSTANTS:
C ------------------------------
C
C
C       THIS MODULE CALLED BY: GENERAL USE
C
C       THIS MODULE CALLS:     DINT
C
C       INCLUDE FILES USED:
C
C       COMMON BLOCKS USED:       
C
C       REFERENCES:            DUFFETT-SMITH, PETER  1982, 'PRACTICAL
C                              ASTRONOMY WITH YOUR CALCULATOR', 2ND
C                              EDITION, CAMBRIDGE UNIVERSITY PRESS,
C                              NEW YORK, P.9
C
C       COMMENTS:              THIS SUBROUTINE REQUIRES THE FULL YEAR,
C                              I.E. 1992 RATHER THAN 92.  
C
C********1*********2*********3*********4*********5*********6*********7**
C::LAST MODIFICATION
C::8909.06, MSS, DOC STANDARD IMPLIMENTED
C::9004.17, MSS, CHANGE ORDER YY MM DD
C********1*********2*********3*********4*********5*********6*********7**
C
      IMPLICIT DOUBLE PRECISION(A-H, O-Z)
      IMPLICIT INTEGER*4 (I-N)
C
      INTEGER*4     A, B, C, D

      IYRP = IYR
C
C........  0.0  EXPLICIT INITIALIZATION
C
      IF( IMON .LT. 3 ) THEN
        IYRP= IYRP - 1
        IMOP= IMON + 12
      ELSE
        IMOP= IMON
      END IF
C
C........  1.0  CALCULATION
C
      A=  IYRP*0.01D0
      B=  2 - A + DINT( A*0.25D0 )
      C=  365.25D0*IYRP
      D=  30.6001D0*(IMOP + 1)
      MINS =  (B + C + D + IDAY - 679006) * (24 * 60)
     &       + (60 * IHR) + IMN
C      
      RETURN
      END
*****************************************************

      SUBROUTINE TOVNEU(GLAT,GLON,VX,VY,VZ,VN,VE,VU)
*** Convert velocities from vx,vy,vz to vn,ve,vu
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      IMPLICIT INTEGER*4 (I-N)

      SLAT = DSIN(GLAT)
      CLAT = DCOS(GLAT)
      SLON = DSIN(GLON)
      CLON = DCOS(GLON)

      VN = -SLAT*CLON*VX - SLAT*SLON*VY + CLAT*VZ
      VE = -SLON*VX + CLON*VY
      VU = CLAT*CLON*VX + CLAT*SLON*VY + SLAT*VZ

      RETURN
      END
***************************************************
      SUBROUTINE TOVXYZ(GLAT,GLON,VN,VE,VU,VX,VY,VZ)
*** Convert velocities from vn,ve,vu to vx,vy,vz
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      IMPLICIT INTEGER*4 (I-N)

      SLAT = DSIN(GLAT)
      CLAT = DCOS(GLAT)
      SLON = DSIN(GLON)
      CLON = DCOS(GLON)

      VX = -SLAT*CLON*VN - SLON*VE + CLAT*CLON*VU
      VY = -SLAT*SLON*VN + CLON*VE + CLAT*SLON*VU
      VZ =  CLAT*VN + SLAT*VU

      RETURN
      END
*****************************************************
      SUBROUTINE DPLACE

*** Predict displacements between two dates.

      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      IMPLICIT INTEGER*4 (I-N)
      parameter (numref = 14)
      COMMON /CONST/ A,F,E2,EPS,AF,PI,TWOPI,RHOSEC
      COMMON /FILES/ LUIN,LUOUT, I1, I2, I3, I4, I5
      CHARACTER*80 CARD
      CHARACTER*30 NAMEF,NAME,NAMEBB
      CHARACTER*24 NAME24
      CHARACTER*17 BLAB
      CHARACTER*10 NAMEG
      CHARACTER*4 TYPE
      CHARACTER*1 OPTION,JN,JW, VOPT
      CHARACTER*1 LATDIR, LONDIR
      character*16 frame1
      LOGICAL TEST

      BLAB = 'OUTSIDE OF REGION'

      WRITE(LUOUT,10)
   10 FORMAT(
     1   ' Displacements will be predicted from time T1 to time T2.')
   20 WRITE(LUOUT,30)
   30 FORMAT(
     1   ' Please enter time T1 (month-day-year) in free format.'/
     2   ' For example, the entry,    5,12,1979'/
     3   ' represents May 12, 1979.  ')
      CALL GETTIM(MONTH1,IDAY1,IYEAR1,DATE1,MIN1,TEST)
      IF(TEST) GO TO 20
   35 WRITE(LUOUT,40)
   40 FORMAT(' Please enter T2 in same format.  ')
      CALL GETTIM(MONTH2,IDAY2,IYEAR2,DATE2,MIN2,TEST)
      IF(TEST) GO TO 35

      WRITE(LUOUT,45)
   45 FORMAT(
     1    ' Please enter the name for the file to contain'/
     2    ' the predicted displacements.  ')
      READ(LUIN,50) NAMEF
   50 FORMAT(A30)
      OPEN(I2,FILE=NAMEF,STATUS='UNKNOWN')
      CALL HEADER

*** Choosing reference frame for displacements
   56 WRITE(LUOUT,55)
   55 FORMAT(' ************************************************'/
     1   ' Select the reference frame to be used for specifying'/
     2   ' positions and displacements.  '/)
      call MENU1(iopt, frame1)

      IF(IOPT .GE. 1 .AND . IOPT .LE. numref) THEN
          WRITE(I2,57) frame1
   57     FORMAT(' DISPLACEMENTS IN METERS RELATIVE TO ', a16)
      ELSE
          WRITE(LUOUT,70)
   70     FORMAT(' Improper selection--try again.  ')
          GO TO 56
      ENDIF
            
      WRITE(I2,71) MONTH1,IDAY1,IYEAR1,MONTH2,IDAY2,IYEAR2
   71 FORMAT (
     1  ' FROM ',I2.2,'-',I2.2,'-',I4,' TO ',
     2           I2.2,'-',I2.2,'-',I4,'(month-day-year)'//
     3  'NAME OF SITE             LATITUDE          LONGITUDE    ',          
     4        '      NORTH    EAST    ')
   75 WRITE(LUOUT,80)
   80 FORMAT(' ********************************'/
     1   ' Displacements will be predicted at each point whose',/
     2   ' horizontal position is specified.',/
     4   ' Please indicate how you wish to supply positions.'/ )
   85 WRITE(LUOUT,86)
   86 FORMAT(
     5   '    0. No more points. Return to main menu.'/
     6   '    1. Individual points entered interactively.'/
     7   '    2. Points on a specified grid.'/
     8   '    3. The *80* records in a specified blue-book file.'/
     9   '    4. Points on a specified line.  ')
      READ(LUIN,'(A1)') OPTION

      IF(OPTION .EQ. '0') THEN
	  GO TO 510               
      ELSEIF(OPTION .EQ. '1') THEN
	  CALL GETPNT(LATD,LATM,SLAT,LATDIR,LOND,LONM,SLON,
     1        LONDIR,NAME24, X,Y,Z,YLAT,YLON,EHT)
	  ELON = - YLON
	  call GETVLY( YLAT, ELON, VX, VY, VZ, VN, VE, VU, VOPT, 210)
	  if (vopt .eq. '0') then
	     call PREDV( ylat, ylon, eht, date1, iopt,
     1                   jregn, vn, ve, vu)
	     if (jregn .eq. 0) then
		write(luout, 140)
		go to 85 
             endif
          endif
          call NEWCOR(ylat, ylon, eht, min1, min2, 
     1       ylatt, ylont, ehtnew, dn, de, du, vn, ve, vu)
  140          FORMAT(' ****************************************'/
     1                ' A displacement can not be predicted because'/
     1                ' the point is outside of the modeled region.'/
     2         ' For additional displacements, please indicate how'/
     3         ' you wish to supply the horizontal coordinates.'/)
	   WRITE(LUOUT,150) DN, DE,DU
  150          FORMAT(' *************************************'/
     1           ' Northward displacement = ',F7.3,' meters.'/
     1           ' Eastward displacement  = ',F7.3,' meters.'/
     1           ' Upward displacement    = ',F7.3,' meters.'/
     1           ' ****************************************'//
     2           ' For additional displacements, please indicate how'/
     3           ' you wish to supply the horizontal coordinates.'/)
	   WRITE(I2,160) NAME24,LATD,LATM,SLAT,LATDIR,
     1	          LOND,LONM,SLON,LONDIR,DN,DE
  160          FORMAT(A24,1X,I2,1X,I2,1X,F8.5,1X,A1,2X,
     1 	          I3,1X,I2,1X,F8.5,1X,A1,1X,2F8.3)
      ELSEIF(OPTION .EQ. '2') THEN
	  CALL GETGRD(NAMEG,MINLAT,MAXLAT,IDS,MINLON,MAXLON,JDS)
	  I = -1
  280     I = I + 1
	  LAT = MINLAT + I*IDS
	  IF(LAT .GT. MAXLAT) GO TO 296
	  XLAT = DBLE(LAT)/RHOSEC
          CALL TODMSS(XLAT,LATD,LATM,SLAT,ISIGN)
	  LATDIR = 'N'
	  IF (ISIGN .eq. -1) LATDIR = 'S'
	  J = -1
  290     J = J + 1
          YLAT = XLAT
	  LON = MINLON + J*JDS
	  IF(LON .GT. MAXLON) GO TO 280
	  YLON = DBLE(LON)/RHOSEC
          CALL TODMSS(YLON,LOND,LONM,SLON,ISIGN)
	  LONDIR = 'W'
	  IF (ISIGN .eq. -1) LONDIR = 'E'
          EHT = 0.D0
	  call PREDV( ylat,ylon, eht, date1, iopt,
     1       jregn, vn, ve, vu)
          IF(JREGN .eq. 0) THEN     
                WRITE(I2,291)NAMEG,I,J,LATD,LATM,SLAT,LATDIR,LOND,
     1            LOND,LONM,SLON,LONDIR,BLAB
  291           FORMAT(A10,2I4, 7X,I2,1X,I2,1X,F8.5,1X,A1,2X,I3,
     1                 1X,I2,1X,F8.5,1X,A1,1X,A17)
          ELSE
	     call NEWCOR( ylat, ylon, eht, min1, min2,
     1          ylatt, ylont, ehtnew, dn, de, du, vn, ve, vu)
	     WRITE(I2,295)NAMEG,I,J,LATD,LATM,SLAT,LATDIR,
     1                 LOND,LONM,SLON,LONDIR,DN,DE
  295        FORMAT(A10,2I4, 7X,I2,1X,I2,1X,F8.5,1X,A1,2X,I3,1X,I2,
     1                 1X,F8.5,1X,A1,1X,2F8.3)
          ENDIF
	  GO TO 290
  296     WRITE(LUOUT,297)
  297     FORMAT(' ***********************************'/
     1    ' Displacements have been calculated for the specified'/
     2    ' grid.  If you wish to calculate additional displacements,'/
     3    ' please indicate how you will supply the coordinates.'/)
      ELSEIF(OPTION .EQ. '3') THEN
	  VOPT = '0'
	  WRITE(LUOUT,300)
  300     FORMAT(' Enter name of blue-book file  ')
	  READ(LUIN,310) NAMEBB
  310     FORMAT(A30)
	  OPEN(I1,FILE=NAMEBB,STATUS='OLD')
  320     READ(I1,330,END=350) CARD
  330     FORMAT(A80)
	  TYPE = CARD(7:10)
	  IF(TYPE .EQ. '*80*') THEN
	      READ(CARD,340)NAME,LATD,LATM,SLAT,JN,
     1                           LOND,LONM,SLON,JW
  340         FORMAT(BZ,14X,A30,I2,I2,F7.5,A1,I3,I2,F7.5,A1)
              NAME24 = NAME(1:24)
C             IF(JN.EQ.'S' .OR. JW.EQ.'E')GO TO 320
	      YLAT =(DBLE((LATD*60+LATM)*60)+SLAT)/RHOSEC
	      IF (JN .eq. 'S') YLAT = -YLAT
	      YLON =(DBLE((LOND*60+LONM)*60)+SLON)/RHOSEC
	      IF (JW .eq. 'E') YLON = -YLON
              EHT = 0.D0
	      call PREDV( ylat, ylon, eht, date1, iopt,
     1          jregn, vn, ve, vu)
              IF(JREGN .EQ. 0) THEN      
                 WRITE(I2,345)NAME24,LATD,LATM,SLAT,JN,LOND,LONM,SLON,
     1                          JW,BLAB
  345            FORMAT(A24,1X,I2,1X,I2,F8.5,1X,A1,2X,I3,1X,I2,1X,F8.5,
     1                    1X,A1,1X,A17)
              ELSE
		 call NEWCOR( ylat, ylon, eht, min1, min2,
     1             ylatt, ylont, ehtnew, dn, de, du, vn, ve, vu)
	         WRITE(I2,160)NAME24,LATD,LATM,SLAT,JN,LOND,LONM,SLON,
     1             JW,DN,DE
              ENDIF
	  ENDIF
	  GO TO 320
  350     CLOSE(I1,STATUS='KEEP')
	  WRITE(LUOUT,360)
  360     FORMAT(' ************************************'/
     1    ' Displacements have been calculated for the specified'/
     2    ' blue-book file.  If you wish to calculate additional'/
     3    ' displacements, please indicate how you will supply'/
     4    ' the horizontal coordinates.'/)
      ELSEIF(OPTION .EQ. '4') THEN
	  VOPT = '0'
	  CALL GETLYN(NAMEG,XLAT,XLON,FAZ,BAZ,XMIN,XMAX,XINC)
	  XLON = TWOPI - XLON
	  I = -1
  400     I = I + 1
	  S = XMIN + I*XINC
	  IF(S .GT. XMAX) GO TO 430
	  IF(S .LT. 0.0D0) THEN
	      S1 = -S
	      AZ = BAZ
          ELSE
	      S1 = S
	      AZ = FAZ
          ENDIF
	  CALL DIRCT1(XLAT,XLON,YLAT,YLON,AZ,AZ1,S1)
	  YLON = TWOPI - YLON
          CALL TODMSS(YLAT,LATD,LATM,SLAT,ISIGN)
	  LATDIR = 'N'
	  IF (ISIGN .eq. -1) LATDIR = 'S'
          CALL TODMSS(YLON,LOND,LONM,SLON,ISIGN)
	  LONDIR = 'W'
	  IF (ISIGN .eq. -1) LONDIR = 'E'
          EHT = 0.D0
	  call PREDV( ylat, ylon, eht, date1, iopt,
     1       jregn, vn, ve, vu)
          IF(JREGN .eq. 0) THEN
              WRITE(I2,405)NAMEG,I,LATD,LATM,SLAT,LATDIR,
     1               LOND,LONM,SLON,LONDIR, BLAB
  405         FORMAT(A10,I4,11X,I2,1X,I2,1X,F8.5,1X,A1,2X,I3,1X,I2,1X,
     1               F8.5,1X,A1,1X,A17)  
          ELSE
	      call NEWCOR( ylat, ylon, eht, min1, min2,
     1           ylatt, ylont, ehtnew, dn, de, du, vn, ve, vu)
	      WRITE(I2,410)NAMEG,I,LATD,LATM,SLAT,LATDIR,LOND,LONM,
     1                 SLON,LONDIR,DN,DE
  410         FORMAT(A10,I4,11X,I2,1X,I2,1X,F8.5,1X,A1,2X,I3,1X,I2,
     1           1X,F8.5,1X,A1,1X,2F8.3)
          ENDIF
	  GO TO 400
  430     WRITE(LUOUT,440)
  440     FORMAT(' ***************************************'/
     1    ' Displacements have been calculated for the specified'/
     2    ' line.  If you wish to calculate additional displacements,'/
     3    ' please indicate how you will supply the coordinates.'/)
      ELSE
	  WRITE(LUOUT,500)
  500     FORMAT(' Improper entry--select again.  ')
      ENDIF
      GO TO 85
  510 CONTINUE
      CLOSE(I2, STATUS = 'KEEP')
      RETURN
      END
********************************************************************
      SUBROUTINE VELOC

*** Compute velocities at specified locations

      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      IMPLICIT INTEGER*4 (I-N)
      parameter (numref = 14)
      parameter (nrsrch = 0)
      COMMON /CONST/ A,F,E2,EPS,AF,PI,TWOPI,RHOSEC
      COMMON /FILES/ LUIN,LUOUT, I1, I2, I3, I4, I5
      CHARACTER*80 CARD
      CHARACTER*30 NAMEF,NAME,NAMEBB,PVFILE
      CHARACTER*24 NAME24
      CHARACTER*17 BLAB
      CHARACTER*10 NAMEG
      CHARACTER*4 TYPE
      CHARACTER*1 OPTION,JN,JW,PVOUT
      CHARACTER*1 LATDIR, LONDIR
      character*16 frame1

*** temporary code to plot results ****************
      character TEMPNA

      TEMPNA = '        '
      DUMMY = 0.0D0
*** end of temporary code *************************

      BLAB = 'OUTSIDE OF REGION'

      WRITE(LUOUT,10)
   10 FORMAT(' Please enter name for the file to contain the'/
     1       ' predicted velocities.  ')
      READ(LUIN,20) NAMEF
   20 FORMAT(A30)
      OPEN(I2,FILE=NAMEF,STATUS='UNKNOWN')
      CALL HEADER

      if (nrsrch .eq. 1) then
         WRITE(LUOUT,21)
   21    FORMAT( 
     1      ' Do you want to create a file of point-velocity (PV)'/
     1      ' records for use with the DYNAPG software (y/n)?   ')
         READ(LUIN,'(A1)') PVOUT
         IF(PVOUT .EQ. 'Y' .OR. PVOUT .EQ. 'y') THEN
            PVOUT = 'Y'
            WRITE(LUOUT,22)
   22       FORMAT(' Enter name for the file that is to contain'/
     1          ' the PV records.  ')
            READ(LUIN,'(A30)') PVFILE
            OPEN(I3,FILE = PVFILE, STATUS = 'UNKNOWN')
         ENDIF
      else
         PVOUT = 'N'
      endif

*** Choosing reference system for velocities
 1000 WRITE(LUOUT,1001)
 1001 FORMAT(' **************************************************'/
     1   ' Select the reference frame to be used for specifying'/
     2   ' positions and velocities. '/
     6   '  0...Positions in NAD 83 and velocities relative to'/
     6   '         a specified point having a specified velocity.')
	   call MENU1(iopt, frame1)
      if (iopt .ge. 1 .and. iopt .le. numref) then
           WRITE(I2,1002) frame1
 1002      FORMAT('VELOCITIES IN MM/YR RELATIVE TO ', a16 /)
           RVN = 0.0D0
           RVE = 0.0D0
           RVU = 0.0D0
      ELSEIF(IOPT .EQ. 0) THEN
           WRITE(LUOUT,1010)
           CALL GETPNT(LATD,LATM,SLAT,LATDIR,LOND,LONM,SLON,
     1          LONDIR, NAME24, X,Y,Z,YLAT,YLON,EHT)
           CALL GETREG(YLAT,YLON,JREGN)
           IF(JREGN .EQ. 0 ) THEN
              WRITE(LUOUT,1008)
 1008         FORMAT(' **********************************'/
     1          ' Point is not in modeled region and it can not'/
     1          ' be used as the reference location.'/)
              GO TO 1000
           ENDIF
           WRITE(I2,1009)
 1009      FORMAT('VELOCITIES IN MM/YR IN A REFERENCE FRAME FOR ',
     1     'WHICH THE FIRST POINT LISTED'/
     2     'BELOW HAS THE VELOCITY AS LISTED'//
     4     '**************REFERENCE SITE')
 1010      FORMAT(' For the reference point...'/)
           WRITE(LUOUT,1030)
 1030      FORMAT(' Enter northward velocity of reference location'/
     1            ' in mm/yr.  ')
           READ(LUIN,*) SVN
           WRITE(LUOUT,1040)
 1040      FORMAT(' Enter eastward velocity of reference location'/
     1            ' in mm/yr.  ')
           READ(LUIN,*) SVE
           WRITE(LUOUT,1050)
 1050      FORMAT(' The upward velocity of the reference location'/
     1            ' will be set to 0.0 mm/yr.  ')
           SVU = 0.0D0
           CALL COMVEL(YLAT,YLON,JREGN,VN,VE,VU)
           RVN = SVN - VN
           RVE = SVE - VE
           RVU = SVU - VU
           GLON = -YLON
           CALL TOVXYZ(YLAT,GLON,SVN,SVE,SVU,SVX,SVY,SVZ)
           WRITE(I2,1060) NAME24,LATD,LATM,SLAT,LATDIR,SVN,LOND,LONM,
     1         SLON,LONDIR,SVE,EHT,SVU,X,SVX,Y,SVY,Z,SVZ
 1060      FORMAT(/10X,A24,/
     1'LATITUDE   = ',2I3,F9.5,1X,A1,'  NORTH VELOCITY =',F7.2,' mm/yr'/
     2'LONGITUDE  = ',2I3,F9.5,1X,A1,'  EAST VELOCITY  =',F7.2,' mm/yr'/ 
     3'ELLIPS. HT. = ',F10.3,' m', 6X,'UP VELOCITY    =',F7.2,' mm/yr'/
     4'X =',F13.3,' m',14X,            'X VELOCITY     =',F7.2,' mm/yr'/
     5'Y =',F13.3,' m',14X,            'Y VELOCITY     =',F7.2,' mm/yr'/
     6'Z =',F13.3,' m',14X,            'Z VELOCITY     =',F7.2,' mm/yr')
           WRITE(I2,1070)
 1070      FORMAT('******************************')
      ELSE
           write(luout, 1080)
 1080      format(' Improper selection -- try again.  ')
           GO TO 1000
      ENDIF

*** Choosing input format for locations where velocities are to be predicted
      WRITE(LUOUT,30)
   30 FORMAT(' ************************************************'/
     1   ' Velocities will be predicted at each point whose'/
     2   ' horizontal position is specified.  Please indicate'/
     4   ' how you wish to supply positions.'/)
   40 WRITE(LUOUT,50)
   50 FORMAT(
     1   '    0... No more points. Return to main menu.'/
     2   '    1... Individual points entered interactively.'/
     3   '    2... Points on a specified grid.'/
     4   '    3... The *80* records in a specified blue-book file.'/
     5   '    4... Points on a specified line.  ')

      READ(LUIN,60) OPTION
   60 FORMAT(A1)

      IF(OPTION .EQ. '0') THEN
	   GO TO 610               
      ELSEIF(OPTION .EQ. '1') THEN
	   CALL GETPNT(LATD,LATM,SLAT,LATDIR,LOND,LONM,SLON,
     1           LONDIR, NAME24, X,Y,Z,YLAT,YLON,EHT)
           CALL GTOVEL(YLAT,YLON,EHT,RVN,RVE,RVU,
     1                 VN,VE,VU,VX,VY,VZ,JREGN,IOPT)
           IF(JREGN .eq. 0 ) THEN
               WRITE(LUOUT,80)
   80          FORMAT(' *************************************'/
     1           ' A velocity can not be predicted because'/
     1           ' the point is outside of the modeled region.'/
     2           ' For additional velocities, please indicate how'/
     3           ' you wish to supply the horizontal coordinates.'/)
           ELSE
	       WRITE(LUOUT,90) VN, VE, VU, VX, VY, VZ
   90          FORMAT(' **************************************'/
     1            ' Northward velocity = ',F6.2,' mm/yr'/
     1            ' Eastward velocity  = ',F6.2,' mm/yr'/
     1            ' Upward velocity    = ',F6.2,' mm/yr'//
     1            ' X-dim. velocity    = ',F6.2,' mm/yr'/
     1            ' Y-dim. velocity    = ',F6.2,' mm/yr'/
     1            ' Z-dim. velocity    = ',F6.2,' mm/yr'/
     1            ' **************************************'//
     2         ' For additional velocities, please indicate how'/
     3         ' you wish to specify the horizontal coordinates.'/)
	       WRITE(I2,1060)NAME24,LATD,LATM,SLAT,LATDIR,VN,LOND,LONM, 
     1                SLON, LONDIR, VE, EHT,VU,X,VX,Y,VY,Z,VZ
  100          FORMAT(A24,1X,I2,1X,I2,1X,F8.5,1X,A1,2X,I3,1X,I2,1X,F8.5,
     1            1X,A1,1X,2F8.2)
               IF(PVOUT .EQ. 'Y') THEN
                   CALL PVPRNT(LATD,LATM,SLAT,LOND,LONM,SLON,VN,VE)
               ENDIF
           ENDIF
      ELSEIF(OPTION .EQ. '2') THEN
           EHT = 0.D0
           WRITE(I2,105)
  105      FORMAT(
     1     'NAME OF SITE',14X,'LATITUDE          LONGITUDE    ',
     2     '     NORTH    EAST'/)
	   CALL GETGRD(NAMEG,MINLAT,MAXLAT,IDS,MINLON,MAXLON,JDS)
	   I = -1
  110      I = I + 1
	   LAT = MINLAT + I*IDS
	   IF(LAT .GT. MAXLAT) GO TO 150
	   XLAT = DBLE(LAT)/RHOSEC
           CALL TODMSS(XLAT,LATD,LATM,SLAT,ISIGN)
	   LATDIR = 'N'
	   IF (ISIGN .eq. -1) LATDIR = 'S'
	   J = -1
  120      J = J + 1
           YLAT = XLAT
	   LON = MINLON + J*JDS
	   IF(LON .GT. MAXLON) GO TO 110
	   YLON = DBLE(LON)/RHOSEC
           CALL TODMSS(YLON,LOND,LONM,SLON,ISIGN)
	   LONDIR = 'W'
	   IF (ISIGN .eq. -1) LONDIR = 'E'
           CALL GTOVEL(YLAT,YLON,EHT,RVN,RVE,RVU,
     1                 VN,VE,VU,VX,VY,VZ,JREGN,IOPT)
           IF(JREGN .EQ. 0 ) THEN
               WRITE(I2,125)NAMEG,I,J,LATD,LATM,SLAT,LATDIR,LOND,LONM,
     1                      SLON,LONDIR,BLAB
  125          FORMAT(A10,2I4, 7X,I2,1X,I2,1X,F8.5,1X,A1,2X,I3,1X,I2,
     1                1X,F8.5,1X,A1, 1X,A17)
           ELSE

*** temporary code to plot results
	       ZLAT = DBLE(LATD) + DBLE(LATM)/60.D0 + SLAT/3600.D0
	       ZLON = DBLE(LOND) + DBLE(LONM)/60.D0 + SLON/3600.D0
	       ZLON = 360.D0 - ZLON
	       TOTVEL = DSQRT(VN*VN + VE*VE)

*** code to create vectors to be plotted
c	       IF (TOTVEL .GE. 5.0D0 .AND. TOTVEL .LE. 50.D0) THEN
c	          TVE = VE/10.D0
c	          TVN = VN/10.D0
c	          WRITE(I2,129) ZLON,ZLAT,TVE,TVN,DUMMY,DUMMY,DUMMY,
c    1                   TEMPNA
c 129             FORMAT(F10.6, 2x, F9.6, 2X, 5(F7.2, 2x), A8)
c 	       ENDIF

*** code to create contour plots
C	       WRITE(I2,129) ZLON, ZLAT, TOTVEL
C 129          FORMAT(F6.2, 1X, F6.2, 1X, F5.1)
 
*** end of temporary code

*** beginning of original code
 	       WRITE(I2,130)NAMEG,I,J,LATD,LATM,SLAT,LATDIR,
     1                  LOND,LONM,SLON,LONDIR,VN,VE
  130          FORMAT(A10,2I4, 7X,I2,1X,I2,1X,F8.5,1X,A1,2X,
     1                 I3,1X,I2,1X,F8.5,1X,A1,1X,2F8.2)
*** end of original code

               IF(PVOUT .EQ. 'Y') THEN
                   CALL PVPRNT(LATD,LATM,SLAT,LOND,LONM,SLON,VN,VE)
               ENDIF
           ENDIF
	   GO TO 120
  150      WRITE(LUOUT,160)
  160      FORMAT(' **********************************************'/
     1     ' Velocities have been calculated for the specified grid.'/
     2     ' If you wish to calculate additional velocities, please'/
     3     ' indicate how you will specify positional coordinates.'/)
      ELSEIF(OPTION .EQ. '3') THEN
           EHT = 0.D0
           WRITE(I2,105)
	   WRITE(LUOUT,200)
  200      FORMAT(' Enter name of blue-book file.  ')
	   READ(LUIN,210) NAMEBB
  210      FORMAT(A30)
	   OPEN(I1,FILE=NAMEBB,STATUS='OLD')
  220      READ(I1,230,END=250) CARD
  230      FORMAT(A80)
	   TYPE = CARD(7:10)
	   IF(TYPE .EQ. '*80*') THEN
		READ(CARD,240)NAME,LATD,LATM,SLAT,JN,
     1                             LOND,LONM,SLON,JW
  240           FORMAT(BZ,14X,A30,I2,I2,F7.5,A1,I3,I2,F7.5,A1)
                NAME24 = NAME(1:24)
C		IF(JN.EQ.'S' .OR. JW.EQ.'E')GO TO 220
		YLAT =(DBLE((LATD*60+LATM)*60)+SLAT)/RHOSEC
		YLON =(DBLE((LOND*60+LONM)*60)+SLON)/RHOSEC
		if (jn .eq. 'S') ylat = -ylat
		if (jw .eq. 'E') ylon = -ylon
                CALL GTOVEL(YLAT,YLON,EHT,RVN,RVE,RVU,
     1                      VN,VE,VU,VX,VY,VZ,JREGN,IOPT)
                IF(JREGN .EQ. 0 ) THEN
                   WRITE(I2,245)NAME24,LATD,LATM,SLAT,JN,LOND,LONM,
     1                          SLON,JW,BLAB
  245              FORMAT(A24,1X,I2,1X,I2,1X,F8.5,1X,A1,2X,I3,1X,I2,
     1                    1X,F8.5,1X,A1,1X,A17)
                ELSE
                   WRITE(I2,100)NAME24,LATD,LATM,SLAT,JN,LOND,LONM,
     1               SLON,JW,VN,VE  
                   IF(PVOUT .EQ. 'Y') THEN
                       CALL PVPRNT(LATD,LATM,SLAT,LOND,LONM,SLON,VN,VE)
                   ENDIF
                ENDIF
	   ENDIF
	   GO TO 220
  250      CLOSE(I1,STATUS='KEEP')
	   WRITE(LUOUT,260)
  260      FORMAT(' ****************************************'/
     1     ' Velocities have been calculated for the specified '/
     2     ' blue-book file.  If you wish to calculate additional'/
     3     ' velocities, please indicate how you will supply the'/
     4     ' horizontal coordinates.'/)
      ELSEIF(OPTION .EQ. '4') THEN
           EHT = 0.D0
           WRITE(I2,105)
	   CALL GETLYN(NAMEG,XLAT,XLON,FAZ,BAZ,XMIN,XMAX,XINC)
	   XLON = TWOPI - XLON
	   I = -1
  300      I= I+1
	   S = XMIN + I*XINC
	   IF(S .GT. XMAX) GO TO 330
	   IF(S .LT. 0.0D0) THEN
	       S1 = -S
	       AZ = BAZ
           ELSE
	       S1 = S
	       AZ = FAZ
           ENDIF
	   CALL DIRCT1(XLAT,XLON,YLAT,YLON,AZ,AZ1,S1)
	   YLON = TWOPI - YLON
           CALL TODMSS(YLAT,LATD,LATM,SLAT,ISIGN)
	   LATDIR = 'N'
	   IF (ISIGN .eq. -1) LATDIR = 'S'
           CALL TODMSS(YLON,LOND,LONM,SLON,ISIGN)
	   LONDIR = 'W'
	   IF (ISIGN .eq. -1) LONDIR = 'E'
           CALL GTOVEL(YLAT,YLON,EHT,RVN,RVE,RVU,
     1                 VN,VE,VU,VX,VY,VZ,JREGN,IOPT)
           IF(JREGN .EQ. 0 ) THEN
               WRITE(I2,305)NAMEG,I,LATD,LATM,SLAT,LATDIR,LOND,LONM,
     1                      SLON,LONDIR,BLAB
  305          FORMAT(A10,I4,11X,I2,1X,I2,1X,F8.5,1X,A1,2X,I3,1X,
     1                I2,1X,F8.5,1X,A1,1X,A17)
           ELSE
	       WRITE(I2,310)NAMEG,I,LATD,LATM,SLAT,LATDIR,LOND,LONM,SLON,
     1                  LONDIR,VN,VE
  310          FORMAT(A10,I4,11X,I2,1X,I2,1X,F8.5,1X,A1,2X,I3,1X,I2,1X,
     1                F8.5,1X,A1,1X,2F8.2)
               IF(PVOUT .EQ. 'Y') THEN
                   CALL PVPRNT(LATD,LATM,SLAT,LOND,LONM,SLON,VN,VE)
               ENDIF
           ENDIF
	   GO TO 300
  330      WRITE(LUOUT,340)
  340      FORMAT(' ***********************************************'/
     1     ' Velocities have been calculated for the specified line.'/
     2     ' If you wish to calculate additional velocities, please'/
     3     ' indicate how you will specify positional coordinates.'/)
C     ELSEIF(OPTION .EQ. '5') THEN
C          WRITE(LUOUT,400)
C 400      FORMAT(' Enter name of input file.  ')
C          READ(LUIN,410) NAMEBB
C 410      FORMAT(A30)
C          OPEN(I1,FILE=NAMEBB,STATUS='OLD')
C          WRITE(I2,415)
C 415      FORMAT('SITE      DIST LATITUDE  LONGITUDE  ',
C    1     'NORTHWARD VELOCITY',10x,'EASTWARD VELOCITY'/
C    2     36x,'OBS.    COMP.  O-C    S.Dev.',
C    3     ' OBS.   COMP.  O-C    S.Dev.'/)
C 420      READ(I1,430,END=450)SITE,OVE,OVN,SDVE,SDVN,XLAT,XLON
C 430      FORMAT(A8,2x,f5.1,2x,f5.1,2x,f5.1,2x,f5.1,8x,F8.5,2x,F9.5)
C          YLAT = XLAT*3600.D0/RHOSEC
C          YLON = XLON*3600.d0/RHOSEC
C          CALL GETREG(YLAT,YLON,JREGN)
C          CALL COMVEL(YLAT,YLON,JREGN,VN,VE,VU)
C          VN = VN + RVN
C          VE = VE + RVE
C          RESVE = OVE - VE
C          RESVN = OVN - VN
C          WRITE(I2,440)SITE,JDG,XLAT,XLON,OVN,VN,RESVN,SDVN,
C    1                                     OVE,VE,RESVE,SDVE
C 440      FORMAT(A8,2x,i3,2x,F8.5,2x,F9.5,8(2x,f5.1))
C          GO TO 420
C 450      CLOSE(I1,STATUS='KEEP')
C          WRITE(LUOUT,460)
C 460      FORMAT(' ****************************************' /
C    1     ' Velocities have been calculated for the specified '/
C    2     ' UCLA file.  If you wish to calculate additional'/
C    3     ' velocities, please indicate how you will supply the'/
C    4     ' horizontal coordinates.'/)
      ELSE
	   WRITE(LUOUT,600)
  600      FORMAT(' Improper entry--select again.  ')
      ENDIF
      GO TO 40
  610 CONTINUE
      CLOSE(I2, STATUS = 'KEEP')
      IF( PVOUT .EQ. 'Y') CLOSE(I3, STATUS = 'KEEP')
      RETURN
      END
**************************************************************************
      SUBROUTINE GTOVEL(YLAT,YLON,EHT,RVN,RVE,RVU,
     1               VN,VE,VU,VX,VY,VZ,JREGN,IOPT)

*** Compute velocity in appropriate reference frame for point with
*** latitude YLAT (radians), longitude YLON (radians, positive west)
*** and ellipsoid height EHT (meters) in this reference frame.

      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      IMPLICIT INTEGER*4 (I-N)

*** Get reference latitude RLAT and reference longitude RLON in NAD 83
      IF(IOPT .EQ. 0 .OR. IOPT .EQ. 1) THEN
          RLAT = YLAT
          RLON = YLON
      ELSE
          ELON = -YLON
          CALL TOXYZ(YLAT,ELON,EHT,X,Y,Z)
          DATE = 1996.0d0
          CALL XTONAD(X,Y,Z,RLAT,RLON,EHTNAD,DATE,IOPT)
      ENDIF

*** Get velocity in NAD 83 
      CALL GETREG(RLAT,RLON,JREGN)
      IF (JREGN .EQ. 0) RETURN
      CALL COMVEL(RLAT,RLON,JREGN,VN,VE,VU)

      VN = VN + RVN
      VE = VE + RVE
      VU = VU + RVU
      ELON = -YLON
      CALL TOVXYZ(YLAT,ELON,VN,VE,VU,VX,VY,VZ)

*** Convert velocity into another reference frame if needed
      IF(IOPT .NE. 0 .AND. IOPT .NE. 1) THEN
          CALL VTRANF(X,Y,Z,VX,VY,VZ, 1, IOPT)
          CALL TOVNEU(YLAT, ELON, VX, VY, VZ, VN, VE, VU)
      ENDIF
     
      RETURN
      END
****************************************************************************

      SUBROUTINE XTONAD (X,Y,Z,RLAT,WLON,EHTNAD,DATE,IOPT)

*** Converts X,Y,Z in specified datum to latitude and
*** longitude (in radians) and height (meters) in NAD 83 
*** datum with longitude positive west.

      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      IMPLICIT INTEGER*4 (I-N)
      LOGICAL FRMXYZ
      COMMON /CONST/ A,F,E2,EPS,AF,PI,TWOPI,RHOSEC

*** Convert to cartesian coordinates in NAD 83
      if (iopt .eq. 0 .or. iopt .eq. 1) then
         x2 = x
         y2 = y
         z2 = z
      else
         call toit94(x,y,z,x1,y1,z1,date,iopt)
         jopt = 1
         call frit94(x1,y1,z1,x2,y2,z2,date,jopt)
      endif

***Convert to geodetic coordinates
      IF(.NOT.FRMXYZ(X2,Y2,Z2,RLAT,ELON,EHTNAD))STOP 666

      WLON = -ELON
 100  IF(WLON .LT. 0.D0) THEN
          WLON = WLON + TWOPI
          GO TO 100
      ENDIF
      RETURN
      END
 
******************************************************

      subroutine TRFPOS

*** Transform position between reference frames

      implicit double precision (a-h,o-z)
      implicit integer*4 (i-n)
      parameter (numref = 14)
      parameter (nbbdim = 100000)
      character*80 card
      character*30 namef, namebb
      character*24 name24
      character*16 frame1, frame2
      character*1 jn, jw, LATDIR, LONDIR
      character*1 option, answer, vopt
      LOGICAL FRMXYZ
      LOGICAL TEST
      COMMON /CONST/ A, F, E2, EPS, AF, PI, TWOPI, RHOSEC
      COMMON /FILES/ LUIN, LUOUT, I1, I2, I3, I4, I5
      COMMON /ARRAYS/ HT(nbbdim), LOC(nbbdim)

      write(luout,80)
   80 format(
     1  ' Please enter the name for the file to contain'/
     2  ' the transformed positions.  ')
      read(luin,'(a30)') namef
      open(i2, file = namef, status = 'unknown')
      CALL HEADER

   95 write(luout,100)
  100 format (' *******************************************'/
     1  ' Enter the reference frame of the input positions')
      call MENU1(iopt1, frame1)
      if (iopt1 .lt. 1 .or. iopt1 .gt. numref) then
         write(luout,*) ' Improper selection -- try again.  '
         go to 95
      endif

  105 write(luout,110)
  110 format (/' Enter the reference frame for the output positions')
      call MENU1(iopt2, frame2)
      if (iopt2 .lt. 1 .or. iopt2 .gt. numref) then
         write(luout,*) ' Improper selection -- try again.  '
         go to 105
      endif

  115 write(luout,120)
  120 format (/
     1   ' Enter epoch date (month-day-year) of the input positions'/
     1   ' in free format. For example, the entry,   5,12,1979'/
     1   ' represents May 12, 1979.  ')
      CALL GETTIM(MONTH1, IDAY1, IYEAR1, DATE1, MIN1, TEST)
      IF(TEST) GO TO 115

  125 write(luout,130)
  130 format(/
     1  '  Enter epoch date for the output positions in same format.  ')
      CALL GETTIM(MONTH2, IDAY2, IYEAR2, DATE2, MIN2, TEST)
      IF(TEST) GO TO 125

      write(i2, 150) frame1, month1, iday1, iyear1,
     1               frame2, month2, iday2, iyear2
  150 format(' TRANSFORMING POSITIONS FROM ',A16,' (EPOCH = ',
     1  I2.2,'-',I2.2,'-',I4,')'/26X,
     1  'TO ', A16, ' (EPOCH = ',I2.2,'-',I2.2,'-',I4,')'//
     1  13X,'INPUT COORDINATES   OUTPUT COORDINATES',
     1     4x, 'INPUT VELOCITY' /)
 
  160 write(luout, 170)
  170 format (/' ***************************************'/
     1  ' Coordinates will be transformed at each specified point.'/
     1  ' Please indicate how you wish to supply positions.'/
     1  '    0... No more points.   Return to main menu.'/
     1  '    1... Individual points entered interactively.'/
     1  '    2... The *80* records in a specified blue-book file.  ')
      read(luin,'(a1)') option

      if (option .eq. '0') then
         go to 500

      elseif (option .eq. '1') then
	 vxsave = 0.d0
	 vysave = 0.d0
	 vzsave = 0.d0
	 vnsave = 0.d0
	 vesave = 0.d0
	 vusave = 0.d0
  180    call GETPNT(latd, latm, slat, LATDIR, lond, lonm, slon, 
     1        LONDIR, name24, x, y, z, ylat, ylon, eht)
         call TOIT94(x, y, z, x1, y1, z1, date1, iopt1)
         call FRIT94(x1, y1, z1, x2, y2, z2, date1, iopt2)

         if (min1 .ne. min2) then
            if(.not.FRMXYZ(x2,y2,z2,ylat1,elon1,eht1)) STOP 666
            ylon1 = -elon1
            if(ylon1 .lt. 0.d0) ylon1 = ylon1 + twopi
	    call GETVLY( ylat1, elon1, vx, vy, vz, vn, ve, vu, vopt, 210)
	    if (vopt .eq. '0') then
	       call PREDV( ylat1, ylon1, eht1, date1, iopt1,
     1                     jregn, vn, ve, vu)
               if (jregn .eq. 0) then
                  write(luout, 200)
  200             format(/' ****************************************'/
     1  ' These coordinates can not be transformed to a different'/
     1  ' date because the point is outside of the modeled region.'/)
                  go to 220
               else
		  call TOVXYZ( ylat1, elon1, vn, ve, vu, vx, vy, vz)
               endif
            endif
	    vxsave = vx
	    vysave = vy
	    vzsave = vz
	    vnsave = vn
	    vesave = ve
	    vusave = vu
	    call VTRANF( x, y, z, vx, vy, vz, iopt1, iopt2)
	    call TOVNEU( ylat1, elon1, vx, vy, vz, vn, ve, vu)
	    call NEWCOR( ylat1, ylon1, eht1, min1, min2, 
     1                 ylatt, ylont, ehtnew, dn, de, du, vn, ve, vu)
            call TOXYZ(ylatt,-ylont, ehtnew, xt, yt, zt)
         else
            xt = x2
            yt = y2
            zt = z2
            if(.not.(FRMXYZ(xt,yt,zt,ylatt,elont,ehtnew))) STOP 666
            ylont = -elont
            if(ylont .lt. 0.0d0) ylont = ylont + twopi
         endif
         
         call PRNTTP(x, y, z, xt, yt, zt, ylat, ylatt,
     1      ylon, ylont, eht, ehtnew, name24, 1,
     2      vxsave, vysave, vzsave, vnsave, vesave, vusave)

  220    write(luout,*) ' Transform more positions? (y/n)  '
         read(luin,'(a1)') answer
         if(answer .eq. 'Y' .or. answer .eq. 'y') go to 180

      elseif (option .eq. '2') then
	 vxsave = 0.d0
	 vysave = 0.d0
	 vzsave = 0.d0
	 vnsave = 0.d0
	 vesave = 0.d0
	 vusave = 0.d0
         write(luout, 300)
  300    format(/ 
     1   ' Enter name of the blue-book file:  ')
         read(luin, '(a30)') namebb
         open (i1, file = namebb, status = 'old')

*** Obtaining the ellipsoid heights from the blue book file
	 do 301 i = 1, 100000
	    ht(i) = 0.d0
  301    continue

  302    read (i1, '(a80)', end = 309) card

	 if (card(7:10) .eq. '*80*') then
	    read (card, 303) isn, eht
  303       format (bz, 10x, i4, t70, f6.2)
	    if (ht(isn) .eq. 0.d0) ht(isn) = eht

         elseif (card(7:10) .eq. '*86*') then
	    if (card(46:52) .ne. '       ') then
	       read (card, 304) isn, eht
  304          format (bz, 10x, i4, t46, f7.3)
	       ht(isn) = eht
            else
	       read (card, 305) isn, oht, ght
  305          format (bz, 10x, i4, t17, f7.3, t36, f7.3)
	       ht(isn) = oht + ght
            endif
         endif
	 go to 302
  309    rewind i1

*** Reread blue book file to get latitudes and longitudes
*** and to perform transformations

  310    read(i1, '(a80)', end = 390) card
         if (card(7:10) .eq. '*80*') then
            read(card,320) isn, name24, latd, latm, slat, jn,
     1        lond, lonm, slon, jw
  320       format(bz, 10x, i4, a24, 6x, i2, i2, f7.5, a1,
     1             i3, i2, f7.5, a1)
            ylat = (dble((latd*60 + latm)*60) + slat) / rhosec
            ylon = (dble((lond*60 + lonm)*60) + slon) / rhosec
	    if (jn .eq. 'S') ylat = -ylat
	    if (jw .eq. 'E') ylon = -ylon
	    eht = ht(isn)
            call TOXYZ(ylat, -ylon, eht, x, y, z)
            call TOIT94(x, y, z, x1, y1, z1, date1, iopt1)
            call FRIT94(x1, y1, z1, x2, y2, z2, date1, iopt2)
            if (min1 .ne. min2) then
               if(.not.FRMXYZ(x2, y2, z2, ylat1, elon1, eht1)) STOP 666
               ylon1 = -elon1
               if (ylon1 .lt. 0.0d0) ylon1 = ylon1 + twopi
	       call PREDV( ylat1, ylon1, eht1, date1, iopt1,
     1            jregn, vn, ve, vu)
               if (jregn .eq. 0) then
                  write(i2, 330) name24
  330             format (/ 1x,a24,
     1               ' is outside of the modeled region.'/)
                  go to 310
               else
		  call TOVXYZ( ylat1, elon1, vn, ve, vu, vx, vy, vz)
		  vxsave = vx
		  vysave = vy
		  vzsave = vz
		  vnsave = vn
		  vesave = ve
		  vusave = vu
		  call VTRANF( x, y, z, vx, vy, vz, iopt1, iopt2)
		  call TOVNEU( ylat1, elon1, vx, vy, vz, vn, ve, vu)
		  call NEWCOR( ylat1, ylon1, eht1, min1, min2,
     1               ylatt, ylont, ehtnew, dn, de, dui, vn, ve, vu)
                  call TOXYZ(ylatt, -ylont, ehtnew, xt, yt, zt)
               endif
            else
               xt = x2
               yt = y2
               zt = z2
               if(.not.FRMXYZ(xt,yt,zt,ylatt, elont, ehtnew)) STOP 666
               ylont = -elont
               if (ylont .lt. 0.0d0) ylont = ylont + twopi
            endif
            call PRNTTP(x,y,z, xt,yt, zt, ylat, ylatt,
     1         ylon, ylont, eht, ehtnew, name24, 0,
     1         vxsave, vysave, vzsave, vnsave, vesave, vusave)
         endif
         go to 310
  390    close (i1, status = 'keep')

      else
         write(luout,*) ' Improper selection -- try again.  '
         go to 160
      endif

  500 continue
      close(i2, status = 'keep')
      return
      end

*****************************************************


      subroutine PRNTTP(x, y, z, x1, y1, z1, ylat,            
     1  ylatt, ylon, ylont, eht, ehtnew, name24, iprint,
     2  vx, vy, vz, vn, ve, vu )

** Print updated and/or transformed parameters               

      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      IMPLICIT INTEGER*4 (I-N)
      COMMON /FILES/ LUIN, LUOUT, I1, I2, I3, I4, I5
      CHARACTER*24 NAME24
      CHARACTER*1 LATDIR, LONDIR, LATDR, LONDR

            CALL TODMSS(YLATT,LATDN,LATMN,SLATN,ISIGN)
            LATDIR = 'N'     
            if (isign .eq. -1) LATDIR = 'S'
            CALL TODMSS(YLONT,LONDN,LONMN,SLONN,ISIGN)
            LONDIR = 'W'
            if (isign .eq. -1) LONDIR = 'E'

      if (iprint .eq. 1) then
            WRITE(LUOUT,1065)LATDN,LATMN,SLATN,LATDIR,LONDN,LONMN,
     1                    SLONN,LONDIR, EHTNEW, X1,Y1,Z1
 1065       FORMAT(' ****************************************'/
     1         ' New latitude   = ',I3,1X,I2,1X,F8.5,1X,A1  /
     2         ' New longitude  = ',I3,1x,I2,1X,F8.5,1X,A1  /
     2         ' New Ellip. Ht. = ', F12.3 ,' meters' /
     3         ' New X          = ',F12.3  ,' meters' /
     4         ' New Y          = ',F12.3  ,' meters' /
     5         ' New Z          = ',F12.3  ,' meters' /
     3         ' ****************************************'/)
      endif

            call TODMSS(ylat,latd,latm,slat,isign)
            latdr = 'N'
            if(isign .eq. -1) latdr = 'S'
            call TODMSS(ylon, lond,lonm,slon,isign)
            londr = 'W'
            if(isign .eq. -1) londr = 'E'
            WRITE(I2,1070)NAME24,
     1          LATD,LATM,SLAT,latdr,LATDN,LATMN,SLATN,latdir,vn,
     1          LOND,LONM,SLON,londr,LONDN,LONMN,SLONN,londir,ve,
     1          EHT, EHTNEW, vu, X, X1, vx,
     1          Y, Y1, vy,  Z, Z1, vz
 1070       FORMAT(1X,A24,/
     1   2X, 'LATITUDE  ',2(2X,I3,1X,I2.2,1X,F8.5,1X,A1,2X),
     1         f8.2, ' mm/yr  north' /
     1   2X, 'LONGITUDE ',2(2X,I3,1X,I2.2,1X,F8.5,1X,A1,2X),
     1         f8.2, ' mm/yr  east' /
     1   2X, 'ELLIP. HT.',2(6X,F13.3),' m  ',
     1         f8.2, ' mm/yr  up' /
     1   2X, 'X         ',2(6X,F13.3),' m  ', f8.2, ' mm/yr' /
     1   2X, 'Y         ',2(6X,F13.3),' m  ', f8.2, ' mm/yr' /
     1   2X, 'Z         ',2(6X,F13.3),' m  ', f8.2, ' mm/yr'/ )
         RETURN
         END

**********************************************************
      subroutine settp

*** Specify transformation parameters from ITRF94
*** to other reference frames

      implicit double precision (a-h, o-z)
      implicit integer*4 (i-n)
      parameter (numref = 14)

      common /const/ a, f, e2, eps, af, pi, twopi, rhosec
      common /tranpa/ tx(numref), ty(numref), tz(numref), 
     &                dtx(numref), dty(numref), dtz(numref),
     &                rx(numref), ry(numref), rz(numref), 
     &                drx(numref), dry(numref), drz(numref),
     &                scale(numref), dscale(numref), refepc(numref)

c     frame(1) = 'NAD_83'
c     frame(2) = 'ITRF88'
c     frame(3) = 'ITRF89'
c     frame(4) = 'ITRF90'
c     frame(5) = 'ITFR91'
c     frame(6) = 'ITRF92'
c     frame(7) = 'ITRF93'
c     frame(8) = 'ITRF96'
c     frame(9) = 'ITRF97'
c     frame(10) = 'WGS_72'
c     frame(11) = 'ITRF00'
c     frame(12) = 'PACP00'
c     frame(13) = 'MARP00'
c     frame(14) = 'ITRF05'

*** From ITRF94 to NAD 83
      tx(1) = 0.9910d0
      ty(1) = -1.9072d0
      tz(1) = -.5129d0
      dtx(1) = 0.d0
      dty(1) = 0.d0
      dtz(1) = 0.d0
      rx(1) = 1.25033d-7
      ry(1) = 0.46785d-7
      rz(1) = 0.56529d-7
      drx(1) = 0.00258d-7
      dry(1) = -.03599d-7
      drz(1) = -.00153d-7
      scale(1) = 0.d0
      dscale(1) = 0.0d0
      refepc(1) = 1997.0d0

*** From ITRF94 to ITRF88
      tx(2) = 0.018d0
      ty(2) = 0.000d0
      tz(2) = -.092d0
      dtx(2) = 0.0d0    
      dty(2) = 0.0d0
      dtz(2) = 0.0d0
      rx(2) = -.0001d0 / rhosec
      ry(2) = 0.0d0                 
      rz(2) = 0.0d0 
      drx(2) = 0.0d0                  
      dry(2) = 0.0d0              
      drz(2) = 0.0d0                   
      scale(2) = 0.74d-8
      dscale(2) = 0.0d0
      refepc(2) = 1988.0d0

*** From ITRF94 to ITRF89
      tx(3) = 0.023d0
      ty(3) = 0.036d0
      tz(3) = -.068d0
      dtx(3) = 0.0d0    
      dty(3) = 0.0d0
      dtz(3) = 0.0d0
      rx(3) = 0.0d0
      ry(3) = 0.0d0                 
      rz(3) = 0.0d0 
      drx(3) = 0.0d0                  
      dry(3) = 0.0d0              
      drz(3) = 0.0d0                   
      scale(3) = 0.43d-8
      dscale(3) = 0.0d0
      refepc(3) = 1988.0d0

*** From ITRF94 to ITRF90
      tx(4) = 0.018d0
      ty(4) = 0.012d0
      tz(4) = -.030d0
      dtx(4) = 0.0d0    
      dty(4) = 0.0d0
      dtz(4) = 0.0d0
      rx(4) = 0.0d0
      ry(4) = 0.0d0                 
      rz(4) = 0.0d0 
      drx(4) = 0.0d0                  
      dry(4) = 0.0d0              
      drz(4) = 0.0d0                   
      scale(4) = 0.09d-8
      dscale(4) = 0.0d0
      refepc(4) = 1988.0d0

*** From ITRF94 to ITRF91
      tx(5) = 0.020d0
      ty(5) = 0.016d0
      tz(5) = -.014d0
      dtx(5) = 0.0d0    
      dty(5) = 0.0d0
      dtz(5) = 0.0d0
      rx(5) = 0.0d0
      ry(5) = 0.0d0                 
      rz(5) = 0.0d0 
      drx(5) = 0.0d0                  
      dry(5) = 0.0d0              
      drz(5) = 0.0d0                   
      scale(5) = 0.06d-8
      dscale(5) = 0.0d0
      refepc(5) = 1988.0d0

*** From ITRF94 to ITRF92
      tx(6) = 0.008d0
      ty(6) = 0.002d0
      tz(6) = -.008d0
      dtx(6) = 0.0d0    
      dty(6) = 0.0d0
      dtz(6) = 0.0d0
      rx(6) = 0.0d0
      ry(6) = 0.0d0                 
      rz(6) = 0.0d0 
      drx(6) = 0.0d0                  
      dry(6) = 0.0d0              
      drz(6) = 0.0d0                   
      scale(6) = -.08d-8
      dscale(6) = 0.0d0
      refepc(6) = 1988.0d0

*** From ITRF94 to ITRF93
      tx(7) = 0.006d0
      ty(7) = -.005d0
      tz(7) = -.015d0
      dtx(7) = -.0029d0
      dty(7) = 0.0004d0
      dtz(7) = 0.0008d0
      rx(7) = 0.00039d0 / rhosec
      ry(7) = -.00080d0 / rhosec
      rz(7) = 0.00096d0 / rhosec
      drx(7) = .00011d0 / rhosec
      dry(7) = .00019d0 / rhosec
      drz(7) =-.00005d0 / rhosec
      scale(7) = 0.04d-8
      dscale(7) = 0.0d0
      refepc(7) = 1988.0d0

*** From ITRF94 to ITRF96
      tx(8) = 0.d0
      ty(8) = 0.d0
      tz(8) = 0.d0
      dtx(8) = 0.d0
      dty(8) = 0.d0
      dtz(8) = 0.d0
      rx(8) = 0.d0
      ry(8) = 0.d0
      rz(8) = 0.d0
      drx(8) = 0.d0
      dry(8) = 0.d0
      drz(8) = 0.d0
      scale(8) = 0.d0
      dscale(8) = 0.0d0
      refepc(8) = 1996.0d0

*** From ITRF94 to ITRF97 (based on IGS adopted values)
*** According to IERS:  ITRF97 = ITRF96 = ITRF94
      tx(9) = 0.00207d0
      ty(9) = 0.00021d0
      tz(9) = -0.00995d0
      dtx(9) = -0.00069d0
      dty(9) = 0.00010d0
      dtz(9) = -0.00186d0
      rx(9) = -0.00012467d0 / rhosec
      ry(9) = 0.00022355d0 / rhosec
      rz(9) = 0.00006065d0 / rhosec
      drx(9) = -0.00001347d0 / rhosec
      dry(9) = 0.00001514d0 / rhosec
      drz(9) = -0.00000027d0 / rhosec
      scale(9) = 0.93496d-9
      dscale(9) = 0.19201d-9
      refepc(9) = 1997.0d0

*** From ITRF94 to WGS 72 (composition of ITRF94 -> NAD_83 -> WGS_72)
      tx(10) = 0.9910d0
      ty(10) = -1.9072d0
      tz(10) = -.5129d0 - 4.5d0
      dtx(10) = 0.d0
      dty(10) = 0.d0
      dtz(10) = 0.d0
      rx(10) = 1.25033d-7
      ry(10) = 0.46785d-7
      rz(10) = 0.56529d-7 + 26.85868d-7
      drx(10) = 0.00258d-7
      dry(10) = -.03599d-7
      drz(10) = -.00153d-7
      scale(10) = 0.d0 - 0.2263d-6
      dscale(10) = 0.0d0
      refepc(10) = 1997.0d0

*** From ITRF94 to ITRF00
*** assumes that ITRF94 = ITRF96 and
*** uses IGS values for ITRF96 -> ITRF97
*** and IERS values for ITRF97 -> ITRF00
      tx(11) = -.00463d0
      ty(11) = -.00589d0
      tz(11) = +.00855d0
      dtx(11) = -0.00069d0
      dty(11) = 0.00070d0
      dtz(11) = -0.00046d0
      rx(11) = -.00012467d0 / rhosec
      ry(11) = 0.00022355d0 / rhosec
      rz(11) = 0.00006065d0 / rhosec
      drx(11) = -0.00001347d0 / rhosec
      dry(11) = 0.00001514d0 / rhosec
      drz(11) = 0.00001973d0 / rhosec
      scale(11) = -0.61504d-9
      dscale(11) = 0.18201d-9
      refepc(11) = 1997.0d0

*** From ITRF94 to PACP00
*** use PA/ITRF00 rotation rates from Beavan et al., (2002)
      tx(12) = 0.9056d0
      ty(12) = -2.0200d0
      tz(12) = -0.5516d0
      dtx(12) = -.00069d0
      dty(12) = 0.00070d0
      dtz(12) = -0.00046d0
      rx(12) = 0.027616d0 / rhosec
      ry(12) = 0.013692d0 / rhosec
      rz(12) = 0.002773d0 / rhosec
      drx(12) = -.000397d0 / rhosec
      dry(12) = 0.001022d0 / rhosec
      drz(12) = -.002166d0 / rhosec
      scale(12) = -0.61504d-9
      dscale(12) = 0.18201d-9
      refepc(12) = 1997.0d0

*** From ITRF94 to MARP00
*** Use velocity of GUAM
      tx(13) = 0.9056d0
      ty(13) = -2.0200d0
      tz(13) = -0.5516d0
      dtx(13) = -0.00069d0
      dty(13) = 0.00070d0
      dtz(13) = -0.00046d0
      rx(13) = .028847d0 / rhosec
      ry(13) = .010644d0 / rhosec
      rz(13) = 0.008989d0 / rhosec
      drx(13) = -0.000033d0 / rhosec
      dry(13) =  0.000120d0 / rhosec
      drz(13) = -0.000327d0 / rhosec
      scale(13) = -0.61504d-9
      dscale(13) = 0.18201d-9
      refepc(13) = 1997.00d0

*** From ITRF94 to ITRF2005
*** assumes that ITRF94 = ITRF96
*** uses IGS values for ITRF96 -> ITRF97
*** uses IERS values for ITRF97 -> ITRF2000
*** uses IERS values for ITRF2000 -> ITRF2005
      tx(14) = -0.00533d0
      ty(14) = -0.00479d0
      tz(14) =  0.00895d0
      dtx(14) = -0.00049d0
      dty(14) =  0.00060d0
      dtz(14) =  0.00134d0
      rx(14) = -.00012467d0 / rhosec
      ry(14) = 0.00022355d0 / rhosec
      rz(14) = 0.00006065d0 / rhosec
      drx(14) = -0.00001347d0 / rhosec
      dry(14) = 0.00001514d0 / rhosec
      drz(14) = 0.00001973d0 / rhosec
      scale(14) = -0.77504d-9
      dscale(14) = 0.10201d-9
      refepc(14) = 1997.0d0

      return
      end
*************************************************************

      subroutine frit94(x1, y1, z1, x2, y2, z2, date, jopt)

*** Converts ITRF94 cartesian coordinates to cartesian
*** coordinates in the specified reference frame for the
*** given date

*** (x1, y1, z1) --> input ITRF94 coordiates (meters)
*** (x2, y2, z2) --> output coordinates (meters)
*** date --> time (decimal years) to which the input & output
***          coordinates correspond
*** jopt --> input specifier of output reference frame

      implicit double precision (a-h, o-z)
      implicit integer*4 (i-n)
      parameter (numref = 14)

      common /tranpa/ tx(numref), ty(numref), tz(numref), 
     &                dtx(numref), dty(numref), dtz(numref),
     &                rx(numref), ry(numref), rz(numref), 
     &                drx(numref), dry(numref), drz(numref),
     &                scale(numref), dscale(numref), refepc(numref)

      if (jopt .eq. 0) then
         iopt = 1
      else
         iopt = jopt
      endif

      dtime = date - refepc(iopt)
      tranx = tx(iopt) + dtx(iopt)*dtime
      trany = ty(iopt) + dty(iopt)*dtime
      tranz = tz(iopt) + dtz(iopt)*dtime
      rotnx  = rx(iopt) + drx(iopt)*dtime
      rotny  = ry(iopt) + dry(iopt)*dtime
      rotnz  = rz(iopt) + drz(iopt)*dtime
      ds     = 1.d0 + scale(iopt) + dscale(iopt)*dtime

      x2 = tranx + ds*x1 + rotnz*y1 - rotny*z1
      y2 = trany - rotnz*x1 + ds*y1 + rotnx*z1
      z2 = tranz + rotny*x1 - rotnx*y1 + ds*z1

      return
      end

***********************************************************

      subroutine toit94(x1, y1, z1, x2, y2, z2, date, jopt)

*** Converts cartesian coordinates in a specified reference
*** to ITRF94 cartesian coordinates for the given date

*** (x1, y1, z1) --> input coordiates (meters)
*** (x2, y2, z2) --> output  ITRF94 coordinates (meters)
*** date --> time (decimal years) to which the input & output
***          coordinates correspond
*** jopt --> input specifier of input reference frame

      implicit double precision (a-h, o-z)
      implicit integer*4 (i-n)
      parameter (numref = 14)

      common /tranpa/ tx(numref), ty(numref), tz(numref), 
     &                dtx(numref), dty(numref), dtz(numref),
     &                rx(numref), ry(numref), rz(numref), 
     &                drx(numref), dry(numref), drz(numref),
     &                scale(numref), dscale(numref), refepc(numref)

      if (jopt .eq. 0) then
         iopt = 1
      else
         iopt = jopt
      endif

      dtime = date - refepc(iopt)
      tranx = -(tx(iopt) + dtx(iopt)*dtime)
      trany = -(ty(iopt) + dty(iopt)*dtime)
      tranz = -(tz(iopt) + dtz(iopt)*dtime)
      rotnx  = -(rx(iopt) + drx(iopt)*dtime)
      rotny  = -(ry(iopt) + dry(iopt)*dtime)
      rotnz  = -(rz(iopt) + drz(iopt)*dtime)
      ds     = 1.d0 - (scale(iopt) + dscale(iopt)*dtime)

      x2 = tranx + ds*x1 + rotnz*y1 - rotny*z1
      y2 = trany - rotnz*x1 + ds*y1 + rotnx*z1
      z2 = tranz + rotny*x1 - rotnx*y1 + ds*z1

      return
      end

*****************************************************************

      subroutine MENU1(kopt, mframe)

** Write out options for reference frames

      implicit integer*4 (i-n)
      character*16 mframe, nframe
      dimension nframe(26)
      dimension iframe(26)
      common /files/ luin, luout, i1, i2, i3, i4, i5

      iframe(1) = 1
      nframe(1) = 'NAD_83(CORS96)  '       
      iframe(2) = 12
      nframe(2) = 'NAD_83(PACP00)  '
      iframe(3) = 13
      nframe(3) = 'NAD_83(MARP00)  '
      iframe(4) = 10
      nframe(4) = 'WGS_72          '
      iframe(5) = 1
      nframe(5) = 'WGS_84(transit) '
      iframe(6) = 6
      nframe(6) = 'WGS_84(G730)    '
      iframe(7) = 8
      nframe(7) = 'WGS_84(G873)    '
      iframe(8) = 11
      nframe(8) = 'WGS_84(G1150)   '
      iframe(9) = 4
      nframe(9) = 'PNEOS_90        '
      iframe(10)= 4
      nframe(10)= 'NEOS_90         '
      iframe(11)= 5
      nframe(11)= 'SIO/MIT_92      '
      iframe(12)= 2
      nframe(12)= 'ITRF88          '
      iframe(13)= 3
      nframe(13)= 'ITRF89          '
      iframe(14)= 4
      nframe(14)= 'ITRF90          '
      iframe(15)= 5
      nframe(15)= 'ITRF91          '
      iframe(16)= 6
      nframe(16)= 'ITRF92          '
      iframe(17)= 7
      nframe(17)= 'ITRF93          '
      iframe(18)= 8
      nframe(18)= 'ITRF94          '
      iframe(19)= 8
      nframe(19)= 'ITRF96          '
      iframe(20)= 9
      nframe(20)= 'ITRF97          '
      iframe(21)= 9 
      nframe(21)= 'IGS97           '
      iframe(22)= 11
      nframe(22)= 'ITRF2000        '
      iframe(23)= 11
      nframe(23)= 'IGS00           '
      iframe(24)= 11
      nframe(24)= 'IGb00           '
      iframe(25)= 14
      nframe(25)= 'ITRF2005        '
      iframe(26)= 14     
      nframe(26)= 'IGS05           '

      write(luout, 100)
  100 format(
     1'  1...NAD_83(CORS96) or NAD_83(NSRS2007) '/
     1'                     North American tectonic plate fixed '/
     1'  2...NAD_83(PACP00) Pacific tectonic plate fixed '/
     1'  3...NAD_83(MARP00) Mariana tectonic plate fixed '/
     1'                                                   '/
     1'  4...WGS_72                             16...ITRF92 '/
     1'  5...WGS_84(transit) = NAD_83(CORS96)   17...ITRF93 '/
     1'  6...WGS_84(G730) = ITRF92              18...ITRF94 = ITRF96 '/
     1'  7...WGS_84(G873) = ITRF96              19...ITRF96 '/
     1'  8...WGS_84(G1150) = ITRF2000           20...ITRF97 '/
     1'  9...PNEOS_90 = ITRF90                  21...IGS97 = ITRF97 '/
     1' 10...NEOS_90 = ITRF90                   22...ITRF2000 '/
     1' 11...SIO/MIT_92 = ITRF91                23...IGS00 = ITRF2000 '/
     1' 12...ITRF88                             24...IGb00 = ITRF2000 '/
     1' 13...ITRF89                             25...ITRF2005 '/
     1' 14...ITRF90                             26...IGS05 = ITRF2005 '/
     1' 15...ITRF91 ' )

      read (luin, *) iopt
      if ( 1 .le. iopt .and. iopt .le. 26) then
	 mframe = nframe(iopt)
	 kopt = iframe(iopt)
      else
	 mframe = '                '
	 kopt = iopt
      endif
      return
      end

***************************************************************
      SUBROUTINE UPDATE

** Update positions and/or observations to a specified date.

      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      IMPLICIT INTEGER*4 (I-N)
      parameter (numref = 14)
      parameter (nbbdim = 100000)
      COMMON /CONST/ A,F,E2,EPS,AF,PI,TWOPI,RHOSEC
      COMMON /FILES/ LUIN, LUOUT, I1, I2, I3, I4, I5
      CHARACTER*30 OLDBB,NEWBB
      CHARACTER*24 NAME24
      CHARACTER*1  OPT, ANSWER, BBTYPE, VOPT
      CHARACTER*1 LATDIR, LONDIR, LATDR, LONDR
      character*16 frame1, frame2
      LOGICAL TEST

   10 WRITE(LUOUT,20)
   20 FORMAT(' ******************************************'/
     1   ' Please enter the time (month-day-year) in free'/
     1   ' format to which the updated positions and/or'/
     1   ' observations are to correspond.'/
     2' For example, the entry, 5,12,1979, represents May 12, 1979.  ')
      CALL GETTIM(MONTH2,IDAY2,IYEAR2,DATE2,MIN2,TEST)
      IF(TEST) GO TO 10

** Choosing reference frame for positions
   35 WRITE(LUOUT,30)
   30 FORMAT(' **************************************************'/
     1   ' Select the reference frame to be used for specifying'/
     2   ' positions. '/)
      call MENU1( iopt, frame1)
      IF(IOPT .LT. 1 .OR. IOPT .GT. numref) THEN
           WRITE(LUOUT,40)
   40      FORMAT(' Improper selection--try again.  ')
           GO TO 35
      ENDIF

  999 WRITE(LUOUT,1000)
 1000 FORMAT(' ******************************'/
     1   ' Select option:'/
     2   '     0...No more updates. Return to main menu.'/
     3   '     1...Update positions for individual points', 
     4             ' entered interactively.'/
     5   '     2...Update positions for blue book stations.'/
     6   '     3...Update values for blue book observations.'/
     7   '     4...Update both the positions for blue book',
     8              ' stations'/
     9   '          and the values for blue book',
     9              ' observations.'/)
      READ(LUIN,'(A1)') OPT

      IF(OPT .eq. '0') THEN
         RETURN
      ELSEIF(OPT .eq. '1') THEN
 1010    WRITE(LUOUT,1020)
 1020    FORMAT(' ************************************'/
     1       ' Enter the time (month-day-year) in free format'/
     2       ' to which the input positions will correspond.  ')
         CALL GETTIM(MONTH1,IDAY1,IYEAR1,DATE1,MIN1,TEST)
         IF(TEST) GO TO 1010
         WRITE(LUOUT,1030)
 1030    FORMAT(' ENTER file to save updated positions.  ')
         READ(LUIN,'(A30)') NEWBB
         OPEN(I2,FILE=NEWBB,STATUS='UNKNOWN')
	 CALL HEADER

         WRITE(I2,1031) frame1     
 1031    FORMAT(' UPDATED POSITIONS IN ', a16)

         WRITE(I2,1040) MONTH1,IDAY1,IYEAR1,MONTH2,IDAY2,IYEAR2
 1040    FORMAT(' FROM ',I2,'-',I2.2,'-',I4,
     1     ' TO ',I2,'-',I2.2,'-',I4,' (month-day-year)'//
     2     16X,'OLD COORDINATE    NEW COORDINATE',
     3     4X,'VELOCITY      DISPLACEMENT',/)
 1050    CALL GETPNT(LATD,LATM,SLAT,LATDIR,LOND,LONM,SLON,
     1       LONDIR, NAME24,  X,Y,Z,YLAT,YLON,EHT)
	 ELON = -YLON
	 call GETVLY(YLAT, ELON, VX, VY, VZ, VN, VE, VU, VOPT, 210)
	 IF ( VOPT .EQ. '0') then
      	    call PREDV( ylat, ylon, eht, date1, iopt,
     1         jregn, vn, ve, vu)
            IF(JREGN .eq. 0) THEN
               WRITE(LUOUT,1060)
 1060          FORMAT(' **************************************'/
     1        ' Can not update the position of this point'/
     2        ' because it is outside of the modeled region.'/)
	      GO TO 1075
            ELSE
	      call TOVXYZ( ylat, elon, vn, ve, vu, vx, vy, vz)
	    ENDIF
         ENDIF
         call NEWCOR( ylat, ylon, eht, min1, min2, 
     1         ylatt, ylont, ehtnew, dn, de, du, vn, ve, vu)
         CALL TODMSS(YLATT,LATDN,LATMN,SLATN,ISIGN)
	 LATDR = 'N'
	 IF (ISIGN .eq. -1) LATDR = 'S'
         CALL TODMSS(YLONT,LONDN,LONMN,SLONN,ISIGN)
	 LONDR = 'W'
	 IF (ISIGN .eq. -1) LONDR = 'E'
         ELONT = -YLONT
         CALL TOXYZ(YLATT,ELONT,EHTNEW,X1,Y1,Z1)
         DX = X1 - X
         DY = Y1 - Y
         DZ = Z1 - Z
         WRITE(LUOUT,1065)LATDN,LATMN,SLATN,LATDR,LONDN,LONMN,SLONN,
     1              LONDR, EHTNEW, X1,Y1,Z1
 1065    FORMAT(' ****************************************'/
     1         ' Updated latitude   = ',I3,I3,1X,F8.5,1X,A1 /
     2         ' Updated longitude  = ',I3,I3,1X,F8.5,1X,A1 /
     2         ' Updated Ellip. Ht. = ', F12.3 ,' meters' /
     3         ' Updated X          = ',F12.3  ,' meters' /
     4         ' Updated Y          = ',F12.3  ,' meters' /
     5         ' Updated Z          = ',F12.3  ,' meters' /
     3         ' ****************************************'/)
         WRITE(I2,1070)NAME24,
     1      LATD,LATM,SLAT,LATDIR,LATDN,LATMN,SLATN,LATDR,vn,DN,
     1      LOND,LONM,SLON,LONDIR,LONDN,LONMN,SLONN,LONDR,ve,DE,
     1             EHT,  EHTNEW, vu,DU, X, X1, vx,DX,
     1             Y, Y1, vy,DY, Z, Z1, vz,DZ
 1070    FORMAT(1X,A24,/
     1   1X, 'LATITUDE  ',2(2X,I3,I3.2,1X,F8.5,1X,A1),
     1             F8.2, ' mm/yr', f8.3, ' m north'/
     1   1X, 'LONGITUDE ',2(2X,I3,I3.2,1X,F8.5,1x,A1),
     1             f8.2, ' mm/yr',f8.3,' m east'/
     1   1X, 'ELLIP. HT.',2(6X,F13.3),
     1             f8.2, ' mm/yr',F8.3,' m up'/
     1   1X, 'X         ',2(6X,F13.3),
     1             f8.2, ' mm/yr',F8.3,' m '/
     1   1X, 'Y         ',2(6X,F13.3),
     1             f8.2, ' mm/yr',f8.3, ' m'/
     1   1X, 'Z         ',2(6X,F13.3),
     1             f8.2, ' mm/yr',F8.3,' m'/)
 1075    WRITE(LUOUT,1080)
 1080    FORMAT(' Update more positions? (y/n)  ')
         READ(LUIN,'(A1)') ANSWER
         IF(ANSWER .eq. 'Y' .or. ANSWER .eq. 'y') GO TO 1050
         CLOSE(I2,STATUS='KEEP')
         RETURN

*** Updating a blue book 

      ELSEIF(OPT .eq. '2' .or. OPT .eq. '3' .or. OPT .eq. '4') THEN

          if (nbbdim .eq. 100000) then
   90        WRITE(LUOUT,91)
   91        FORMAT(
     1       ' Identify type of blue bbook:'/
     2       '    1...Standard (4-digit SSN)'/
     3       '    2...Non-standard (5-digit SSN)  ')
             READ(LUIN,'(A1)') BBTYPE
             IF(BBTYPE .NE. '1' .AND. BBTYPE .NE. '2') GO TO 90
          else
             BBTYPE = '1'
          endif

          WRITE(LUOUT,100)
  100     FORMAT(' Enter name of the blue book file to be updated.'/)
          READ(LUIN,110) OLDBB
  110     FORMAT(A30)
          WRITE(LUOUT,120)
  120     FORMAT(' Enter name for the new blue book file that is to '/
     1       'contain the updated information.'/)
          READ(LUIN,110) NEWBB
          OPEN(I1,FILE = OLDBB , STATUS = 'OLD')

C         OPEN(I4, FILE = 'TEMPGP', ACCESS = 'DIRECT', RECL = 20,
C    1         FORM = 'UNFORMATTED')
          OPEN(I4, ACCESS = 'DIRECT', RECL = 40,
     1         FORM = 'UNFORMATTED', STATUS = 'SCRATCH')

          IF(OPT .eq. '2' .or. OPT .eq. '4') THEN
  121        WRITE(LUOUT,122)
  122        FORMAT(' *********************************************'/
     1           ' Enter the time (month-day-year) in free format '/
     1           ' to which the input positions correspond.'/)
             CALL GETTIM(MONTH1,IDAY1,IYEAR1,DATE1,MIN1,TEST)
             IF(TEST) GO TO 121
          ENDIF

*** Retrieve geodetic positions from old blue-book file

         IF(BBTYPE .EQ. '1') THEN
              CALL GETPO4(IOPT, DATE1)
         ELSEIF(BBTYPE .EQ. '2') THEN
              CALL GETPO5(IOPT, DATE1)
         ENDIF

*** Create new blue book file

         OPEN(I2,FILE = NEWBB, STATUS = 'UNKNOWN')
         IF (OPT .EQ. '3' .OR. OPT .EQ. '4') THEN
            WRITE(I2, 130) MONTH2, IDAY2, IYEAR2
  130       FORMAT(' *** CAUTION: Observations in this file have ',
     *      'been updated to ',I2,'-',I2.2,'-',I4, ' ***')
         ENDIF

         IF(BBTYPE .EQ. '1') THEN
             CALL UPBB4(MIN1,MIN2,OPT,IOPT)
         ELSEIF(BBTYPE .EQ. '2') THEN
             CALL UPBB5(MIN1,MIN2,OPT,IOPT)
         ENDIF
         CLOSE(I1, STATUS = 'KEEP')
         CLOSE(I2, STATUS = 'KEEP')

*** Update G-FILE

         IF(OPT .eq. '3' .or. OPT .eq. '4') THEN
  605      WRITE(LUOUT,610)
  610      FORMAT(/' Is there a G-FILE to be updated? (y/n)  ')
           READ(LUIN,'(A1)') ANSWER
           IF(ANSWER .eq. 'N' .or. ANSWER .eq. 'n') THEN
             CONTINUE
           ELSEIF(ANSWER .eq. 'Y' .or. ANSWER .eq. 'y')THEN
             WRITE(LUOUT,620)
  620        FORMAT(' Enter name of old G-FILE to be updated.  ')
             READ(LUIN,'(A30)') OLDBB
             WRITE(LUOUT,630)
  630        FORMAT(' Enter name for the new updated G-FILE.  ')
             READ(LUIN,'(A30)') NEWBB
             OPEN(I1,FILE=OLDBB,STATUS='OLD')
             OPEN(I2,FILE=NEWBB,STATUS='UNKNOWN')
             WRITE(I2,130) MONTH2, IDAY2, IYEAR2
        
  634        WRITE(LUOUT, 632)
  632        FORMAT(/' ***************************'/
     *              ' To what reference frame should the GPS'/
     *              ' vectors be transformed?'/
     *              '    -1...Do not transform GPS vectors.')
             CALL MENU1(kopt, frame2)
             IF(KOPT .LT. -1 .OR. KOPT .GT. numref) THEN
                WRITE(LUOUT, 40)
                GO TO 634
             ELSEIF (1 .LE. KOPT .AND. KOPT .LE. numref) then
		write( I2, 640) frame2
  640           format( ' *** CAUTION: All GPS interstation vectors',
     1                  ' have been transformed to ', a16, ' ***')
             ENDIF

             IF(BBTYPE .EQ. '1') THEN
                 CALL UPGFI4(DATE2, MIN2, IOPT, KOPT, 
     *                       MONTH2, IDAY2, IYEAR2)
             ELSEIF(BBTYPE .EQ. '2') THEN
                 CALL UPGFI5(DATE2, MIN2, IOPT, KOPT,
     *                       MONTH2, IDAY2, IYEAR2)
             ENDIF
             CLOSE(I1, STATUS = 'KEEP')
             CLOSE(I2, STATUS = 'KEEP')
           ELSE
             WRITE(LUOUT,700)
             GO TO 605
           ENDIF
         ENDIF
         CLOSE(I4, STATUS = 'DELETE')
         RETURN
      ELSE
         WRITE(LUOUT,700)
  700    FORMAT(' Improper entry !'/)
         GO TO 999
      ENDIF
      END
*******************************************************************
      SUBROUTINE GETPO4(IOPT, DATE)

*** Retrieve geodetic coordinates from the blue book

      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      IMPLICIT INTEGER*4 (I-N)
      parameter (nbbdim = 100000)
      CHARACTER*1 JN,JW
      CHARACTER*4 TYPE
      CHARACTER*80 CARD
      COMMON /CONST/ A,F,E2,EPS,AF,PI,TWOPI,RHOSEC
      COMMON /ARRAYS/ HT(nbbdim),LOC(nbbdim)
      COMMON /FILES/ LUIN, LUOUT, I1, I2, I3, I4, I5

      DO 100 I = 1, 10000
          LOC(I) = 0 
          HT(I) = 0.D0
  100 CONTINUE
          
      JREC = 0
  125 READ(I1,130,END=160) CARD
  130 FORMAT(A80)
      TYPE = CARD(7:10)
      IF(TYPE .EQ. '*80*') THEN
         JREC = JREC + 1
         READ(CARD,140)ISN,LATD,LATM,SLAT,JN,LOND,LONM,SLON,JW,OH
  140    FORMAT(BZ,10X,I4,T45,2I2,F7.5,A1,I3,I2,F7.5,A1,F6.2)
         LOC(ISN) = JREC
C        HT(ISN) = HT(ISN) + OH
	 IF ( HT(ISN) .EQ. 0.D0 ) HT(ISN) = OH
         YLAT = (DBLE((LATD*60+LATM)*60)+SLAT)/RHOSEC
         YLON = (DBLE((LOND*60+LONM)*60)+SLON)/RHOSEC
         IF(JN .EQ. 'S') YLAT = -YLAT
         IF(JW .EQ. 'E') YLON = -YLON
	 call PREDV( ylat, ylon, ht(isn), date, iopt,
     1      IDG, vn, ve, vu)
         IF(IDG .eq. 0) THEN
           WRITE(LUOUT,150) CARD
  150      FORMAT('  **WARNING**  The following point is outside of ',
     1     'the modeled region.'/
     2     ' It will be assumed that this point has not moved.'/A80/)
         ENDIF
         WRITE(I4, REC = JREC) YLAT, YLON, VN, VE, VU      
C     ELSEIF(TYPE .eq. '*84*') THEN
C        READ(CARD,155) ISN,GH
C 155    FORMAT(BZ,10X,I4,T70,F6.2)
C        HT(ISN) = HT(ISN) + GH
      ELSEIF(TYPE .eq. '*86*') THEN
         IF(CARD(46:52) .ne. '       ') THEN
            READ(CARD,156) ISN, EHT
  156       FORMAT(BZ,10X,I4,T46,F7.3)
            HT(ISN) = EHT
         ELSE
            READ(CARD,157) ISN, OHT, GHT
  157       FORMAT(BZ,10X,I4,T17,F7.3,T36,F7.3)
            HT(ISN) = OHT + GHT
         ENDIF
      ENDIF
      GO TO 125
  160 REWIND I1
      RETURN
      END
******************************************************************
      SUBROUTINE GETPO5(IOPT, DATE)

*** Retrieve geodetic position from blue book with 5-digit SSN

      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      IMPLICIT INTEGER*4 (I-N)
      parameter (nbbdim = 100000)
      CHARACTER*1 JN,JW
      CHARACTER*3 TYPE
      CHARACTER*80 CARD
      COMMON /CONST/ A,F,E2,EPS,AF,PI,TWOPI,RHOSEC
      COMMON /ARRAYS/ HT(nbbdim),LOC(nbbdim)
      COMMON /FILES/ LUIN, LUOUT, I1, I2, I3, I4, I5

      DO 100 I = 1, 100000
          LOC(I) = 0
          HT(I) = 0.D0
  100 CONTINUE
          
      JREC = 0

  125 READ(I1,130,END=160) CARD
  130 FORMAT(A80)
      TYPE = CARD(7:9)
      IF(TYPE .EQ. '*80') THEN
         JREC = JREC + 1
         READ(CARD,140)ISN,LATD,LATM,SLAT,JN,LOND,LONM,SLON,JW,OH
  140    FORMAT(BZ, 9X,I5,T45,2I2,F7.5,A1,I3,I2,F7.5,A1,F6.2)
         LOC(ISN) = JREC
C        HT(ISN) = HT(ISN) + OH
	 IF ( HT(ISN) .EQ. 0.D0 ) HT(ISN) = OH
         YLAT = (DBLE((LATD*60+LATM)*60)+SLAT)/RHOSEC
         YLON = (DBLE((LOND*60+LONM)*60)+SLON)/RHOSEC
         IF(JN .EQ. 'S') YLAT = -YLAT
         IF(JW .EQ. 'E') YLON = -YLON
	 call PREDV( ylat, ylon, ht(isn), date, iopt,
     1       idg, vn, ve, vu)
         IF(IDG .eq. 0) THEN
           WRITE(LUOUT,150) CARD
  150      FORMAT('  **WARNING**  The following point is outside of ',
     1     'the modeled region.'/
     2     ' It will be assumed that this point has not moved.'/A80/)
         ENDIF
         WRITE(I4, REC = JREC) YLAT, YLON, VN, VE, VU      
C     ELSEIF(TYPE .eq. '*84') THEN
C        READ(CARD,155) ISN,GH
C 155    FORMAT(BZ, 9X,I5,T70,F6.2)
C        HT(ISN) = HT(ISN) + GH
      ELSEIF(TYPE .eq. '*86') THEN
         IF(CARD(46:52) .ne. '       ') THEN
            READ(CARD,156) ISN, EHT
  156       FORMAT(BZ, 9X,I5,T46,F7.3)
            HT(ISN) = EHT
         ELSE
            READ(CARD,157) ISN, OHT, GHT
  157       FORMAT(BZ, 9X,I5,T17,F7.3,T36,F7.3)
            HT(ISN) = OHT + GHT
         ENDIF
      ENDIF
      GO TO 125
  160 REWIND I1
      RETURN
      END
******************************************************************
      SUBROUTINE UPBB4(MIN1,MIN2,OPT,IOPT)

*** Update blue book

      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      IMPLICIT INTEGER*4 (I-N)
      parameter (nbbdim = 100000)
      CHARACTER*80 CARD
      CHARACTER*6 DATE
      CHARACTER*4 TYPE
      CHARACTER*1 OPT,JN,JW
      CHARACTER*1 LATDIR, LONDIR
      LOGICAL TEST, TEST1
      COMMON /ARRAYS/ HT(nbbdim),LOC(nbbdim) 
      COMMON /FILES/ LUIN, LUOUT, I1, I2, I3, I4, I5
      COMMON /CONST/ A,F,E2,EPS,AF,PI,TWOPI,RHOSEC

C***    To update classical observations an *12* record
C***    is needed to identify the correct century, as
C***    classical observation records contain only a 2-digit year
      IREC12 = 0

  170 READ(I1,175,END=600) CARD
  175 FORMAT(A80)
      TYPE = CARD(7:10)
      IF(TYPE .EQ. '*A1*' .OR.
     1      TYPE .EQ. '*AA*' .OR.
     1      TYPE .EQ. '*10*' .OR.
     1      TYPE .EQ. '*11*' .OR.
     1      TYPE .EQ. '*13*' .OR.
     1      TYPE .EQ. '*21*' .OR.
     1      TYPE .EQ. '*25*' .OR.
     1      TYPE .EQ. '*26*' .OR.
     1      TYPE .EQ. '*27*' .OR.
     1      TYPE .EQ. '*28*' .OR.
     1      TYPE .EQ. '*29*' ) THEN
              CONTINUE
      ELSEIF(TYPE .EQ. '*31*' .OR.
     1      TYPE .EQ. '*40*' .OR.
     1      TYPE .EQ. '*41*' .OR.
     1      TYPE .EQ. '*42*' .OR.
     1      TYPE .EQ. '*45*' .OR.
     1      TYPE .EQ. '*46*' .OR.
     1      TYPE .EQ. '*47*' .OR.
     1      TYPE .EQ. '*70*' .OR.
     1      TYPE .EQ. '*81*' .OR.
     1      TYPE .EQ. '*82*' .OR.
     1      TYPE .EQ. '*83*' .OR.
     1      TYPE .EQ. '*84*' .OR.
     1      TYPE .EQ. '*85*' .OR.
     1      TYPE .EQ. '*86*' .OR.
     1      TYPE .EQ. '*90*') THEN
	      CONTINUE

      ELSEIF (TYPE .EQ. '*12*') THEN
         IF( CARD(11:14) .EQ. '    ' .OR.
     1       CARD(17:20) .EQ. '    ') THEN
             WRITE ( LUOUT, 176 )
  176        FORMAT( ' ERROR: The *12* record does not contain'/
     1               '   appropriate dates.')
         ELSE
             READ ( CARD, 177) IYEAR1, IYEAR2
  177        FORMAT ( 10X, I4, 2X, I4)
             IF ( (IYEAR2 - IYEAR1) .LT. 0 .OR.
     1            (IYEAR2 - IYEAR1) .GT. 99 ) THEN
                WRITE (LUOUT, 178)
  178           FORMAT(' ERROR: The dates in the *12* record are in'/
     1            ' error. Either they span more than 99 years or '/
     1            ' the end date preceedes the start date.'/
     1            ' If they span more than 99 years, then the Bluebook'/
     1            ' will need to divided into two or more bluebooks'/
     1            ' with the observations in each spanning no more'/
     1            ' than 99 years.')
             ELSE
                IREC12 = 1
             ENDIF
         ENDIF

*** Regular distance

      ELSEIF(TYPE .EQ. '*50*' .OR.
     1       TYPE .EQ. '*51*' .OR.
     1       TYPE .EQ. '*52*') THEN
         IF(OPT .eq. '3' .or. OPT .eq. '4')THEN
           READ(CARD,180) ISN,DATE,JSN,OBS
  180      FORMAT(BZ,10X,I4,T35,A6,T46,I4,T64,F9.4)
           CALL CHECK(ISN,JSN,CARD,TEST)
           IF(TEST) THEN
	      CALL TRFDAT(CARD,DATE,IREC12, IYEAR1, IYEAR2, MINO)
	      CALL DSDA(LOC(ISN), LOC(JSN), 
     1           MINO, MIN2, DS, DA)     
	      IOBS = IDNINT((OBS+DS)*10000.D0)
	      WRITE(CARD(64:72),190) IOBS
  190         FORMAT(I9)
            ENDIF
         ENDIF

*** Azimuth

      ELSEIF(TYPE .EQ. '*60*' .OR. TYPE .EQ. '*61*') THEN
         IF(OPT .eq. '3' .or. OPT .eq. '4') THEN
         READ(CARD,200) ISN,DATE,JSN,IDEG,MIN,SEC
  200    FORMAT(BZ,10X,I4,T40,A6,T51,I4,T64,I3,I2,F3.1)
         CALL CHECK(ISN,JSN,CARD,TEST)
         IF(TEST) THEN
	      CALL TRFDAT(CARD,DATE,IREC12, IYEAR1, IYEAR2, MINO)
	      CALL DSDA(LOC(ISN), LOC(JSN), 
     1           MINO, MIN2, DS, DA)    
              OBS = (DBLE((IDEG*60+MIN)*60)+SEC)/RHOSEC
	      OBS = OBS + DA
	      IF(OBS .GE. TWOPI) THEN
	        OBS = OBS - TWOPI
              ELSEIF(OBS .LT. 0.D0) THEN
	        OBS = OBS + TWOPI
              ENDIF
	      CALL TODMSS(OBS,IDEG,MIN,SEC,ISIGN)
	      ISEC = IDNINT(SEC*10.D0)
	      WRITE(CARD(64:71),210) IDEG,MIN,ISEC
  210         FORMAT(I3,I2.2,I3.3)
            ENDIF
         ENDIF

*** Direction observation

      ELSEIF(TYPE .EQ. '*20*') THEN
         IF(OPT .eq. '3' .or. OPT .eq. '4') THEN
            READ(CARD,220) ISN0,LIST0,DATE,JSN
  220       FORMAT(BZ,10X,I4,I2,T40,A6,T51,I4)
            CALL CHECK(ISN0,JSN,CARD,TEST) 
            CALL TRFDAT(CARD,DATE,IREC12, IYEAR1, IYEAR2, MINO)
            IF(TEST) THEN
	      CALL DSDA(LOC(ISN0), LOC(JSN), 
     1           MINO, MIN2, DS, DA0)     
            ELSE
              DA0 = 0.D0
            ENDIF
         ENDIF
      ELSEIF(TYPE .EQ. '*22*') THEN
         IF(OPT .eq. '3' .or. OPT .eq. '4') THEN
	   READ(CARD,230) ISN,LIST,JSN,IDEG,MIN,SEC
  230      FORMAT(BZ,10X,I4,I2,T51,I4,T64,I3,I2,F4.2)
	   IF(LIST.NE.LIST0 .OR. ISN.NE.ISN0) THEN
	        WRITE(LUOUT,240) CARD
  240           FORMAT(' Blue-book file has incorrect structure.'/
     1          ' A *22* record disagrees with its corresponding'/
     2          ' *20* record.  The record reads:'/A80)
	        STOP
           ENDIF
           CALL CHECK(ISN,JSN,CARD,TEST)
           IF(TEST) THEN
	      CALL DSDA(LOC(ISN), LOC(JSN), 
     1           MINO, MIN2, DS, DA)    
	      OBS=(DBLE((IDEG*60+MIN)*60)+SEC)/RHOSEC
	      OBS = OBS + DA - DA0
	      IF(OBS .GT. TWOPI) THEN
	        OBS = OBS - TWOPI
              ELSEIF(OBS .LT. 0.D0) THEN
	        OBS = OBS + TWOPI
              ENDIF
	      CALL TODMSS(OBS,IDEG,MIN,SEC,ISIGN)
	      ISEC = IDNINT(SEC*100.D0)
	      WRITE(CARD(64:72),250) IDEG,MIN,ISEC
  250         FORMAT(I3.3,I2.2,I4.4)
            ENDIF
         ENDIF

*** Long distance

      ELSEIF(TYPE .EQ. '*53*' .OR.
     1       TYPE .EQ. '*54*') THEN
         IF(OPT .eq. '3' .or. OPT .eq. '4') THEN
           READ(CARD,260) ISN,DATE,JSN,OBS
  260      FORMAT(BZ,10X,I4,T35,A6,T46,I4,T64,F10.3)
           CALL CHECK(ISN,JSN,CARD,TEST)
           IF(TEST) THEN
	      CALL TRFDAT(CARD,DATE,IREC12, IYEAR1, IYEAR2, MINO)
              CALL DSDA(LOC(ISN), LOC(JSN), 
     1           MINO, MIN2, DS, DA)    
	      IOBS = IDNINT((OBS + DS)*1000.D0)
	      WRITE(CARD(64:73),270) IOBS
  270         FORMAT(I10)
            ENDIF
         ENDIF
  
*** Horizontal angle

      ELSEIF(TYPE .EQ. '*30*' .OR.
     1       TYPE .EQ. '*32*') THEN
         IF(OPT .eq. '3' .or. OPT .eq. '4') THEN
           READ(CARD,280) ISN,JSN,IDEG,MIN,SEC,KSN
  280      FORMAT(BZ,10X,I4,T51,I4,T64,I3,I2,F3.1,I4)
           IF(TYPE.EQ.'*30*') THEN
		  DATE = CARD(40:45)
		  CALL TRFDAT(CARD,DATE,IREC12, IYEAR1, IYEAR2, MINO)
           ENDIF
           CALL CHECK(ISN,JSN,CARD,TEST)
           CALL CHECK(ISN,KSN,CARD,TEST1)
           IF(TEST .and. TEST1) THEN
              CALL DSDA(LOC(ISN), LOC(JSN), 
     1           MINO, MIN2, DS, DA0)   
              CALL DSDA(LOC(ISN), LOC(KSN), 
     1           MINO, MIN2, DS, DA)     
              OBS=(DBLE((IDEG*60+MIN)*60)+SEC)/RHOSEC
              OBS = OBS + DA - DA0
              IF(OBS .GE. TWOPI) THEN
		   OBS = OBS - TWOPI
              ELSEIF(OBS .LT. 0.D0) THEN
		   OBS = OBS + TWOPI
              ENDIF
              CALL TODMSS(OBS,IDEG,MIN,SEC,ISIGN)
              ISEC = IDNINT(SEC*10.D0)
              WRITE(CARD(64:71),290)IDEG,MIN,SEC
  290         FORMAT(I3.3,I2.2,I3.3)
            ENDIF
         ENDIF

*** position record

      ELSEIF(TYPE .EQ. '*80*') THEN
            IF(OPT .eq. '2' .or. OPT .eq. '4') THEN
              READ(CARD,300) ISN,LATD,LATM,SLAT,JN,
     1                LOND,LONM,SLON,JW
  300         FORMAT(BZ,10X,I4,T45,2I2,F7.5,A1,I3,I2,F7.5,A1)
              YLAT = (DBLE((LATD*60+LATM)*60)+SLAT)/RHOSEC
              YLON = (DBLE((LOND*60+LONM)*60)+SLON)/RHOSEC
              IF(JN .EQ. 'S') YLAT = -YLAT
              IF(JW .EQ. 'E') YLON = -YLON
C             READ(I4, REC = LOC(ISN)) RLAT, RLON, IDG
	      READ(I4, REC = LOC(ISN)) RLAT, RLON, VN, VE, VU
	      call NEWCOR( ylat, ylon, ht(isn), min1, min2,
     1           ylatt, ylont, ehtnew, dn, de, du, vn, ve, vu)
C             CALL NWCORD(YLAT,YLON,HT(ISN),
C    1          RLAT,RLON,IDG,MIN1,MIN2,
C    1          YLATT,YLONT,EHTNEW,DN,DE,DU,IOPT)
              CALL TODMSS(YLATT,LATDN,LATMN,SLATN,ISIGN)
	      LATDIR = 'N'
	      IF (ISIGN .eq. -1) LATDIR = 'S'
              CALL TODMSS(YLONT,LONDN,LONMN,SLONN,ISIGN)
	      LONDIR = 'W'
	      IF (ISIGN .eq. -1) LONDIR = 'E'
              LATS = IDNINT(SLATN*100000.D0)
              LONS = IDNINT(SLONN*100000.D0)
              WRITE(CARD(45:56),310) LATDN,LATMN,LATS,LATDIR
  310         FORMAT(I2,I2.2,I7.7,A1)
              WRITE(CARD(57:69),320) LONDN,LONMN,LONS,LONDIR
  320         FORMAT(I3,I2.2,I7.7,A1)
            ENDIF

*** Unrecognized blue book record

      ELSE
            WRITE(LUOUT,500) TYPE
  500       FORMAT(' This software does not recognize an ',A4,/
     1       ' record.  The record will be copied to the new'/
     2       ' file without change.')
      ENDIF
      WRITE(I2,175) CARD
      GO TO 170
  600 CONTINUE
      RETURN
      END
***************************************************************
      SUBROUTINE UPBB5(MIN1,MIN2,OPT,IOPT)

*** Update 5-digit blue book

      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      IMPLICIT INTEGER*4 (I-N)
      parameter (nbbdim = 100000)
      CHARACTER*212 CARD
      CHARACTER*80 SUBCRD
C     CHARACTER*6 DATE
      CHARACTER*8 DATE8
      CHARACTER*3 TYPE
      CHARACTER*1 OPT,SIGN,JN,JW
      CHARACTER*1 LATDIR, LONDIR
      LOGICAL TEST
      COMMON /ARRAYS/ HT(nbbdim),LOC(nbbdim) 
      COMMON /FILES/ LUIN, LUOUT, I1, I2, I3, I4, I5
      COMMON /CONST/ A,F,E2,EPS,AF,PI,TWOPI,RHOSEC

  170 READ(I1,175,END=600) CARD
  175 FORMAT(A212)
      SUBCRD = CARD(1:80)
      TYPE = CARD(7:9) 
      IF(TYPE .EQ. '*A1' .OR.
     1      TYPE .EQ. '*AA' .OR.
     1      TYPE .EQ. '*10' .OR.
     1      TYPE .EQ. '*11' .OR.
     1      TYPE .EQ. '*12' .OR.
     1      TYPE .EQ. '*13' .OR.
     1      TYPE .EQ. '*21' .OR.
     1      TYPE .EQ. '*25' .OR.
     1      TYPE .EQ. '*26' .OR.
     1      TYPE .EQ. '*27' .OR.
     1      TYPE .EQ. '*28' .OR.
     1      TYPE .EQ. '*29' ) THEN
              CONTINUE
      ELSEIF(TYPE .EQ. '*31' .OR.
     1      TYPE .EQ. '*40' .OR.
     1      TYPE .EQ. '*41' .OR.
     1      TYPE .EQ. '*42' .OR.
     1      TYPE .EQ. '*45' .OR.
     1      TYPE .EQ. '*46' .OR.
     1      TYPE .EQ. '*47' .OR.
     1      TYPE .EQ. '*70' .OR.
     1      TYPE .EQ. '*81' .OR.
     1      TYPE .EQ. '*82' .OR.
     1      TYPE .EQ. '*83' .OR.
     1      TYPE .EQ. '*84' .OR.
     1      TYPE .EQ. '*85' .OR.
     1      TYPE .EQ. '*86' .OR.
     1      TYPE .EQ. '*90') THEN
	      CONTINUE

*** Regular distance

      ELSEIF(TYPE .EQ. '*50' .OR.
     1       TYPE .EQ. '*51' .OR.
     1       TYPE .EQ. '*52') THEN
         IF(OPT .eq. '3' .or. OPT .eq. '4')THEN
C          READ(CARD,180) ISN,DATE,JSN,OBS
C 180      FORMAT(BZ, 9X,I5,T35,A6,T46,I5,T64,F9.4)
           READ(CARD,180) ISN, JSN, OBS, DATE8
  180      FORMAT(BZ, 9X,I5,T46,I5,T64,F9.4,T101,A8)
           CALL CHECK(ISN,JSN,SUBCRD,TEST)
           IF(TEST) THEN
	      CALL TNFDAT(DATE8,MINO)
	      CALL DSDA(LOC(ISN), LOC(JSN), 
     1           MINO, MIN2, DS, DA)    
	      IOBS = IDNINT((OBS+DS)*10000.D0)
	      WRITE(CARD(64:72),190) IOBS
  190         FORMAT(I9)
              WRITE(CARD(174:181),191) DS
  191         FORMAT(F8.4)
            ENDIF
         ENDIF

*** Azimuth

      ELSEIF(TYPE .EQ. '*60' .OR. TYPE .EQ. '*61') THEN
         IF(OPT .eq. '3' .or. OPT .eq. '4') THEN
C          READ(CARD,200) ISN,DATE,JSN,IDEG,MIN,SEC
C 200      FORMAT(BZ, 9X,I5,T40,A6,T51,I5,T64,I3,I2,F3.1)
           READ(CARD,200) ISN,JSN,IDEG,MIN,SEC,DATE8
  200      FORMAT(BZ, 9X,I5,T51,I5,T64,I3,I2,F3.1,T101,A8)
           CALL CHECK(ISN,JSN,SUBCRD,TEST)
           IF(TEST) THEN
	      CALL TNFDAT(DATE8,MINO)
	      CALL DSDA(LOC(ISN), LOC(JSN), 
     1           MINO, MIN2, DS, DA)     
              OBS = (DBLE((IDEG*60+MIN)*60)+SEC)/RHOSEC
	      OBS = OBS + DA
	      IF(OBS .GE. TWOPI) THEN
	        OBS = OBS - TWOPI
              ELSEIF(OBS .LT. 0.D0) THEN
	        OBS = OBS + TWOPI
              ENDIF
	      CALL TODMSS(OBS,IDEG,MIN,SEC,ISIGN)
	      ISEC = IDNINT(SEC*10.D0)
	      WRITE(CARD(64:71),210) IDEG,MIN,ISEC
  210         FORMAT(I3,I2.2,I3.3)
              IF(DA .GE. 0.0D0) THEN
                 SIGN = ' '
              ELSE
                 SIGN = '-'
              ENDIF
              ANGLE = DABS(DA)
              CALL TODMSS(ANGLE,IDEG,MIN,SEC,ISIGN)
              ISEC1 = SEC
              ISEC2 = IDNINT((SEC - DBLE(ISEC1)) * 100.D0)
              WRITE(CARD(152:162),211)SIGN,IDEG,MIN,ISEC1,ISEC2
  211         FORMAT(A1,I3.3,I2.2,I2.2,'.',I2.2)
            ENDIF
         ENDIF

*** Direction observation

      ELSEIF(TYPE .EQ. '*20') THEN
         IF(OPT .eq. '3' .or. OPT .eq. '4') THEN
C           READ(CARD,220) ISN0,LIST0,DATE,JSN
C 220       FORMAT(BZ, 9X,I5,I2,T40,A6,T51,I5)
            READ(CARD,220) ISN0,LIST0,JSN,DATE8
  220       FORMAT(BZ, 9X,I5,I2,T51,I5,T101,A8)
            CALL CHECK(ISN0,JSN,SUBCRD,TEST) 
            CALL TNFDAT(DATE8,MINO)
            IF(TEST) THEN
	      CALL DSDA(LOC(ISN0), LOC(JSN), 
     1           MINO, MIN2, DS, DA0)     
            ELSE
              DA0 = 0.D0
            ENDIF
            CARD(132:142) = ' 0000000.00'
         ENDIF
      ELSEIF(TYPE .EQ. '*22') THEN
         IF(OPT .eq. '3' .or. OPT .eq. '4') THEN
	   READ(CARD,230) ISN,LIST,JSN,IDEG,MIN,SEC
  230      FORMAT(BZ, 9X,I5,I2,T51,I5,T64,I3,I2,F4.2)
	   IF(LIST.NE.LIST0 .OR. ISN.NE.ISN0) THEN
	        WRITE(LUOUT,240) CARD
  240           FORMAT(' Blue-book file has incorrect structure.'/
     1          ' A *22* record disagrees with its corresponding'/
     2          ' *20* record.  The record reads:'/A212)
	        STOP
           ENDIF
           CALL CHECK(ISN,JSN,SUBCRD,TEST)
           IF(TEST) THEN
	      CALL DSDA(LOC(ISN), LOC(JSN), 
     1           MINO, MIN2, DS, DA)    
           ELSE
              DA = 0.D0
           ENDIF
	   OBS=(DBLE((IDEG*60+MIN)*60)+SEC)/RHOSEC
	   OBS = OBS + DA - DA0
	   IF(OBS .GT. TWOPI) THEN
	       OBS = OBS - TWOPI
           ELSEIF(OBS .LT. 0.D0) THEN
	       OBS = OBS + TWOPI
           ENDIF
	   CALL TODMSS(OBS,IDEG,MIN,SEC,ISIGN)
	   ISEC = IDNINT(SEC*100.D0)
	   WRITE(CARD(64:72),250) IDEG,MIN,ISEC
  250      FORMAT(I3.3,I2.2,I4.4)
           IF((DA-DA0) .GE. 0.D0) THEN
                 SIGN = ' '
           ELSE
                 SIGN = '-'
           ENDIF
           ANGLE = DABS(DA - DA0)
           CALL TODMSS(ANGLE,IDEG,MIN,SEC,ISIGN)
           ISEC1 = SEC
           ISEC2 = IDNINT((SEC-DBLE(ISEC1))*100.D0)
           WRITE(CARD(132:142),251) SIGN,IDEG,MIN,ISEC1,ISEC2
  251      FORMAT(A1,I3.3,I2.2,I2.2,'.',I2.2)
         ENDIF

*** Long distance

      ELSEIF(TYPE .EQ. '*53' .OR.
     1       TYPE .EQ. '*54') THEN
         IF(OPT .eq. '3' .or. OPT .eq. '4') THEN
C          READ(CARD,260) ISN,DATE,JSN,OBS
C 260      FORMAT(BZ, 9X,I5,T35,A6,T46,I5,T64,F10.3)
           READ(CARD,260) ISN,JSN,OBS,DATE8
  260      FORMAT(BZ, 9X,I5,T46,I5,T64,F10.3,T101,A8)
           CALL CHECK(ISN,JSN,SUBCRD,TEST)
           IF(TEST) THEN
	      CALL TNFDAT(DATE8,MINO)
              CALL DSDA(LOC(ISN), LOC(JSN), 
     1           MINO, MIN2, DS, DA)     
	      IOBS = IDNINT((OBS + DS)*1000.D0)
	      WRITE(CARD(64:73),270) IOBS
  270         FORMAT(I10)
              CORR = IDNINT(DS*10000.D0)
              WRITE(CARD(174:181),271) CORR
  271         FORMAT(F8.4)
            ENDIF
         ENDIF
  
*** position record

      ELSEIF(TYPE .EQ. '*80') THEN
            IF(OPT .eq. '2' .or. OPT .eq. '4') THEN
              READ(CARD,300) ISN,LATD,LATM,SLAT,JN,
     1             LOND,LONM,SLON,JW
  300         FORMAT(BZ,9X,I5,T45,2I2,F7.5,A1,I3,I2,F7.5,A1)
              YLAT = (DBLE((LATD*60+LATM)*60)+SLAT)/RHOSEC
              YLON = (DBLE((LOND*60+LONM)*60)+SLON)/RHOSEC
              IF(JN .EQ. 'S') YLAT = -YLAT
              IF(JW .EQ. 'E') YLON = -YLON
C             READ(I4, REC = LOC(ISN)) RLAT, RLON, IDG
C             CALL NWCORD(YLAT,YLON,HT(ISN),
C    1          RLAT,RLON,IDG,MIN1,MIN2,
C    1          YLATT,YLONT,EHTNEW,DN,DE,DU,IOPT)
	      READ(I4, REC = LOC(ISN)) RLAT, RLON, VN, VE, VU
	      call NEWCOR( ylat, ylon, ht(isn), min1, min2,
     1           ylatt, ylont, ehtnew, dn, de, du, vn, ve, vu)
              CALL TODMSS(YLATT,LATDN,LATMN,SLATN,ISIGN)
	      LATDIR = 'N'
	      IF (ISIGN .eq. -1) LATDIR = 'S'
              CALL TODMSS(YLONT,LONDN,LONMN,SLONN,ISIGN)
	      LONDIR = 'W'
	      IF (ISIGN .eq. -1) LONDIR = 'E'
              LATS = IDNINT(SLATN*100000.D0)
              LONS = IDNINT(SLONN*100000.D0)
              WRITE(CARD(45:56),310) LATDN,LATMN,LATS,LATDIR
  310         FORMAT(I2,I2.2,I7.7,A1)
              WRITE(CARD(57:69),320) LONDN,LONMN,LONS,LONDIR
  320         FORMAT(I3,I2.2,I7.7,A1)
            ENDIF

*** Unrecognized blue book record

      ELSE
            WRITE(LUOUT,500) TYPE
  500       FORMAT(' This software does not recognize an ',A3,/
     1       ' record.  The record will be copied to the new'/
     2       ' file without change.')
      ENDIF
      WRITE(I2,175) CARD
      GO TO 170
  600 CONTINUE
      RETURN
      END
***************************************************************
      SUBROUTINE CHECK(ISN,JSN,CARD,TEST)

*** Check if stations have *80* records

      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      IMPLICIT INTEGER*4 (I-N)
      parameter (nbbdim = 100000)
      CHARACTER*80 CARD
      LOGICAL TEST
      COMMON /ARRAYS/ HT(nbbdim),LOC(nbbdim)
      COMMON /FILES/ LUIN, LUOUT, I1, I2, I3, I4, I5

      TEST = .TRUE.

      IF(LOC(ISN) .eq. 0) THEN
          WRITE(LUOUT,100) ISN, CARD
  100     FORMAT(' No *80* record for SSN = ',I4/A80/)
          TEST = .FALSE.
      ENDIF

      IF(LOC(JSN) .eq. 0) THEN
          WRITE(LUOUT,100) JSN, CARD
          TEST = .FALSE.
      ENDIF

      RETURN
      END

*************************************************
      SUBROUTINE UPGFI4(DATE2, MIN2, IOPT, KOPT,
     *     MONTH, IDAY, IYEAR)

*** Update G-FILE of blue book

      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      IMPLICIT INTEGER*4 (I-N)
c     CHARACTER*80 CARD
      CHARACTER*120 CARD
      CHARACTER*1 TYPE
      CHARACTER*2 NRF
      CHARACTER*2 ZT
      CHARACTER*14 CHAR14
      LOGICAL TEST
      COMMON /FILES/ LUIN, LUOUT, I1, I2, I3, I4, I5

      ZT = 'ZT'

*** Obtain blue-book reference frame identifier
*** corresponding to IOPT
      IF (KOPT .NE. -1) THEN
         CALL RFCON1(KOPT, NBBREF)
         WRITE(NRF,10) NBBREF
   10    FORMAT(I2.2)
      ENDIF

   90 READ(I1,100,END=200) CARD
c 100 FORMAT(A80)
  100 FORMAT(A120)
      TYPE = CARD(1:1)
      IF(TYPE .eq. 'A') THEN
         IF (CARD(79:80) .EQ. ZT) THEN
            WRITE(LUOUT, 103)
  103       FORMAT(
     1     ' *****************************************************'/
     1     ' * ERROR: The input GFILE contains the letters, ZT,  *'/
     1     ' * in columns 79-80 of its A-record.  This indicates *'/
     1     ' * that the GPS vectors in this file have already    *'/
     1     ' * been updated to a common date.  This software     *'/
     1     ' * will not further modify the GPS vectors.          *'/
     1     ' *****************************************************'/)
            RETURN
         ENDIF
         WRITE(CARD(79:80),101) ZT
  101    FORMAT(A2)
         WRITE(CARD(4:11), 102) IYEAR, MONTH, IDAY
  102    FORMAT(I4, I2.2, I2.2)
         WRITE(CARD(12:19), 102) IYEAR, MONTH, IDAY
                  
      ELSEIF(TYPE .eq. 'B') THEN
         READ(CARD,110)IYEAR1,MONTH1,IDAY1,
     1        IYEAR2,MONTH2,IDAY2,IBBREF
  110    FORMAT(1X,I4,I2,I2,4X,I4,I2,I2,30X,I2)
         CALL TOTIME(IYEAR1,MONTH1,IDAY1,MINO1)
	 CALL TOTIME(IYEAR1, 1, 1, MIN00)
	 DECYR1 = DBLE(IYEAR1) + DBLE(MINO1 - MIN00)/525600.D0
         CALL TOTIME(IYEAR2,MONTH2,IDAY2,MINO2)
	 CALL TOTIME(IYEAR2, 1, 1, MIN00)
	 DECYR2 = DBLE(IYEAR2) + DBLE(MINO2 - MIN00)/525600.D0
         MINO = (MINO1 + MINO2) / 2
	 DECYR = (DECYR1 + DECYR2) / 2.D0
         CALL RFCON(IBBREF, JREF)
         IF (KOPT .NE. -1) THEN
            CARD(52:53) = NRF
         ENDIF
      ELSEIF(TYPE .eq. 'C') THEN
         READ(CARD,120)ISN,JSN,DX,DY,DZ
  120    FORMAT(BZ,1X,2I4,F11.4,5X,F11.4,5X,F11.4)
   
         CALL CHECK(ISN, JSN, CARD, TEST)
         IF (TEST) THEN
            CALL DDXYZ(ISN, JSN,                                 
     1              MINO, MIN2, DDX, DDY, DDZ)
*** Convert vector from JREF to IOPT frame                        
            call TRAVEC( DX, DY, DZ, DECYR, JREF, IOPT)

            DX = DX + DDX
            DY = DY + DDY
            DZ = DZ + DDZ

*** Convert GPS vector from IOPT to KOPT reference frame
            IF (KOPT .NE. -1) THEN
               CALL TRAVEC(DX, DY, DZ, DATE2, IOPT, KOPT)
            ELSE
	       CALL TRAVEC(DX, DY, DZ, DATE2, IOPT, JREF)
            ENDIF

*** Rewrite GPS observational record
            CALL TOCHAR(DX,CHAR14)          
            CARD(10:20) = CHAR14(3:13)          

            CALL TOCHAR(DY,CHAR14)
            CARD(26:36) = CHAR14(3:13)    

            CALL TOCHAR(DZ,CHAR14)
            CARD(42:52) = CHAR14(3:13)    
         ENDIF

      ELSEIF(TYPE .eq. 'F') THEN
         READ(CARD,140) ISN, JSN, DX, DY, DZ
  140    FORMAT(BZ,1X,2I4,F13.4,5X,F13.4,5X,F13.4)

         CALL CHECK(ISN, JSN, CARD, TEST)
         IF (TEST) THEN
            CALL DDXYZ(ISN, JSN,                               
     1              MINO, MIN2, DDX, DDY, DDZ)

	    call TRAVEC( DX, DY, DZ, DECYR, JREF, IOPT) 

            DX = DX + DDX
            DY = DY + DDY
            DZ = DZ + DDZ

*** Convert GPS vector to output reference frame
            IF (KOPT .NE. -1) THEN
               CALL TRAVEC(DX, DY, DZ, DATE2, IOPT, KOPT)
            ELSE
	       CALL TRAVEC(DX, DY, DZ, DATE2, IOPT, JREF)
            ENDIF

*** Rewrite GPS observational record
            CALL TOCHAR(DX,CHAR14)
            CARD(10:22) = CHAR14(1:13)

            CALL TOCHAR(DY,CHAR14)
            CARD(28:40) = CHAR14(1:13)           

            CALL TOCHAR(DZ,CHAR14)
            CARD(46:58) = CHAR14(1:13)
         ENDIF
      ENDIF
      WRITE(I2,100) CARD
      GO TO 90
  200 CONTINUE
      RETURN
      END
*********************************************************
      SUBROUTINE UPGFI5(DATE2, MIN2, IOPT, KOPT,
     *                  MONTH, IDAY, IYEAR)

*** Update G-FILE of 5-digit blue book

      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      IMPLICIT INTEGER*4 (I-N)
      CHARACTER*180 CARD
      CHARACTER*80 SUBCRD
      CHARACTER*1 TYPE
      CHARACTER*2 NRF
      CHARACTER*2 ZT
      CHARACTER*14 CHAR14
      LOGICAL TEST
      COMMON /FILES/ LUIN, LUOUT, I1, I2, I3, I4, I5

      ZT = 'ZT'

*** Obtain blue-book reference frame identifier
*** corresponding to IOPT
      IF (KOPT .NE. -1) THEN
         CALL RFCON1(KOPT, NBBREF)
         WRITE(NRF, 10) NBBREF
   10    FORMAT(I2.2)
      ENDIF

   90 READ(I1,100,END=200) CARD
  100 FORMAT(A180)
      TYPE = CARD(1:1)

      IF (TYPE .eq. 'A') THEN
         IF (CARD(79:80) .EQ. ZT) THEN
            WRITE(LUOUT, 103)
  103       FORMAT(
     1     ' *****************************************************'/
     1     ' * ERROR: The input GFILE contains the letters, ZT,  *'/
     1     ' * in columns 79-80 of its A-record.  This indicates *'/
     1     ' * that the GPS vectors in this file have already    *'/
     1     ' * been updated to a common date.  This software     *'/
     1     ' * will not further modify the GPS vectors.          *'/
     1     ' *****************************************************'/)
            RETURN
         ENDIF
         WRITE(CARD(79:80), 101) ZT
  101    FORMAT(A2)
         WRITE(CARD(4:11), 102) IYEAR, MONTH, IDAY
  102    FORMAT(I4, I2.2, I2.2)
         WRITE(CARD(12:19), 102) IYEAR, MONTH, IDAY
                            
      ELSEIF(TYPE .eq. 'B') THEN
         READ(CARD,110)IYEAR1,MONTH1,IDAY1,
     1        IYEAR2,MONTH2,IDAY2,IBBREF
  110    FORMAT(1X,I4,I2,I2,4X,I4,I2,I2,30X,I2)
         CALL TOTIME(IYEAR1,MONTH1,IDAY1,MINO1)
	 CALL TOTIME(IYEAR1, 1, 1, MIN00)
	 DECYR1 = DBLE(IYEAR1) + DBLE(MINO1 - MIN00)/525600.D0
         CALL TOTIME(IYEAR2,MONTH2,IDAY2,MINO2)
	 CALL TOTIME(IYEAR2, 1, 1, MIN00)
	 DECYR2 = DBLE(IYEAR2) + DBLE(MINO2 - MIN00)/525600.D0
         MINO = (MINO1 + MINO2) / 2
	 DECYR = (DECYR1 + DECYR2) / 2.D0
         CALL RFCON(IBBREF, JREF)
         IF (KOPT .NE. -1) THEN
            CARD(52:53) = NRF
         ENDIF

      ELSEIF(TYPE .eq. 'F') THEN
         READ(CARD,140) ISN, DX, DY, DZ, JSN
  140    FORMAT(BZ,1X,I5,3X,F13.4,5X,F13.4,5X,F13.4,T81,I5)

         SUBCRD = CARD(1:80)
         CALL CHECK(ISN, JSN, SUBCRD, TEST)
         IF (TEST) THEN
            CALL DDXYZ(ISN, JSN,                                 
     1              MINO,MIN2,DDX, DDY, DDZ)

	    call TRAVEC( DX, DY, DZ, DECYR, JREF, IOPT)

            DX = DX + DDX
            DY = DY + DDY
            DZ = DZ + DDZ

*** Convert GPS vector to outout reference frame
            IF (KOPT .NE. -1) THEN
               CALL TRAVEC(DX, DY, DZ, DATE2, IOPT, KOPT)
            ELSE
	       CALL TRAVEC(DX, DY, DZ, DATE2, IOPT, JREF)
            ENDIF

*** Rewrite GPS observational record
            CALL TOCHAR(DX,CHAR14)
            CARD(10:22) = CHAR14(1:13)

            CALL TOCHAR(DY,CHAR14)
            CARD(28:40) = CHAR14(1:13)           

            CALL TOCHAR(DZ,CHAR14)
            CARD(46:58) = CHAR14(1:13)
 
            ISHIFT = IDNINT(DDX * 10000.D0)
            WRITE(CARD(115:121),150) ISHIFT
  150       FORMAT(I7)

            ISHIFT = IDNINT(DDY * 10000.D0)
            WRITE(CARD(125:131),150) ISHIFT

            ISHIFT = IDNINT(DDZ * 10000.D0)
            WRITE(CARD(135:141),150) ISHIFT
         ENDIF

      ENDIF
      WRITE(I2,100) CARD
      GO TO 90
  200 CONTINUE
      RETURN
      END
*********************************************************

      SUBROUTINE TODMSS(val,id,im,s,isign)
 
*** convert position radians to deg,min,sec
*** range is [-twopi to +twopi]
 
      implicit double precision(a-h,o-z)
      IMPLICIT INTEGER*4 (I-N)
      common/CONST/A,F,E2,EP2,AF,PI,TWOPI,RHOSEC
 
    1 if(val.gt.twopi) then
        val=val-twopi
        go to 1
      endif
 
    2 if(val.lt.-twopi) then
        val=val+twopi
        go to 2
      endif
 
      if(val.lt.0.d0) then
        isign=-1
      else
        isign=+1
      endif
 
      s=dabs(val*RHOSEC/3600.D0)
      id=idint(s)
      s=(s-id)*60.d0
      im=idint(s)
      s=(s-im)*60.d0
 
*** account for rounding error
 
      is=idnint(s*1.d5)
      if(is.ge.6000000) then
        s=0.d0
        im=im+1
      endif
      if(im.ge.60) then
        im=0
        id=id+1
      endif
 
      return
      end
*********************************************************
      SUBROUTINE SETRF

*** Specify arrays that may be used to convert
*** a reference frame identifier in the blue book
*** to a reference frame identifier in HTDP and back

      IMPLICIT INTEGER*4 (I-N)
      parameter ( numref = 14 )
      COMMON /REFCON/ IRFCON(26), JRFCON(numref)

*** From blue book identifier to HTDP indentifier
*** WGS 72 Precise
      IRFCON(1) = 10

*** WGS 84 (orig) Precise (set  equal to NAD 83)
      IRFCON(2) = 1

*** WGS 72 Broadcast
      IRFCON(3) = 10

*** WGS 84 (orig) Broadcast (set equal to NAD 83)
      IRFCON(4) = 1

*** ITRF89
      IRFCON(5) = 3

*** PNEOS 90 or NEOS 91.25 (set equal to ITRF90)
      IRFCON(6) = 4

*** NEOS 90 (set equal to ITRF90)
      IRFCON(7) = 4

*** ITRF91
      IRFCON(8) = 5

*** SIO/MIT 92.57 (set equal to ITRF91)
      IRFCON(9) = 5

*** ITRF91
      IRFCON(10) = 5

*** ITRF92
      IRFCON(11) = 6

*** ITRF93
      IRFCON(12) = 7

*** WGS 84 (G730) Precise (set equal to ITRF92)
      IRFCON(13) = 6

*** WGS 84 (G730) Broadcast (set equal to ITRF92)
      IRFCON(14) = 6

*** ITRF94
      IRFCON(15) = 8

*** WGS 84 (G873) Precise  (set equal to ITRF94)
      IRFCON(16) = 8

*** WGS 84 (G873) Broadcast (set equal to ITRF94)
      IRFCON(17) = 8

*** ITRF96
      IRFCON(18) = 8

*** ITRF97
      IRFCON(19) = 9

*** IGS97
      IRFCON(20) = 9

*** ITRF00
      IRFCON(21) = 11

*** IGS00
      IRFCON(22) = 11

*** WGS 84 (G1150)
      IRFCON(23) = 11

*** IGb00
      IRFCON(24) = 11

*** ITRF2005
      IRFCON(25) = 14

*** IGS05
      IRFCON(26) = 14

*** From HTDP identifier to blue book identifier
*** NAD 83 (set equal to WGS 84 (transit))
      JRFCON(1) = 2

*** ITRF88 (set equal to ITRF89)
      JRFCON(2) = 5

*** ITRF89
      JRFCON(3) = 5

*** ITRF90 (set equal to NEOS 90)
      JRFCON(4) = 7

*** ITRF91
      JRFCON(5) = 8

*** ITRF92
      JRFCON(6) = 11

*** ITRF93
      JRFCON(7) = 12

*** ITRF96 (= ITRF94)
      JRFCON(8) = 18

*** ITRF97
      JRFCON(9) = 19

*** WGS 72
      JRFCON(10) = 1

*** ITRF00
      JRFCON(11) = 21

*** NAD 83 (PACP00)
      JRFCON(12) = 0

*** NAD 83 (MARP00)
      JRFCON(13) = 0

*** ITRF2005
      JRFCON(14) = 26

      RETURN
      END
***************************************************
      SUBROUTINE RFCON(IBBREF, JREF)

*** Convert reference frame identifier from
*** system used in the blue-book to the
*** system used in HTDP

      IMPLICIT INTEGER*4 (I-N)
      parameter ( numref = 14 )
      COMMON /REFCON/ IRFCON(26), JRFCON(numref)

      IF (1 .LE. IBBREF .AND. IBBREF .LE. 26) THEN
          JREF = IRFCON(IBBREF)
      ELSE
          WRITE(6, 10) IBBREF
   10     FORMAT(' Improper reference frame identifier (=',
     1      I4, ')' /
     1      ' appearing in B-record of the G-FILE')
          STOP
       ENDIF

       RETURN
       END
*******************************************************

      SUBROUTINE RFCON1(JREF, IBBREF)

*** Convert reference frame identifier from
*** system used in HTDP to the  system
*** used in the blue-book

      IMPLICIT INTEGER*4 (I-N)
      parameter ( numref = 14 )
      COMMON /REFCON/ IRFCON(26), JRFCON(numref)

      IF (JREF .EQ. 0) THEN
         I = 1
      ELSE
         I = JREF
      ENDIF

      IF(1. LE. I .AND. I .LE. numref) THEN
          IBBREF = JRFCON(I)
	  IF ( IBBREF .eq. 0) THEN
	     write(6,5) JREF
    5        format(' ERROR: The BlueBook does not recognize '/
     *              'this reference frame, HTDP ID = ',I2)
	     stop
          ENDIF

      ELSE
          WRITE(6, 10) JREF
   10     FORMAT(' Improper reference frame identifier (=',
     *       I4, ')' / 'appearing in routine RFCON1')
          STOP
      ENDIF

      RETURN
      END
*****************************************************************

      subroutine TRAVEC(dxi, dyi, dzi, date, jopt1, jopt2)

*** Transform GPS or other vector from one reference frame to another
*** for the given date                                     

*** (dxi, dyi, dzi) --> (input) components of input vector in meters
***                 --> (output) components of transformed vector in meters

*** date --> (input) time (decimal years) to which the input & output
***          vectors correspond

*** jopt1 --> (input) specifier of reference frame for input vector
*** jopt2 --> (input) specifier of reference frame for output vector

      implicit double precision (a-h, o-z)
      implicit integer*4 (i-n)
      parameter (numref = 14)

      common /tranpa/ tx(numref), ty(numref), tz(numref), 
     &                dtx(numref), dty(numref), dtz(numref),
     &                rx(numref), ry(numref), rz(numref), 
     &                drx(numref), dry(numref), drz(numref),
     &                scale(numref), dscale(numref), refepc(numref)

*** Transform input vector to ITRF94 reference frame
      if (jopt1 .eq. 0) then
         iopt = 1
      else
         iopt = jopt1
      endif

      dtime = date - refepc(iopt)
      rotnx  = -(rx(iopt) + drx(iopt)*dtime)
      rotny  = -(ry(iopt) + dry(iopt)*dtime)
      rotnz  = -(rz(iopt) + drz(iopt)*dtime)
      ds     = 1.d0 - (scale(iopt) + dscale(iopt)*dtime)

      dxt = + ds*dxi + rotnz*dyi - rotny*dzi
      dyt = - rotnz*dxi + ds*dyi + rotnx*dzi
      dzt = + rotny*dxi - rotnx*dyi + ds*dzi

*** Transform ITRF94 vector to new reference frame
      if (jopt2 .eq. 0) then
         iopt = 1
      else
         iopt = jopt2
      endif

      dtime = date - refepc(iopt)
      rotnx  = rx(iopt) + drx(iopt)*dtime
      rotny  = ry(iopt) + dry(iopt)*dtime
      rotnz  = rz(iopt) + drz(iopt)*dtime
      ds     = 1.d0 + scale(iopt) + dscale(iopt)*dtime

      dxi = + ds*dxt + rotnz*dyt - rotny*dzt
      dyi = - rotnz*dxt + ds*dyt + rotnx*dzt
      dzi = + rotny*dxt - rotnx*dyt + ds*dzt

      return
      end

***********************************************************
      SUBROUTINE GETPNT(LATD,LATM,SLAT,LATDIR,LOND,LONM,SLON,
     1     LONDIR, NAME, X,Y,Z,XLAT,XLON,EHT)
   
*** Interactively obtain name and coordinates for a point.
*** Output longitude will be positive west.

      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      IMPLICIT INTEGER*4 (I-N)
      CHARACTER*24 NAME
      CHARACTER*1 COPT,LATDIR,LONDIR
      LOGICAL FRMXYZ
      COMMON /FILES/ LUIN,LUOUT, I1, I2, I3, I4, I5
      COMMON /CONST/ A,F,E2,EPS,AF,PI,TWOPI,RHOSEC

      WRITE(LUOUT,100)
  100 FORMAT(' Enter name for point (24 character max).  ')
      READ(LUIN,105) NAME
  105 FORMAT(A24)

  110 WRITE(LUOUT,111)
  111 FORMAT(' How do you wish to specify positional coordinates:'/
     1       '     1...geodetic latitude and longitude'/
     2       '     2...Cartesian (X,Y,Z) coordinates.  ')
      READ(LUIN,'(A1)') COPT

      IF(COPT .EQ. '1') THEN
	  WRITE(LUOUT,115)
  115     FORMAT(
     1    ' Enter latitude degrees-minutes-seconds in free format'/,
     2    ' with north being positive. For example,    35,17,28.3  '/
     2    ' For a point in the southern hemisphere, enter a minus sign'/
     3    ' before each value. For example, -35,-17,-28.3')
	  READ(LUIN,*) LATD, LATM, SLAT
	  WRITE(LUOUT,120)
  120     FORMAT(
     1    ' Enter longitude degrees-minutes-seconds in free format'/,
     2    ' with west being positive.  To express a longitude measured'/
     3    ' eastward, enter a minus sign before each value.')
	  READ(LUIN,*) LOND, LONM, SLON

          WRITE(LUOUT, 125)
  125     FORMAT(
     1    ' Enter ellipsoid height in meters. (Note that'/,
     1    ' predicted motions are independent of this height.)  ')
          READ(LUIN,*) EHT

          XLAT =  (DBLE((LATD*60 + LATM)*60) + SLAT)/RHOSEC
	  LATDIR = 'N'
	  IF (XLAT .lt. 0.0D0) then
	     LATD = - LATD
	     LATM = - LATM
	     SLAT = - SLAT
	     LATDIR = 'S'
          ENDIF
          XLON = (DBLE((LOND*60 + LONM)*60) + SLON)/RHOSEC
	  ELON = -XLON
          CALL TOXYZ(XLAT,ELON,EHT,X,Y,Z)
	  LONDIR = 'W'
	  IF (XLON .lt. 0.0D0) then
	     LOND = -LOND
	     LONM = -LONM
	     SLON = -SLON
	     LONDIR = 'E'
          ENDIF

      ELSEIF(COPT .EQ. '2') THEN
          WRITE(LUOUT,130)
  130     FORMAT(' Enter X coordinate in meters.  ')
          READ(LUIN,*) X
          WRITE(LUOUT,140)
  140     FORMAT(' Enter Y coordinate in meters.  ')
          READ(LUIN,*) Y
          WRITE(LUOUT,150)
  150     FORMAT(' Enter Z coordinate in meters.  ')
          READ(LUIN,*) Z
          IF(.NOT.FRMXYZ(X,Y,Z,XLAT,XLON,EHT)) STOP 666
          XLON = -XLON
          IF(XLON .LT. 0.0D0) XLON = XLON + TWOPI
          CALL TODMSS(XLAT,LATD,LATM,SLAT,ISIGN)
	  LATDIR = 'N'
	  IF (ISIGN .eq. -1) LATDIR = 'S'
          CALL TODMSS(XLON,LOND,LONM,SLON,ISIGN)
	  LONDIR = 'W'
	  IF (ISIGN .eq. -1) LONDIR = 'E'

      ELSE
          WRITE(LUOUT,*) ' Improper response -- try again.  '
          GO TO 110
      ENDIF

      RETURN
      END
*****************************************************************
      SUBROUTINE GETVLY(GLAT, GLON, VX, VY, VZ,
     1      VNORTH, VEAST, VUP, VOPT, IFORM)

*** Interactively optain velocity for a point

      IMPLICIT DOUBLE PRECISION (A-H, O-Z)
      IMPLICIT INTEGER*4 (I-N)
      CHARACTER*1 VOPT
      COMMON /FILES/ LUIN, LUOUT, I1, I2, I3, I4, I5

  200 CONTINUE
      IF (IFORM .eq. 210) then
         WRITE(LUOUT, 210)
  210    FORMAT(' What is the velocity of this site relative to '/ 
     1       ' the input reference frame:'/ 
     1       '     0...use velocity predicted by this software.'/ 
     1       '     1...user will specify the north-east-up'/ 
     1       '         components of site velocity.'/ 
     1       '     2...user will specify the global x-y-z'/
     1       '         components of site velocity.' )
      else
	write(luout, 211)
  211   FORMAT(' How do you wish to specify the velocity: '/
     1       '     1...north-east-up components.'/
     1       '     2...global x-y-z components.' )
      endif

      READ(LUIN, '(A1)') VOPT

      IF (VOPT .EQ. '0') THEN
	 CONTINUE

      ELSEIF (VOPT .EQ. '1') THEN
	 WRITE(LUOUT, 220)
  220    FORMAT( ' Enter north-south component of velocity in mm/yr'/
     1           ' with north being positive and south being negative')
	 READ(LUIN, *) VNORTH
	 WRITE(LUOUT, 221)
  221    FORMAT( ' Enter east-west component of velocity in mm/yr'/
     1           ' with east being positive and west being negative')
	 READ(LUIN, *) VEAST
	 WRITE(LUOUT, 222)
  222    FORMAT( ' Enter vertical component of velocity in mm/yr'/
     1           ' with up being positive and down being negative'/
     1           ' or enter 0.0 if unknown.')
	 READ(LUIN, *) VUP
	 CALL TOVXYZ( GLAT, GLON, VNORTH, VEAST, VUP, VX, VY, VZ)

      ELSEIF (VOPT .EQ. '2') THEN
	 WRITE(LUOUT, *) ' Enter x-component of velocity in mm/yr.'
	 READ(LUIN, *) VX
	 WRITE(LUOUT, *) ' Enter y-component of velocity in mm/yr.'
	 READ(LUIN, *) VY
	 WRITE(LUOUT, *) ' Enter z-component of velocity in mm/yr.'
	 READ(LUIN, *) VZ
	 CALL TOVNEU(GLAT, GLON, VX, VY, VZ, VNORTH, VEAST, VUP)

      ELSE
	 WRITE(LUOUT, *) 'Improper response -- try again. '
	 GO TO 200

      ENDIF
      RETURN
      END

************************************************************************

      SUBROUTINE COMPSN(YLATT,YLONT,HTT,YLAT,YLON,HT,
     1                  MIN,VN, VE, VU)

*** Compute the position of a point at specified time
*** Upon input VN, VE, and VU are in mm/yr

      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      IMPLICIT INTEGER*4 (I-N)
      parameter (NDLOC = 1990)

      COMMON /CONST/ A,F,E2,EPS,AF,PI,TWOPI,RHOSEC
      COMMON /TIMREF/ ITREF
      COMMON /QPARM/ STRIKE(NDLOC), HL(NDLOC), EQLAT(NDLOC),
     1          EQLON(NDLOC), SSLIP(NDLOC), DSLIP(NDLOC),
     1          DIP(NDLOC), DEPTH(NDLOC), WIDTH(NDLOC),
     1               EQLATR(50),EQLONR(50),EQRAD(50),
     1               ITEQK(50),NLOC(50),NFP(50),NUMEQ
      COMMON /FILES/ LUIN,LUOUT, I1, I2, I3, I4, I5

** Compute the contribution due to constant velocity
         DTIME = DBLE(MIN - ITREF) / 525960.D0
         CALL RADR8T(YLAT,VN,VE,VNR,VER)
         YLATT = YLAT + VNR*DTIME
         YLONT = YLON - VER*DTIME
         HTT   = HT + ((VU * DTIME) /1000.D0)
       
** Compute the contribution due to earthquakes.
** It is assumed that the components of displacement,
** DNORTH,DWEST,DUP, do not vary from one reference
** frame to another given the accuracy of dislocation
** models.
      DO 10 I = 1, NUMEQ
          IF(ITEQK(I) .GT. ITREF) THEN 
               NTIME = 1
          ELSE
	       NTIME = 0
          ENDIF
	  IF(MIN .LT. ITEQK(I)) NTIME = NTIME - 1
	  IF(NTIME .NE. 0) THEN 
             CALL RADII(EQLATR(I),RADMER,RADPAR)
             DDLAT = (YLAT - EQLATR(I))*RADMER
             DDLON = (YLON - EQLONR(I))*RADPAR
             DIST = DSQRT(DDLAT*DDLAT + DDLON*DDLON)
             IF(DIST .LE. EQRAD(I)) THEN
               ISTART = NLOC(I)
               IEND = NLOC(I) + NFP(I) - 1
               DO 5 JREC = ISTART,IEND
                 CALL DISLOC(YLAT,YLON,STRIKE(JREC),HL(JREC),
     &              EQLAT(JREC),EQLON(JREC),SSLIP(JREC),     
     &              DSLIP(JREC),DIP(JREC),DEPTH(JREC),
     &              WIDTH(JREC),DNORTH,DWEST,DUP)     
                 YLATT = YLATT + NTIME*DNORTH
                 YLONT = YLONT + NTIME*DWEST     
                 HTT   = HTT   + NTIME*DUP
    5          CONTINUE
             ENDIF
          ENDIF  
   10 CONTINUE
      RETURN
      END
***************************************************************

      SUBROUTINE NEWCOR(YLAT,YLON,HTOLD,MIN1,MIN2,
     1         YLAT3,YLON3,HTNEW,DN,DE,DU,VN, VE, VU)

*** Predict coordinates at time MIN2 given coordinates at time MIN1.
*** Predict displacements from time MIN1 to time MIN2.

      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      IMPLICIT INTEGER*4 (I-N)

      HT = HTOLD

      CALL COMPSN(YLAT1,YLON1,HT1,YLAT,YLON,HT,
     1            MIN1,VN, VE, VU)

      CALL COMPSN(YLAT2,YLON2,HT2,YLAT,YLON,HT,
     1            MIN2, VN, VE, VU)

      YLAT3 = YLAT + YLAT2 - YLAT1
      YLON3 = YLON + YLON2 - YLON1
      HTNEW   = HT   + HT2   - HT1

      CALL RADII(YLAT,RADMER,RADPAR)

      DN =  RADMER * (YLAT2 - YLAT1)
      DE = -RADPAR * (YLON2 - YLON1)
      DU =  HT2 - HT1

      RETURN
      END
******************************************************************


      subroutine PREDV(ylat, ylon, eht, date, iopt,
     1   jregn, vn, ve, vu) 

** Predict velocity in iopt reference frame       

** ylat       input - north latitude (radians)
** ylon       input - west longitude (radians)
** eht        input - ellipsoid height (meters)
** date       input - date (decimal years)
** iopt       input - reference frame
** jregn      output - deformation region
** vn         output - northward velocity in mm/yr
** ve         output - eastward velocity in mm/yr
** vu         output - upward velocity in mm/yr

      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      IMPLICIT INTEGER*4 (I-N)

** Get reference latitude (RLAT) and reference longitude (RLON)
         IF(IOPT .EQ. 0 .OR. IOPT .EQ. 1) THEN
             RLAT = YLAT
             RLON = YLON
         ELSE
             elon = -ylon
             call TOXYZ(ylat, elon, eht, x, y, z)
             CALL XTONAD(X,Y,Z,RLAT,RLON,EHTNAD,DATE,IOPT)
         ENDIF

** Get deformation region
         CALL GETREG(RLAT,RLON,JREGN)
	 IF (JREGN .EQ. 0) THEN
	    VN = 0.D0
	    VE = 0.D0
	    VU = 0.D0
	    RETURN
         ENDIF
	 CALL COMVEL( RLAT, RLON, JREGN, VN, VE, VU)
** Convert  velocity to reference of iopt, if iopt != NAD83
	 IF (IOPT .NE. 0 .AND. IOPT .NE. 1) THEN
	    CALL TOVXYZ( YLAT, ELON, VN, VE, VU, VX, VY, VZ)
	    CALL VTRANF( X, Y, Z, VX, VY, VZ, 1, IOPT)
	    CALL TOVNEU( YLAT, ELON, VX, VY, VZ, VN, VE, VU)
         ENDIF

         RETURN
         END

****************************************************************

      subroutine TRFVEL

*** Transform velocities from one reference frame to another

      implicit double precision (a-h, o-z)
      implicit integer*4 (i-n)
      parameter (numref = 14)
      character*30 namef
      character*24 name24
      character*16 frame1, frame2
      character*1 option
      character*1 vopt, LATDIR, LONDIR
      COMMON /FILES/ LUIN, LUOUT, I1, I2, I3, I4, I5

      write( luout, 100)
  100 format(
     1  ' Please enter the name of the file to contain '/
     1  ' the transformed velocities. ')
      read( luin, '(a30)') namef
      open( i2, file = namef, status = 'unknown')
      CALL HEADER

  105 write( luout, 110)
  110 format( /'*******************************'/
     1   ' Enter the reference frame of the input velocities.')
      call MENU1(iopt1, frame1)
      if (iopt1 .lt. 1 .or. iopt1 .gt. numref) then
	 write( luout, *) ' Improper selection -- try again.'
	 go to 105
      endif

  115 write( luout, 120)
  120 format( /' Enter the reference frame for the output velocities.')
      call MENU1(iopt2, frame2)
      if (iopt2 .lt. 1 .or. iopt2 .gt. numref) then
	 write( luout, *) 'Improper selection -- try again.'
	 go to 115
      endif

      write( i2, 125) frame1, frame2
  125 format( ' TRANSFORMING VELOCITIES FROM ', A16, ' TO ', a16//
     1   16X, ' INPUT VELOCITIES      OUTPUT VELOCITIES'/)

  130 write( luout, 140)
  140 format( /'**********************************'/
     1  ' Velocities will be transformed at each specified point.'/
     1  ' Please indicate how you wish to input points.'/
     1  '    0...No more points.  Return to main menu.'/
     1  '    1...Individual points entered interactively.')
      read( luin, '(a1)') option

      if (option .eq. '0') then
	 go to 500

      elseif (option .eq. '1') then
	 call GETPNT( latd, latm, slat, LATDIR, lond, lonm, slon,
     1       LONDIR, name24, x, y, z, ylat, ylon, eht)
	 elon = - ylon
	 call GETVLY( ylat, elon, vx, vy, vz, vn, ve, vu, vopt, 211)
	 vx1 = vx
	 vy1 = vy
	 vz1 = vz
	 call VTRANF( x, y, z, vx1, vy1, vz1, iopt1, iopt2)
	 call TOVNEU( ylat, elon, vx1, vy1, vz1, vn1, ve1, vu1)
	 call PRNTVL( vn, ve, vu, vx, vy, vz, vn1, ve1, vu1,
     1                vx1, vy1, vz1, name24, 1)

	 go to 130
      endif
  500 continue
      return
      end
*******************************************************************

      SUBROUTINE VTRANF(X,Y,Z,VX,VY,VZ, IOPT1, IOPT2)

*** Convert velocity from reference frame of IOPT1 to 
*** reference frame of IOPT2.

      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      IMPLICIT INTEGER*4 (I-N)
      parameter (numref = 14)
      common /tranpa/ tx(numref), ty(numref), tz(numref),
     &                dtx(numref), dty(numref), dtz(numref),
     &                rx(numref), ry(numref), rz(numref),
     &                drx(numref), dry(numref), drz(numref),
     &                scale(numref), dscale(numref), refepc(numref)
      COMMON /FILES/ LUIN, LUOUT, I1, I2, I3, I4, I5

      IF(IOPT1 .le. numref .and. IOPT2. le. numref
     &   .and. IOPT1 .gt. 0 .and. IOPT2 .gt. 0 ) THEN

*** Convert from mm/yr to m/yr
         VX = VX /1000.d0
         VY = VY / 1000.d0
         VZ = VZ / 1000.d0

*** From IOPT1 to ITRF94 
*** (following equations use approximations assuming
*** that rotations and scale change are small)
         WX = -drx(iopt1)           
         WY = -dry(iopt1)      
         WZ = -drz(iopt1)      
	 DS = -dscale(iopt1)
         VX = VX - dtx(iopt1) + DS*X + WZ*Y - WY*Z
         VY = VY - dty(iopt1) - WZ*X  +DS*Y + WX*Z
         VZ = VZ - dtz(iopt1) + WY*X - WX*Y + DS*Z

*** From ITRF94 to IOPT2 reference frame
*** (following equations use approximations assuming
***  that rotations and scale change are small)
         WX = drx(iopt2)
         WY = dry(iopt2)
         WZ = drz(iopt2)
	 DS = dscale(iopt2)
         VX = VX + dtx(iopt2) + DS*X + WZ*Y - WY*Z
         VY = VY + dty(iopt2) - WZ*X + DS*Y + WX*Z 
         VZ = VZ + dtz(iopt2) + WY*X - WX*Y + DS*Z

*** FROM m/yr to mm/yr
         VX = VX * 1000.d0
         VY = VY * 1000.d0
         VZ = VZ * 1000.d0

      ELSE
         write(luout,*) ' Improper reference frame in routine vtranf'
         stop
      ENDIF

      RETURN
      END
******************************************************

      subroutine PRNTVL(VN, VE, VU, VX, VY, VZ, VN1, VE1, VU1,
     1                  VX1, VY1, VZ1, NAME24, IPRINT)

*** Print transformed velocities

      implicit double precision (a-h, o-z)
      implicit integer*4 (i-n)
      character*24 name24
      COMMON /FILES/ LUIN, LUOUT, I1, I2, I3, I4, I5

      if (iprint .eq. 1) then
      write( luout, 100) vn1, ve1, vu1, vx1, vy1, vz1
  100 format( ' ****************************************'/
     1  ' New northward velocity = ', f8.2, ' mm/yr' /
     1  ' New eastward velocity  = ', f8.2, ' mm/yr'/
     1  ' New upward velocity    = ', f8.2, ' mm/yr'/
     1  ' New x velocity         = ', f8.2, ' mm/yr'/
     1  ' New y velocity         = ', f8.2, ' mm/yr'/
     1  ' New z velocity         = ', f8.2, ' mm/yr'/)
      endif 

      write( i2, 200) name24, vn, vn1, ve, ve1, vu, vu1,
     1    vx, vx1, vy, vy1, vz, vz1
  200 format(1x, a24 /
     1   5x, 'northward velocity ', f8.2, 6x, f8.2, ' mm/yr' /
     1   5x, 'eastward velocity  ', f8.2, 6x, f8.2, ' mm/yr' /
     1   5x, 'upward velocity    ', f8.2, 6x, f8.2, ' mm/yr' /
     1   5x, 'x velocity         ', f8.2, 6x, f8.2, ' mm/yr' /
     1   5x, 'y velocity         ', f8.2, 6x, f8.2, ' mm/yr' /
     1   5x, 'z velocity         ', f8.2, 6x, f8.2, ' mm/yr' /)

      return 
      end
*******************************************************************
       SUBROUTINE HEADER

       IMPLICIT DOUBLE PRECISION (A-H, O-Z)
       IMPLICIT INTEGER*4 (I-N)
       COMMON /FILES/ LUIN, LUOUT, I1, I2, I3, I4, I5

       WRITE(I2, 10)
   10  FORMAT(' HTDP (version 3.0) OUTPUT' / )
       RETURN
       END

      BLOCK DATA INITBD
      IMPLICIT DOUBLE PRECISION (A-H, O-Z)
      IMPLICIT INTEGER*4 (I-N)
      parameter (NMREGN = 11)
      COMMON /BNDRY/ X(40,NMREGN), Y(40,NMREGN), NPOINT(NMREGN)
      
      DATA  X( 1, 1), Y( 1, 1) /  31.00,  114.00/
      DATA  X( 2, 1), Y( 2, 1) /  36.00,  114.00/
      DATA  X( 3, 1), Y( 3, 1) /  36.00,  121.00/
      DATA  X( 4, 1), Y( 4, 1) /  31.00,  121.00/
      DATA  X( 1, 2), Y( 1, 2) /  36.00,  119.00/
      DATA  X( 2, 2), Y( 2, 2) /  40.00,  119.00/
      DATA  X( 3, 2), Y( 3, 2) /  40.00,  125.00/
      DATA  X( 4, 2), Y( 4, 2) /  36.00,  125.00/
      DATA  X( 1, 3), Y( 1, 3) /  40.00,  122.00/
      DATA  X( 2, 3), Y( 2, 3) /  49.00,  122.00/
      DATA  X( 3, 3), Y( 3, 3) /  49.00,  125.00/
      DATA  X( 4, 3), Y( 4, 3) /  40.00,  125.00/
      DATA  X( 1, 4), Y( 1, 4) /  31.00,  100.00/
      DATA  X( 2, 4), Y( 2, 4) /  49.00,  100.00/
      DATA  X( 3, 4), Y( 3, 4) /  49.00,  125.00/
      DATA  X( 4, 4), Y( 4, 4) /  31.00,  125.00/
      DATA  X( 1, 5), Y( 1, 5) /  55.00,  131.00/
      DATA  X( 2, 5), Y( 2, 5) /  56.00,  131.00/
      DATA  X( 3, 5), Y( 3, 5) /  56.00,  132.00/
      DATA  X( 4, 5), Y( 4, 5) /  55.00,  132.00/
      DATA  X( 1, 6), Y( 1, 6) /  89.00,  180.00/
      DATA  X( 2, 6), Y( 2, 6) /  50.00,  180.00/
      DATA  X( 3, 6), Y( 3, 6) /  51.00,  171.00/
      DATA  X( 4, 6), Y( 4, 6) /  54.00,  159.00/
      DATA  X( 5, 6), Y( 5, 6) /  56.00,  152.00/
      DATA  X( 6, 6), Y( 6, 6) /  59.00,  146.00/
      DATA  X( 7, 6), Y( 7, 6) /  60.00,  140.00/
      DATA  X( 8, 6), Y( 8, 6) /  51.00,  131.00/
      DATA  X( 9, 6), Y( 9, 6) /  49.00,  126.00/
      DATA  X(10, 6), Y(10, 6) /  41.00,  125.00/
      DATA  X(11, 6), Y(11, 6) /  38.00,  123.00/
      DATA  X(12, 6), Y(12, 6) /  33.00,  116.00/
      DATA  X(13, 6), Y(13, 6) /  24.00,  109.00/
      DATA  X(14, 6), Y(14, 6) /  22.00,  108.00/
      DATA  X(15, 6), Y(15, 6) /  21.00,  107.00/
      DATA  X(16, 6), Y(16, 6) /  19.00,  106.00/
      DATA  X(17, 6), Y(17, 6) /  16.00,   98.00/
      DATA  X(18, 6), Y(18, 6) /  16.00,   87.00/
      DATA  X(19, 6), Y(19, 6) /  18.00,   82.00/
      DATA  X(20, 6), Y(20, 6) /  20.00,   71.00/
      DATA  X(21, 6), Y(21, 6) /  20.00,   63.00/
      DATA  X(22, 6), Y(22, 6) /  16.00,   59.00/
      DATA  X(23, 6), Y(23, 6) /  16.00,   47.00/
      DATA  X(24, 6), Y(24, 6) /  28.00,   44.00/
      DATA  X(25, 6), Y(25, 6) /  39.00,   30.00/
      DATA  X(26, 6), Y(26, 6) /  50.00,   29.00/
      DATA  X(27, 6), Y(27, 6) /  54.00,   35.00/
      DATA  X(28, 6), Y(28, 6) /  64.00,   22.00/
      DATA  X(29, 6), Y(29, 6) /  66.00,   18.00/
      DATA  X(30, 6), Y(30, 6) /  72.00,    0.00/
      DATA  X(31, 6), Y(31, 6) /  74.00,   -9.00/
      DATA  X(32, 6), Y(32, 6) /  89.00,   -9.00/
      DATA  X( 1, 7), Y( 1, 7) /  16.00,   98.00/
      DATA  X( 2, 7), Y( 2, 7) /  16.00,   87.00/
      DATA  X( 3, 7), Y( 3, 7) /  18.00,   82.00/
      DATA  X( 4, 7), Y( 4, 7) /  20.00,   71.00/
      DATA  X( 5, 7), Y( 5, 7) /  20.00,   63.00/
      DATA  X( 6, 7), Y( 6, 7) /  16.00,   59.00/
      DATA  X( 7, 7), Y( 7, 7) /  11.00,   58.00/
      DATA  X( 8, 7), Y( 8, 7) /  12.00,   66.00/
      DATA  X( 9, 7), Y( 9, 7) /  13.00,   73.00/
      DATA  X(10, 7), Y(10, 7) /   7.00,   79.00/
      DATA  X(11, 7), Y(11, 7) /   8.00,   85.00/
      DATA  X( 1, 8), Y( 1, 8) /  50.00,  193.00/
      DATA  X( 2, 8), Y( 2, 8) /  51.00,  171.00/
      DATA  X( 3, 8), Y( 3, 8) /  54.00,  159.00/
      DATA  X( 4, 8), Y( 4, 8) /  56.00,  152.00/
      DATA  X( 5, 8), Y( 5, 8) /  59.00,  146.00/
      DATA  X( 6, 8), Y( 6, 8) /  60.00,  140.00/
      DATA  X( 7, 8), Y( 7, 8) /  51.00,  131.00/
      DATA  X( 8, 8), Y( 8, 8) /  49.00,  131.00/
      DATA  X( 9, 8), Y( 9, 8) /  49.00,  129.00/
      DATA  X(10, 8), Y(10, 8) /  45.00,  130.00/
      DATA  X(11, 8), Y(11, 8) /  43.00,  127.00/
      DATA  X(12, 8), Y(12, 8) /  41.00,  125.00/
      DATA  X(13, 8), Y(13, 8) /  38.00,  123.00/
      DATA  X(14, 8), Y(14, 8) /  33.00,  116.00/
      DATA  X(15, 8), Y(15, 8) /  24.00,  109.00/
      DATA  X(16, 8), Y(16, 8) /  22.00,  108.00/
      DATA  X(17, 8), Y(17, 8) /  20.00,  109.00/
      DATA  X(18, 8), Y(18, 8) /  15.00,  105.00/
      DATA  X(19, 8), Y(19, 8) /   2.00,  102.00/
      DATA  X(20, 8), Y(20, 8) / -35.00,  111.00/
      DATA  X(21, 8), Y(21, 8) / -56.00,  122.00/
      DATA  X(22, 8), Y(22, 8) / -66.00,  193.00/
      DATA  X( 1, 9), Y( 1, 9) /  51.00,  131.00/
      DATA  X( 2, 9), Y( 2, 9) /  49.00,  126.00/
      DATA  X( 3, 9), Y( 3, 9) /  41.00,  125.00/
      DATA  X( 4, 9), Y( 4, 9) /  43.00,  127.00/
      DATA  X( 5, 9), Y( 5, 9) /  45.00,  130.00/
      DATA  X( 6, 9), Y( 6, 9) /  49.00,  129.00/
      DATA  X( 7, 9), Y( 7, 9) /  49.00,  131.00/
      DATA  X( 1,10), Y( 1,10) /  22.00,  108.00/
      DATA  X( 2,10), Y( 2,10) /  21.00,  107.00/
      DATA  X( 3,10), Y( 3,10) /  19.00,  106.00/
      DATA  X( 4,10), Y( 4,10) /  16.00,   98.00/
      DATA  X( 5,10), Y( 5,10) /   8.00,   85.00/
      DATA  X( 6,10), Y( 6,10) /   7.00,   79.00/
      DATA  X( 7,10), Y( 7,10) /   2.00,   85.00/
      DATA  X( 8,10), Y( 8,10) /   2.00,  102.00/
      DATA  X( 9,10), Y( 9,10) /  15.00,  105.00/
      DATA  X(10,10), Y(10,10) /  20.00,  109.00/
      DATA  X( 1,11), Y( 1,11) /  13.00,  214.00/
      DATA  X( 2,11), Y( 2,11) /  13.00,  216.00/
      DATA  X( 3,11), Y( 3,11) /  16.00,  216.00/
      DATA  X( 4,11), Y( 4,11) /  16.00,  214.00/
     
      DATA
     * NPOINT( 1) / 4/,
     * NPOINT( 2) / 4/,
     * NPOINT( 3) / 4/,
     * NPOINT( 4) / 4/,
     * NPOINT( 5) / 4/,
     * NPOINT( 6) /32/,
     * NPOINT( 7) /11/,
     * NPOINT( 8) /22/,
     * NPOINT( 9) / 7/,
     * NPOINT(10) /10/,
     * NPOINT(11) / 4/
  
      END

      BLOCK DATA INITVL
      IMPLICIT DOUBLE PRECISION (A-H, O-Z)
      IMPLICIT INTEGER*4 (I-N)
      parameter (NUMGRD = 5)
      COMMON /CDGRID/ GRDLX(NUMGRD), GRDUX(NUMGRD),
     *   GRDLY(NUMGRD), GRDUY(NUMGRD),
     *   ICNTX(NUMGRD), ICNTY(NUMGRD), NBASE(NUMGRD)
      COMMON /VGRID/ B(93000)

      DATA GRDLX( 1) / 239.00000000000 /,
     *     GRDUX( 1) / 246.00000000000 /,
     *     GRDLY( 1) /  31.00000000000 /,
     *     GRDUY( 1) /  36.00000000000 /,
     *     ICNTX( 1) /112 /,
     *     ICNTY( 1) / 80 /,
     *     NBASE( 1) /    0 /
      DATA B(    1), B(    2), B(    3) /    25.54,  -45.97,    0.00 /
      DATA B(  340), B(  341), B(  342) /    25.54,  -45.91,    0.00 /
      DATA B(  679), B(  680), B(  681) /    25.54,  -45.84,    0.00 /
      DATA B( 1018), B( 1019), B( 1020) /    25.54,  -45.78,    0.00 /
      DATA B( 1357), B( 1358), B( 1359) /    25.54,  -45.71,    0.00 /
      DATA B( 1696), B( 1697), B( 1698) /    25.54,  -45.65,    0.00 /
      DATA B( 2035), B( 2036), B( 2037) /    25.53,  -45.58,    0.00 /
      DATA B( 2374), B( 2375), B( 2376) /    25.53,  -45.52,    0.00 /
      DATA B( 2713), B( 2714), B( 2715) /    25.53,  -45.45,    0.00 /
      DATA B( 3052), B( 3053), B( 3054) /    25.53,  -45.39,    0.00 /
      DATA B( 3391), B( 3392), B( 3393) /    25.53,  -45.32,    0.00 /
      DATA B( 3730), B( 3731), B( 3732) /    25.53,  -45.25,    0.00 /
      DATA B( 4069), B( 4070), B( 4071) /    25.53,  -45.19,    0.00 /
      DATA B( 4408), B( 4409), B( 4410) /    25.52,  -45.12,    0.00 /
      DATA B( 4747), B( 4748), B( 4749) /    25.52,  -45.05,    0.00 /
      DATA B( 5086), B( 5087), B( 5088) /    25.52,  -44.99,    0.00 /
      DATA B( 5425), B( 5426), B( 5427) /    25.52,  -44.92,    0.00 /
      DATA B( 5764), B( 5765), B( 5766) /    25.52,  -44.85,    0.00 /
      DATA B( 6103), B( 6104), B( 6105) /    25.52,  -44.79,    0.00 /
      DATA B( 6442), B( 6443), B( 6444) /    25.52,  -44.72,    0.00 /
      DATA B( 6781), B( 6782), B( 6783) /    25.51,  -44.65,    0.00 /
      DATA B( 7120), B( 7121), B( 7122) /    25.51,  -44.58,    0.00 /
      DATA B( 7459), B( 7460), B( 7461) /    25.51,  -44.51,    0.00 /
      DATA B( 7798), B( 7799), B( 7800) /    25.51,  -44.45,    0.00 /
      DATA B( 8137), B( 8138), B( 8139) /    25.51,  -44.38,    0.00 /
      DATA B( 8476), B( 8477), B( 8478) /    25.51,  -44.31,    0.00 /
      DATA B( 8815), B( 8816), B( 8817) /    25.50,  -44.24,    0.00 /
      DATA B( 9154), B( 9155), B( 9156) /    25.50,  -44.17,    0.00 /
      DATA B( 9493), B( 9494), B( 9495) /    25.50,  -44.10,    0.00 /
      DATA B( 9832), B( 9833), B( 9834) /    25.50,  -44.03,    0.00 /
      DATA B(10171), B(10172), B(10173) /    25.50,  -43.96,    0.00 /
      DATA B(10510), B(10511), B(10512) /    25.50,  -43.89,    0.00 /
      DATA B(10849), B(10850), B(10851) /    25.49,  -43.82,    0.00 /
      DATA B(11188), B(11189), B(11190) /    25.49,  -43.75,    0.00 /
      DATA B(11527), B(11528), B(11529) /    25.49,  -43.68,    0.00 /
      DATA B(11866), B(11867), B(11868) /    25.49,  -43.60,    0.00 /
      DATA B(12205), B(12206), B(12207) /    25.48,  -43.53,    0.00 /
      DATA B(12544), B(12545), B(12546) /    25.48,  -43.46,    0.00 /
      DATA B(12883), B(12884), B(12885) /    25.48,  -43.39,    0.00 /
      DATA B(13222), B(13223), B(13224) /    25.48,  -43.32,    0.00 /
      DATA B(13561), B(13562), B(13563) /    25.47,  -43.25,    0.00 /
      DATA B(13900), B(13901), B(13902) /    25.47,  -43.17,    0.00 /
      DATA B(14239), B(14240), B(14241) /    25.46,  -43.10,    0.00 /
      DATA B(14578), B(14579), B(14580) /    25.46,  -43.03,    0.00 /
      DATA B(14917), B(14918), B(14919) /    25.46,  -42.96,    0.00 /
      DATA B(15256), B(15257), B(15258) /    25.45,  -42.88,    0.00 /
      DATA B(15595), B(15596), B(15597) /    25.45,  -42.81,    0.00 /
      DATA B(15934), B(15935), B(15936) /    25.44,  -42.74,    0.00 /
      DATA B(16273), B(16274), B(16275) /    25.43,  -42.66,    0.00 /
      DATA B(16612), B(16613), B(16614) /    25.43,  -42.59,    0.00 /
      DATA B(16951), B(16952), B(16953) /    25.42,  -42.51,    0.00 /
      DATA B(17290), B(17291), B(17292) /    25.41,  -42.44,    0.00 /
      DATA B(17629), B(17630), B(17631) /    25.41,  -42.36,    0.00 /
      DATA B(17968), B(17969), B(17970) /    25.40,  -42.28,    0.00 /
      DATA B(18307), B(18308), B(18309) /    25.39,  -42.19,    0.00 /
      DATA B(18646), B(18647), B(18648) /    25.37,  -42.11,    0.00 /
      DATA B(18985), B(18986), B(18987) /    25.35,  -42.02,    0.00 /
      DATA B(19324), B(19325), B(19326) /    25.32,  -41.94,    0.00 /
      DATA B(19663), B(19664), B(19665) /    25.29,  -41.86,    0.00 /
      DATA B(20002), B(20003), B(20004) /    25.25,  -41.78,    0.00 /
      DATA B(20341), B(20342), B(20343) /    25.19,  -41.72,    0.00 /
      DATA B(20680), B(20681), B(20682) /    25.14,  -41.66,    0.00 /
      DATA B(21019), B(21020), B(21021) /    25.10,  -41.60,    0.00 /
      DATA B(21358), B(21359), B(21360) /    25.05,  -41.51,    0.00 /
      DATA B(21697), B(21698), B(21699) /    25.01,  -41.39,    0.00 /
      DATA B(22036), B(22037), B(22038) /    24.96,  -41.26,    0.00 /
      DATA B(22375), B(22376), B(22377) /    24.90,  -41.13,    0.00 /
      DATA B(22714), B(22715), B(22716) /    24.84,  -40.99,    0.00 /
      DATA B(23053), B(23054), B(23055) /    24.77,  -40.86,    0.00 /
      DATA B(23392), B(23393), B(23394) /    24.75,  -40.75,    0.00 /
      DATA B(23731), B(23732), B(23733) /    24.66,  -40.64,    0.00 /
      DATA B(24070), B(24071), B(24072) /    24.57,  -40.52,    0.00 /
      DATA B(24409), B(24410), B(24411) /    24.47,  -40.38,    0.00 /
      DATA B(24748), B(24749), B(24750) /    24.36,  -40.24,    0.00 /
      DATA B(25087), B(25088), B(25089) /    24.23,  -40.08,    0.00 /
      DATA B(25426), B(25427), B(25428) /    24.08,  -39.92,    0.00 /
      DATA B(25765), B(25766), B(25767) /    23.88,  -39.74,    0.00 /
      DATA B(26104), B(26105), B(26106) /    23.64,  -39.53,    0.00 /
      DATA B(26443), B(26444), B(26445) /    23.35,  -39.31,    0.00 /
      DATA B(26782), B(26783), B(26784) /    23.00,  -39.08,    0.00 /
      DATA B(27121), B(27122), B(27123) /    22.69,  -38.90,    0.00 /
      DATA B(    4), B(    5), B(    6) /    25.51,  -45.96,    0.00 /
      DATA B(  343), B(  344), B(  345) /    25.51,  -45.89,    0.00 /
      DATA B(  682), B(  683), B(  684) /    25.51,  -45.83,    0.00 /
      DATA B( 1021), B( 1022), B( 1023) /    25.51,  -45.76,    0.00 /
      DATA B( 1360), B( 1361), B( 1362) /    25.51,  -45.70,    0.00 /
      DATA B( 1699), B( 1700), B( 1701) /    25.51,  -45.63,    0.00 /
      DATA B( 2038), B( 2039), B( 2040) /    25.51,  -45.56,    0.00 /
      DATA B( 2377), B( 2378), B( 2379) /    25.51,  -45.50,    0.00 /
      DATA B( 2716), B( 2717), B( 2718) /    25.50,  -45.43,    0.00 /
      DATA B( 3055), B( 3056), B( 3057) /    25.50,  -45.37,    0.00 /
      DATA B( 3394), B( 3395), B( 3396) /    25.50,  -45.30,    0.00 /
      DATA B( 3733), B( 3734), B( 3735) /    25.50,  -45.23,    0.00 /
      DATA B( 4072), B( 4073), B( 4074) /    25.50,  -45.17,    0.00 /
      DATA B( 4411), B( 4412), B( 4413) /    25.50,  -45.10,    0.00 /
      DATA B( 4750), B( 4751), B( 4752) /    25.50,  -45.03,    0.00 /
      DATA B( 5089), B( 5090), B( 5091) /    25.49,  -44.97,    0.00 /
      DATA B( 5428), B( 5429), B( 5430) /    25.49,  -44.90,    0.00 /
      DATA B( 5767), B( 5768), B( 5769) /    25.49,  -44.83,    0.00 /
      DATA B( 6106), B( 6107), B( 6108) /    25.49,  -44.77,    0.00 /
      DATA B( 6445), B( 6446), B( 6447) /    25.49,  -44.70,    0.00 /
      DATA B( 6784), B( 6785), B( 6786) /    25.49,  -44.63,    0.00 /
      DATA B( 7123), B( 7124), B( 7125) /    25.49,  -44.56,    0.00 /
      DATA B( 7462), B( 7463), B( 7464) /    25.48,  -44.49,    0.00 /
      DATA B( 7801), B( 7802), B( 7803) /    25.48,  -44.42,    0.00 /
      DATA B( 8140), B( 8141), B( 8142) /    25.48,  -44.35,    0.00 /
      DATA B( 8479), B( 8480), B( 8481) /    25.48,  -44.28,    0.00 /
      DATA B( 8818), B( 8819), B( 8820) /    25.48,  -44.22,    0.00 /
      DATA B( 9157), B( 9158), B( 9159) /    25.48,  -44.15,    0.00 /
      DATA B( 9496), B( 9497), B( 9498) /    25.47,  -44.08,    0.00 /
      DATA B( 9835), B( 9836), B( 9837) /    25.47,  -44.01,    0.00 /
      DATA B(10174), B(10175), B(10176) /    25.47,  -43.93,    0.00 /
      DATA B(10513), B(10514), B(10515) /    25.47,  -43.86,    0.00 /
      DATA B(10852), B(10853), B(10854) /    25.47,  -43.79,    0.00 /
      DATA B(11191), B(11192), B(11193) /    25.46,  -43.72,    0.00 /
      DATA B(11530), B(11531), B(11532) /    25.46,  -43.65,    0.00 /
      DATA B(11869), B(11870), B(11871) /    25.46,  -43.58,    0.00 /
      DATA B(12208), B(12209), B(12210) /    25.46,  -43.51,    0.00 /
      DATA B(12547), B(12548), B(12549) /    25.45,  -43.43,    0.00 /
      DATA B(12886), B(12887), B(12888) /    25.45,  -43.36,    0.00 /
      DATA B(13225), B(13226), B(13227) /    25.45,  -43.29,    0.00 /
      DATA B(13564), B(13565), B(13566) /    25.45,  -43.21,    0.00 /
      DATA B(13903), B(13904), B(13905) /    25.44,  -43.14,    0.00 /
      DATA B(14242), B(14243), B(14244) /    25.44,  -43.07,    0.00 /
      DATA B(14581), B(14582), B(14583) /    25.44,  -42.99,    0.00 /
      DATA B(14920), B(14921), B(14922) /    25.43,  -42.92,    0.00 /
      DATA B(15259), B(15260), B(15261) /    25.43,  -42.85,    0.00 /
      DATA B(15598), B(15599), B(15600) /    25.42,  -42.77,    0.00 /
      DATA B(15937), B(15938), B(15939) /    25.42,  -42.70,    0.00 /
      DATA B(16276), B(16277), B(16278) /    25.41,  -42.62,    0.00 /
      DATA B(16615), B(16616), B(16617) /    25.41,  -42.55,    0.00 /
      DATA B(16954), B(16955), B(16956) /    25.40,  -42.47,    0.00 /
      DATA B(17293), B(17294), B(17295) /    25.39,  -42.39,    0.00 /
      DATA B(17632), B(17633), B(17634) /    25.39,  -42.31,    0.00 /
      DATA B(17971), B(17972), B(17973) /    25.38,  -42.23,    0.00 /
      DATA B(18310), B(18311), B(18312) /    25.37,  -42.14,    0.00 /
      DATA B(18649), B(18650), B(18651) /    25.35,  -42.05,    0.00 /
      DATA B(18988), B(18989), B(18990) /    25.34,  -41.96,    0.00 /
      DATA B(19327), B(19328), B(19329) /    25.31,  -41.86,    0.00 /
      DATA B(19666), B(19667), B(19668) /    25.27,  -41.77,    0.00 /
      DATA B(20005), B(20006), B(20007) /    25.22,  -41.69,    0.00 /
      DATA B(20344), B(20345), B(20346) /    25.15,  -41.63,    0.00 /
      DATA B(20683), B(20684), B(20685) /    25.07,  -41.59,    0.00 /
      DATA B(21022), B(21023), B(21024) /    25.01,  -41.54,    0.00 /
      DATA B(21361), B(21362), B(21363) /    24.95,  -41.45,    0.00 /
      DATA B(21700), B(21701), B(21702) /    24.88,  -41.32,    0.00 /
      DATA B(22039), B(22040), B(22041) /    24.81,  -41.17,    0.00 /
      DATA B(22378), B(22379), B(22380) /    24.74,  -41.03,    0.00 /
      DATA B(22717), B(22718), B(22719) /    24.66,  -40.88,    0.00 /
      DATA B(23056), B(23057), B(23058) /    24.57,  -40.76,    0.00 /
      DATA B(23395), B(23396), B(23397) /    24.47,  -40.63,    0.00 /
      DATA B(23734), B(23735), B(23736) /    24.38,  -40.50,    0.00 /
      DATA B(24073), B(24074), B(24075) /    24.28,  -40.36,    0.00 /
      DATA B(24412), B(24413), B(24414) /    24.17,  -40.21,    0.00 /
      DATA B(24751), B(24752), B(24753) /    24.05,  -40.05,    0.00 /
      DATA B(25090), B(25091), B(25092) /    23.90,  -39.87,    0.00 /
      DATA B(25429), B(25430), B(25431) /    23.72,  -39.66,    0.00 /
      DATA B(25768), B(25769), B(25770) /    23.48,  -39.42,    0.00 /
      DATA B(26107), B(26108), B(26109) /    23.20,  -39.17,    0.00 /
      DATA B(26446), B(26447), B(26448) /    22.87,  -38.89,    0.00 /
      DATA B(26785), B(26786), B(26787) /    22.56,  -38.68,    0.00 /
      DATA B(27124), B(27125), B(27126) /    22.30,  -38.57,    0.00 /
      DATA B(    7), B(    8), B(    9) /    25.49,  -45.94,    0.00 /
      DATA B(  346), B(  347), B(  348) /    25.49,  -45.87,    0.00 /
      DATA B(  685), B(  686), B(  687) /    25.49,  -45.81,    0.00 /
      DATA B( 1024), B( 1025), B( 1026) /    25.48,  -45.74,    0.00 /
      DATA B( 1363), B( 1364), B( 1365) /    25.48,  -45.68,    0.00 /
      DATA B( 1702), B( 1703), B( 1704) /    25.48,  -45.61,    0.00 /
      DATA B( 2041), B( 2042), B( 2043) /    25.48,  -45.55,    0.00 /
      DATA B( 2380), B( 2381), B( 2382) /    25.48,  -45.48,    0.00 /
      DATA B( 2719), B( 2720), B( 2721) /    25.48,  -45.41,    0.00 /
      DATA B( 3058), B( 3059), B( 3060) /    25.48,  -45.35,    0.00 /
      DATA B( 3397), B( 3398), B( 3399) /    25.47,  -45.28,    0.00 /
      DATA B( 3736), B( 3737), B( 3738) /    25.47,  -45.22,    0.00 /
      DATA B( 4075), B( 4076), B( 4077) /    25.47,  -45.15,    0.00 /
      DATA B( 4414), B( 4415), B( 4416) /    25.47,  -45.08,    0.00 /
      DATA B( 4753), B( 4754), B( 4755) /    25.47,  -45.01,    0.00 /
      DATA B( 5092), B( 5093), B( 5094) /    25.47,  -44.95,    0.00 /
      DATA B( 5431), B( 5432), B( 5433) /    25.47,  -44.88,    0.00 /
      DATA B( 5770), B( 5771), B( 5772) /    25.46,  -44.81,    0.00 /
      DATA B( 6109), B( 6110), B( 6111) /    25.46,  -44.74,    0.00 /
      DATA B( 6448), B( 6449), B( 6450) /    25.46,  -44.68,    0.00 /
      DATA B( 6787), B( 6788), B( 6789) /    25.46,  -44.61,    0.00 /
      DATA B( 7126), B( 7127), B( 7128) /    25.46,  -44.54,    0.00 /
      DATA B( 7465), B( 7466), B( 7467) /    25.46,  -44.47,    0.00 /
      DATA B( 7804), B( 7805), B( 7806) /    25.45,  -44.40,    0.00 /
      DATA B( 8143), B( 8144), B( 8145) /    25.45,  -44.33,    0.00 /
      DATA B( 8482), B( 8483), B( 8484) /    25.45,  -44.26,    0.00 /
      DATA B( 8821), B( 8822), B( 8823) /    25.45,  -44.19,    0.00 /
      DATA B( 9160), B( 9161), B( 9162) /    25.45,  -44.12,    0.00 /
      DATA B( 9499), B( 9500), B( 9501) /    25.45,  -44.05,    0.00 /
      DATA B( 9838), B( 9839), B( 9840) /    25.44,  -43.98,    0.00 /
      DATA B(10177), B(10178), B(10179) /    25.44,  -43.91,    0.00 /
      DATA B(10516), B(10517), B(10518) /    25.44,  -43.84,    0.00 /
      DATA B(10855), B(10856), B(10857) /    25.44,  -43.77,    0.00 /
      DATA B(11194), B(11195), B(11196) /    25.44,  -43.69,    0.00 /
      DATA B(11533), B(11534), B(11535) /    25.43,  -43.62,    0.00 /
      DATA B(11872), B(11873), B(11874) /    25.43,  -43.55,    0.00 /
      DATA B(12211), B(12212), B(12213) /    25.43,  -43.48,    0.00 /
      DATA B(12550), B(12551), B(12552) /    25.43,  -43.40,    0.00 /
      DATA B(12889), B(12890), B(12891) /    25.43,  -43.33,    0.00 /
      DATA B(13228), B(13229), B(13230) /    25.42,  -43.26,    0.00 /
      DATA B(13567), B(13568), B(13569) /    25.42,  -43.18,    0.00 /
      DATA B(13906), B(13907), B(13908) /    25.42,  -43.11,    0.00 /
      DATA B(14245), B(14246), B(14247) /    25.41,  -43.03,    0.00 /
      DATA B(14584), B(14585), B(14586) /    25.41,  -42.96,    0.00 /
      DATA B(14923), B(14924), B(14925) /    25.41,  -42.89,    0.00 /
      DATA B(15262), B(15263), B(15264) /    25.40,  -42.81,    0.00 /
      DATA B(15601), B(15602), B(15603) /    25.40,  -42.74,    0.00 /
      DATA B(15940), B(15941), B(15942) /    25.39,  -42.66,    0.00 /
      DATA B(16279), B(16280), B(16281) /    25.39,  -42.58,    0.00 /
      DATA B(16618), B(16619), B(16620) /    25.38,  -42.51,    0.00 /
      DATA B(16957), B(16958), B(16959) /    25.38,  -42.43,    0.00 /
      DATA B(17296), B(17297), B(17298) /    25.37,  -42.35,    0.00 /
      DATA B(17635), B(17636), B(17637) /    25.37,  -42.26,    0.00 /
      DATA B(17974), B(17975), B(17976) /    25.36,  -42.18,    0.00 /
      DATA B(18313), B(18314), B(18315) /    25.35,  -42.08,    0.00 /
      DATA B(18652), B(18653), B(18654) /    25.34,  -41.99,    0.00 /
      DATA B(18991), B(18992), B(18993) /    25.33,  -41.88,    0.00 /
      DATA B(19330), B(19331), B(19332) /    25.31,  -41.77,    0.00 /
      DATA B(19669), B(19670), B(19671) /    25.27,  -41.67,    0.00 /
      DATA B(20008), B(20009), B(20010) /    25.21,  -41.57,    0.00 /
      DATA B(20347), B(20348), B(20349) /    25.12,  -41.50,    0.00 /
      DATA B(20686), B(20687), B(20688) /    25.00,  -41.48,    0.00 /
      DATA B(21025), B(21026), B(21027) /    24.89,  -41.47,    0.00 /
      DATA B(21364), B(21365), B(21366) /    24.81,  -41.38,    0.00 /
      DATA B(21703), B(21704), B(21705) /    24.71,  -41.23,    0.00 /
      DATA B(22042), B(22043), B(22044) /    24.61,  -41.08,    0.00 /
      DATA B(22381), B(22382), B(22383) /    24.51,  -40.92,    0.00 /
      DATA B(22720), B(22721), B(22722) /    24.39,  -40.77,    0.00 /
      DATA B(23059), B(23060), B(23061) /    24.28,  -40.63,    0.00 /
      DATA B(23398), B(23399), B(23400) /    24.18,  -40.50,    0.00 /
      DATA B(23737), B(23738), B(23739) /    24.08,  -40.36,    0.00 /
      DATA B(24076), B(24077), B(24078) /    23.98,  -40.20,    0.00 /
      DATA B(24415), B(24416), B(24417) /    23.86,  -40.03,    0.00 /
      DATA B(24754), B(24755), B(24756) /    23.71,  -39.84,    0.00 /
      DATA B(25093), B(25094), B(25095) /    23.53,  -39.61,    0.00 /
      DATA B(25432), B(25433), B(25434) /    23.31,  -39.35,    0.00 /
      DATA B(25771), B(25772), B(25773) /    23.04,  -39.05,    0.00 /
      DATA B(26110), B(26111), B(26112) /    22.72,  -38.72,    0.00 /
      DATA B(26449), B(26450), B(26451) /    22.43,  -38.45,    0.00 /
      DATA B(26788), B(26789), B(26790) /    22.17,  -38.29,    0.00 /
      DATA B(27127), B(27128), B(27129) /    21.96,  -38.26,    0.00 /
      DATA B(   10), B(   11), B(   12) /    25.46,  -45.92,    0.00 /
      DATA B(  349), B(  350), B(  351) /    25.46,  -45.86,    0.00 /
      DATA B(  688), B(  689), B(  690) /    25.46,  -45.79,    0.00 /
      DATA B( 1027), B( 1028), B( 1029) /    25.46,  -45.73,    0.00 /
      DATA B( 1366), B( 1367), B( 1368) /    25.46,  -45.66,    0.00 /
      DATA B( 1705), B( 1706), B( 1707) /    25.45,  -45.59,    0.00 /
      DATA B( 2044), B( 2045), B( 2046) /    25.45,  -45.53,    0.00 /
      DATA B( 2383), B( 2384), B( 2385) /    25.45,  -45.46,    0.00 /
      DATA B( 2722), B( 2723), B( 2724) /    25.45,  -45.40,    0.00 /
      DATA B( 3061), B( 3062), B( 3063) /    25.45,  -45.33,    0.00 /
      DATA B( 3400), B( 3401), B( 3402) /    25.45,  -45.26,    0.00 /
      DATA B( 3739), B( 3740), B( 3741) /    25.45,  -45.20,    0.00 /
      DATA B( 4078), B( 4079), B( 4080) /    25.44,  -45.13,    0.00 /
      DATA B( 4417), B( 4418), B( 4419) /    25.44,  -45.06,    0.00 /
      DATA B( 4756), B( 4757), B( 4758) /    25.44,  -44.99,    0.00 /
      DATA B( 5095), B( 5096), B( 5097) /    25.44,  -44.93,    0.00 /
      DATA B( 5434), B( 5435), B( 5436) /    25.44,  -44.86,    0.00 /
      DATA B( 5773), B( 5774), B( 5775) /    25.44,  -44.79,    0.00 /
      DATA B( 6112), B( 6113), B( 6114) /    25.43,  -44.72,    0.00 /
      DATA B( 6451), B( 6452), B( 6453) /    25.43,  -44.66,    0.00 /
      DATA B( 6790), B( 6791), B( 6792) /    25.43,  -44.59,    0.00 /
      DATA B( 7129), B( 7130), B( 7131) /    25.43,  -44.52,    0.00 /
      DATA B( 7468), B( 7469), B( 7470) /    25.43,  -44.45,    0.00 /
      DATA B( 7807), B( 7808), B( 7809) /    25.43,  -44.38,    0.00 /
      DATA B( 8146), B( 8147), B( 8148) /    25.42,  -44.31,    0.00 /
      DATA B( 8485), B( 8486), B( 8487) /    25.42,  -44.24,    0.00 /
      DATA B( 8824), B( 8825), B( 8826) /    25.42,  -44.17,    0.00 /
      DATA B( 9163), B( 9164), B( 9165) /    25.42,  -44.10,    0.00 /
      DATA B( 9502), B( 9503), B( 9504) /    25.42,  -44.03,    0.00 /
      DATA B( 9841), B( 9842), B( 9843) /    25.42,  -43.96,    0.00 /
      DATA B(10180), B(10181), B(10182) /    25.41,  -43.88,    0.00 /
      DATA B(10519), B(10520), B(10521) /    25.41,  -43.81,    0.00 /
      DATA B(10858), B(10859), B(10860) /    25.41,  -43.74,    0.00 /
      DATA B(11197), B(11198), B(11199) /    25.41,  -43.67,    0.00 /
      DATA B(11536), B(11537), B(11538) /    25.41,  -43.60,    0.00 /
      DATA B(11875), B(11876), B(11877) /    25.41,  -43.52,    0.00 /
      DATA B(12214), B(12215), B(12216) /    25.40,  -43.45,    0.00 /
      DATA B(12553), B(12554), B(12555) /    25.40,  -43.37,    0.00 /
      DATA B(12892), B(12893), B(12894) /    25.40,  -43.30,    0.00 /
      DATA B(13231), B(13232), B(13233) /    25.40,  -43.23,    0.00 /
      DATA B(13570), B(13571), B(13572) /    25.40,  -43.15,    0.00 /
      DATA B(13909), B(13910), B(13911) /    25.39,  -43.08,    0.00 /
      DATA B(14248), B(14249), B(14250) /    25.39,  -43.00,    0.00 /
      DATA B(14587), B(14588), B(14589) /    25.39,  -42.92,    0.00 /
      DATA B(14926), B(14927), B(14928) /    25.38,  -42.85,    0.00 /
      DATA B(15265), B(15266), B(15267) /    25.38,  -42.77,    0.00 /
      DATA B(15604), B(15605), B(15606) /    25.38,  -42.69,    0.00 /
      DATA B(15943), B(15944), B(15945) /    25.37,  -42.62,    0.00 /
      DATA B(16282), B(16283), B(16284) /    25.37,  -42.54,    0.00 /
      DATA B(16621), B(16622), B(16623) /    25.36,  -42.46,    0.00 /
      DATA B(16960), B(16961), B(16962) /    25.36,  -42.38,    0.00 /
      DATA B(17299), B(17300), B(17301) /    25.35,  -42.30,    0.00 /
      DATA B(17638), B(17639), B(17640) /    25.35,  -42.21,    0.00 /
      DATA B(17977), B(17978), B(17979) /    25.34,  -42.12,    0.00 /
      DATA B(18316), B(18317), B(18318) /    25.34,  -42.02,    0.00 /
      DATA B(18655), B(18656), B(18657) /    25.34,  -41.92,    0.00 /
      DATA B(18994), B(18995), B(18996) /    25.33,  -41.80,    0.00 /
      DATA B(19333), B(19334), B(19335) /    25.32,  -41.68,    0.00 /
      DATA B(19672), B(19673), B(19674) /    25.29,  -41.54,    0.00 /
      DATA B(20011), B(20012), B(20013) /    25.24,  -41.41,    0.00 /
      DATA B(20350), B(20351), B(20352) /    25.13,  -41.31,    0.00 /
      DATA B(20689), B(20690), B(20691) /    24.96,  -41.29,    0.00 /
      DATA B(21028), B(21029), B(21030) /    24.76,  -41.39,    0.00 /
      DATA B(21367), B(21368), B(21369) /    24.61,  -41.31,    0.00 /
      DATA B(21706), B(21707), B(21708) /    23.73,  -40.37,    0.00 /
      DATA B(22045), B(22046), B(22047) /    24.31,  -40.96,    0.00 /
      DATA B(22384), B(22385), B(22386) /    24.19,  -40.80,    0.00 /
      DATA B(22723), B(22724), B(22725) /    24.07,  -40.66,    0.00 /
      DATA B(23062), B(23063), B(23064) /    23.97,  -40.51,    0.00 /
      DATA B(23401), B(23402), B(23403) /    23.87,  -40.36,    0.00 /
      DATA B(23740), B(23741), B(23742) /    23.77,  -40.20,    0.00 /
      DATA B(24079), B(24080), B(24081) /    23.65,  -40.03,    0.00 /
      DATA B(24418), B(24419), B(24420) /    23.51,  -39.82,    0.00 /
      DATA B(24757), B(24758), B(24759) /    23.33,  -39.59,    0.00 /
      DATA B(25096), B(25097), B(25098) /    23.11,  -39.30,    0.00 /
      DATA B(25435), B(25436), B(25437) /    22.85,  -38.98,    0.00 /
      DATA B(25774), B(25775), B(25776) /    22.54,  -38.60,    0.00 /
      DATA B(26113), B(26114), B(26115) /    22.28,  -38.26,    0.00 /
      DATA B(26452), B(26453), B(26454) /    22.05,  -38.01,    0.00 /
      DATA B(26791), B(26792), B(26793) /    21.85,  -37.89,    0.00 /
      DATA B(27130), B(27131), B(27132) /    21.68,  -37.94,    0.00 /
      DATA B(   13), B(   14), B(   15) /    25.43,  -45.90,    0.00 /
      DATA B(  352), B(  353), B(  354) /    25.43,  -45.84,    0.00 /
      DATA B(  691), B(  692), B(  693) /    25.43,  -45.77,    0.00 /
      DATA B( 1030), B( 1031), B( 1032) /    25.43,  -45.71,    0.00 /
      DATA B( 1369), B( 1370), B( 1371) /    25.43,  -45.64,    0.00 /
      DATA B( 1708), B( 1709), B( 1710) /    25.43,  -45.58,    0.00 /
      DATA B( 2047), B( 2048), B( 2049) /    25.43,  -45.51,    0.00 /
      DATA B( 2386), B( 2387), B( 2388) /    25.42,  -45.44,    0.00 /
      DATA B( 2725), B( 2726), B( 2727) /    25.42,  -45.38,    0.00 /
      DATA B( 3064), B( 3065), B( 3066) /    25.42,  -45.31,    0.00 /
      DATA B( 3403), B( 3404), B( 3405) /    25.42,  -45.24,    0.00 /
      DATA B( 3742), B( 3743), B( 3744) /    25.42,  -45.18,    0.00 /
      DATA B( 4081), B( 4082), B( 4083) /    25.42,  -45.11,    0.00 /
      DATA B( 4420), B( 4421), B( 4422) /    25.41,  -45.04,    0.00 /
      DATA B( 4759), B( 4760), B( 4761) /    25.41,  -44.97,    0.00 /
      DATA B( 5098), B( 5099), B( 5100) /    25.41,  -44.91,    0.00 /
      DATA B( 5437), B( 5438), B( 5439) /    25.41,  -44.84,    0.00 /
      DATA B( 5776), B( 5777), B( 5778) /    25.41,  -44.77,    0.00 /
      DATA B( 6115), B( 6116), B( 6117) /    25.41,  -44.70,    0.00 /
      DATA B( 6454), B( 6455), B( 6456) /    25.40,  -44.63,    0.00 /
      DATA B( 6793), B( 6794), B( 6795) /    25.40,  -44.56,    0.00 /
      DATA B( 7132), B( 7133), B( 7134) /    25.40,  -44.50,    0.00 /
      DATA B( 7471), B( 7472), B( 7473) /    25.40,  -44.43,    0.00 /
      DATA B( 7810), B( 7811), B( 7812) /    25.40,  -44.36,    0.00 /
      DATA B( 8149), B( 8150), B( 8151) /    25.40,  -44.29,    0.00 /
      DATA B( 8488), B( 8489), B( 8490) /    25.39,  -44.22,    0.00 /
      DATA B( 8827), B( 8828), B( 8829) /    25.39,  -44.15,    0.00 /
      DATA B( 9166), B( 9167), B( 9168) /    25.39,  -44.07,    0.00 /
      DATA B( 9505), B( 9506), B( 9507) /    25.39,  -44.00,    0.00 /
      DATA B( 9844), B( 9845), B( 9846) /    25.39,  -43.93,    0.00 /
      DATA B(10183), B(10184), B(10185) /    25.39,  -43.86,    0.00 /
      DATA B(10522), B(10523), B(10524) /    25.38,  -43.79,    0.00 /
      DATA B(10861), B(10862), B(10863) /    25.38,  -43.71,    0.00 /
      DATA B(11200), B(11201), B(11202) /    25.38,  -43.64,    0.00 /
      DATA B(11539), B(11540), B(11541) /    25.38,  -43.57,    0.00 /
      DATA B(11878), B(11879), B(11880) /    25.38,  -43.49,    0.00 /
      DATA B(12217), B(12218), B(12219) /    25.38,  -43.42,    0.00 /
      DATA B(12556), B(12557), B(12558) /    25.38,  -43.34,    0.00 /
      DATA B(12895), B(12896), B(12897) /    25.37,  -43.27,    0.00 /
      DATA B(13234), B(13235), B(13236) /    25.37,  -43.19,    0.00 /
      DATA B(13573), B(13574), B(13575) /    25.37,  -43.12,    0.00 /
      DATA B(13912), B(13913), B(13914) /    25.37,  -43.04,    0.00 /
      DATA B(14251), B(14252), B(14253) /    25.37,  -42.96,    0.00 /
      DATA B(14590), B(14591), B(14592) /    25.36,  -42.89,    0.00 /
      DATA B(14929), B(14930), B(14931) /    25.36,  -42.81,    0.00 /
      DATA B(15268), B(15269), B(15270) /    25.36,  -42.73,    0.00 /
      DATA B(15607), B(15608), B(15609) /    25.35,  -42.65,    0.00 /
      DATA B(15946), B(15947), B(15948) /    25.35,  -42.57,    0.00 /
      DATA B(16285), B(16286), B(16287) /    25.35,  -42.49,    0.00 /
      DATA B(16624), B(16625), B(16626) /    25.34,  -42.41,    0.00 /
      DATA B(16963), B(16964), B(16965) /    25.34,  -42.33,    0.00 /
      DATA B(17302), B(17303), B(17304) /    25.33,  -42.24,    0.00 /
      DATA B(17641), B(17642), B(17643) /    25.33,  -42.15,    0.00 /
      DATA B(17980), B(17981), B(17982) /    25.33,  -42.06,    0.00 /
      DATA B(18319), B(18320), B(18321) /    25.33,  -41.96,    0.00 /
      DATA B(18658), B(18659), B(18660) /    25.33,  -41.84,    0.00 /
      DATA B(18997), B(18998), B(18999) /    25.34,  -41.72,    0.00 /
      DATA B(19336), B(19337), B(19338) /    25.34,  -41.57,    0.00 /
      DATA B(19675), B(19676), B(19677) /    25.34,  -41.41,    0.00 /
      DATA B(20014), B(20015), B(20016) /    25.31,  -41.23,    0.00 /
      DATA B(20353), B(20354), B(20355) /    25.24,  -41.06,    0.00 /
      DATA B(20692), B(20693), B(20694) /    25.10,  -40.97,    0.00 /
      DATA B(21031), B(21032), B(21033) /    24.65,  -41.26,    0.00 /
      DATA B(21370), B(21371), B(21372) /    24.21,  -41.20,    0.00 /
      DATA B(21709), B(21710), B(21711) /    24.05,  -41.00,    0.00 /
      DATA B(22048), B(22049), B(22050) /    23.94,  -40.84,    0.00 /
      DATA B(22387), B(22388), B(22389) /    23.83,  -40.69,    0.00 /
      DATA B(22726), B(22727), B(22728) /    23.74,  -40.54,    0.00 /
      DATA B(23065), B(23066), B(23067) /    23.65,  -40.39,    0.00 /
      DATA B(23404), B(23405), B(23406) /    23.55,  -40.22,    0.00 /
      DATA B(23743), B(23744), B(23745) /    23.43,  -40.04,    0.00 /
      DATA B(24082), B(24083), B(24084) /    23.29,  -39.83,    0.00 /
      DATA B(24421), B(24422), B(24423) /    23.11,  -39.58,    0.00 /
      DATA B(24760), B(24761), B(24762) /    22.88,  -39.28,    0.00 /
      DATA B(25099), B(25100), B(25101) /    22.62,  -38.93,    0.00 /
      DATA B(25438), B(25439), B(25440) /    22.32,  -38.53,    0.00 /
      DATA B(25777), B(25778), B(25779) /    22.07,  -38.14,    0.00 /
      DATA B(26116), B(26117), B(26118) /    21.87,  -37.81,    0.00 /
      DATA B(26455), B(26456), B(26457) /    21.70,  -37.55,    0.00 /
      DATA B(26794), B(26795), B(26796) /    21.56,  -37.43,    0.00 /
      DATA B(27133), B(27134), B(27135) /    21.43,  -37.57,    0.00 /
      DATA B(   16), B(   17), B(   18) /    25.41,  -45.89,    0.00 /
      DATA B(  355), B(  356), B(  357) /    25.41,  -45.82,    0.00 /
      DATA B(  694), B(  695), B(  696) /    25.40,  -45.75,    0.00 /
      DATA B( 1033), B( 1034), B( 1035) /    25.40,  -45.69,    0.00 /
      DATA B( 1372), B( 1373), B( 1374) /    25.40,  -45.62,    0.00 /
      DATA B( 1711), B( 1712), B( 1713) /    25.40,  -45.56,    0.00 /
      DATA B( 2050), B( 2051), B( 2052) /    25.40,  -45.49,    0.00 /
      DATA B( 2389), B( 2390), B( 2391) /    25.40,  -45.42,    0.00 /
      DATA B( 2728), B( 2729), B( 2730) /    25.39,  -45.36,    0.00 /
      DATA B( 3067), B( 3068), B( 3069) /    25.39,  -45.29,    0.00 /
      DATA B( 3406), B( 3407), B( 3408) /    25.39,  -45.22,    0.00 /
      DATA B( 3745), B( 3746), B( 3747) /    25.39,  -45.16,    0.00 /
      DATA B( 4084), B( 4085), B( 4086) /    25.39,  -45.09,    0.00 /
      DATA B( 4423), B( 4424), B( 4425) /    25.39,  -45.02,    0.00 /
      DATA B( 4762), B( 4763), B( 4764) /    25.39,  -44.95,    0.00 /
      DATA B( 5101), B( 5102), B( 5103) /    25.38,  -44.89,    0.00 /
      DATA B( 5440), B( 5441), B( 5442) /    25.38,  -44.82,    0.00 /
      DATA B( 5779), B( 5780), B( 5781) /    25.38,  -44.75,    0.00 /
      DATA B( 6118), B( 6119), B( 6120) /    25.38,  -44.68,    0.00 /
      DATA B( 6457), B( 6458), B( 6459) /    25.38,  -44.61,    0.00 /
      DATA B( 6796), B( 6797), B( 6798) /    25.38,  -44.54,    0.00 /
      DATA B( 7135), B( 7136), B( 7137) /    25.37,  -44.47,    0.00 /
      DATA B( 7474), B( 7475), B( 7476) /    25.37,  -44.40,    0.00 /
      DATA B( 7813), B( 7814), B( 7815) /    25.37,  -44.33,    0.00 /
      DATA B( 8152), B( 8153), B( 8154) /    25.37,  -44.26,    0.00 /
      DATA B( 8491), B( 8492), B( 8493) /    25.37,  -44.19,    0.00 /
      DATA B( 8830), B( 8831), B( 8832) /    25.36,  -44.12,    0.00 /
      DATA B( 9169), B( 9170), B( 9171) /    25.36,  -44.05,    0.00 /
      DATA B( 9508), B( 9509), B( 9510) /    25.36,  -43.98,    0.00 /
      DATA B( 9847), B( 9848), B( 9849) /    25.36,  -43.91,    0.00 /
      DATA B(10186), B(10187), B(10188) /    25.36,  -43.83,    0.00 /
      DATA B(10525), B(10526), B(10527) /    25.36,  -43.76,    0.00 /
      DATA B(10864), B(10865), B(10866) /    25.36,  -43.69,    0.00 /
      DATA B(11203), B(11204), B(11205) /    25.35,  -43.61,    0.00 /
      DATA B(11542), B(11543), B(11544) /    25.35,  -43.54,    0.00 /
      DATA B(11881), B(11882), B(11883) /    25.35,  -43.46,    0.00 /
      DATA B(12220), B(12221), B(12222) /    25.35,  -43.39,    0.00 /
      DATA B(12559), B(12560), B(12561) /    25.35,  -43.31,    0.00 /
      DATA B(12898), B(12899), B(12900) /    25.35,  -43.24,    0.00 /
      DATA B(13237), B(13238), B(13239) /    25.35,  -43.16,    0.00 /
      DATA B(13576), B(13577), B(13578) /    25.34,  -43.08,    0.00 /
      DATA B(13915), B(13916), B(13917) /    25.34,  -43.01,    0.00 /
      DATA B(14254), B(14255), B(14256) /    25.34,  -42.93,    0.00 /
      DATA B(14593), B(14594), B(14595) /    25.34,  -42.85,    0.00 /
      DATA B(14932), B(14933), B(14934) /    25.34,  -42.77,    0.00 /
      DATA B(15271), B(15272), B(15273) /    25.34,  -42.69,    0.00 /
      DATA B(15610), B(15611), B(15612) /    25.33,  -42.61,    0.00 /
      DATA B(15949), B(15950), B(15951) /    25.33,  -42.53,    0.00 /
      DATA B(16288), B(16289), B(16290) /    25.33,  -42.44,    0.00 /
      DATA B(16627), B(16628), B(16629) /    25.32,  -42.36,    0.00 /
      DATA B(16966), B(16967), B(16968) /    25.32,  -42.28,    0.00 /
      DATA B(17305), B(17306), B(17307) /    25.32,  -42.19,    0.00 /
      DATA B(17644), B(17645), B(17646) /    25.32,  -42.09,    0.00 /
      DATA B(17983), B(17984), B(17985) /    25.32,  -41.99,    0.00 /
      DATA B(18322), B(18323), B(18324) /    25.32,  -41.88,    0.00 /
      DATA B(18661), B(18662), B(18663) /    25.33,  -41.76,    0.00 /
      DATA B(19000), B(19001), B(19002) /    25.35,  -41.62,    0.00 /
      DATA B(19339), B(19340), B(19341) /    25.37,  -41.46,    0.00 /
      DATA B(19678), B(19679), B(19680) /    25.39,  -41.27,    0.00 /
      DATA B(20017), B(20018), B(20019) /    25.41,  -41.06,    0.00 /
      DATA B(20356), B(20357), B(20358) /    25.43,  -40.87,    0.00 /
      DATA B(20695), B(20696), B(20697) /    25.53,  -40.72,    0.00 /
      DATA B(21034), B(21035), B(21036) /    23.06,  -41.92,    0.00 /
      DATA B(21373), B(21374), B(21375) /    23.50,  -41.15,    0.00 /
      DATA B(21712), B(21713), B(21714) /    23.57,  -40.92,    0.00 /
      DATA B(22051), B(22052), B(22053) /    23.54,  -40.75,    0.00 /
      DATA B(22390), B(22391), B(22392) /    23.48,  -40.59,    0.00 /
      DATA B(22729), B(22730), B(22731) /    23.40,  -40.43,    0.00 /
      DATA B(23068), B(23069), B(23070) /    23.31,  -40.26,    0.00 /
      DATA B(23407), B(23408), B(23409) /    23.20,  -40.07,    0.00 /
      DATA B(23746), B(23747), B(23748) /    23.06,  -39.85,    0.00 /
      DATA B(24085), B(24086), B(24087) /    22.88,  -39.59,    0.00 /
      DATA B(24424), B(24425), B(24426) /    22.65,  -39.28,    0.00 /
      DATA B(24763), B(24764), B(24765) /    22.38,  -38.91,    0.00 /
      DATA B(25102), B(25103), B(25104) /    22.06,  -38.49,    0.00 /
      DATA B(25441), B(25442), B(25443) /    21.80,  -38.08,    0.00 /
      DATA B(25780), B(25781), B(25782) /    21.59,  -37.70,    0.00 /
      DATA B(26119), B(26120), B(26121) /    21.45,  -37.35,    0.00 /
      DATA B(26458), B(26459), B(26460) /    21.35,  -37.05,    0.00 /
      DATA B(26797), B(26798), B(26799) /    21.29,  -36.89,    0.00 /
      DATA B(27136), B(27137), B(27138) /    21.22,  -37.10,    0.00 /
      DATA B(   19), B(   20), B(   21) /    25.38,  -45.87,    0.00 /
      DATA B(  358), B(  359), B(  360) /    25.38,  -45.80,    0.00 /
      DATA B(  697), B(  698), B(  699) /    25.38,  -45.74,    0.00 /
      DATA B( 1036), B( 1037), B( 1038) /    25.37,  -45.67,    0.00 /
      DATA B( 1375), B( 1376), B( 1377) /    25.37,  -45.61,    0.00 /
      DATA B( 1714), B( 1715), B( 1716) /    25.37,  -45.54,    0.00 /
      DATA B( 2053), B( 2054), B( 2055) /    25.37,  -45.47,    0.00 /
      DATA B( 2392), B( 2393), B( 2394) /    25.37,  -45.41,    0.00 /
      DATA B( 2731), B( 2732), B( 2733) /    25.37,  -45.34,    0.00 /
      DATA B( 3070), B( 3071), B( 3072) /    25.37,  -45.27,    0.00 /
      DATA B( 3409), B( 3410), B( 3411) /    25.36,  -45.21,    0.00 /
      DATA B( 3748), B( 3749), B( 3750) /    25.36,  -45.14,    0.00 /
      DATA B( 4087), B( 4088), B( 4089) /    25.36,  -45.07,    0.00 /
      DATA B( 4426), B( 4427), B( 4428) /    25.36,  -45.00,    0.00 /
      DATA B( 4765), B( 4766), B( 4767) /    25.36,  -44.93,    0.00 /
      DATA B( 5104), B( 5105), B( 5106) /    25.36,  -44.87,    0.00 /
      DATA B( 5443), B( 5444), B( 5445) /    25.35,  -44.80,    0.00 /
      DATA B( 5782), B( 5783), B( 5784) /    25.35,  -44.73,    0.00 /
      DATA B( 6121), B( 6122), B( 6123) /    25.35,  -44.66,    0.00 /
      DATA B( 6460), B( 6461), B( 6462) /    25.35,  -44.59,    0.00 /
      DATA B( 6799), B( 6800), B( 6801) /    25.35,  -44.52,    0.00 /
      DATA B( 7138), B( 7139), B( 7140) /    25.34,  -44.45,    0.00 /
      DATA B( 7477), B( 7478), B( 7479) /    25.34,  -44.38,    0.00 /
      DATA B( 7816), B( 7817), B( 7818) /    25.34,  -44.31,    0.00 /
      DATA B( 8155), B( 8156), B( 8157) /    25.34,  -44.24,    0.00 /
      DATA B( 8494), B( 8495), B( 8496) /    25.34,  -44.17,    0.00 /
      DATA B( 8833), B( 8834), B( 8835) /    25.34,  -44.10,    0.00 /
      DATA B( 9172), B( 9173), B( 9174) /    25.33,  -44.03,    0.00 /
      DATA B( 9511), B( 9512), B( 9513) /    25.33,  -43.95,    0.00 /
      DATA B( 9850), B( 9851), B( 9852) /    25.33,  -43.88,    0.00 /
      DATA B(10189), B(10190), B(10191) /    25.33,  -43.81,    0.00 /
      DATA B(10528), B(10529), B(10530) /    25.33,  -43.73,    0.00 /
      DATA B(10867), B(10868), B(10869) /    25.33,  -43.66,    0.00 /
      DATA B(11206), B(11207), B(11208) /    25.33,  -43.59,    0.00 /
      DATA B(11545), B(11546), B(11547) /    25.32,  -43.51,    0.00 /
      DATA B(11884), B(11885), B(11886) /    25.32,  -43.43,    0.00 /
      DATA B(12223), B(12224), B(12225) /    25.32,  -43.36,    0.00 /
      DATA B(12562), B(12563), B(12564) /    25.32,  -43.28,    0.00 /
      DATA B(12901), B(12902), B(12903) /    25.32,  -43.20,    0.00 /
      DATA B(13240), B(13241), B(13242) /    25.32,  -43.13,    0.00 /
      DATA B(13579), B(13580), B(13581) /    25.32,  -43.05,    0.00 /
      DATA B(13918), B(13919), B(13920) /    25.32,  -42.97,    0.00 /
      DATA B(14257), B(14258), B(14259) /    25.32,  -42.89,    0.00 /
      DATA B(14596), B(14597), B(14598) /    25.32,  -42.81,    0.00 /
      DATA B(14935), B(14936), B(14937) /    25.32,  -42.73,    0.00 /
      DATA B(15274), B(15275), B(15276) /    25.32,  -42.64,    0.00 /
      DATA B(15613), B(15614), B(15615) /    25.32,  -42.56,    0.00 /
      DATA B(15952), B(15953), B(15954) /    25.31,  -42.48,    0.00 /
      DATA B(16291), B(16292), B(16293) /    25.31,  -42.39,    0.00 /
      DATA B(16630), B(16631), B(16632) /    25.31,  -42.30,    0.00 /
      DATA B(16969), B(16970), B(16971) /    25.31,  -42.22,    0.00 /
      DATA B(17308), B(17309), B(17310) /    25.30,  -42.12,    0.00 /
      DATA B(17647), B(17648), B(17649) /    25.30,  -42.03,    0.00 /
      DATA B(17986), B(17987), B(17988) /    25.31,  -41.92,    0.00 /
      DATA B(18325), B(18326), B(18327) /    25.31,  -41.81,    0.00 /
      DATA B(18664), B(18665), B(18666) /    25.33,  -41.68,    0.00 /
      DATA B(19003), B(19004), B(19005) /    25.35,  -41.53,    0.00 /
      DATA B(19342), B(19343), B(19344) /    25.38,  -41.35,    0.00 /
      DATA B(19681), B(19682), B(19683) /    25.42,  -41.15,    0.00 /
      DATA B(20020), B(20021), B(20022) /    25.47,  -40.94,    0.00 /
      DATA B(20359), B(20360), B(20361) /    20.73,  -43.40,    0.00 /
      DATA B(20698), B(20699), B(20700) /    20.42,  -43.32,    0.00 /
      DATA B(21037), B(21038), B(21039) /    22.72,  -41.67,    0.00 /
      DATA B(21376), B(21377), B(21378) /    22.98,  -41.16,    0.00 /
      DATA B(21715), B(21716), B(21717) /    23.12,  -40.87,    0.00 /
      DATA B(22054), B(22055), B(22056) /    23.14,  -40.67,    0.00 /
      DATA B(22393), B(22394), B(22395) /    23.11,  -40.50,    0.00 /
      DATA B(22732), B(22733), B(22734) /    23.05,  -40.32,    0.00 /
      DATA B(23071), B(23072), B(23073) /    22.95,  -40.12,    0.00 /
      DATA B(23410), B(23411), B(23412) /    22.82,  -39.89,    0.00 /
      DATA B(23749), B(23750), B(23751) /    22.63,  -39.62,    0.00 /
      DATA B(24088), B(24089), B(24090) /    22.40,  -39.30,    0.00 /
      DATA B(24427), B(24428), B(24429) /    22.13,  -38.91,    0.00 /
      DATA B(24766), B(24767), B(24768) /    21.79,  -38.47,    0.00 /
      DATA B(25105), B(25106), B(25107) /    21.50,  -38.04,    0.00 /
      DATA B(25444), B(25445), B(25446) /    21.26,  -37.63,    0.00 /
      DATA B(25783), B(25784), B(25785) /    21.07,  -37.25,    0.00 /
      DATA B(26122), B(26123), B(26124) /    20.96,  -36.86,    0.00 /
      DATA B(26461), B(26462), B(26463) /    20.90,  -36.47,    0.00 /
      DATA B(26800), B(26801), B(26802) /    20.88,  -36.25,    0.00 /
      DATA B(27139), B(27140), B(27141) /    21.09,  -36.42,    0.00 /
      DATA B(   22), B(   23), B(   24) /    25.35,  -45.85,    0.00 /
      DATA B(  361), B(  362), B(  363) /    25.35,  -45.78,    0.00 /
      DATA B(  700), B(  701), B(  702) /    25.35,  -45.72,    0.00 /
      DATA B( 1039), B( 1040), B( 1041) /    25.35,  -45.65,    0.00 /
      DATA B( 1378), B( 1379), B( 1380) /    25.35,  -45.59,    0.00 /
      DATA B( 1717), B( 1718), B( 1719) /    25.34,  -45.52,    0.00 /
      DATA B( 2056), B( 2057), B( 2058) /    25.34,  -45.45,    0.00 /
      DATA B( 2395), B( 2396), B( 2397) /    25.34,  -45.39,    0.00 /
      DATA B( 2734), B( 2735), B( 2736) /    25.34,  -45.32,    0.00 /
      DATA B( 3073), B( 3074), B( 3075) /    25.34,  -45.25,    0.00 /
      DATA B( 3412), B( 3413), B( 3414) /    25.34,  -45.19,    0.00 /
      DATA B( 3751), B( 3752), B( 3753) /    25.33,  -45.12,    0.00 /
      DATA B( 4090), B( 4091), B( 4092) /    25.33,  -45.05,    0.00 /
      DATA B( 4429), B( 4430), B( 4431) /    25.33,  -44.98,    0.00 /
      DATA B( 4768), B( 4769), B( 4770) /    25.33,  -44.91,    0.00 /
      DATA B( 5107), B( 5108), B( 5109) /    25.33,  -44.85,    0.00 /
      DATA B( 5446), B( 5447), B( 5448) /    25.33,  -44.78,    0.00 /
      DATA B( 5785), B( 5786), B( 5787) /    25.32,  -44.71,    0.00 /
      DATA B( 6124), B( 6125), B( 6126) /    25.32,  -44.64,    0.00 /
      DATA B( 6463), B( 6464), B( 6465) /    25.32,  -44.57,    0.00 /
      DATA B( 6802), B( 6803), B( 6804) /    25.32,  -44.50,    0.00 /
      DATA B( 7141), B( 7142), B( 7143) /    25.32,  -44.43,    0.00 /
      DATA B( 7480), B( 7481), B( 7482) /    25.31,  -44.36,    0.00 /
      DATA B( 7819), B( 7820), B( 7821) /    25.31,  -44.29,    0.00 /
      DATA B( 8158), B( 8159), B( 8160) /    25.31,  -44.22,    0.00 /
      DATA B( 8497), B( 8498), B( 8499) /    25.31,  -44.14,    0.00 /
      DATA B( 8836), B( 8837), B( 8838) /    25.31,  -44.07,    0.00 /
      DATA B( 9175), B( 9176), B( 9177) /    25.31,  -44.00,    0.00 /
      DATA B( 9514), B( 9515), B( 9516) /    25.30,  -43.93,    0.00 /
      DATA B( 9853), B( 9854), B( 9855) /    25.30,  -43.85,    0.00 /
      DATA B(10192), B(10193), B(10194) /    25.30,  -43.78,    0.00 /
      DATA B(10531), B(10532), B(10533) /    25.30,  -43.71,    0.00 /
      DATA B(10870), B(10871), B(10872) /    25.30,  -43.63,    0.00 /
      DATA B(11209), B(11210), B(11211) /    25.30,  -43.56,    0.00 /
      DATA B(11548), B(11549), B(11550) /    25.30,  -43.48,    0.00 /
      DATA B(11887), B(11888), B(11889) /    25.29,  -43.40,    0.00 /
      DATA B(12226), B(12227), B(12228) /    25.29,  -43.33,    0.00 /
      DATA B(12565), B(12566), B(12567) /    25.29,  -43.25,    0.00 /
      DATA B(12904), B(12905), B(12906) /    25.29,  -43.17,    0.00 /
      DATA B(13243), B(13244), B(13245) /    25.29,  -43.09,    0.00 /
      DATA B(13582), B(13583), B(13584) /    25.29,  -43.01,    0.00 /
      DATA B(13921), B(13922), B(13923) /    25.30,  -42.93,    0.00 /
      DATA B(14260), B(14261), B(14262) /    25.30,  -42.85,    0.00 /
      DATA B(14599), B(14600), B(14601) /    25.30,  -42.77,    0.00 /
      DATA B(14938), B(14939), B(14940) /    25.30,  -42.68,    0.00 /
      DATA B(15277), B(15278), B(15279) /    25.30,  -42.59,    0.00 /
      DATA B(15616), B(15617), B(15618) /    25.30,  -42.51,    0.00 /
      DATA B(15955), B(15956), B(15957) /    25.30,  -42.42,    0.00 /
      DATA B(16294), B(16295), B(16296) /    25.30,  -42.33,    0.00 /
      DATA B(16633), B(16634), B(16635) /    25.30,  -42.24,    0.00 /
      DATA B(16972), B(16973), B(16974) /    25.29,  -42.15,    0.00 /
      DATA B(17311), B(17312), B(17313) /    25.29,  -42.05,    0.00 /
      DATA B(17650), B(17651), B(17652) /    25.29,  -41.95,    0.00 /
      DATA B(17989), B(17990), B(17991) /    25.30,  -41.84,    0.00 /
      DATA B(18328), B(18329), B(18330) /    25.30,  -41.72,    0.00 /
      DATA B(18667), B(18668), B(18669) /    25.32,  -41.58,    0.00 /
      DATA B(19006), B(19007), B(19008) /    25.34,  -41.43,    0.00 /
      DATA B(19345), B(19346), B(19347) /    25.37,  -41.26,    0.00 /
      DATA B(19684), B(19685), B(19686) /    25.44,  -41.04,    0.00 /
      DATA B(20023), B(20024), B(20025) /    20.97,  -43.24,    0.00 /
      DATA B(20362), B(20363), B(20364) /    20.25,  -43.25,    0.00 /
      DATA B(20701), B(20702), B(20703) /    22.42,  -41.80,    0.00 /
      DATA B(21040), B(21041), B(21042) /    22.46,  -41.51,    0.00 /
      DATA B(21379), B(21380), B(21381) /    22.62,  -41.12,    0.00 /
      DATA B(21718), B(21719), B(21720) /    22.74,  -40.83,    0.00 /
      DATA B(22057), B(22058), B(22059) /    22.77,  -40.60,    0.00 /
      DATA B(22396), B(22397), B(22398) /    22.74,  -40.40,    0.00 /
      DATA B(22735), B(22736), B(22737) /    22.67,  -40.20,    0.00 /
      DATA B(23074), B(23075), B(23076) /    22.55,  -39.96,    0.00 /
      DATA B(23413), B(23414), B(23415) /    22.38,  -39.68,    0.00 /
      DATA B(23752), B(23753), B(23754) /    22.15,  -39.34,    0.00 /
      DATA B(24091), B(24092), B(24093) /    21.86,  -38.94,    0.00 /
      DATA B(24430), B(24431), B(24432) /    21.52,  -38.47,    0.00 /
      DATA B(24769), B(24770), B(24771) /    21.20,  -38.01,    0.00 /
      DATA B(25108), B(25109), B(25110) /    20.92,  -37.57,    0.00 /
      DATA B(25447), B(25448), B(25449) /    20.68,  -37.16,    0.00 /
      DATA B(25786), B(25787), B(25788) /    20.46,  -36.74,    0.00 /
      DATA B(26125), B(26126), B(26127) /    20.28,  -36.30,    0.00 /
      DATA B(26464), B(26465), B(26466) /    20.17,  -35.77,    0.00 /
      DATA B(26803), B(26804), B(26805) /    19.94,  -35.37,    0.00 /
      DATA B(27142), B(27143), B(27144) /    19.49,  -35.64,    0.00 /
      DATA B(   25), B(   26), B(   27) /    25.32,  -45.83,    0.00 /
      DATA B(  364), B(  365), B(  366) /    25.32,  -45.77,    0.00 /
      DATA B(  703), B(  704), B(  705) /    25.32,  -45.70,    0.00 /
      DATA B( 1042), B( 1043), B( 1044) /    25.32,  -45.63,    0.00 /
      DATA B( 1381), B( 1382), B( 1383) /    25.32,  -45.57,    0.00 /
      DATA B( 1720), B( 1721), B( 1722) /    25.32,  -45.50,    0.00 /
      DATA B( 2059), B( 2060), B( 2061) /    25.31,  -45.44,    0.00 /
      DATA B( 2398), B( 2399), B( 2400) /    25.31,  -45.37,    0.00 /
      DATA B( 2737), B( 2738), B( 2739) /    25.31,  -45.30,    0.00 /
      DATA B( 3076), B( 3077), B( 3078) /    25.31,  -45.23,    0.00 /
      DATA B( 3415), B( 3416), B( 3417) /    25.31,  -45.17,    0.00 /
      DATA B( 3754), B( 3755), B( 3756) /    25.31,  -45.10,    0.00 /
      DATA B( 4093), B( 4094), B( 4095) /    25.30,  -45.03,    0.00 /
      DATA B( 4432), B( 4433), B( 4434) /    25.30,  -44.96,    0.00 /
      DATA B( 4771), B( 4772), B( 4773) /    25.30,  -44.89,    0.00 /
      DATA B( 5110), B( 5111), B( 5112) /    25.30,  -44.82,    0.00 /
      DATA B( 5449), B( 5450), B( 5451) /    25.30,  -44.76,    0.00 /
      DATA B( 5788), B( 5789), B( 5790) /    25.29,  -44.69,    0.00 /
      DATA B( 6127), B( 6128), B( 6129) /    25.29,  -44.62,    0.00 /
      DATA B( 6466), B( 6467), B( 6468) /    25.29,  -44.55,    0.00 /
      DATA B( 6805), B( 6806), B( 6807) /    25.29,  -44.48,    0.00 /
      DATA B( 7144), B( 7145), B( 7146) /    25.29,  -44.41,    0.00 /
      DATA B( 7483), B( 7484), B( 7485) /    25.29,  -44.34,    0.00 /
      DATA B( 7822), B( 7823), B( 7824) /    25.28,  -44.26,    0.00 /
      DATA B( 8161), B( 8162), B( 8163) /    25.28,  -44.19,    0.00 /
      DATA B( 8500), B( 8501), B( 8502) /    25.28,  -44.12,    0.00 /
      DATA B( 8839), B( 8840), B( 8841) /    25.28,  -44.05,    0.00 /
      DATA B( 9178), B( 9179), B( 9180) /    25.28,  -43.98,    0.00 /
      DATA B( 9517), B( 9518), B( 9519) /    25.27,  -43.90,    0.00 /
      DATA B( 9856), B( 9857), B( 9858) /    25.27,  -43.83,    0.00 /
      DATA B(10195), B(10196), B(10197) /    25.27,  -43.75,    0.00 /
      DATA B(10534), B(10535), B(10536) /    25.27,  -43.68,    0.00 /
      DATA B(10873), B(10874), B(10875) /    25.27,  -43.60,    0.00 /
      DATA B(11212), B(11213), B(11214) /    25.27,  -43.53,    0.00 /
      DATA B(11551), B(11552), B(11553) /    25.27,  -43.45,    0.00 /
      DATA B(11890), B(11891), B(11892) /    25.27,  -43.37,    0.00 /
      DATA B(12229), B(12230), B(12231) /    25.27,  -43.30,    0.00 /
      DATA B(12568), B(12569), B(12570) /    25.27,  -43.22,    0.00 /
      DATA B(12907), B(12908), B(12909) /    25.27,  -43.14,    0.00 /
      DATA B(13246), B(13247), B(13248) /    25.27,  -43.06,    0.00 /
      DATA B(13585), B(13586), B(13587) /    25.27,  -42.98,    0.00 /
      DATA B(13924), B(13925), B(13926) /    25.27,  -42.89,    0.00 /
      DATA B(14263), B(14264), B(14265) /    25.27,  -42.81,    0.00 /
      DATA B(14602), B(14603), B(14604) /    25.28,  -42.72,    0.00 /
      DATA B(14941), B(14942), B(14943) /    25.28,  -42.63,    0.00 /
      DATA B(15280), B(15281), B(15282) /    25.28,  -42.54,    0.00 /
      DATA B(15619), B(15620), B(15621) /    25.29,  -42.45,    0.00 /
      DATA B(15958), B(15959), B(15960) /    25.29,  -42.36,    0.00 /
      DATA B(16297), B(16298), B(16299) /    25.29,  -42.27,    0.00 /
      DATA B(16636), B(16637), B(16638) /    25.29,  -42.17,    0.00 /
      DATA B(16975), B(16976), B(16977) /    25.29,  -42.07,    0.00 /
      DATA B(17314), B(17315), B(17316) /    25.29,  -41.97,    0.00 /
      DATA B(17653), B(17654), B(17655) /    25.29,  -41.86,    0.00 /
      DATA B(17992), B(17993), B(17994) /    25.29,  -41.74,    0.00 /
      DATA B(18331), B(18332), B(18333) /    25.29,  -41.62,    0.00 /
      DATA B(18670), B(18671), B(18672) /    25.30,  -41.48,    0.00 /
      DATA B(19009), B(19010), B(19011) /    25.31,  -41.35,    0.00 /
      DATA B(19348), B(19349), B(19350) /    21.80,  -43.16,    0.00 /
      DATA B(19687), B(19688), B(19689) /    21.20,  -43.12,    0.00 /
      DATA B(20026), B(20027), B(20028) /    20.47,  -43.12,    0.00 /
      DATA B(20365), B(20366), B(20367) /    22.19,  -41.77,    0.00 /
      DATA B(20704), B(20705), B(20706) /    22.15,  -41.65,    0.00 /
      DATA B(21043), B(21044), B(21045) /    22.24,  -41.37,    0.00 /
      DATA B(21382), B(21383), B(21384) /    22.33,  -41.05,    0.00 /
      DATA B(21721), B(21722), B(21723) /    22.40,  -40.77,    0.00 /
      DATA B(22060), B(22061), B(22062) /    22.41,  -40.53,    0.00 /
      DATA B(22399), B(22400), B(22401) /    22.37,  -40.30,    0.00 /
      DATA B(22738), B(22739), B(22740) /    22.27,  -40.05,    0.00 /
      DATA B(23077), B(23078), B(23079) /    22.11,  -39.77,    0.00 /
      DATA B(23416), B(23417), B(23418) /    21.89,  -39.42,    0.00 /
      DATA B(23755), B(23756), B(23757) /    21.60,  -39.00,    0.00 /
      DATA B(24094), B(24095), B(24096) /    21.25,  -38.51,    0.00 /
      DATA B(24433), B(24434), B(24435) /    20.92,  -38.01,    0.00 /
      DATA B(24772), B(24773), B(24774) /    20.61,  -37.54,    0.00 /
      DATA B(25111), B(25112), B(25113) /    20.31,  -37.08,    0.00 /
      DATA B(25450), B(25451), B(25452) /    20.02,  -36.62,    0.00 /
      DATA B(25789), B(25790), B(25791) /    19.69,  -36.12,    0.00 /
      DATA B(26128), B(26129), B(26130) /    19.29,  -35.58,    0.00 /
      DATA B(26467), B(26468), B(26469) /    18.79,  -34.91,    0.00 /
      DATA B(26806), B(26807), B(26808) /    18.29,  -33.78,    0.00 /
      DATA B(27145), B(27146), B(27147) /     5.72,  -22.18,    0.00 /
      DATA B(   28), B(   29), B(   30) /    25.30,  -45.81,    0.00 /
      DATA B(  367), B(  368), B(  369) /    25.30,  -45.75,    0.00 /
      DATA B(  706), B(  707), B(  708) /    25.29,  -45.68,    0.00 /
      DATA B( 1045), B( 1046), B( 1047) /    25.29,  -45.62,    0.00 /
      DATA B( 1384), B( 1385), B( 1386) /    25.29,  -45.55,    0.00 /
      DATA B( 1723), B( 1724), B( 1725) /    25.29,  -45.48,    0.00 /
      DATA B( 2062), B( 2063), B( 2064) /    25.29,  -45.42,    0.00 /
      DATA B( 2401), B( 2402), B( 2403) /    25.29,  -45.35,    0.00 /
      DATA B( 2740), B( 2741), B( 2742) /    25.28,  -45.28,    0.00 /
      DATA B( 3079), B( 3080), B( 3081) /    25.28,  -45.21,    0.00 /
      DATA B( 3418), B( 3419), B( 3420) /    25.28,  -45.15,    0.00 /
      DATA B( 3757), B( 3758), B( 3759) /    25.28,  -45.08,    0.00 /
      DATA B( 4096), B( 4097), B( 4098) /    25.28,  -45.01,    0.00 /
      DATA B( 4435), B( 4436), B( 4437) /    25.27,  -44.94,    0.00 /
      DATA B( 4774), B( 4775), B( 4776) /    25.27,  -44.87,    0.00 /
      DATA B( 5113), B( 5114), B( 5115) /    25.27,  -44.80,    0.00 /
      DATA B( 5452), B( 5453), B( 5454) /    25.27,  -44.73,    0.00 /
      DATA B( 5791), B( 5792), B( 5793) /    25.27,  -44.66,    0.00 /
      DATA B( 6130), B( 6131), B( 6132) /    25.26,  -44.59,    0.00 /
      DATA B( 6469), B( 6470), B( 6471) /    25.26,  -44.52,    0.00 /
      DATA B( 6808), B( 6809), B( 6810) /    25.26,  -44.45,    0.00 /
      DATA B( 7147), B( 7148), B( 7149) /    25.26,  -44.38,    0.00 /
      DATA B( 7486), B( 7487), B( 7488) /    25.26,  -44.31,    0.00 /
      DATA B( 7825), B( 7826), B( 7827) /    25.25,  -44.24,    0.00 /
      DATA B( 8164), B( 8165), B( 8166) /    25.25,  -44.17,    0.00 /
      DATA B( 8503), B( 8504), B( 8505) /    25.25,  -44.10,    0.00 /
      DATA B( 8842), B( 8843), B( 8844) /    25.25,  -44.02,    0.00 /
      DATA B( 9181), B( 9182), B( 9183) /    25.25,  -43.95,    0.00 /
      DATA B( 9520), B( 9521), B( 9522) /    25.24,  -43.88,    0.00 /
      DATA B( 9859), B( 9860), B( 9861) /    25.24,  -43.80,    0.00 /
      DATA B(10198), B(10199), B(10200) /    25.24,  -43.73,    0.00 /
      DATA B(10537), B(10538), B(10539) /    25.24,  -43.65,    0.00 /
      DATA B(10876), B(10877), B(10878) /    25.24,  -43.58,    0.00 /
      DATA B(11215), B(11216), B(11217) /    25.24,  -43.50,    0.00 /
      DATA B(11554), B(11555), B(11556) /    25.24,  -43.42,    0.00 /
      DATA B(11893), B(11894), B(11895) /    25.24,  -43.34,    0.00 /
      DATA B(12232), B(12233), B(12234) /    25.24,  -43.26,    0.00 /
      DATA B(12571), B(12572), B(12573) /    25.24,  -43.18,    0.00 /
      DATA B(12910), B(12911), B(12912) /    25.24,  -43.10,    0.00 /
      DATA B(13249), B(13250), B(13251) /    25.24,  -43.02,    0.00 /
      DATA B(13588), B(13589), B(13590) /    25.24,  -42.94,    0.00 /
      DATA B(13927), B(13928), B(13929) /    25.25,  -42.85,    0.00 /
      DATA B(14266), B(14267), B(14268) /    25.25,  -42.77,    0.00 /
      DATA B(14605), B(14606), B(14607) /    25.26,  -42.68,    0.00 /
      DATA B(14944), B(14945), B(14946) /    25.27,  -42.58,    0.00 /
      DATA B(15283), B(15284), B(15285) /    25.27,  -42.49,    0.00 /
      DATA B(15622), B(15623), B(15624) /    25.28,  -42.39,    0.00 /
      DATA B(15961), B(15962), B(15963) /    25.28,  -42.29,    0.00 /
      DATA B(16300), B(16301), B(16302) /    25.29,  -42.19,    0.00 /
      DATA B(16639), B(16640), B(16641) /    25.29,  -42.09,    0.00 /
      DATA B(16978), B(16979), B(16980) /    25.29,  -41.98,    0.00 /
      DATA B(17317), B(17318), B(17319) /    25.29,  -41.87,    0.00 /
      DATA B(17656), B(17657), B(17658) /    25.28,  -41.76,    0.00 /
      DATA B(17995), B(17996), B(17997) /    25.27,  -41.64,    0.00 /
      DATA B(18334), B(18335), B(18336) /    25.26,  -41.52,    0.00 /
      DATA B(18673), B(18674), B(18675) /    25.27,  -41.40,    0.00 /
      DATA B(19012), B(19013), B(19014) /    22.02,  -43.01,    0.00 /
      DATA B(19351), B(19352), B(19353) /    21.40,  -43.02,    0.00 /
      DATA B(19690), B(19691), B(19692) /    20.75,  -43.00,    0.00 /
      DATA B(20029), B(20030), B(20031) /    20.26,  -42.80,    0.00 /
      DATA B(20368), B(20369), B(20370) /    21.89,  -41.68,    0.00 /
      DATA B(20707), B(20708), B(20709) /    21.95,  -41.49,    0.00 /
      DATA B(21046), B(21047), B(21048) /    22.01,  -41.23,    0.00 /
      DATA B(21385), B(21386), B(21387) /    22.06,  -40.95,    0.00 /
      DATA B(21724), B(21725), B(21726) /    22.08,  -40.68,    0.00 /
      DATA B(22063), B(22064), B(22065) /    22.06,  -40.43,    0.00 /
      DATA B(22402), B(22403), B(22404) /    21.98,  -40.17,    0.00 /
      DATA B(22741), B(22742), B(22743) /    21.83,  -39.87,    0.00 /
      DATA B(23080), B(23081), B(23082) /    21.62,  -39.52,    0.00 /
      DATA B(23419), B(23420), B(23421) /    21.35,  -39.10,    0.00 /
      DATA B(23758), B(23759), B(23760) /    20.99,  -38.58,    0.00 /
      DATA B(24097), B(24098), B(24099) /    20.64,  -38.05,    0.00 /
      DATA B(24436), B(24437), B(24438) /    20.30,  -37.54,    0.00 /
      DATA B(24775), B(24776), B(24777) /    19.97,  -37.03,    0.00 /
      DATA B(25114), B(25115), B(25116) /    19.63,  -36.51,    0.00 /
      DATA B(25453), B(25454), B(25455) /    19.23,  -35.94,    0.00 /
      DATA B(25792), B(25793), B(25794) /    18.70,  -35.30,    0.00 /
      DATA B(26131), B(26132), B(26133) /    17.93,  -34.60,    0.00 /
      DATA B(26470), B(26471), B(26472) /    16.86,  -33.59,    0.00 /
      DATA B(26809), B(26810), B(26811) /     6.96,  -23.75,    0.00 /
      DATA B(27148), B(27149), B(27150) /     5.39,  -21.75,    0.00 /
      DATA B(   31), B(   32), B(   33) /    25.27,  -45.80,    0.00 /
      DATA B(  370), B(  371), B(  372) /    25.27,  -45.73,    0.00 /
      DATA B(  709), B(  710), B(  711) /    25.27,  -45.66,    0.00 /
      DATA B( 1048), B( 1049), B( 1050) /    25.26,  -45.60,    0.00 /
      DATA B( 1387), B( 1388), B( 1389) /    25.26,  -45.53,    0.00 /
      DATA B( 1726), B( 1727), B( 1728) /    25.26,  -45.46,    0.00 /
      DATA B( 2065), B( 2066), B( 2067) /    25.26,  -45.40,    0.00 /
      DATA B( 2404), B( 2405), B( 2406) /    25.26,  -45.33,    0.00 /
      DATA B( 2743), B( 2744), B( 2745) /    25.26,  -45.26,    0.00 /
      DATA B( 3082), B( 3083), B( 3084) /    25.25,  -45.19,    0.00 /
      DATA B( 3421), B( 3422), B( 3423) /    25.25,  -45.13,    0.00 /
      DATA B( 3760), B( 3761), B( 3762) /    25.25,  -45.06,    0.00 /
      DATA B( 4099), B( 4100), B( 4101) /    25.25,  -44.99,    0.00 /
      DATA B( 4438), B( 4439), B( 4440) /    25.25,  -44.92,    0.00 /
      DATA B( 4777), B( 4778), B( 4779) /    25.24,  -44.85,    0.00 /
      DATA B( 5116), B( 5117), B( 5118) /    25.24,  -44.78,    0.00 /
      DATA B( 5455), B( 5456), B( 5457) /    25.24,  -44.71,    0.00 /
      DATA B( 5794), B( 5795), B( 5796) /    25.24,  -44.64,    0.00 /
      DATA B( 6133), B( 6134), B( 6135) /    25.23,  -44.57,    0.00 /
      DATA B( 6472), B( 6473), B( 6474) /    25.23,  -44.50,    0.00 /
      DATA B( 6811), B( 6812), B( 6813) /    25.23,  -44.43,    0.00 /
      DATA B( 7150), B( 7151), B( 7152) /    25.23,  -44.36,    0.00 /
      DATA B( 7489), B( 7490), B( 7491) /    25.23,  -44.29,    0.00 /
      DATA B( 7828), B( 7829), B( 7830) /    25.22,  -44.22,    0.00 /
      DATA B( 8167), B( 8168), B( 8169) /    25.22,  -44.14,    0.00 /
      DATA B( 8506), B( 8507), B( 8508) /    25.22,  -44.07,    0.00 /
      DATA B( 8845), B( 8846), B( 8847) /    25.22,  -44.00,    0.00 /
      DATA B( 9184), B( 9185), B( 9186) /    25.22,  -43.92,    0.00 /
      DATA B( 9523), B( 9524), B( 9525) /    25.21,  -43.85,    0.00 /
      DATA B( 9862), B( 9863), B( 9864) /    25.21,  -43.77,    0.00 /
      DATA B(10201), B(10202), B(10203) /    25.21,  -43.70,    0.00 /
      DATA B(10540), B(10541), B(10542) /    25.21,  -43.62,    0.00 /
      DATA B(10879), B(10880), B(10881) /    25.21,  -43.55,    0.00 /
      DATA B(11218), B(11219), B(11220) /    25.21,  -43.47,    0.00 /
      DATA B(11557), B(11558), B(11559) /    25.21,  -43.39,    0.00 /
      DATA B(11896), B(11897), B(11898) /    25.21,  -43.31,    0.00 /
      DATA B(12235), B(12236), B(12237) /    25.21,  -43.23,    0.00 /
      DATA B(12574), B(12575), B(12576) /    25.21,  -43.15,    0.00 /
      DATA B(12913), B(12914), B(12915) /    25.21,  -43.07,    0.00 /
      DATA B(13252), B(13253), B(13254) /    25.21,  -42.98,    0.00 /
      DATA B(13591), B(13592), B(13593) /    25.22,  -42.90,    0.00 /
      DATA B(13930), B(13931), B(13932) /    25.22,  -42.81,    0.00 /
      DATA B(14269), B(14270), B(14271) /    25.23,  -42.72,    0.00 /
      DATA B(14608), B(14609), B(14610) /    25.24,  -42.63,    0.00 /
      DATA B(14947), B(14948), B(14949) /    25.25,  -42.53,    0.00 /
      DATA B(15286), B(15287), B(15288) /    25.26,  -42.43,    0.00 /
      DATA B(15625), B(15626), B(15627) /    25.28,  -42.32,    0.00 /
      DATA B(15964), B(15965), B(15966) /    25.29,  -42.22,    0.00 /
      DATA B(16303), B(16304), B(16305) /    25.30,  -42.10,    0.00 /
      DATA B(16642), B(16643), B(16644) /    25.30,  -41.99,    0.00 /
      DATA B(16981), B(16982), B(16983) /    25.30,  -41.88,    0.00 /
      DATA B(17320), B(17321), B(17322) /    25.29,  -41.76,    0.00 /
      DATA B(17659), B(17660), B(17661) /    25.28,  -41.65,    0.00 /
      DATA B(17998), B(17999), B(18000) /    25.25,  -41.55,    0.00 /
      DATA B(18337), B(18338), B(18339) /    25.25,  -41.44,    0.00 /
      DATA B(18676), B(18677), B(18678) /    22.27,  -42.83,    0.00 /
      DATA B(19015), B(19016), B(19017) /    21.62,  -42.87,    0.00 /
      DATA B(19354), B(19355), B(19356) /    20.98,  -42.87,    0.00 /
      DATA B(19693), B(19694), B(19695) /    20.29,  -42.87,    0.00 /
      DATA B(20032), B(20033), B(20034) /    21.69,  -41.70,    0.00 /
      DATA B(20371), B(20372), B(20373) /    21.67,  -41.57,    0.00 /
      DATA B(20710), B(20711), B(20712) /    21.73,  -41.35,    0.00 /
      DATA B(21049), B(21050), B(21051) /    21.77,  -41.10,    0.00 /
      DATA B(21388), B(21389), B(21390) /    21.78,  -40.85,    0.00 /
      DATA B(21727), B(21728), B(21729) /    21.76,  -40.58,    0.00 /
      DATA B(22066), B(22067), B(22068) /    21.69,  -40.30,    0.00 /
      DATA B(22405), B(22406), B(22407) /    21.56,  -40.00,    0.00 /
      DATA B(22744), B(22745), B(22746) /    21.35,  -39.64,    0.00 /
      DATA B(23083), B(23084), B(23085) /    21.09,  -39.21,    0.00 /
      DATA B(23422), B(23423), B(23424) /    20.73,  -38.68,    0.00 /
      DATA B(23761), B(23762), B(23763) /    20.37,  -38.13,    0.00 /
      DATA B(24100), B(24101), B(24102) /    20.01,  -37.58,    0.00 /
      DATA B(24439), B(24440), B(24441) /    19.65,  -37.03,    0.00 /
      DATA B(24778), B(24779), B(24780) /    19.27,  -36.45,    0.00 /
      DATA B(25117), B(25118), B(25119) /    18.81,  -35.81,    0.00 /
      DATA B(25456), B(25457), B(25458) /    18.21,  -35.08,    0.00 /
      DATA B(25795), B(25796), B(25797) /    17.40,  -34.26,    0.00 /
      DATA B(26134), B(26135), B(26136) /    16.33,  -33.41,    0.00 /
      DATA B(26473), B(26474), B(26475) /     7.91,  -26.54,    0.00 /
      DATA B(26812), B(26813), B(26814) /     5.88,  -22.95,    0.00 /
      DATA B(27151), B(27152), B(27153) /     4.61,  -21.63,    0.00 /
      DATA B(   34), B(   35), B(   36) /    25.24,  -45.78,    0.00 /
      DATA B(  373), B(  374), B(  375) /    25.24,  -45.71,    0.00 /
      DATA B(  712), B(  713), B(  714) /    25.24,  -45.65,    0.00 /
      DATA B( 1051), B( 1052), B( 1053) /    25.24,  -45.58,    0.00 /
      DATA B( 1390), B( 1391), B( 1392) /    25.23,  -45.51,    0.00 /
      DATA B( 1729), B( 1730), B( 1731) /    25.23,  -45.45,    0.00 /
      DATA B( 2068), B( 2069), B( 2070) /    25.23,  -45.38,    0.00 /
      DATA B( 2407), B( 2408), B( 2409) /    25.23,  -45.31,    0.00 /
      DATA B( 2746), B( 2747), B( 2748) /    25.23,  -45.24,    0.00 /
      DATA B( 3085), B( 3086), B( 3087) /    25.22,  -45.17,    0.00 /
      DATA B( 3424), B( 3425), B( 3426) /    25.22,  -45.11,    0.00 /
      DATA B( 3763), B( 3764), B( 3765) /    25.22,  -45.04,    0.00 /
      DATA B( 4102), B( 4103), B( 4104) /    25.22,  -44.97,    0.00 /
      DATA B( 4441), B( 4442), B( 4443) /    25.22,  -44.90,    0.00 /
      DATA B( 4780), B( 4781), B( 4782) /    25.21,  -44.83,    0.00 /
      DATA B( 5119), B( 5120), B( 5121) /    25.21,  -44.76,    0.00 /
      DATA B( 5458), B( 5459), B( 5460) /    25.21,  -44.69,    0.00 /
      DATA B( 5797), B( 5798), B( 5799) /    25.21,  -44.62,    0.00 /
      DATA B( 6136), B( 6137), B( 6138) /    25.21,  -44.55,    0.00 /
      DATA B( 6475), B( 6476), B( 6477) /    25.20,  -44.48,    0.00 /
      DATA B( 6814), B( 6815), B( 6816) /    25.20,  -44.41,    0.00 /
      DATA B( 7153), B( 7154), B( 7155) /    25.20,  -44.34,    0.00 /
      DATA B( 7492), B( 7493), B( 7494) /    25.20,  -44.26,    0.00 /
      DATA B( 7831), B( 7832), B( 7833) /    25.19,  -44.19,    0.00 /
      DATA B( 8170), B( 8171), B( 8172) /    25.19,  -44.12,    0.00 /
      DATA B( 8509), B( 8510), B( 8511) /    25.19,  -44.05,    0.00 /
      DATA B( 8848), B( 8849), B( 8850) /    25.19,  -43.97,    0.00 /
      DATA B( 9187), B( 9188), B( 9189) /    25.19,  -43.90,    0.00 /
      DATA B( 9526), B( 9527), B( 9528) /    25.18,  -43.82,    0.00 /
      DATA B( 9865), B( 9866), B( 9867) /    25.18,  -43.75,    0.00 /
      DATA B(10204), B(10205), B(10206) /    25.18,  -43.67,    0.00 /
      DATA B(10543), B(10544), B(10545) /    25.18,  -43.59,    0.00 /
      DATA B(10882), B(10883), B(10884) /    25.18,  -43.52,    0.00 /
      DATA B(11221), B(11222), B(11223) /    25.18,  -43.44,    0.00 /
      DATA B(11560), B(11561), B(11562) /    25.18,  -43.36,    0.00 /
      DATA B(11899), B(11900), B(11901) /    25.18,  -43.28,    0.00 /
      DATA B(12238), B(12239), B(12240) /    25.18,  -43.20,    0.00 /
      DATA B(12577), B(12578), B(12579) /    25.18,  -43.12,    0.00 /
      DATA B(12916), B(12917), B(12918) /    25.18,  -43.03,    0.00 /
      DATA B(13255), B(13256), B(13257) /    25.19,  -42.95,    0.00 /
      DATA B(13594), B(13595), B(13596) /    25.19,  -42.86,    0.00 /
      DATA B(13933), B(13934), B(13935) /    25.20,  -42.77,    0.00 /
      DATA B(14272), B(14273), B(14274) /    25.21,  -42.68,    0.00 /
      DATA B(14611), B(14612), B(14613) /    25.22,  -42.58,    0.00 /
      DATA B(14950), B(14951), B(14952) /    25.24,  -42.48,    0.00 /
      DATA B(15289), B(15290), B(15291) /    25.26,  -42.37,    0.00 /
      DATA B(15628), B(15629), B(15630) /    25.28,  -42.25,    0.00 /
      DATA B(15967), B(15968), B(15969) /    25.30,  -42.13,    0.00 /
      DATA B(16306), B(16307), B(16308) /    25.31,  -42.01,    0.00 /
      DATA B(16645), B(16646), B(16647) /    25.32,  -41.88,    0.00 /
      DATA B(16984), B(16985), B(16986) /    25.31,  -41.77,    0.00 /
      DATA B(17323), B(17324), B(17325) /    25.30,  -41.66,    0.00 /
      DATA B(17662), B(17663), B(17664) /    25.26,  -41.58,    0.00 /
      DATA B(18001), B(18002), B(18003) /    23.22,  -42.59,    0.00 /
      DATA B(18340), B(18341), B(18342) /    22.55,  -42.64,    0.00 /
      DATA B(18679), B(18680), B(18681) /    21.88,  -42.70,    0.00 /
      DATA B(19018), B(19019), B(19020) /    21.24,  -42.72,    0.00 /
      DATA B(19357), B(19358), B(19359) /    20.60,  -42.72,    0.00 /
      DATA B(19696), B(19697), B(19698) /    19.89,  -42.72,    0.00 /
      DATA B(20035), B(20036), B(20037) /    21.45,  -41.59,    0.00 /
      DATA B(20374), B(20375), B(20376) /    21.46,  -41.43,    0.00 /
      DATA B(20713), B(20714), B(20715) /    21.49,  -41.21,    0.00 /
      DATA B(21052), B(21053), B(21054) /    21.51,  -40.98,    0.00 /
      DATA B(21391), B(21392), B(21393) /    21.49,  -40.73,    0.00 /
      DATA B(21730), B(21731), B(21732) /    21.42,  -40.45,    0.00 /
      DATA B(22069), B(22070), B(22071) /    21.29,  -40.14,    0.00 /
      DATA B(22408), B(22409), B(22410) /    21.10,  -39.78,    0.00 /
      DATA B(22747), B(22748), B(22749) /    20.83,  -39.34,    0.00 /
      DATA B(23086), B(23087), B(23088) /    20.48,  -38.80,    0.00 /
      DATA B(23425), B(23426), B(23427) /    20.12,  -38.23,    0.00 /
      DATA B(23764), B(23765), B(23766) /    19.73,  -37.66,    0.00 /
      DATA B(24103), B(24104), B(24105) /    19.34,  -37.08,    0.00 /
      DATA B(24442), B(24443), B(24444) /    18.91,  -36.44,    0.00 /
      DATA B(24781), B(24782), B(24783) /    18.40,  -35.73,    0.00 /
      DATA B(25120), B(25121), B(25122) /    17.73,  -34.90,    0.00 /
      DATA B(25459), B(25460), B(25461) /    16.84,  -33.95,    0.00 /
      DATA B(25798), B(25799), B(25800) /    15.58,  -33.04,    0.00 /
      DATA B(26137), B(26138), B(26139) /     8.44,  -27.06,    0.00 /
      DATA B(26476), B(26477), B(26478) /     6.83,  -25.58,    0.00 /
      DATA B(26815), B(26816), B(26817) /     5.03,  -22.42,    0.00 /
      DATA B(27154), B(27155), B(27156) /     3.98,  -21.51,    0.00 /
      DATA B(   37), B(   38), B(   39) /    25.21,  -45.76,    0.00 /
      DATA B(  376), B(  377), B(  378) /    25.21,  -45.69,    0.00 /
      DATA B(  715), B(  716), B(  717) /    25.21,  -45.63,    0.00 /
      DATA B( 1054), B( 1055), B( 1056) /    25.21,  -45.56,    0.00 /
      DATA B( 1393), B( 1394), B( 1395) /    25.21,  -45.49,    0.00 /
      DATA B( 1732), B( 1733), B( 1734) /    25.20,  -45.43,    0.00 /
      DATA B( 2071), B( 2072), B( 2073) /    25.20,  -45.36,    0.00 /
      DATA B( 2410), B( 2411), B( 2412) /    25.20,  -45.29,    0.00 /
      DATA B( 2749), B( 2750), B( 2751) /    25.20,  -45.22,    0.00 /
      DATA B( 3088), B( 3089), B( 3090) /    25.20,  -45.15,    0.00 /
      DATA B( 3427), B( 3428), B( 3429) /    25.19,  -45.09,    0.00 /
      DATA B( 3766), B( 3767), B( 3768) /    25.19,  -45.02,    0.00 /
      DATA B( 4105), B( 4106), B( 4107) /    25.19,  -44.95,    0.00 /
      DATA B( 4444), B( 4445), B( 4446) /    25.19,  -44.88,    0.00 /
      DATA B( 4783), B( 4784), B( 4785) /    25.19,  -44.81,    0.00 /
      DATA B( 5122), B( 5123), B( 5124) /    25.18,  -44.74,    0.00 /
      DATA B( 5461), B( 5462), B( 5463) /    25.18,  -44.67,    0.00 /
      DATA B( 5800), B( 5801), B( 5802) /    25.18,  -44.60,    0.00 /
      DATA B( 6139), B( 6140), B( 6141) /    25.18,  -44.53,    0.00 /
      DATA B( 6478), B( 6479), B( 6480) /    25.17,  -44.46,    0.00 /
      DATA B( 6817), B( 6818), B( 6819) /    25.17,  -44.38,    0.00 /
      DATA B( 7156), B( 7157), B( 7158) /    25.17,  -44.31,    0.00 /
      DATA B( 7495), B( 7496), B( 7497) /    25.17,  -44.24,    0.00 /
      DATA B( 7834), B( 7835), B( 7836) /    25.16,  -44.17,    0.00 /
      DATA B( 8173), B( 8174), B( 8175) /    25.16,  -44.09,    0.00 /
      DATA B( 8512), B( 8513), B( 8514) /    25.16,  -44.02,    0.00 /
      DATA B( 8851), B( 8852), B( 8853) /    25.16,  -43.95,    0.00 /
      DATA B( 9190), B( 9191), B( 9192) /    25.15,  -43.87,    0.00 /
      DATA B( 9529), B( 9530), B( 9531) /    25.15,  -43.79,    0.00 /
      DATA B( 9868), B( 9869), B( 9870) /    25.15,  -43.72,    0.00 /
      DATA B(10207), B(10208), B(10209) /    25.15,  -43.64,    0.00 /
      DATA B(10546), B(10547), B(10548) /    25.15,  -43.56,    0.00 /
      DATA B(10885), B(10886), B(10887) /    25.15,  -43.49,    0.00 /
      DATA B(11224), B(11225), B(11226) /    25.15,  -43.41,    0.00 /
      DATA B(11563), B(11564), B(11565) /    25.15,  -43.33,    0.00 /
      DATA B(11902), B(11903), B(11904) /    25.15,  -43.25,    0.00 /
      DATA B(12241), B(12242), B(12243) /    25.15,  -43.16,    0.00 /
      DATA B(12580), B(12581), B(12582) /    25.15,  -43.08,    0.00 /
      DATA B(12919), B(12920), B(12921) /    25.15,  -42.99,    0.00 /
      DATA B(13258), B(13259), B(13260) /    25.16,  -42.91,    0.00 /
      DATA B(13597), B(13598), B(13599) /    25.16,  -42.82,    0.00 /
      DATA B(13936), B(13937), B(13938) /    25.17,  -42.73,    0.00 /
      DATA B(14275), B(14276), B(14277) /    25.19,  -42.63,    0.00 /
      DATA B(14614), B(14615), B(14616) /    25.20,  -42.53,    0.00 /
      DATA B(14953), B(14954), B(14955) /    25.23,  -42.42,    0.00 /
      DATA B(15292), B(15293), B(15294) /    25.26,  -42.30,    0.00 /
      DATA B(15631), B(15632), B(15633) /    25.30,  -42.17,    0.00 /
      DATA B(15970), B(15971), B(15972) /    25.33,  -42.04,    0.00 /
      DATA B(16309), B(16310), B(16311) /    25.35,  -41.90,    0.00 /
      DATA B(16648), B(16649), B(16650) /    25.35,  -41.78,    0.00 /
      DATA B(16987), B(16988), B(16989) /    25.33,  -41.66,    0.00 /
      DATA B(17326), B(17327), B(17328) /    25.30,  -41.59,    0.00 /
      DATA B(17665), B(17666), B(17667) /    23.53,  -42.37,    0.00 /
      DATA B(18004), B(18005), B(18006) /    22.85,  -42.45,    0.00 /
      DATA B(18343), B(18344), B(18345) /    22.17,  -42.51,    0.00 /
      DATA B(18682), B(18683), B(18684) /    21.53,  -42.55,    0.00 /
      DATA B(19021), B(19022), B(19023) /    20.89,  -42.57,    0.00 /
      DATA B(19360), B(19361), B(19362) /    20.24,  -42.58,    0.00 /
      DATA B(19699), B(19700), B(19701) /    19.51,  -42.59,    0.00 /
      DATA B(20038), B(20039), B(20040) /    21.19,  -41.48,    0.00 /
      DATA B(20377), B(20378), B(20379) /    21.22,  -41.30,    0.00 /
      DATA B(20716), B(20717), B(20718) /    21.24,  -41.09,    0.00 /
      DATA B(21055), B(21056), B(21057) /    21.23,  -40.86,    0.00 /
      DATA B(21394), B(21395), B(21396) /    21.16,  -40.60,    0.00 /
      DATA B(21733), B(21734), B(21735) /    21.05,  -40.30,    0.00 /
      DATA B(22072), B(22073), B(22074) /    20.86,  -39.94,    0.00 /
      DATA B(22411), B(22412), B(22413) /    20.59,  -39.50,    0.00 /
      DATA B(22750), B(22751), B(22752) /    18.86,  -38.02,    0.00 /
      DATA B(23089), B(23090), B(23091) /    19.86,  -38.36,    0.00 /
      DATA B(23428), B(23429), B(23430) /    19.46,  -37.77,    0.00 /
      DATA B(23767), B(23768), B(23769) /    19.03,  -37.17,    0.00 /
      DATA B(24106), B(24107), B(24108) /    18.57,  -36.50,    0.00 /
      DATA B(24445), B(24446), B(24447) /    18.00,  -35.72,    0.00 /
      DATA B(24784), B(24785), B(24786) /    17.25,  -34.79,    0.00 /
      DATA B(25123), B(25124), B(25125) /    16.24,  -33.68,    0.00 /
      DATA B(25462), B(25463), B(25464) /    14.80,  -32.62,    0.00 /
      DATA B(25801), B(25802), B(25803) /     8.93,  -27.68,    0.00 /
      DATA B(26140), B(26141), B(26142) /     7.17,  -26.13,    0.00 /
      DATA B(26479), B(26480), B(26481) /     5.95,  -24.86,    0.00 /
      DATA B(26818), B(26819), B(26820) /     4.37,  -22.01,    0.00 /
      DATA B(27157), B(27158), B(27159) /     3.47,  -21.37,    0.00 /
      DATA B(   40), B(   41), B(   42) /    25.19,  -45.74,    0.00 /
      DATA B(  379), B(  380), B(  381) /    25.18,  -45.68,    0.00 /
      DATA B(  718), B(  719), B(  720) /    25.18,  -45.61,    0.00 /
      DATA B( 1057), B( 1058), B( 1059) /    25.18,  -45.54,    0.00 /
      DATA B( 1396), B( 1397), B( 1398) /    25.18,  -45.47,    0.00 /
      DATA B( 1735), B( 1736), B( 1737) /    25.18,  -45.41,    0.00 /
      DATA B( 2074), B( 2075), B( 2076) /    25.17,  -45.34,    0.00 /
      DATA B( 2413), B( 2414), B( 2415) /    25.17,  -45.27,    0.00 /
      DATA B( 2752), B( 2753), B( 2754) /    25.17,  -45.20,    0.00 /
      DATA B( 3091), B( 3092), B( 3093) /    25.17,  -45.13,    0.00 /
      DATA B( 3430), B( 3431), B( 3432) /    25.17,  -45.07,    0.00 /
      DATA B( 3769), B( 3770), B( 3771) /    25.16,  -45.00,    0.00 /
      DATA B( 4108), B( 4109), B( 4110) /    25.16,  -44.93,    0.00 /
      DATA B( 4447), B( 4448), B( 4449) /    25.16,  -44.86,    0.00 /
      DATA B( 4786), B( 4787), B( 4788) /    25.16,  -44.79,    0.00 /
      DATA B( 5125), B( 5126), B( 5127) /    25.15,  -44.72,    0.00 /
      DATA B( 5464), B( 5465), B( 5466) /    25.15,  -44.65,    0.00 /
      DATA B( 5803), B( 5804), B( 5805) /    25.15,  -44.58,    0.00 /
      DATA B( 6142), B( 6143), B( 6144) /    25.15,  -44.50,    0.00 /
      DATA B( 6481), B( 6482), B( 6483) /    25.14,  -44.43,    0.00 /
      DATA B( 6820), B( 6821), B( 6822) /    25.14,  -44.36,    0.00 /
      DATA B( 7159), B( 7160), B( 7161) /    25.14,  -44.29,    0.00 /
      DATA B( 7498), B( 7499), B( 7500) /    25.14,  -44.22,    0.00 /
      DATA B( 7837), B( 7838), B( 7839) /    25.13,  -44.14,    0.00 /
      DATA B( 8176), B( 8177), B( 8178) /    25.13,  -44.07,    0.00 /
      DATA B( 8515), B( 8516), B( 8517) /    25.13,  -43.99,    0.00 /
      DATA B( 8854), B( 8855), B( 8856) /    25.13,  -43.92,    0.00 /
      DATA B( 9193), B( 9194), B( 9195) /    25.12,  -43.84,    0.00 /
      DATA B( 9532), B( 9533), B( 9534) /    25.12,  -43.77,    0.00 /
      DATA B( 9871), B( 9872), B( 9873) /    25.12,  -43.69,    0.00 /
      DATA B(10210), B(10211), B(10212) /    25.12,  -43.61,    0.00 /
      DATA B(10549), B(10550), B(10551) /    25.12,  -43.53,    0.00 /
      DATA B(10888), B(10889), B(10890) /    25.11,  -43.45,    0.00 /
      DATA B(11227), B(11228), B(11229) /    25.11,  -43.37,    0.00 /
      DATA B(11566), B(11567), B(11568) /    25.11,  -43.29,    0.00 /
      DATA B(11905), B(11906), B(11907) /    25.11,  -43.21,    0.00 /
      DATA B(12244), B(12245), B(12246) /    25.11,  -43.13,    0.00 /
      DATA B(12583), B(12584), B(12585) /    25.12,  -43.04,    0.00 /
      DATA B(12922), B(12923), B(12924) /    25.12,  -42.96,    0.00 /
      DATA B(13261), B(13262), B(13263) /    25.12,  -42.87,    0.00 /
      DATA B(13600), B(13601), B(13602) /    25.13,  -42.78,    0.00 /
      DATA B(13939), B(13940), B(13941) /    25.14,  -42.68,    0.00 /
      DATA B(14278), B(14279), B(14280) /    25.16,  -42.59,    0.00 /
      DATA B(14617), B(14618), B(14619) /    25.18,  -42.48,    0.00 /
      DATA B(14956), B(14957), B(14958) /    25.22,  -42.37,    0.00 /
      DATA B(15295), B(15296), B(15297) /    25.26,  -42.24,    0.00 /
      DATA B(15634), B(15635), B(15636) /    25.32,  -42.09,    0.00 /
      DATA B(15973), B(15974), B(15975) /    25.36,  -41.94,    0.00 /
      DATA B(16312), B(16313), B(16314) /    25.39,  -41.80,    0.00 /
      DATA B(16651), B(16652), B(16653) /    25.38,  -41.68,    0.00 /
      DATA B(16990), B(16991), B(16992) /    24.58,  -42.04,    0.00 /
      DATA B(17329), B(17330), B(17331) /    23.87,  -42.15,    0.00 /
      DATA B(17668), B(17669), B(17670) /    23.18,  -42.24,    0.00 /
      DATA B(18007), B(18008), B(18009) /    22.50,  -42.31,    0.00 /
      DATA B(18346), B(18347), B(18348) /    21.84,  -42.36,    0.00 /
      DATA B(18685), B(18686), B(18687) /    21.20,  -42.40,    0.00 /
      DATA B(19024), B(19025), B(19026) /    20.56,  -42.42,    0.00 /
      DATA B(19363), B(19364), B(19365) /    19.89,  -42.44,    0.00 /
      DATA B(19702), B(19703), B(19704) /    19.13,  -42.45,    0.00 /
      DATA B(20041), B(20042), B(20043) /    20.96,  -41.38,    0.00 /
      DATA B(20380), B(20381), B(20382) /    20.97,  -41.18,    0.00 /
      DATA B(20719), B(20720), B(20721) /    20.97,  -40.97,    0.00 /
      DATA B(21058), B(21059), B(21060) /    20.92,  -40.73,    0.00 /
      DATA B(21397), B(21398), B(21399) /    20.81,  -40.45,    0.00 /
      DATA B(21736), B(21737), B(21738) /    20.64,  -40.11,    0.00 /
      DATA B(22075), B(22076), B(22077) /    20.38,  -39.68,    0.00 /
      DATA B(22414), B(22415), B(22416) /    20.06,  -39.15,    0.00 /
      DATA B(22753), B(22754), B(22755) /    19.64,  -38.53,    0.00 /
      DATA B(23092), B(23093), B(23094) /    19.21,  -37.91,    0.00 /
      DATA B(23431), B(23432), B(23433) /    18.75,  -37.28,    0.00 /
      DATA B(23770), B(23771), B(23772) /    18.23,  -36.61,    0.00 /
      DATA B(24109), B(24110), B(24111) /    17.61,  -35.79,    0.00 /
      DATA B(24448), B(24449), B(24450) /    16.79,  -34.77,    0.00 /
      DATA B(24787), B(24788), B(24789) /    15.63,  -33.52,    0.00 /
      DATA B(25126), B(25127), B(25128) /    14.04,  -32.21,    0.00 /
      DATA B(25465), B(25466), B(25467) /     9.29,  -28.32,    0.00 /
      DATA B(25804), B(25805), B(25806) /     7.47,  -26.60,    0.00 /
      DATA B(26143), B(26144), B(26145) /     6.17,  -25.33,    0.00 /
      DATA B(26482), B(26483), B(26484) /     5.26,  -24.37,    0.00 /
      DATA B(26821), B(26822), B(26823) /     4.62,  -23.64,    0.00 /
      DATA B(27160), B(27161), B(27162) /     3.02,  -21.21,    0.00 /
      DATA B(   43), B(   44), B(   45) /    25.16,  -45.72,    0.00 /
      DATA B(  382), B(  383), B(  384) /    25.16,  -45.66,    0.00 /
      DATA B(  721), B(  722), B(  723) /    25.15,  -45.59,    0.00 /
      DATA B( 1060), B( 1061), B( 1062) /    25.15,  -45.52,    0.00 /
      DATA B( 1399), B( 1400), B( 1401) /    25.15,  -45.46,    0.00 /
      DATA B( 1738), B( 1739), B( 1740) /    25.15,  -45.39,    0.00 /
      DATA B( 2077), B( 2078), B( 2079) /    25.15,  -45.32,    0.00 /
      DATA B( 2416), B( 2417), B( 2418) /    25.14,  -45.25,    0.00 /
      DATA B( 2755), B( 2756), B( 2757) /    25.14,  -45.18,    0.00 /
      DATA B( 3094), B( 3095), B( 3096) /    25.14,  -45.11,    0.00 /
      DATA B( 3433), B( 3434), B( 3435) /    25.14,  -45.04,    0.00 /
      DATA B( 3772), B( 3773), B( 3774) /    25.13,  -44.98,    0.00 /
      DATA B( 4111), B( 4112), B( 4113) /    25.13,  -44.91,    0.00 /
      DATA B( 4450), B( 4451), B( 4452) /    25.13,  -44.84,    0.00 /
      DATA B( 4789), B( 4790), B( 4791) /    25.13,  -44.77,    0.00 /
      DATA B( 5128), B( 5129), B( 5130) /    25.12,  -44.69,    0.00 /
      DATA B( 5467), B( 5468), B( 5469) /    25.12,  -44.62,    0.00 /
      DATA B( 5806), B( 5807), B( 5808) /    25.12,  -44.55,    0.00 /
      DATA B( 6145), B( 6146), B( 6147) /    25.12,  -44.48,    0.00 /
      DATA B( 6484), B( 6485), B( 6486) /    25.11,  -44.41,    0.00 /
      DATA B( 6823), B( 6824), B( 6825) /    25.11,  -44.34,    0.00 /
      DATA B( 7162), B( 7163), B( 7164) /    25.11,  -44.26,    0.00 /
      DATA B( 7501), B( 7502), B( 7503) /    25.11,  -44.19,    0.00 /
      DATA B( 7840), B( 7841), B( 7842) /    25.10,  -44.12,    0.00 /
      DATA B( 8179), B( 8180), B( 8181) /    25.10,  -44.04,    0.00 /
      DATA B( 8518), B( 8519), B( 8520) /    25.10,  -43.97,    0.00 /
      DATA B( 8857), B( 8858), B( 8859) /    25.09,  -43.89,    0.00 /
      DATA B( 9196), B( 9197), B( 9198) /    25.09,  -43.82,    0.00 /
      DATA B( 9535), B( 9536), B( 9537) /    25.09,  -43.74,    0.00 /
      DATA B( 9874), B( 9875), B( 9876) /    25.09,  -43.66,    0.00 /
      DATA B(10213), B(10214), B(10215) /    25.08,  -43.58,    0.00 /
      DATA B(10552), B(10553), B(10554) /    25.08,  -43.50,    0.00 /
      DATA B(10891), B(10892), B(10893) /    25.08,  -43.42,    0.00 /
      DATA B(11230), B(11231), B(11232) /    25.08,  -43.34,    0.00 /
      DATA B(11569), B(11570), B(11571) /    25.08,  -43.26,    0.00 /
      DATA B(11908), B(11909), B(11910) /    25.08,  -43.18,    0.00 /
      DATA B(12247), B(12248), B(12249) /    25.08,  -43.09,    0.00 /
      DATA B(12586), B(12587), B(12588) /    25.08,  -43.00,    0.00 /
      DATA B(12925), B(12926), B(12927) /    25.09,  -42.92,    0.00 /
      DATA B(13264), B(13265), B(13266) /    25.09,  -42.83,    0.00 /
      DATA B(13603), B(13604), B(13605) /    25.10,  -42.73,    0.00 /
      DATA B(13942), B(13943), B(13944) /    25.11,  -42.64,    0.00 /
      DATA B(14281), B(14282), B(14283) /    25.13,  -42.54,    0.00 /
      DATA B(14620), B(14621), B(14622) /    25.16,  -42.43,    0.00 /
      DATA B(14959), B(14960), B(14961) /    25.19,  -42.32,    0.00 /
      DATA B(15298), B(15299), B(15300) /    25.25,  -42.18,    0.00 /
      DATA B(15637), B(15638), B(15639) /    25.33,  -42.02,    0.00 /
      DATA B(15976), B(15977), B(15978) /    25.41,  -41.84,    0.00 /
      DATA B(16315), B(16316), B(16317) /    25.43,  -41.73,    0.00 /
      DATA B(16654), B(16655), B(16656) /    24.94,  -41.84,    0.00 /
      DATA B(16993), B(16994), B(16995) /    24.24,  -41.93,    0.00 /
      DATA B(17332), B(17333), B(17334) /    23.54,  -42.02,    0.00 /
      DATA B(17671), B(17672), B(17673) /    22.86,  -42.09,    0.00 /
      DATA B(18010), B(18011), B(18012) /    22.19,  -42.15,    0.00 /
      DATA B(18349), B(18350), B(18351) /    21.54,  -42.20,    0.00 /
      DATA B(18688), B(18689), B(18690) /    20.89,  -42.25,    0.00 /
      DATA B(19027), B(19028), B(19029) /    20.24,  -42.28,    0.00 /
      DATA B(19366), B(19367), B(19368) /    19.53,  -42.31,    0.00 /
      DATA B(19705), B(19706), B(19707) /    18.76,  -42.32,    0.00 /
      DATA B(20044), B(20045), B(20046) /    20.70,  -41.27,    0.00 /
      DATA B(20383), B(20384), B(20385) /    20.70,  -41.07,    0.00 /
      DATA B(20722), B(20723), B(20724) /    20.66,  -40.85,    0.00 /
      DATA B(21061), B(21062), B(21063) /    20.57,  -40.59,    0.00 /
      DATA B(21400), B(21401), B(21402) /    20.42,  -40.28,    0.00 /
      DATA B(21739), B(21740), B(21741) /    20.18,  -39.87,    0.00 /
      DATA B(22078), B(22079), B(22080) /    19.86,  -39.36,    0.00 /
      DATA B(22417), B(22418), B(22419) /    19.45,  -38.72,    0.00 /
      DATA B(22756), B(22757), B(22758) /    18.99,  -38.07,    0.00 /
      DATA B(23095), B(23096), B(23097) /    18.50,  -37.42,    0.00 /
      DATA B(23434), B(23435), B(23436) /    17.93,  -36.73,    0.00 /
      DATA B(23773), B(23774), B(23775) /    17.25,  -35.91,    0.00 /
      DATA B(24112), B(24113), B(24114) /    16.35,  -34.85,    0.00 /
      DATA B(24451), B(24452), B(24453) /    15.07,  -33.51,    0.00 /
      DATA B(24790), B(24791), B(24792) /    13.41,  -31.85,    0.00 /
      DATA B(25129), B(25130), B(25131) /     9.62,  -28.88,    0.00 /
      DATA B(25468), B(25469), B(25470) /     7.75,  -27.04,    0.00 /
      DATA B(25807), B(25808), B(25809) /     6.35,  -25.72,    0.00 /
      DATA B(26146), B(26147), B(26148) /     5.39,  -24.75,    0.00 /
      DATA B(26485), B(26486), B(26487) /     4.70,  -24.01,    0.00 /
      DATA B(26824), B(26825), B(26826) /     4.21,  -23.44,    0.00 /
      DATA B(27163), B(27164), B(27165) /     2.62,  -21.05,    0.00 /
      DATA B(   46), B(   47), B(   48) /    25.13,  -45.71,    0.00 /
      DATA B(  385), B(  386), B(  387) /    25.13,  -45.64,    0.00 /
      DATA B(  724), B(  725), B(  726) /    25.13,  -45.57,    0.00 /
      DATA B( 1063), B( 1064), B( 1065) /    25.12,  -45.50,    0.00 /
      DATA B( 1402), B( 1403), B( 1404) /    25.12,  -45.44,    0.00 /
      DATA B( 1741), B( 1742), B( 1743) /    25.12,  -45.37,    0.00 /
      DATA B( 2080), B( 2081), B( 2082) /    25.12,  -45.30,    0.00 /
      DATA B( 2419), B( 2420), B( 2421) /    25.11,  -45.23,    0.00 /
      DATA B( 2758), B( 2759), B( 2760) /    25.11,  -45.16,    0.00 /
      DATA B( 3097), B( 3098), B( 3099) /    25.11,  -45.09,    0.00 /
      DATA B( 3436), B( 3437), B( 3438) /    25.11,  -45.02,    0.00 /
      DATA B( 3775), B( 3776), B( 3777) /    25.10,  -44.95,    0.00 /
      DATA B( 4114), B( 4115), B( 4116) /    25.10,  -44.88,    0.00 /
      DATA B( 4453), B( 4454), B( 4455) /    25.10,  -44.81,    0.00 /
      DATA B( 4792), B( 4793), B( 4794) /    25.10,  -44.74,    0.00 /
      DATA B( 5131), B( 5132), B( 5133) /    25.09,  -44.67,    0.00 /
      DATA B( 5470), B( 5471), B( 5472) /    25.09,  -44.60,    0.00 /
      DATA B( 5809), B( 5810), B( 5811) /    25.09,  -44.53,    0.00 /
      DATA B( 6148), B( 6149), B( 6150) /    25.09,  -44.46,    0.00 /
      DATA B( 6487), B( 6488), B( 6489) /    25.08,  -44.38,    0.00 /
      DATA B( 6826), B( 6827), B( 6828) /    25.08,  -44.31,    0.00 /
      DATA B( 7165), B( 7166), B( 7167) /    25.08,  -44.24,    0.00 /
      DATA B( 7504), B( 7505), B( 7506) /    25.07,  -44.16,    0.00 /
      DATA B( 7843), B( 7844), B( 7845) /    25.07,  -44.09,    0.00 /
      DATA B( 8182), B( 8183), B( 8184) /    25.07,  -44.02,    0.00 /
      DATA B( 8521), B( 8522), B( 8523) /    25.07,  -43.94,    0.00 /
      DATA B( 8860), B( 8861), B( 8862) /    25.06,  -43.86,    0.00 /
      DATA B( 9199), B( 9200), B( 9201) /    25.06,  -43.79,    0.00 /
      DATA B( 9538), B( 9539), B( 9540) /    25.06,  -43.71,    0.00 /
      DATA B( 9877), B( 9878), B( 9879) /    25.05,  -43.63,    0.00 /
      DATA B(10216), B(10217), B(10218) /    25.05,  -43.55,    0.00 /
      DATA B(10555), B(10556), B(10557) /    25.05,  -43.47,    0.00 /
      DATA B(10894), B(10895), B(10896) /    25.05,  -43.39,    0.00 /
      DATA B(11233), B(11234), B(11235) /    25.05,  -43.31,    0.00 /
      DATA B(11572), B(11573), B(11574) /    25.04,  -43.22,    0.00 /
      DATA B(11911), B(11912), B(11913) /    25.04,  -43.14,    0.00 /
      DATA B(12250), B(12251), B(12252) /    25.05,  -43.05,    0.00 /
      DATA B(12589), B(12590), B(12591) /    25.05,  -42.96,    0.00 /
      DATA B(12928), B(12929), B(12930) /    25.05,  -42.87,    0.00 /
      DATA B(13267), B(13268), B(13269) /    25.05,  -42.78,    0.00 /
      DATA B(13606), B(13607), B(13608) /    25.06,  -42.69,    0.00 /
      DATA B(13945), B(13946), B(13947) /    25.07,  -42.59,    0.00 /
      DATA B(14284), B(14285), B(14286) /    25.09,  -42.49,    0.00 /
      DATA B(14623), B(14624), B(14625) /    25.12,  -42.38,    0.00 /
      DATA B(14962), B(14963), B(14964) /    25.16,  -42.26,    0.00 /
      DATA B(15301), B(15302), B(15303) /    25.22,  -42.13,    0.00 /
      DATA B(15640), B(15641), B(15642) /    25.31,  -41.97,    0.00 /
      DATA B(15979), B(15980), B(15981) /    25.38,  -41.77,    0.00 /
      DATA B(16318), B(16319), B(16320) /    25.39,  -41.58,    0.00 /
      DATA B(16657), B(16658), B(16659) /    24.66,  -41.72,    0.00 /
      DATA B(16996), B(16997), B(16998) /    23.95,  -41.80,    0.00 /
      DATA B(17335), B(17336), B(17337) /    23.26,  -41.86,    0.00 /
      DATA B(17674), B(17675), B(17676) /    22.58,  -41.92,    0.00 /
      DATA B(18013), B(18014), B(18015) /    21.90,  -41.99,    0.00 /
      DATA B(18352), B(18353), B(18354) /    21.24,  -42.05,    0.00 /
      DATA B(18691), B(18692), B(18693) /    20.58,  -42.11,    0.00 /
      DATA B(19030), B(19031), B(19032) /    19.91,  -42.15,    0.00 /
      DATA B(19369), B(19370), B(19371) /    19.18,  -42.19,    0.00 /
      DATA B(19708), B(19709), B(19710) /    20.49,  -41.36,    0.00 /
      DATA B(20047), B(20048), B(20049) /    20.44,  -41.17,    0.00 /
      DATA B(20386), B(20387), B(20388) /    20.40,  -40.96,    0.00 /
      DATA B(20725), B(20726), B(20727) /    20.33,  -40.72,    0.00 /
      DATA B(21064), B(21065), B(21066) /    20.19,  -40.44,    0.00 /
      DATA B(21403), B(21404), B(21405) /    19.98,  -40.07,    0.00 /
      DATA B(21742), B(21743), B(21744) /    19.68,  -39.59,    0.00 /
      DATA B(22081), B(22082), B(22083) /    19.28,  -38.96,    0.00 /
      DATA B(22420), B(22421), B(22422) /    18.82,  -38.27,    0.00 /
      DATA B(22759), B(22760), B(22761) /    18.30,  -37.58,    0.00 /
      DATA B(23098), B(23099), B(23100) /    17.70,  -36.86,    0.00 /
      DATA B(23437), B(23438), B(23439) /    16.96,  -36.04,    0.00 /
      DATA B(23776), B(23777), B(23778) /    15.97,  -34.99,    0.00 /
      DATA B(24115), B(24116), B(24117) /    14.61,  -33.59,    0.00 /
      DATA B(24454), B(24455), B(24456) /    12.81,  -31.88,    0.00 /
      DATA B(24793), B(24794), B(24795) /     9.92,  -29.38,    0.00 /
      DATA B(25132), B(25133), B(25134) /     7.96,  -27.46,    0.00 /
      DATA B(25471), B(25472), B(25473) /     6.48,  -26.08,    0.00 /
      DATA B(25810), B(25811), B(25812) /     5.47,  -25.07,    0.00 /
      DATA B(26149), B(26150), B(26151) /     4.75,  -24.33,    0.00 /
      DATA B(26488), B(26489), B(26490) /     4.23,  -23.75,    0.00 /
      DATA B(26827), B(26828), B(26829) /     3.86,  -23.29,    0.00 /
      DATA B(27166), B(27167), B(27168) /     2.25,  -20.90,    0.00 /
      DATA B(   49), B(   50), B(   51) /    25.10,  -45.69,    0.00 /
      DATA B(  388), B(  389), B(  390) /    25.10,  -45.62,    0.00 /
      DATA B(  727), B(  728), B(  729) /    25.10,  -45.55,    0.00 /
      DATA B( 1066), B( 1067), B( 1068) /    25.10,  -45.48,    0.00 /
      DATA B( 1405), B( 1406), B( 1407) /    25.09,  -45.42,    0.00 /
      DATA B( 1744), B( 1745), B( 1746) /    25.09,  -45.35,    0.00 /
      DATA B( 2083), B( 2084), B( 2085) /    25.09,  -45.28,    0.00 /
      DATA B( 2422), B( 2423), B( 2424) /    25.09,  -45.21,    0.00 /
      DATA B( 2761), B( 2762), B( 2763) /    25.08,  -45.14,    0.00 /
      DATA B( 3100), B( 3101), B( 3102) /    25.08,  -45.07,    0.00 /
      DATA B( 3439), B( 3440), B( 3441) /    25.08,  -45.00,    0.00 /
      DATA B( 3778), B( 3779), B( 3780) /    25.08,  -44.93,    0.00 /
      DATA B( 4117), B( 4118), B( 4119) /    25.07,  -44.86,    0.00 /
      DATA B( 4456), B( 4457), B( 4458) /    25.07,  -44.79,    0.00 /
      DATA B( 4795), B( 4796), B( 4797) /    25.07,  -44.72,    0.00 /
      DATA B( 5134), B( 5135), B( 5136) /    25.06,  -44.65,    0.00 /
      DATA B( 5473), B( 5474), B( 5475) /    25.06,  -44.58,    0.00 /
      DATA B( 5812), B( 5813), B( 5814) /    25.06,  -44.51,    0.00 /
      DATA B( 6151), B( 6152), B( 6153) /    25.06,  -44.43,    0.00 /
      DATA B( 6490), B( 6491), B( 6492) /    25.05,  -44.36,    0.00 /
      DATA B( 6829), B( 6830), B( 6831) /    25.05,  -44.29,    0.00 /
      DATA B( 7168), B( 7169), B( 7170) /    25.05,  -44.21,    0.00 /
      DATA B( 7507), B( 7508), B( 7509) /    25.04,  -44.14,    0.00 /
      DATA B( 7846), B( 7847), B( 7848) /    25.04,  -44.06,    0.00 /
      DATA B( 8185), B( 8186), B( 8187) /    25.04,  -43.99,    0.00 /
      DATA B( 8524), B( 8525), B( 8526) /    25.03,  -43.91,    0.00 /
      DATA B( 8863), B( 8864), B( 8865) /    25.03,  -43.84,    0.00 /
      DATA B( 9202), B( 9203), B( 9204) /    25.03,  -43.76,    0.00 /
      DATA B( 9541), B( 9542), B( 9543) /    25.02,  -43.68,    0.00 /
      DATA B( 9880), B( 9881), B( 9882) /    25.02,  -43.60,    0.00 /
      DATA B(10219), B(10220), B(10221) /    25.02,  -43.52,    0.00 /
      DATA B(10558), B(10559), B(10560) /    25.01,  -43.44,    0.00 /
      DATA B(10897), B(10898), B(10899) /    25.01,  -43.36,    0.00 /
      DATA B(11236), B(11237), B(11238) /    25.01,  -43.27,    0.00 /
      DATA B(11575), B(11576), B(11577) /    25.01,  -43.19,    0.00 /
      DATA B(11914), B(11915), B(11916) /    25.01,  -43.10,    0.00 /
      DATA B(12253), B(12254), B(12255) /    25.01,  -43.01,    0.00 /
      DATA B(12592), B(12593), B(12594) /    25.01,  -42.92,    0.00 /
      DATA B(12931), B(12932), B(12933) /    25.01,  -42.83,    0.00 /
      DATA B(13270), B(13271), B(13272) /    25.02,  -42.74,    0.00 /
      DATA B(13609), B(13610), B(13611) /    25.02,  -42.64,    0.00 /
      DATA B(13948), B(13949), B(13950) /    25.03,  -42.54,    0.00 /
      DATA B(14287), B(14288), B(14289) /    25.05,  -42.43,    0.00 /
      DATA B(14626), B(14627), B(14628) /    25.07,  -42.32,    0.00 /
      DATA B(14965), B(14966), B(14967) /    25.11,  -42.20,    0.00 /
      DATA B(15304), B(15305), B(15306) /    25.16,  -42.07,    0.00 /
      DATA B(15643), B(15644), B(15645) /    25.23,  -41.90,    0.00 /
      DATA B(15982), B(15983), B(15984) /    25.28,  -41.68,    0.00 /
      DATA B(16321), B(16322), B(16323) /    25.11,  -41.44,    0.00 /
      DATA B(16660), B(16661), B(16662) /    24.42,  -41.55,    0.00 /
      DATA B(16999), B(17000), B(17001) /    23.70,  -41.63,    0.00 /
      DATA B(17338), B(17339), B(17340) /    23.00,  -41.69,    0.00 /
      DATA B(17677), B(17678), B(17679) /    22.31,  -41.76,    0.00 /
      DATA B(18016), B(18017), B(18018) /    21.62,  -41.83,    0.00 /
      DATA B(18355), B(18356), B(18357) /    20.94,  -41.91,    0.00 /
      DATA B(18694), B(18695), B(18696) /    20.27,  -41.98,    0.00 /
      DATA B(19033), B(19034), B(19035) /    19.59,  -42.03,    0.00 /
      DATA B(19372), B(19373), B(19374) /    18.86,  -42.07,    0.00 /
      DATA B(19711), B(19712), B(19713) /    20.16,  -41.27,    0.00 /
      DATA B(20050), B(20051), B(20052) /    20.14,  -41.06,    0.00 /
      DATA B(20389), B(20390), B(20391) /    20.08,  -40.84,    0.00 /
      DATA B(20728), B(20729), B(20730) /    19.96,  -40.58,    0.00 /
      DATA B(21067), B(21068), B(21069) /    19.76,  -40.26,    0.00 /
      DATA B(21406), B(21407), B(21408) /    19.50,  -39.82,    0.00 /
      DATA B(21745), B(21746), B(21747) /    17.45,  -37.68,    0.00 /
      DATA B(22084), B(22085), B(22086) /    18.68,  -38.51,    0.00 /
      DATA B(22423), B(22424), B(22425) /    18.14,  -37.78,    0.00 /
      DATA B(22762), B(22763), B(22764) /    17.52,  -37.03,    0.00 /
      DATA B(23101), B(23102), B(23103) /    16.75,  -36.18,    0.00 /
      DATA B(23440), B(23441), B(23442) /    15.73,  -35.12,    0.00 /
      DATA B(23779), B(23780), B(23781) /    14.29,  -33.72,    0.00 /
      DATA B(24118), B(24119), B(24120) /    12.33,  -31.91,    0.00 /
      DATA B(24457), B(24458), B(24459) /    10.04,  -29.74,    0.00 /
      DATA B(24796), B(24797), B(24798) /     8.02,  -27.88,    0.00 /
      DATA B(25135), B(25136), B(25137) /     6.54,  -26.42,    0.00 /
      DATA B(25474), B(25475), B(25476) /     5.49,  -25.38,    0.00 /
      DATA B(25813), B(25814), B(25815) /     4.76,  -24.62,    0.00 /
      DATA B(26152), B(26153), B(26154) /     4.22,  -24.04,    0.00 /
      DATA B(26491), B(26492), B(26493) /     3.84,  -23.58,    0.00 /
      DATA B(26830), B(26831), B(26832) /     3.55,  -23.21,    0.00 /
      DATA B(27169), B(27170), B(27171) /    -0.19,  -23.30,    0.00 /
      DATA B(   52), B(   53), B(   54) /    25.07,  -45.67,    0.00 /
      DATA B(  391), B(  392), B(  393) /    25.07,  -45.60,    0.00 /
      DATA B(  730), B(  731), B(  732) /    25.07,  -45.53,    0.00 /
      DATA B( 1069), B( 1070), B( 1071) /    25.07,  -45.46,    0.00 /
      DATA B( 1408), B( 1409), B( 1410) /    25.06,  -45.40,    0.00 /
      DATA B( 1747), B( 1748), B( 1749) /    25.06,  -45.33,    0.00 /
      DATA B( 2086), B( 2087), B( 2088) /    25.06,  -45.26,    0.00 /
      DATA B( 2425), B( 2426), B( 2427) /    25.06,  -45.19,    0.00 /
      DATA B( 2764), B( 2765), B( 2766) /    25.05,  -45.12,    0.00 /
      DATA B( 3103), B( 3104), B( 3105) /    25.05,  -45.05,    0.00 /
      DATA B( 3442), B( 3443), B( 3444) /    25.05,  -44.98,    0.00 /
      DATA B( 3781), B( 3782), B( 3783) /    25.05,  -44.91,    0.00 /
      DATA B( 4120), B( 4121), B( 4122) /    25.04,  -44.84,    0.00 /
      DATA B( 4459), B( 4460), B( 4461) /    25.04,  -44.77,    0.00 /
      DATA B( 4798), B( 4799), B( 4800) /    25.04,  -44.70,    0.00 /
      DATA B( 5137), B( 5138), B( 5139) /    25.03,  -44.63,    0.00 /
      DATA B( 5476), B( 5477), B( 5478) /    25.03,  -44.55,    0.00 /
      DATA B( 5815), B( 5816), B( 5817) /    25.03,  -44.48,    0.00 /
      DATA B( 6154), B( 6155), B( 6156) /    25.02,  -44.41,    0.00 /
      DATA B( 6493), B( 6494), B( 6495) /    25.02,  -44.34,    0.00 /
      DATA B( 6832), B( 6833), B( 6834) /    25.02,  -44.26,    0.00 /
      DATA B( 7171), B( 7172), B( 7173) /    25.01,  -44.19,    0.00 /
      DATA B( 7510), B( 7511), B( 7512) /    25.01,  -44.11,    0.00 /
      DATA B( 7849), B( 7850), B( 7851) /    25.01,  -44.04,    0.00 /
      DATA B( 8188), B( 8189), B( 8190) /    25.00,  -43.96,    0.00 /
      DATA B( 8527), B( 8528), B( 8529) /    25.00,  -43.88,    0.00 /
      DATA B( 8866), B( 8867), B( 8868) /    25.00,  -43.81,    0.00 /
      DATA B( 9205), B( 9206), B( 9207) /    24.99,  -43.73,    0.00 /
      DATA B( 9544), B( 9545), B( 9546) /    24.99,  -43.65,    0.00 /
      DATA B( 9883), B( 9884), B( 9885) /    24.99,  -43.57,    0.00 /
      DATA B(10222), B(10223), B(10224) /    24.98,  -43.49,    0.00 /
      DATA B(10561), B(10562), B(10563) /    24.98,  -43.40,    0.00 /
      DATA B(10900), B(10901), B(10902) /    24.98,  -43.32,    0.00 /
      DATA B(11239), B(11240), B(11241) /    24.97,  -43.24,    0.00 /
      DATA B(11578), B(11579), B(11580) /    24.97,  -43.15,    0.00 /
      DATA B(11917), B(11918), B(11919) /    24.97,  -43.06,    0.00 /
      DATA B(12256), B(12257), B(12258) /    24.97,  -42.97,    0.00 /
      DATA B(12595), B(12596), B(12597) /    24.97,  -42.88,    0.00 /
      DATA B(12934), B(12935), B(12936) /    24.97,  -42.79,    0.00 /
      DATA B(13273), B(13274), B(13275) /    24.98,  -42.69,    0.00 /
      DATA B(13612), B(13613), B(13614) /    24.98,  -42.59,    0.00 /
      DATA B(13951), B(13952), B(13953) /    24.99,  -42.48,    0.00 /
      DATA B(14290), B(14291), B(14292) /    25.00,  -42.37,    0.00 /
      DATA B(14629), B(14630), B(14631) /    25.02,  -42.26,    0.00 /
      DATA B(14968), B(14969), B(14970) /    25.05,  -42.13,    0.00 /
      DATA B(15307), B(15308), B(15309) /    25.08,  -41.99,    0.00 /
      DATA B(15646), B(15647), B(15648) /    25.12,  -41.81,    0.00 /
      DATA B(15985), B(15986), B(15987) /    25.12,  -41.55,    0.00 /
      DATA B(16324), B(16325), B(16326) /    24.95,  -41.30,    0.00 /
      DATA B(16663), B(16664), B(16665) /    24.20,  -41.38,    0.00 /
      DATA B(17002), B(17003), B(17004) /    23.47,  -41.45,    0.00 /
      DATA B(17341), B(17342), B(17343) /    22.76,  -41.52,    0.00 /
      DATA B(17680), B(17681), B(17682) /    22.05,  -41.60,    0.00 /
      DATA B(18019), B(18020), B(18021) /    21.34,  -41.69,    0.00 /
      DATA B(18358), B(18359), B(18360) /    20.65,  -41.77,    0.00 /
      DATA B(18697), B(18698), B(18699) /    19.96,  -41.85,    0.00 /
      DATA B(19036), B(19037), B(19038) /    19.26,  -41.91,    0.00 /
      DATA B(19375), B(19376), B(19377) /    18.48,  -41.95,    0.00 /
      DATA B(19714), B(19715), B(19716) /    19.91,  -41.18,    0.00 /
      DATA B(20053), B(20054), B(20055) /    19.81,  -40.95,    0.00 /
      DATA B(20392), B(20393), B(20394) /    19.71,  -40.71,    0.00 /
      DATA B(20731), B(20732), B(20733) /    19.54,  -40.42,    0.00 /
      DATA B(21070), B(21071), B(21072) /    19.29,  -40.05,    0.00 /
      DATA B(21409), B(21410), B(21411) /    18.97,  -39.52,    0.00 /
      DATA B(21748), B(21749), B(21750) /    18.54,  -38.81,    0.00 /
      DATA B(22087), B(22088), B(22089) /    18.02,  -38.03,    0.00 /
      DATA B(22426), B(22427), B(22428) /    17.38,  -37.23,    0.00 /
      DATA B(22765), B(22766), B(22767) /    16.60,  -36.35,    0.00 /
      DATA B(23104), B(23105), B(23106) /    15.57,  -35.28,    0.00 /
      DATA B(23443), B(23444), B(23445) /    14.13,  -33.88,    0.00 /
      DATA B(23782), B(23783), B(23784) /    12.19,  -32.08,    0.00 /
      DATA B(24121), B(24122), B(24123) /     9.97,  -30.08,    0.00 /
      DATA B(24460), B(24461), B(24462) /     7.99,  -28.21,    0.00 /
      DATA B(24799), B(24800), B(24801) /     6.51,  -26.75,    0.00 /
      DATA B(25138), B(25139), B(25140) /     5.46,  -25.68,    0.00 /
      DATA B(25477), B(25478), B(25479) /     4.72,  -24.90,    0.00 /
      DATA B(25816), B(25817), B(25818) /     4.20,  -24.32,    0.00 /
      DATA B(26155), B(26156), B(26157) /     3.82,  -23.85,    0.00 /
      DATA B(26494), B(26495), B(26496) /     3.53,  -23.45,    0.00 /
      DATA B(26833), B(26834), B(26835) /     0.33,  -23.37,    0.00 /
      DATA B(27172), B(27173), B(27174) /     0.06,  -23.14,    0.00 /
      DATA B(   55), B(   56), B(   57) /    25.04,  -45.65,    0.00 /
      DATA B(  394), B(  395), B(  396) /    25.04,  -45.58,    0.00 /
      DATA B(  733), B(  734), B(  735) /    25.04,  -45.51,    0.00 /
      DATA B( 1072), B( 1073), B( 1074) /    25.04,  -45.45,    0.00 /
      DATA B( 1411), B( 1412), B( 1413) /    25.04,  -45.38,    0.00 /
      DATA B( 1750), B( 1751), B( 1752) /    25.03,  -45.31,    0.00 /
      DATA B( 2089), B( 2090), B( 2091) /    25.03,  -45.24,    0.00 /
      DATA B( 2428), B( 2429), B( 2430) /    25.03,  -45.17,    0.00 /
      DATA B( 2767), B( 2768), B( 2769) /    25.02,  -45.10,    0.00 /
      DATA B( 3106), B( 3107), B( 3108) /    25.02,  -45.03,    0.00 /
      DATA B( 3445), B( 3446), B( 3447) /    25.02,  -44.96,    0.00 /
      DATA B( 3784), B( 3785), B( 3786) /    25.02,  -44.89,    0.00 /
      DATA B( 4123), B( 4124), B( 4125) /    25.01,  -44.82,    0.00 /
      DATA B( 4462), B( 4463), B( 4464) /    25.01,  -44.75,    0.00 /
      DATA B( 4801), B( 4802), B( 4803) /    25.01,  -44.68,    0.00 /
      DATA B( 5140), B( 5141), B( 5142) /    25.00,  -44.60,    0.00 /
      DATA B( 5479), B( 5480), B( 5481) /    25.00,  -44.53,    0.00 /
      DATA B( 5818), B( 5819), B( 5820) /    25.00,  -44.46,    0.00 /
      DATA B( 6157), B( 6158), B( 6159) /    24.99,  -44.38,    0.00 /
      DATA B( 6496), B( 6497), B( 6498) /    24.99,  -44.31,    0.00 /
      DATA B( 6835), B( 6836), B( 6837) /    24.99,  -44.24,    0.00 /
      DATA B( 7174), B( 7175), B( 7176) /    24.98,  -44.16,    0.00 /
      DATA B( 7513), B( 7514), B( 7515) /    24.98,  -44.09,    0.00 /
      DATA B( 7852), B( 7853), B( 7854) /    24.97,  -44.01,    0.00 /
      DATA B( 8191), B( 8192), B( 8193) /    24.97,  -43.93,    0.00 /
      DATA B( 8530), B( 8531), B( 8532) /    24.97,  -43.85,    0.00 /
      DATA B( 8869), B( 8870), B( 8871) /    24.96,  -43.78,    0.00 /
      DATA B( 9208), B( 9209), B( 9210) /    24.96,  -43.70,    0.00 /
      DATA B( 9547), B( 9548), B( 9549) /    24.95,  -43.62,    0.00 /
      DATA B( 9886), B( 9887), B( 9888) /    24.95,  -43.54,    0.00 /
      DATA B(10225), B(10226), B(10227) /    24.95,  -43.45,    0.00 /
      DATA B(10564), B(10565), B(10566) /    24.94,  -43.37,    0.00 /
      DATA B(10903), B(10904), B(10905) /    24.94,  -43.29,    0.00 /
      DATA B(11242), B(11243), B(11244) /    24.94,  -43.20,    0.00 /
      DATA B(11581), B(11582), B(11583) /    24.93,  -43.11,    0.00 /
      DATA B(11920), B(11921), B(11922) /    24.93,  -43.02,    0.00 /
      DATA B(12259), B(12260), B(12261) /    24.93,  -42.93,    0.00 /
      DATA B(12598), B(12599), B(12600) /    24.93,  -42.83,    0.00 /
      DATA B(12937), B(12938), B(12939) /    24.93,  -42.74,    0.00 /
      DATA B(13276), B(13277), B(13278) /    24.93,  -42.64,    0.00 /
      DATA B(13615), B(13616), B(13617) /    24.93,  -42.53,    0.00 /
      DATA B(13954), B(13955), B(13956) /    24.94,  -42.42,    0.00 /
      DATA B(14293), B(14294), B(14295) /    24.95,  -42.31,    0.00 /
      DATA B(14632), B(14633), B(14634) /    24.96,  -42.19,    0.00 /
      DATA B(14971), B(14972), B(14973) /    24.97,  -42.05,    0.00 /
      DATA B(15310), B(15311), B(15312) /    24.99,  -41.90,    0.00 /
      DATA B(15649), B(15650), B(15651) /    25.00,  -41.70,    0.00 /
      DATA B(15988), B(15989), B(15990) /    24.99,  -41.42,    0.00 /
      DATA B(16327), B(16328), B(16329) /    24.71,  -41.18,    0.00 /
      DATA B(16666), B(16667), B(16668) /    23.98,  -41.22,    0.00 /
      DATA B(17005), B(17006), B(17007) /    23.24,  -41.28,    0.00 /
      DATA B(17344), B(17345), B(17346) /    22.51,  -41.37,    0.00 /
      DATA B(17683), B(17684), B(17685) /    21.78,  -41.45,    0.00 /
      DATA B(18022), B(18023), B(18024) /    21.06,  -41.55,    0.00 /
      DATA B(18361), B(18362), B(18363) /    20.35,  -41.64,    0.00 /
      DATA B(18700), B(18701), B(18702) /    19.64,  -41.72,    0.00 /
      DATA B(19039), B(19040), B(19041) /    18.93,  -41.78,    0.00 /
      DATA B(19378), B(19379), B(19380) /    18.14,  -41.82,    0.00 /
      DATA B(19717), B(19718), B(19719) /    19.56,  -41.08,    0.00 /
      DATA B(20056), B(20057), B(20058) /    19.45,  -40.83,    0.00 /
      DATA B(20395), B(20396), B(20397) /    19.30,  -40.57,    0.00 /
      DATA B(20734), B(20735), B(20736) /    19.08,  -40.25,    0.00 /
      DATA B(21073), B(21074), B(21075) /    18.77,  -39.80,    0.00 /
      DATA B(21412), B(21413), B(21414) /    18.22,  -39.12,    0.00 /
      DATA B(21751), B(21752), B(21753) /    17.89,  -38.36,    0.00 /
      DATA B(22090), B(22091), B(22092) /    17.26,  -37.51,    0.00 /
      DATA B(22429), B(22430), B(22431) /    16.47,  -36.58,    0.00 /
      DATA B(22768), B(22769), B(22770) /    15.45,  -35.48,    0.00 /
      DATA B(23107), B(23108), B(23109) /    14.03,  -34.07,    0.00 /
      DATA B(23446), B(23447), B(23448) /    12.12,  -32.29,    0.00 /
      DATA B(23785), B(23786), B(23787) /     9.91,  -30.30,    0.00 /
      DATA B(24124), B(24125), B(24126) /     7.93,  -28.48,    0.00 /
      DATA B(24463), B(24464), B(24465) /     6.43,  -27.05,    0.00 /
      DATA B(24802), B(24803), B(24804) /     5.39,  -25.98,    0.00 /
      DATA B(25141), B(25142), B(25143) /     4.66,  -25.19,    0.00 /
      DATA B(25480), B(25481), B(25482) /     4.18,  -24.59,    0.00 /
      DATA B(25819), B(25820), B(25821) /     3.83,  -24.12,    0.00 /
      DATA B(26158), B(26159), B(26160) /     0.79,  -23.88,    0.00 /
      DATA B(26497), B(26498), B(26499) /     0.47,  -23.56,    0.00 /
      DATA B(26836), B(26837), B(26838) /     0.20,  -23.29,    0.00 /
      DATA B(27175), B(27176), B(27177) /    -0.03,  -23.09,    0.00 /
      DATA B(   58), B(   59), B(   60) /    25.02,  -45.63,    0.00 /
      DATA B(  397), B(  398), B(  399) /    25.01,  -45.56,    0.00 /
      DATA B(  736), B(  737), B(  738) /    25.01,  -45.49,    0.00 /
      DATA B( 1075), B( 1076), B( 1077) /    25.01,  -45.43,    0.00 /
      DATA B( 1414), B( 1415), B( 1416) /    25.01,  -45.36,    0.00 /
      DATA B( 1753), B( 1754), B( 1755) /    25.00,  -45.29,    0.00 /
      DATA B( 2092), B( 2093), B( 2094) /    25.00,  -45.22,    0.00 /
      DATA B( 2431), B( 2432), B( 2433) /    25.00,  -45.15,    0.00 /
      DATA B( 2770), B( 2771), B( 2772) /    25.00,  -45.08,    0.00 /
      DATA B( 3109), B( 3110), B( 3111) /    24.99,  -45.01,    0.00 /
      DATA B( 3448), B( 3449), B( 3450) /    24.99,  -44.94,    0.00 /
      DATA B( 3787), B( 3788), B( 3789) /    24.99,  -44.87,    0.00 /
      DATA B( 4126), B( 4127), B( 4128) /    24.98,  -44.80,    0.00 /
      DATA B( 4465), B( 4466), B( 4467) /    24.98,  -44.72,    0.00 /
      DATA B( 4804), B( 4805), B( 4806) /    24.98,  -44.65,    0.00 /
      DATA B( 5143), B( 5144), B( 5145) /    24.97,  -44.58,    0.00 /
      DATA B( 5482), B( 5483), B( 5484) /    24.97,  -44.51,    0.00 /
      DATA B( 5821), B( 5822), B( 5823) /    24.97,  -44.43,    0.00 /
      DATA B( 6160), B( 6161), B( 6162) /    24.96,  -44.36,    0.00 /
      DATA B( 6499), B( 6500), B( 6501) /    24.96,  -44.28,    0.00 /
      DATA B( 6838), B( 6839), B( 6840) /    24.95,  -44.21,    0.00 /
      DATA B( 7177), B( 7178), B( 7179) /    24.95,  -44.13,    0.00 /
      DATA B( 7516), B( 7517), B( 7518) /    24.95,  -44.06,    0.00 /
      DATA B( 7855), B( 7856), B( 7857) /    24.94,  -43.98,    0.00 /
      DATA B( 8194), B( 8195), B( 8196) /    24.94,  -43.90,    0.00 /
      DATA B( 8533), B( 8534), B( 8535) /    24.93,  -43.82,    0.00 /
      DATA B( 8872), B( 8873), B( 8874) /    24.93,  -43.75,    0.00 /
      DATA B( 9211), B( 9212), B( 9213) /    24.92,  -43.67,    0.00 /
      DATA B( 9550), B( 9551), B( 9552) /    24.92,  -43.58,    0.00 /
      DATA B( 9889), B( 9890), B( 9891) /    24.92,  -43.50,    0.00 /
      DATA B(10228), B(10229), B(10230) /    24.91,  -43.42,    0.00 /
      DATA B(10567), B(10568), B(10569) /    24.91,  -43.33,    0.00 /
      DATA B(10906), B(10907), B(10908) /    24.90,  -43.25,    0.00 /
      DATA B(11245), B(11246), B(11247) /    24.90,  -43.16,    0.00 /
      DATA B(11584), B(11585), B(11586) /    24.89,  -43.07,    0.00 /
      DATA B(11923), B(11924), B(11925) /    24.89,  -42.98,    0.00 /
      DATA B(12262), B(12263), B(12264) /    24.89,  -42.88,    0.00 /
      DATA B(12601), B(12602), B(12603) /    24.89,  -42.79,    0.00 /
      DATA B(12940), B(12941), B(12942) /    24.89,  -42.69,    0.00 /
      DATA B(13279), B(13280), B(13281) /    24.88,  -42.58,    0.00 /
      DATA B(13618), B(13619), B(13620) /    24.89,  -42.47,    0.00 /
      DATA B(13957), B(13958), B(13959) /    24.89,  -42.36,    0.00 /
      DATA B(14296), B(14297), B(14298) /    24.89,  -42.23,    0.00 /
      DATA B(14635), B(14636), B(14637) /    24.89,  -42.10,    0.00 /
      DATA B(14974), B(14975), B(14976) /    24.89,  -41.96,    0.00 /
      DATA B(15313), B(15314), B(15315) /    24.89,  -41.79,    0.00 /
      DATA B(15652), B(15653), B(15654) /    24.87,  -41.57,    0.00 /
      DATA B(15991), B(15992), B(15993) /    24.82,  -41.25,    0.00 /
      DATA B(16330), B(16331), B(16332) /    24.51,  -41.01,    0.00 /
      DATA B(16669), B(16670), B(16671) /    23.75,  -41.06,    0.00 /
      DATA B(17008), B(17009), B(17010) /    23.00,  -41.13,    0.00 /
      DATA B(17347), B(17348), B(17349) /    22.26,  -41.22,    0.00 /
      DATA B(17686), B(17687), B(17688) /    21.52,  -41.31,    0.00 /
      DATA B(18025), B(18026), B(18027) /    20.78,  -41.41,    0.00 /
      DATA B(18364), B(18365), B(18366) /    20.05,  -41.50,    0.00 /
      DATA B(18703), B(18704), B(18705) /    19.33,  -41.59,    0.00 /
      DATA B(19042), B(19043), B(19044) /    18.59,  -41.66,    0.00 /
      DATA B(19381), B(19382), B(19383) /    17.78,  -41.69,    0.00 /
      DATA B(19720), B(19721), B(19722) /    19.22,  -40.99,    0.00 /
      DATA B(20059), B(20060), B(20061) /    19.05,  -40.70,    0.00 /
      DATA B(20398), B(20399), B(20400) /    18.85,  -40.41,    0.00 /
      DATA B(20737), B(20738), B(20739) /    18.56,  -40.03,    0.00 /
      DATA B(21076), B(21077), B(21078) /    18.19,  -39.51,    0.00 /
      DATA B(21415), B(21416), B(21417) /    17.72,  -38.77,    0.00 /
      DATA B(21754), B(21755), B(21756) /    17.13,  -37.89,    0.00 /
      DATA B(22093), B(22094), B(22095) /    16.36,  -36.91,    0.00 /
      DATA B(22432), B(22433), B(22434) /    15.32,  -35.74,    0.00 /
      DATA B(22771), B(22772), B(22773) /    13.91,  -34.31,    0.00 /
      DATA B(23110), B(23111), B(23112) /    12.07,  -32.53,    0.00 /
      DATA B(23449), B(23450), B(23451) /     9.94,  -30.54,    0.00 /
      DATA B(23788), B(23789), B(23790) /     7.91,  -28.73,    0.00 /
      DATA B(24127), B(24128), B(24129) /     6.38,  -27.31,    0.00 /
      DATA B(24466), B(24467), B(24468) /     5.34,  -26.27,    0.00 /
      DATA B(24805), B(24806), B(24807) /     4.65,  -25.49,    0.00 /
      DATA B(25144), B(25145), B(25146) /     4.19,  -24.86,    0.00 /
      DATA B(25483), B(25484), B(25485) /     1.33,  -24.47,    0.00 /
      DATA B(25822), B(25823), B(25824) /     0.95,  -24.06,    0.00 /
      DATA B(26161), B(26162), B(26163) /     0.62,  -23.73,    0.00 /
      DATA B(26500), B(26501), B(26502) /     0.34,  -23.46,    0.00 /
      DATA B(26839), B(26840), B(26841) /     0.10,  -23.23,    0.00 /
      DATA B(27178), B(27179), B(27180) /    -0.11,  -23.05,    0.00 /
      DATA B(   61), B(   62), B(   63) /    24.99,  -45.61,    0.00 /
      DATA B(  400), B(  401), B(  402) /    24.99,  -45.54,    0.00 /
      DATA B(  739), B(  740), B(  741) /    24.98,  -45.47,    0.00 /
      DATA B( 1078), B( 1079), B( 1080) /    24.98,  -45.41,    0.00 /
      DATA B( 1417), B( 1418), B( 1419) /    24.98,  -45.34,    0.00 /
      DATA B( 1756), B( 1757), B( 1758) /    24.97,  -45.27,    0.00 /
      DATA B( 2095), B( 2096), B( 2097) /    24.97,  -45.20,    0.00 /
      DATA B( 2434), B( 2435), B( 2436) /    24.97,  -45.13,    0.00 /
      DATA B( 2773), B( 2774), B( 2775) /    24.97,  -45.06,    0.00 /
      DATA B( 3112), B( 3113), B( 3114) /    24.96,  -44.99,    0.00 /
      DATA B( 3451), B( 3452), B( 3453) /    24.96,  -44.92,    0.00 /
      DATA B( 3790), B( 3791), B( 3792) /    24.96,  -44.84,    0.00 /
      DATA B( 4129), B( 4130), B( 4131) /    24.95,  -44.77,    0.00 /
      DATA B( 4468), B( 4469), B( 4470) /    24.95,  -44.70,    0.00 /
      DATA B( 4807), B( 4808), B( 4809) /    24.95,  -44.63,    0.00 /
      DATA B( 5146), B( 5147), B( 5148) /    24.94,  -44.56,    0.00 /
      DATA B( 5485), B( 5486), B( 5487) /    24.94,  -44.48,    0.00 /
      DATA B( 5824), B( 5825), B( 5826) /    24.93,  -44.41,    0.00 /
      DATA B( 6163), B( 6164), B( 6165) /    24.93,  -44.33,    0.00 /
      DATA B( 6502), B( 6503), B( 6504) /    24.93,  -44.26,    0.00 /
      DATA B( 6841), B( 6842), B( 6843) /    24.92,  -44.18,    0.00 /
      DATA B( 7180), B( 7181), B( 7182) /    24.92,  -44.11,    0.00 /
      DATA B( 7519), B( 7520), B( 7521) /    24.91,  -44.03,    0.00 /
      DATA B( 7858), B( 7859), B( 7860) /    24.91,  -43.95,    0.00 /
      DATA B( 8197), B( 8198), B( 8199) /    24.90,  -43.87,    0.00 /
      DATA B( 8536), B( 8537), B( 8538) /    24.90,  -43.79,    0.00 /
      DATA B( 8875), B( 8876), B( 8877) /    24.89,  -43.71,    0.00 /
      DATA B( 9214), B( 9215), B( 9216) /    24.89,  -43.63,    0.00 /
      DATA B( 9553), B( 9554), B( 9555) /    24.88,  -43.55,    0.00 /
      DATA B( 9892), B( 9893), B( 9894) /    24.88,  -43.47,    0.00 /
      DATA B(10231), B(10232), B(10233) /    24.87,  -43.38,    0.00 /
      DATA B(10570), B(10571), B(10572) /    24.87,  -43.30,    0.00 /
      DATA B(10909), B(10910), B(10911) /    24.86,  -43.21,    0.00 /
      DATA B(11248), B(11249), B(11250) /    24.86,  -43.12,    0.00 /
      DATA B(11587), B(11588), B(11589) /    24.85,  -43.03,    0.00 /
      DATA B(11926), B(11927), B(11928) /    24.85,  -42.93,    0.00 /
      DATA B(12265), B(12266), B(12267) /    24.84,  -42.84,    0.00 /
      DATA B(12604), B(12605), B(12606) /    24.84,  -42.74,    0.00 /
      DATA B(12943), B(12944), B(12945) /    24.84,  -42.63,    0.00 /
      DATA B(13282), B(13283), B(13284) /    24.84,  -42.52,    0.00 /
      DATA B(13621), B(13622), B(13623) /    24.83,  -42.41,    0.00 /
      DATA B(13960), B(13961), B(13962) /    24.83,  -42.28,    0.00 /
      DATA B(14299), B(14300), B(14301) /    24.83,  -42.15,    0.00 /
      DATA B(14638), B(14639), B(14640) /    24.82,  -42.00,    0.00 /
      DATA B(14977), B(14978), B(14979) /    24.81,  -41.84,    0.00 /
      DATA B(15316), B(15317), B(15318) /    24.78,  -41.65,    0.00 /
      DATA B(15655), B(15656), B(15657) /    24.74,  -41.42,    0.00 /
      DATA B(15994), B(15995), B(15996) /    24.68,  -41.10,    0.00 /
      DATA B(16333), B(16334), B(16335) /    24.30,  -40.89,    0.00 /
      DATA B(16672), B(16673), B(16674) /    23.53,  -40.93,    0.00 /
      DATA B(17011), B(17012), B(17013) /    22.77,  -41.00,    0.00 /
      DATA B(17350), B(17351), B(17352) /    22.01,  -41.08,    0.00 /
      DATA B(17689), B(17690), B(17691) /    21.25,  -41.18,    0.00 /
      DATA B(18028), B(18029), B(18030) /    20.50,  -41.28,    0.00 /
      DATA B(18367), B(18368), B(18369) /    19.75,  -41.37,    0.00 /
      DATA B(18706), B(18707), B(18708) /    19.00,  -41.46,    0.00 /
      DATA B(19045), B(19046), B(19047) /    18.25,  -41.52,    0.00 /
      DATA B(19384), B(19385), B(19386) /    17.42,  -41.55,    0.00 /
      DATA B(19723), B(19724), B(19725) /    16.50,  -41.53,    0.00 /
      DATA B(20062), B(20063), B(20064) /    18.62,  -40.57,    0.00 /
      DATA B(20401), B(20402), B(20403) /    18.36,  -40.22,    0.00 /
      DATA B(20740), B(20741), B(20742) /    17.99,  -39.78,    0.00 /
      DATA B(21079), B(21080), B(21081) /    17.44,  -39.15,    0.00 /
      DATA B(21418), B(21419), B(21420) /    16.95,  -38.37,    0.00 /
      DATA B(21757), B(21758), B(21759) /    16.23,  -37.39,    0.00 /
      DATA B(22096), B(22097), B(22098) /    15.22,  -36.15,    0.00 /
      DATA B(22435), B(22436), B(22437) /    13.81,  -34.61,    0.00 /
      DATA B(22774), B(22775), B(22776) /    11.91,  -32.76,    0.00 /
      DATA B(23113), B(23114), B(23115) /    10.11,  -30.83,    0.00 /
      DATA B(23452), B(23453), B(23454) /     8.00,  -28.99,    0.00 /
      DATA B(23791), B(23792), B(23793) /     6.42,  -27.58,    0.00 /
      DATA B(24130), B(24131), B(24132) /     5.37,  -26.54,    0.00 /
      DATA B(24469), B(24470), B(24471) /     4.71,  -25.77,    0.00 /
      DATA B(24808), B(24809), B(24810) /     1.98,  -25.15,    0.00 /
      DATA B(25147), B(25148), B(25149) /     1.50,  -24.67,    0.00 /
      DATA B(25486), B(25487), B(25488) /     1.10,  -24.26,    0.00 /
      DATA B(25825), B(25826), B(25827) /     0.76,  -23.91,    0.00 /
      DATA B(26164), B(26165), B(26166) /     0.47,  -23.62,    0.00 /
      DATA B(26503), B(26504), B(26505) /     0.23,  -23.37,    0.00 /
      DATA B(26842), B(26843), B(26844) /     0.02,  -23.17,    0.00 /
      DATA B(27181), B(27182), B(27183) /    -0.17,  -23.00,    0.00 /
      DATA B(   64), B(   65), B(   66) /    24.96,  -45.59,    0.00 /
      DATA B(  403), B(  404), B(  405) /    24.96,  -45.52,    0.00 /
      DATA B(  742), B(  743), B(  744) /    24.95,  -45.45,    0.00 /
      DATA B( 1081), B( 1082), B( 1083) /    24.95,  -45.39,    0.00 /
      DATA B( 1420), B( 1421), B( 1422) /    24.95,  -45.32,    0.00 /
      DATA B( 1759), B( 1760), B( 1761) /    24.95,  -45.25,    0.00 /
      DATA B( 2098), B( 2099), B( 2100) /    24.94,  -45.18,    0.00 /
      DATA B( 2437), B( 2438), B( 2439) /    24.94,  -45.11,    0.00 /
      DATA B( 2776), B( 2777), B( 2778) /    24.94,  -45.04,    0.00 /
      DATA B( 3115), B( 3116), B( 3117) /    24.93,  -44.96,    0.00 /
      DATA B( 3454), B( 3455), B( 3456) /    24.93,  -44.89,    0.00 /
      DATA B( 3793), B( 3794), B( 3795) /    24.93,  -44.82,    0.00 /
      DATA B( 4132), B( 4133), B( 4134) /    24.92,  -44.75,    0.00 /
      DATA B( 4471), B( 4472), B( 4473) /    24.92,  -44.68,    0.00 /
      DATA B( 4810), B( 4811), B( 4812) /    24.91,  -44.60,    0.00 /
      DATA B( 5149), B( 5150), B( 5151) /    24.91,  -44.53,    0.00 /
      DATA B( 5488), B( 5489), B( 5490) /    24.91,  -44.46,    0.00 /
      DATA B( 5827), B( 5828), B( 5829) /    24.90,  -44.38,    0.00 /
      DATA B( 6166), B( 6167), B( 6168) /    24.90,  -44.31,    0.00 /
      DATA B( 6505), B( 6506), B( 6507) /    24.89,  -44.23,    0.00 /
      DATA B( 6844), B( 6845), B( 6846) /    24.89,  -44.16,    0.00 /
      DATA B( 7183), B( 7184), B( 7185) /    24.89,  -44.08,    0.00 /
      DATA B( 7522), B( 7523), B( 7524) /    24.88,  -44.00,    0.00 /
      DATA B( 7861), B( 7862), B( 7863) /    24.88,  -43.92,    0.00 /
      DATA B( 8200), B( 8201), B( 8202) /    24.87,  -43.84,    0.00 /
      DATA B( 8539), B( 8540), B( 8541) /    24.86,  -43.76,    0.00 /
      DATA B( 8878), B( 8879), B( 8880) /    24.86,  -43.68,    0.00 /
      DATA B( 9217), B( 9218), B( 9219) /    24.85,  -43.60,    0.00 /
      DATA B( 9556), B( 9557), B( 9558) /    24.85,  -43.51,    0.00 /
      DATA B( 9895), B( 9896), B( 9897) /    24.84,  -43.43,    0.00 /
      DATA B(10234), B(10235), B(10236) /    24.84,  -43.34,    0.00 /
      DATA B(10573), B(10574), B(10575) /    24.83,  -43.26,    0.00 /
      DATA B(10912), B(10913), B(10914) /    24.82,  -43.17,    0.00 /
      DATA B(11251), B(11252), B(11253) /    24.82,  -43.08,    0.00 /
      DATA B(11590), B(11591), B(11592) /    24.81,  -42.98,    0.00 /
      DATA B(11929), B(11930), B(11931) /    24.80,  -42.88,    0.00 /
      DATA B(12268), B(12269), B(12270) /    24.80,  -42.78,    0.00 /
      DATA B(12607), B(12608), B(12609) /    24.79,  -42.68,    0.00 /
      DATA B(12946), B(12947), B(12948) /    24.79,  -42.57,    0.00 /
      DATA B(13285), B(13286), B(13287) /    24.78,  -42.46,    0.00 /
      DATA B(13624), B(13625), B(13626) /    24.78,  -42.33,    0.00 /
      DATA B(13963), B(13964), B(13965) /    24.77,  -42.20,    0.00 /
      DATA B(14302), B(14303), B(14304) /    24.76,  -42.06,    0.00 /
      DATA B(14641), B(14642), B(14643) /    24.75,  -41.89,    0.00 /
      DATA B(14980), B(14981), B(14982) /    24.73,  -41.71,    0.00 /
      DATA B(15319), B(15320), B(15321) /    24.68,  -41.50,    0.00 /
      DATA B(15658), B(15659), B(15660) /    24.61,  -41.24,    0.00 /
      DATA B(15997), B(15998), B(15999) /    24.52,  -40.89,    0.00 /
      DATA B(16336), B(16337), B(16338) /    24.08,  -40.73,    0.00 /
      DATA B(16675), B(16676), B(16677) /    23.31,  -40.79,    0.00 /
      DATA B(17014), B(17015), B(17016) /    22.54,  -40.87,    0.00 /
      DATA B(17353), B(17354), B(17355) /    21.77,  -40.96,    0.00 /
      DATA B(17692), B(17693), B(17694) /    20.99,  -41.05,    0.00 /
      DATA B(18031), B(18032), B(18033) /    20.22,  -41.14,    0.00 /
      DATA B(18370), B(18371), B(18372) /    19.44,  -41.23,    0.00 /
      DATA B(18709), B(18710), B(18711) /    18.67,  -41.32,    0.00 /
      DATA B(19048), B(19049), B(19050) /    17.89,  -41.39,    0.00 /
      DATA B(19387), B(19388), B(19389) /    17.03,  -41.41,    0.00 /
      DATA B(19726), B(19727), B(19728) /    16.03,  -41.37,    0.00 /
      DATA B(20065), B(20066), B(20067) /    18.15,  -40.41,    0.00 /
      DATA B(20404), B(20405), B(20406) /    17.82,  -40.00,    0.00 /
      DATA B(20743), B(20744), B(20745) /    17.36,  -39.47,    0.00 /
      DATA B(21082), B(21083), B(21084) /    16.75,  -38.79,    0.00 /
      DATA B(21421), B(21422), B(21423) /    16.03,  -37.97,    0.00 /
      DATA B(21760), B(21761), B(21762) /    15.11,  -36.81,    0.00 /
      DATA B(22099), B(22100), B(22101) /    13.71,  -35.16,    0.00 /
      DATA B(22438), B(22439), B(22440) /    11.75,  -33.17,    0.00 /
      DATA B(22777), B(22778), B(22779) /    10.43,  -31.34,    0.00 /
      DATA B(23116), B(23117), B(23118) /     8.22,  -29.32,    0.00 /
      DATA B(23455), B(23456), B(23457) /     6.60,  -27.86,    0.00 /
      DATA B(23794), B(23795), B(23796) /     5.54,  -26.83,    0.00 /
      DATA B(24133), B(24134), B(24135) /     6.07,  -26.57,    0.00 /
      DATA B(24472), B(24473), B(24474) /     2.20,  -25.37,    0.00 /
      DATA B(24811), B(24812), B(24813) /     1.68,  -24.87,    0.00 /
      DATA B(25150), B(25151), B(25152) /     1.25,  -24.44,    0.00 /
      DATA B(25489), B(25490), B(25491) /     0.90,  -24.08,    0.00 /
      DATA B(25828), B(25829), B(25830) /     0.61,  -23.77,    0.00 /
      DATA B(26167), B(26168), B(26169) /     0.36,  -23.51,    0.00 /
      DATA B(26506), B(26507), B(26508) /     0.14,  -23.29,    0.00 /
      DATA B(26845), B(26846), B(26847) /    -0.05,  -23.11,    0.00 /
      DATA B(27184), B(27185), B(27186) /    -0.21,  -22.96,    0.00 /
      DATA B(   67), B(   68), B(   69) /    24.93,  -45.57,    0.00 /
      DATA B(  406), B(  407), B(  408) /    24.93,  -45.50,    0.00 /
      DATA B(  745), B(  746), B(  747) /    24.93,  -45.43,    0.00 /
      DATA B( 1084), B( 1085), B( 1086) /    24.92,  -45.36,    0.00 /
      DATA B( 1423), B( 1424), B( 1425) /    24.92,  -45.30,    0.00 /
      DATA B( 1762), B( 1763), B( 1764) /    24.92,  -45.23,    0.00 /
      DATA B( 2101), B( 2102), B( 2103) /    24.91,  -45.15,    0.00 /
      DATA B( 2440), B( 2441), B( 2442) /    24.91,  -45.08,    0.00 /
      DATA B( 2779), B( 2780), B( 2781) /    24.91,  -45.01,    0.00 /
      DATA B( 3118), B( 3119), B( 3120) /    24.90,  -44.94,    0.00 /
      DATA B( 3457), B( 3458), B( 3459) /    24.90,  -44.87,    0.00 /
      DATA B( 3796), B( 3797), B( 3798) /    24.90,  -44.80,    0.00 /
      DATA B( 4135), B( 4136), B( 4137) /    24.89,  -44.73,    0.00 /
      DATA B( 4474), B( 4475), B( 4476) /    24.89,  -44.65,    0.00 /
      DATA B( 4813), B( 4814), B( 4815) /    24.88,  -44.58,    0.00 /
      DATA B( 5152), B( 5153), B( 5154) /    24.88,  -44.51,    0.00 /
      DATA B( 5491), B( 5492), B( 5493) /    24.88,  -44.43,    0.00 /
      DATA B( 5830), B( 5831), B( 5832) /    24.87,  -44.36,    0.00 /
      DATA B( 6169), B( 6170), B( 6171) /    24.87,  -44.28,    0.00 /
      DATA B( 6508), B( 6509), B( 6510) /    24.86,  -44.20,    0.00 /
      DATA B( 6847), B( 6848), B( 6849) /    24.86,  -44.13,    0.00 /
      DATA B( 7186), B( 7187), B( 7188) /    24.85,  -44.05,    0.00 /
      DATA B( 7525), B( 7526), B( 7527) /    24.85,  -43.97,    0.00 /
      DATA B( 7864), B( 7865), B( 7866) /    24.84,  -43.89,    0.00 /
      DATA B( 8203), B( 8204), B( 8205) /    24.84,  -43.81,    0.00 /
      DATA B( 8542), B( 8543), B( 8544) /    24.83,  -43.73,    0.00 /
      DATA B( 8881), B( 8882), B( 8883) /    24.82,  -43.65,    0.00 /
      DATA B( 9220), B( 9221), B( 9222) /    24.82,  -43.56,    0.00 /
      DATA B( 9559), B( 9560), B( 9561) /    24.81,  -43.48,    0.00 /
      DATA B( 9898), B( 9899), B( 9900) /    24.80,  -43.39,    0.00 /
      DATA B(10237), B(10238), B(10239) /    24.80,  -43.30,    0.00 /
      DATA B(10576), B(10577), B(10578) /    24.79,  -43.21,    0.00 /
      DATA B(10915), B(10916), B(10917) /    24.78,  -43.12,    0.00 /
      DATA B(11254), B(11255), B(11256) /    24.77,  -43.03,    0.00 /
      DATA B(11593), B(11594), B(11595) /    24.77,  -42.93,    0.00 /
      DATA B(11932), B(11933), B(11934) /    24.76,  -42.83,    0.00 /
      DATA B(12271), B(12272), B(12273) /    24.75,  -42.73,    0.00 /
      DATA B(12610), B(12611), B(12612) /    24.74,  -42.62,    0.00 /
      DATA B(12949), B(12950), B(12951) /    24.74,  -42.51,    0.00 /
      DATA B(13288), B(13289), B(13290) /    24.73,  -42.39,    0.00 /
      DATA B(13627), B(13628), B(13629) /    24.72,  -42.26,    0.00 /
      DATA B(13966), B(13967), B(13968) /    24.71,  -42.11,    0.00 /
      DATA B(14305), B(14306), B(14307) /    24.70,  -41.95,    0.00 /
      DATA B(14644), B(14645), B(14646) /    24.68,  -41.77,    0.00 /
      DATA B(14983), B(14984), B(14985) /    24.65,  -41.55,    0.00 /
      DATA B(15322), B(15323), B(15324) /    24.59,  -41.30,    0.00 /
      DATA B(15661), B(15662), B(15663) /    24.49,  -41.01,    0.00 /
      DATA B(16000), B(16001), B(16002) /    24.36,  -40.70,    0.00 /
      DATA B(16339), B(16340), B(16341) /    23.89,  -40.60,    0.00 /
      DATA B(16678), B(16679), B(16680) /    23.11,  -40.68,    0.00 /
      DATA B(17017), B(17018), B(17019) /    22.32,  -40.76,    0.00 /
      DATA B(17356), B(17357), B(17358) /    21.53,  -40.83,    0.00 /
      DATA B(17695), B(17696), B(17697) /    20.73,  -40.92,    0.00 /
      DATA B(18034), B(18035), B(18036) /    19.94,  -41.00,    0.00 /
      DATA B(18373), B(18374), B(18375) /    19.14,  -41.09,    0.00 /
      DATA B(18712), B(18713), B(18714) /    18.34,  -41.17,    0.00 /
      DATA B(19051), B(19052), B(19053) /    17.53,  -41.24,    0.00 /
      DATA B(19390), B(19391), B(19392) /    16.64,  -41.26,    0.00 /
      DATA B(19729), B(19730), B(19731) /    15.61,  -41.20,    0.00 /
      DATA B(20068), B(20069), B(20070) /    17.66,  -40.23,    0.00 /
      DATA B(20407), B(20408), B(20409) /    17.23,  -39.72,    0.00 /
      DATA B(20746), B(20747), B(20748) /    16.61,  -39.07,    0.00 /
      DATA B(21085), B(21086), B(21087) /    15.88,  -38.34,    0.00 /
      DATA B(21424), B(21425), B(21426) /    14.90,  -37.49,    0.00 /
      DATA B(21763), B(21764), B(21765) /    13.69,  -36.10,    0.00 /
      DATA B(22102), B(22103), B(22104) /    11.83,  -33.84,    0.00 /
      DATA B(22441), B(22442), B(22443) /    10.85,  -32.15,    0.00 /
      DATA B(22780), B(22781), B(22782) /     8.61,  -29.82,    0.00 /
      DATA B(23119), B(23120), B(23121) /     6.95,  -28.20,    0.00 /
      DATA B(23458), B(23459), B(23460) /     5.82,  -27.11,    0.00 /
      DATA B(23797), B(23798), B(23799) /     3.14,  -26.18,    0.00 /
      DATA B(24136), B(24137), B(24138) /     2.44,  -25.56,    0.00 /
      DATA B(24475), B(24476), B(24477) /     1.88,  -25.04,    0.00 /
      DATA B(24814), B(24815), B(24816) /     1.43,  -24.61,    0.00 /
      DATA B(25153), B(25154), B(25155) /     1.06,  -24.24,    0.00 /
      DATA B(25492), B(25493), B(25494) /     0.75,  -23.92,    0.00 /
      DATA B(25831), B(25832), B(25833) /     0.49,  -23.65,    0.00 /
      DATA B(26170), B(26171), B(26172) /     0.27,  -23.42,    0.00 /
      DATA B(26509), B(26510), B(26511) /     0.08,  -23.22,    0.00 /
      DATA B(26848), B(26849), B(26850) /    -0.09,  -23.06,    0.00 /
      DATA B(27187), B(27188), B(27189) /    -0.25,  -22.92,    0.00 /
      DATA B(   70), B(   71), B(   72) /    24.90,  -45.55,    0.00 /
      DATA B(  409), B(  410), B(  411) /    24.90,  -45.48,    0.00 /
      DATA B(  748), B(  749), B(  750) /    24.90,  -45.41,    0.00 /
      DATA B( 1087), B( 1088), B( 1089) /    24.89,  -45.34,    0.00 /
      DATA B( 1426), B( 1427), B( 1428) /    24.89,  -45.27,    0.00 /
      DATA B( 1765), B( 1766), B( 1767) /    24.89,  -45.20,    0.00 /
      DATA B( 2104), B( 2105), B( 2106) /    24.88,  -45.13,    0.00 /
      DATA B( 2443), B( 2444), B( 2445) /    24.88,  -45.06,    0.00 /
      DATA B( 2782), B( 2783), B( 2784) /    24.88,  -44.99,    0.00 /
      DATA B( 3121), B( 3122), B( 3123) /    24.87,  -44.92,    0.00 /
      DATA B( 3460), B( 3461), B( 3462) /    24.87,  -44.85,    0.00 /
      DATA B( 3799), B( 3800), B( 3801) /    24.87,  -44.77,    0.00 /
      DATA B( 4138), B( 4139), B( 4140) /    24.86,  -44.70,    0.00 /
      DATA B( 4477), B( 4478), B( 4479) /    24.86,  -44.63,    0.00 /
      DATA B( 4816), B( 4817), B( 4818) /    24.85,  -44.55,    0.00 /
      DATA B( 5155), B( 5156), B( 5157) /    24.85,  -44.48,    0.00 /
      DATA B( 5494), B( 5495), B( 5496) /    24.84,  -44.40,    0.00 /
      DATA B( 5833), B( 5834), B( 5835) /    24.84,  -44.33,    0.00 /
      DATA B( 6172), B( 6173), B( 6174) /    24.83,  -44.25,    0.00 /
      DATA B( 6511), B( 6512), B( 6513) /    24.83,  -44.18,    0.00 /
      DATA B( 6850), B( 6851), B( 6852) /    24.82,  -44.10,    0.00 /
      DATA B( 7189), B( 7190), B( 7191) /    24.82,  -44.02,    0.00 /
      DATA B( 7528), B( 7529), B( 7530) /    24.81,  -43.94,    0.00 /
      DATA B( 7867), B( 7868), B( 7869) /    24.81,  -43.86,    0.00 /
      DATA B( 8206), B( 8207), B( 8208) /    24.80,  -43.78,    0.00 /
      DATA B( 8545), B( 8546), B( 8547) /    24.79,  -43.70,    0.00 /
      DATA B( 8884), B( 8885), B( 8886) /    24.79,  -43.61,    0.00 /
      DATA B( 9223), B( 9224), B( 9225) /    24.78,  -43.53,    0.00 /
      DATA B( 9562), B( 9563), B( 9564) /    24.77,  -43.44,    0.00 /
      DATA B( 9901), B( 9902), B( 9903) /    24.77,  -43.35,    0.00 /
      DATA B(10240), B(10241), B(10242) /    24.76,  -43.26,    0.00 /
      DATA B(10579), B(10580), B(10581) /    24.75,  -43.17,    0.00 /
      DATA B(10918), B(10919), B(10920) /    24.74,  -43.08,    0.00 /
      DATA B(11257), B(11258), B(11259) /    24.73,  -42.98,    0.00 /
      DATA B(11596), B(11597), B(11598) /    24.72,  -42.88,    0.00 /
      DATA B(11935), B(11936), B(11937) /    24.71,  -42.78,    0.00 /
      DATA B(12274), B(12275), B(12276) /    24.70,  -42.67,    0.00 /
      DATA B(12613), B(12614), B(12615) /    24.69,  -42.56,    0.00 /
      DATA B(12952), B(12953), B(12954) /    24.68,  -42.44,    0.00 /
      DATA B(13291), B(13292), B(13293) /    24.67,  -42.31,    0.00 /
      DATA B(13630), B(13631), B(13632) /    24.66,  -42.17,    0.00 /
      DATA B(13969), B(13970), B(13971) /    24.64,  -42.01,    0.00 /
      DATA B(14308), B(14309), B(14310) /    24.63,  -41.84,    0.00 /
      DATA B(14647), B(14648), B(14649) /    24.61,  -41.63,    0.00 /
      DATA B(14986), B(14987), B(14988) /    24.57,  -41.37,    0.00 /
      DATA B(15325), B(15326), B(15327) /    24.51,  -41.06,    0.00 /
      DATA B(15664), B(15665), B(15666) /    24.38,  -40.71,    0.00 /
      DATA B(16003), B(16004), B(16005) /    24.22,  -40.40,    0.00 /
      DATA B(16342), B(16343), B(16344) /    23.67,  -40.46,    0.00 /
      DATA B(16681), B(16682), B(16683) /    22.92,  -40.59,    0.00 /
      DATA B(17020), B(17021), B(17022) /    22.12,  -40.66,    0.00 /
      DATA B(17359), B(17360), B(17361) /    21.30,  -40.72,    0.00 /
      DATA B(17698), B(17699), B(17700) /    20.48,  -40.78,    0.00 /
      DATA B(18037), B(18038), B(18039) /    19.66,  -40.86,    0.00 /
      DATA B(18376), B(18377), B(18378) /    18.83,  -40.94,    0.00 /
      DATA B(18715), B(18716), B(18717) /    18.00,  -41.02,    0.00 /
      DATA B(19054), B(19055), B(19056) /    17.15,  -41.08,    0.00 /
      DATA B(19393), B(19394), B(19395) /    16.22,  -41.10,    0.00 /
      DATA B(19732), B(19733), B(19734) /    15.13,  -41.01,    0.00 /
      DATA B(20071), B(20072), B(20073) /    17.13,  -40.01,    0.00 /
      DATA B(20410), B(20411), B(20412) /    16.61,  -39.37,    0.00 /
      DATA B(20749), B(20750), B(20751) /    15.89,  -38.62,    0.00 /
      DATA B(21088), B(21089), B(21090) /    14.95,  -37.81,    0.00 /
      DATA B(21427), B(21428), B(21429) /    13.64,  -36.81,    0.00 /
      DATA B(21766), B(21767), B(21768) /    11.96,  -35.08,    0.00 /
      DATA B(22105), B(22106), B(22107) /    11.71,  -33.28,    0.00 /
      DATA B(22444), B(22445), B(22446) /     9.28,  -30.64,    0.00 /
      DATA B(22783), B(22784), B(22785) /     7.42,  -28.71,    0.00 /
      DATA B(23122), B(23123), B(23124) /     4.53,  -27.28,    0.00 /
      DATA B(23461), B(23462), B(23463) /     3.50,  -26.41,    0.00 /
      DATA B(23800), B(23801), B(23802) /     2.72,  -25.75,    0.00 /
      DATA B(24139), B(24140), B(24141) /     2.11,  -25.22,    0.00 /
      DATA B(24478), B(24479), B(24480) /     1.63,  -24.77,    0.00 /
      DATA B(24817), B(24818), B(24819) /     1.24,  -24.39,    0.00 /
      DATA B(25156), B(25157), B(25158) /     0.92,  -24.07,    0.00 /
      DATA B(25495), B(25496), B(25497) /     0.64,  -23.79,    0.00 /
      DATA B(25834), B(25835), B(25836) /     0.41,  -23.55,    0.00 /
      DATA B(26173), B(26174), B(26175) /     0.21,  -23.34,    0.00 /
      DATA B(26512), B(26513), B(26514) /     0.03,  -23.16,    0.00 /
      DATA B(26851), B(26852), B(26853) /    -0.13,  -23.00,    0.00 /
      DATA B(27190), B(27191), B(27192) /    -0.27,  -22.87,    0.00 /
      DATA B(   73), B(   74), B(   75) /    24.87,  -45.53,    0.00 /
      DATA B(  412), B(  413), B(  414) /    24.87,  -45.46,    0.00 /
      DATA B(  751), B(  752), B(  753) /    24.87,  -45.39,    0.00 /
      DATA B( 1090), B( 1091), B( 1092) /    24.86,  -45.32,    0.00 /
      DATA B( 1429), B( 1430), B( 1431) /    24.86,  -45.25,    0.00 /
      DATA B( 1768), B( 1769), B( 1770) /    24.86,  -45.18,    0.00 /
      DATA B( 2107), B( 2108), B( 2109) /    24.85,  -45.11,    0.00 /
      DATA B( 2446), B( 2447), B( 2448) /    24.85,  -45.04,    0.00 /
      DATA B( 2785), B( 2786), B( 2787) /    24.85,  -44.97,    0.00 /
      DATA B( 3124), B( 3125), B( 3126) /    24.84,  -44.90,    0.00 /
      DATA B( 3463), B( 3464), B( 3465) /    24.84,  -44.82,    0.00 /
      DATA B( 3802), B( 3803), B( 3804) /    24.83,  -44.75,    0.00 /
      DATA B( 4141), B( 4142), B( 4143) /    24.83,  -44.68,    0.00 /
      DATA B( 4480), B( 4481), B( 4482) /    24.83,  -44.60,    0.00 /
      DATA B( 4819), B( 4820), B( 4821) /    24.82,  -44.53,    0.00 /
      DATA B( 5158), B( 5159), B( 5160) /    24.82,  -44.45,    0.00 /
      DATA B( 5497), B( 5498), B( 5499) /    24.81,  -44.38,    0.00 /
      DATA B( 5836), B( 5837), B( 5838) /    24.81,  -44.30,    0.00 /
      DATA B( 6175), B( 6176), B( 6177) /    24.80,  -44.22,    0.00 /
      DATA B( 6514), B( 6515), B( 6516) /    24.80,  -44.15,    0.00 /
      DATA B( 6853), B( 6854), B( 6855) /    24.79,  -44.07,    0.00 /
      DATA B( 7192), B( 7193), B( 7194) /    24.79,  -43.99,    0.00 /
      DATA B( 7531), B( 7532), B( 7533) /    24.78,  -43.91,    0.00 /
      DATA B( 7870), B( 7871), B( 7872) /    24.77,  -43.83,    0.00 /
      DATA B( 8209), B( 8210), B( 8211) /    24.77,  -43.74,    0.00 /
      DATA B( 8548), B( 8549), B( 8550) /    24.76,  -43.66,    0.00 /
      DATA B( 8887), B( 8888), B( 8889) /    24.75,  -43.57,    0.00 /
      DATA B( 9226), B( 9227), B( 9228) /    24.74,  -43.49,    0.00 /
      DATA B( 9565), B( 9566), B( 9567) /    24.74,  -43.40,    0.00 /
      DATA B( 9904), B( 9905), B( 9906) /    24.73,  -43.31,    0.00 /
      DATA B(10243), B(10244), B(10245) /    24.72,  -43.22,    0.00 /
      DATA B(10582), B(10583), B(10584) /    24.71,  -43.13,    0.00 /
      DATA B(10921), B(10922), B(10923) /    24.70,  -43.03,    0.00 /
      DATA B(11260), B(11261), B(11262) /    24.69,  -42.93,    0.00 /
      DATA B(11599), B(11600), B(11601) /    24.68,  -42.83,    0.00 /
      DATA B(11938), B(11939), B(11940) /    24.66,  -42.72,    0.00 /
      DATA B(12277), B(12278), B(12279) /    24.65,  -42.61,    0.00 /
      DATA B(12616), B(12617), B(12618) /    24.64,  -42.49,    0.00 /
      DATA B(12955), B(12956), B(12957) /    24.62,  -42.36,    0.00 /
      DATA B(13294), B(13295), B(13296) /    24.61,  -42.23,    0.00 /
      DATA B(13633), B(13634), B(13635) /    24.59,  -42.08,    0.00 /
      DATA B(13972), B(13973), B(13974) /    24.57,  -41.91,    0.00 /
      DATA B(14311), B(14312), B(14313) /    24.55,  -41.71,    0.00 /
      DATA B(14650), B(14651), B(14652) /    24.52,  -41.47,    0.00 /
      DATA B(14989), B(14990), B(14991) /    24.49,  -41.17,    0.00 /
      DATA B(15328), B(15329), B(15330) /    24.44,  -40.78,    0.00 /
      DATA B(15667), B(15668), B(15669) /    24.32,  -40.30,    0.00 /
      DATA B(16006), B(16007), B(16008) /    24.05,  -40.03,    0.00 /
      DATA B(16345), B(16346), B(16347) /    23.54,  -40.41,    0.00 /
      DATA B(16684), B(16685), B(16686) /    22.79,  -40.55,    0.00 /
      DATA B(17023), B(17024), B(17025) /    21.94,  -40.56,    0.00 /
      DATA B(17362), B(17363), B(17364) /    21.08,  -40.59,    0.00 /
      DATA B(17701), B(17702), B(17703) /    20.22,  -40.64,    0.00 /
      DATA B(18040), B(18041), B(18042) /    19.38,  -40.71,    0.00 /
      DATA B(18379), B(18380), B(18381) /    18.53,  -40.78,    0.00 /
      DATA B(18718), B(18719), B(18720) /    17.67,  -40.85,    0.00 /
      DATA B(19057), B(19058), B(19059) /    16.78,  -40.91,    0.00 /
      DATA B(19396), B(19397), B(19398) /    15.79,  -40.93,    0.00 /
      DATA B(19735), B(19736), B(19737) /    14.63,  -40.83,    0.00 /
      DATA B(20074), B(20075), B(20076) /    16.56,  -39.75,    0.00 /
      DATA B(20413), B(20414), B(20415) /    15.85,  -38.92,    0.00 /
      DATA B(20752), B(20753), B(20754) /    15.03,  -38.09,    0.00 /
      DATA B(21091), B(21092), B(21093) /    13.93,  -37.19,    0.00 /
      DATA B(21430), B(21431), B(21432) /    12.49,  -35.92,    0.00 /
      DATA B(21769), B(21770), B(21771) /     5.64,  -27.66,    0.00 /
      DATA B(22108), B(22109), B(22110) /     7.35,  -30.41,    0.00 /
      DATA B(22447), B(22448), B(22449) /     6.65,  -29.18,    0.00 /
      DATA B(22786), B(22787), B(22788) /     5.06,  -27.72,    0.00 /
      DATA B(23125), B(23126), B(23127) /     3.91,  -26.70,    0.00 /
      DATA B(23464), B(23465), B(23466) /     3.05,  -25.97,    0.00 /
      DATA B(23803), B(23804), B(23805) /     2.39,  -25.40,    0.00 /
      DATA B(24142), B(24143), B(24144) /     1.87,  -24.93,    0.00 /
      DATA B(24481), B(24482), B(24483) /     1.45,  -24.54,    0.00 /
      DATA B(24820), B(24821), B(24822) /     1.10,  -24.21,    0.00 /
      DATA B(25159), B(25160), B(25161) /     0.81,  -23.92,    0.00 /
      DATA B(25498), B(25499), B(25500) /     0.56,  -23.67,    0.00 /
      DATA B(25837), B(25838), B(25839) /     0.35,  -23.45,    0.00 /
      DATA B(26176), B(26177), B(26178) /     0.16,  -23.26,    0.00 /
      DATA B(26515), B(26516), B(26517) /    -0.01,  -23.10,    0.00 /
      DATA B(26854), B(26855), B(26856) /    -0.15,  -22.95,    0.00 /
      DATA B(27193), B(27194), B(27195) /    -0.29,  -22.83,    0.00 /
      DATA B(   76), B(   77), B(   78) /    24.84,  -45.51,    0.00 /
      DATA B(  415), B(  416), B(  417) /    24.84,  -45.44,    0.00 /
      DATA B(  754), B(  755), B(  756) /    24.84,  -45.37,    0.00 /
      DATA B( 1093), B( 1094), B( 1095) /    24.83,  -45.30,    0.00 /
      DATA B( 1432), B( 1433), B( 1434) /    24.83,  -45.23,    0.00 /
      DATA B( 1771), B( 1772), B( 1773) /    24.83,  -45.16,    0.00 /
      DATA B( 2110), B( 2111), B( 2112) /    24.82,  -45.09,    0.00 /
      DATA B( 2449), B( 2450), B( 2451) /    24.82,  -45.02,    0.00 /
      DATA B( 2788), B( 2789), B( 2790) /    24.82,  -44.95,    0.00 /
      DATA B( 3127), B( 3128), B( 3129) /    24.81,  -44.87,    0.00 /
      DATA B( 3466), B( 3467), B( 3468) /    24.81,  -44.80,    0.00 /
      DATA B( 3805), B( 3806), B( 3807) /    24.80,  -44.73,    0.00 /
      DATA B( 4144), B( 4145), B( 4146) /    24.80,  -44.65,    0.00 /
      DATA B( 4483), B( 4484), B( 4485) /    24.79,  -44.58,    0.00 /
      DATA B( 4822), B( 4823), B( 4824) /    24.79,  -44.50,    0.00 /
      DATA B( 5161), B( 5162), B( 5163) /    24.79,  -44.43,    0.00 /
      DATA B( 5500), B( 5501), B( 5502) /    24.78,  -44.35,    0.00 /
      DATA B( 5839), B( 5840), B( 5841) /    24.78,  -44.27,    0.00 /
      DATA B( 6178), B( 6179), B( 6180) /    24.77,  -44.20,    0.00 /
      DATA B( 6517), B( 6518), B( 6519) /    24.76,  -44.12,    0.00 /
      DATA B( 6856), B( 6857), B( 6858) /    24.76,  -44.04,    0.00 /
      DATA B( 7195), B( 7196), B( 7197) /    24.75,  -43.96,    0.00 /
      DATA B( 7534), B( 7535), B( 7536) /    24.75,  -43.88,    0.00 /
      DATA B( 7873), B( 7874), B( 7875) /    24.74,  -43.79,    0.00 /
      DATA B( 8212), B( 8213), B( 8214) /    24.73,  -43.71,    0.00 /
      DATA B( 8551), B( 8552), B( 8553) /    24.72,  -43.62,    0.00 /
      DATA B( 8890), B( 8891), B( 8892) /    24.72,  -43.54,    0.00 /
      DATA B( 9229), B( 9230), B( 9231) /    24.71,  -43.45,    0.00 /
      DATA B( 9568), B( 9569), B( 9570) /    24.70,  -43.36,    0.00 /
      DATA B( 9907), B( 9908), B( 9909) /    24.69,  -43.27,    0.00 /
      DATA B(10246), B(10247), B(10248) /    24.68,  -43.17,    0.00 /
      DATA B(10585), B(10586), B(10587) /    24.67,  -43.08,    0.00 /
      DATA B(10924), B(10925), B(10926) /    24.65,  -42.98,    0.00 /
      DATA B(11263), B(11264), B(11265) /    24.64,  -42.87,    0.00 /
      DATA B(11602), B(11603), B(11604) /    24.63,  -42.77,    0.00 /
      DATA B(11941), B(11942), B(11943) /    24.61,  -42.66,    0.00 /
      DATA B(12280), B(12281), B(12282) /    24.60,  -42.54,    0.00 /
      DATA B(12619), B(12620), B(12621) /    24.58,  -42.42,    0.00 /
      DATA B(12958), B(12959), B(12960) /    24.56,  -42.28,    0.00 /
      DATA B(13297), B(13298), B(13299) /    24.54,  -42.13,    0.00 /
      DATA B(13636), B(13637), B(13638) /    24.52,  -41.97,    0.00 /
      DATA B(13975), B(13976), B(13977) /    24.49,  -41.78,    0.00 /
      DATA B(14314), B(14315), B(14316) /    24.45,  -41.56,    0.00 /
      DATA B(14653), B(14654), B(14655) /    24.42,  -41.29,    0.00 /
      DATA B(14992), B(14993), B(14994) /    24.37,  -40.94,    0.00 /
      DATA B(15331), B(15332), B(15333) /    24.32,  -40.46,    0.00 /
      DATA B(15670), B(15671), B(15672) /    24.29,  -39.79,    0.00 /
      DATA B(16009), B(16010), B(16011) /    24.07,  -39.31,    0.00 /
      DATA B(16348), B(16349), B(16350) /    23.63,  -40.57,    0.00 /
      DATA B(16687), B(16688), B(16689) /    22.73,  -40.50,    0.00 /
      DATA B(17026), B(17027), B(17028) /    21.76,  -40.45,    0.00 /
      DATA B(17365), B(17366), B(17367) /    20.84,  -40.46,    0.00 /
      DATA B(17704), B(17705), B(17706) /    19.96,  -40.50,    0.00 /
      DATA B(18043), B(18044), B(18045) /    19.09,  -40.55,    0.00 /
      DATA B(18382), B(18383), B(18384) /    18.23,  -40.61,    0.00 /
      DATA B(18721), B(18722), B(18723) /    17.36,  -40.67,    0.00 /
      DATA B(19060), B(19061), B(19062) /    16.43,  -40.71,    0.00 /
      DATA B(19399), B(19400), B(19401) /    15.38,  -40.72,    0.00 /
      DATA B(19738), B(19739), B(19740) /    14.11,  -40.64,    0.00 /
      DATA B(20077), B(20078), B(20079) /    15.94,  -39.42,    0.00 /
      DATA B(20416), B(20417), B(20418) /    15.01,  -38.36,    0.00 /
      DATA B(20755), B(20756), B(20757) /    13.99,  -37.50,    0.00 /
      DATA B(21094), B(21095), B(21096) /    12.76,  -36.42,    0.00 /
      DATA B(21433), B(21434), B(21435) /    11.25,  -34.85,    0.00 /
      DATA B(21772), B(21773), B(21774) /     9.60,  -32.62,    0.00 /
      DATA B(22111), B(22112), B(22113) /     7.58,  -30.13,    0.00 /
      DATA B(22450), B(22451), B(22452) /     5.79,  -28.34,    0.00 /
      DATA B(22789), B(22790), B(22791) /     4.45,  -27.13,    0.00 /
      DATA B(23128), B(23129), B(23130) /     3.47,  -26.26,    0.00 /
      DATA B(23467), B(23468), B(23469) /     2.73,  -25.62,    0.00 /
      DATA B(23806), B(23807), B(23808) /     2.15,  -25.11,    0.00 /
      DATA B(24145), B(24146), B(24147) /     1.69,  -24.70,    0.00 /
      DATA B(24484), B(24485), B(24486) /     1.31,  -24.35,    0.00 /
      DATA B(24823), B(24824), B(24825) /     1.00,  -24.05,    0.00 /
      DATA B(25162), B(25163), B(25164) /     0.73,  -23.79,    0.00 /
      DATA B(25501), B(25502), B(25503) /     0.50,  -23.57,    0.00 /
      DATA B(25840), B(25841), B(25842) /     0.30,  -23.37,    0.00 /
      DATA B(26179), B(26180), B(26181) /     0.13,  -23.19,    0.00 /
      DATA B(26518), B(26519), B(26520) /    -0.03,  -23.03,    0.00 /
      DATA B(26857), B(26858), B(26859) /    -0.17,  -22.90,    0.00 /
      DATA B(27196), B(27197), B(27198) /    -0.30,  -22.78,    0.00 /
      DATA B(   79), B(   80), B(   81) /    24.81,  -45.49,    0.00 /
      DATA B(  418), B(  419), B(  420) /    24.81,  -45.42,    0.00 /
      DATA B(  757), B(  758), B(  759) /    24.81,  -45.35,    0.00 /
      DATA B( 1096), B( 1097), B( 1098) /    24.80,  -45.28,    0.00 /
      DATA B( 1435), B( 1436), B( 1437) /    24.80,  -45.21,    0.00 /
      DATA B( 1774), B( 1775), B( 1776) /    24.80,  -45.14,    0.00 /
      DATA B( 2113), B( 2114), B( 2115) /    24.79,  -45.07,    0.00 /
      DATA B( 2452), B( 2453), B( 2454) /    24.79,  -44.99,    0.00 /
      DATA B( 2791), B( 2792), B( 2793) /    24.79,  -44.92,    0.00 /
      DATA B( 3130), B( 3131), B( 3132) /    24.78,  -44.85,    0.00 /
      DATA B( 3469), B( 3470), B( 3471) /    24.78,  -44.78,    0.00 /
      DATA B( 3808), B( 3809), B( 3810) /    24.77,  -44.70,    0.00 /
      DATA B( 4147), B( 4148), B( 4149) /    24.77,  -44.63,    0.00 /
      DATA B( 4486), B( 4487), B( 4488) /    24.76,  -44.55,    0.00 /
      DATA B( 4825), B( 4826), B( 4827) /    24.76,  -44.48,    0.00 /
      DATA B( 5164), B( 5165), B( 5166) /    24.75,  -44.40,    0.00 /
      DATA B( 5503), B( 5504), B( 5505) /    24.75,  -44.32,    0.00 /
      DATA B( 5842), B( 5843), B( 5844) /    24.74,  -44.24,    0.00 /
      DATA B( 6181), B( 6182), B( 6183) /    24.74,  -44.17,    0.00 /
      DATA B( 6520), B( 6521), B( 6522) /    24.73,  -44.09,    0.00 /
      DATA B( 6859), B( 6860), B( 6861) /    24.72,  -44.01,    0.00 /
      DATA B( 7198), B( 7199), B( 7200) /    24.72,  -43.92,    0.00 /
      DATA B( 7537), B( 7538), B( 7539) /    24.71,  -43.84,    0.00 /
      DATA B( 7876), B( 7877), B( 7878) /    24.70,  -43.76,    0.00 /
      DATA B( 8215), B( 8216), B( 8217) /    24.70,  -43.67,    0.00 /
      DATA B( 8554), B( 8555), B( 8556) /    24.69,  -43.59,    0.00 /
      DATA B( 8893), B( 8894), B( 8895) /    24.68,  -43.50,    0.00 /
      DATA B( 9232), B( 9233), B( 9234) /    24.67,  -43.41,    0.00 /
      DATA B( 9571), B( 9572), B( 9573) /    24.66,  -43.31,    0.00 /
      DATA B( 9910), B( 9911), B( 9912) /    24.65,  -43.22,    0.00 /
      DATA B(10249), B(10250), B(10251) /    24.64,  -43.12,    0.00 /
      DATA B(10588), B(10589), B(10590) /    24.62,  -43.02,    0.00 /
      DATA B(10927), B(10928), B(10929) /    24.61,  -42.92,    0.00 /
      DATA B(11266), B(11267), B(11268) /    24.59,  -42.82,    0.00 /
      DATA B(11605), B(11606), B(11607) /    24.58,  -42.70,    0.00 /
      DATA B(11944), B(11945), B(11946) /    24.56,  -42.59,    0.00 /
      DATA B(12283), B(12284), B(12285) /    24.54,  -42.47,    0.00 /
      DATA B(12622), B(12623), B(12624) /    24.52,  -42.33,    0.00 /
      DATA B(12961), B(12962), B(12963) /    24.50,  -42.19,    0.00 /
      DATA B(13300), B(13301), B(13302) /    24.47,  -42.03,    0.00 /
      DATA B(13639), B(13640), B(13641) /    24.44,  -41.85,    0.00 /
      DATA B(13978), B(13979), B(13980) /    24.40,  -41.64,    0.00 /
      DATA B(14317), B(14318), B(14319) /    24.35,  -41.39,    0.00 /
      DATA B(14656), B(14657), B(14658) /    24.28,  -41.07,    0.00 /
      DATA B(14995), B(14996), B(14997) /    24.19,  -40.66,    0.00 /
      DATA B(15334), B(15335), B(15336) /    24.06,  -40.10,    0.00 /
      DATA B(15673), B(15674), B(15675) /    23.88,  -39.26,    0.00 /
      DATA B(16012), B(16013), B(16014) /    23.02,  -36.86,    0.00 /
      DATA B(16351), B(16352), B(16353) /    23.76,  -40.63,    0.00 /
      DATA B(16690), B(16691), B(16692) /    22.56,  -40.38,    0.00 /
      DATA B(17029), B(17030), B(17031) /    21.52,  -40.31,    0.00 /
      DATA B(17368), B(17369), B(17370) /    20.57,  -40.31,    0.00 /
      DATA B(17707), B(17708), B(17709) /    19.68,  -40.34,    0.00 /
      DATA B(18046), B(18047), B(18048) /    18.81,  -40.39,    0.00 /
      DATA B(18385), B(18386), B(18387) /    17.94,  -40.44,    0.00 /
      DATA B(18724), B(18725), B(18726) /    17.06,  -40.47,    0.00 /
      DATA B(19063), B(19064), B(19065) /    16.14,  -40.49,    0.00 /
      DATA B(19402), B(19403), B(19404) /    15.08,  -40.46,    0.00 /
      DATA B(19741), B(19742), B(19743) /    13.69,  -40.38,    0.00 /
      DATA B(20080), B(20081), B(20082) /    15.01,  -38.76,    0.00 /
      DATA B(20419), B(20420), B(20421) /    13.86,  -37.68,    0.00 /
      DATA B(20758), B(20759), B(20760) /    12.73,  -36.82,    0.00 /
      DATA B(21097), B(21098), B(21099) /    11.33,  -35.45,    0.00 /
      DATA B(21436), B(21437), B(21438) /    10.36,  -33.64,    0.00 /
      DATA B(21775), B(21776), B(21777) /     8.97,  -31.34,    0.00 /
      DATA B(22114), B(22115), B(22116) /     6.97,  -29.23,    0.00 /
      DATA B(22453), B(22454), B(22455) /     5.31,  -27.74,    0.00 /
      DATA B(22792), B(22793), B(22794) /     4.09,  -26.70,    0.00 /
      DATA B(23131), B(23132), B(23133) /     3.20,  -25.93,    0.00 /
      DATA B(23470), B(23471), B(23472) /     2.53,  -25.34,    0.00 /
      DATA B(23809), B(23810), B(23811) /     2.00,  -24.88,    0.00 /
      DATA B(24148), B(24149), B(24150) /     1.57,  -24.51,    0.00 /
      DATA B(24487), B(24488), B(24489) /     1.22,  -24.19,    0.00 /
      DATA B(24826), B(24827), B(24828) /     0.93,  -23.92,    0.00 /
      DATA B(25165), B(25166), B(25167) /     0.68,  -23.68,    0.00 /
      DATA B(25504), B(25505), B(25506) /     0.46,  -23.47,    0.00 /
      DATA B(25843), B(25844), B(25845) /     0.27,  -23.28,    0.00 /
      DATA B(26182), B(26183), B(26184) /     0.10,  -23.12,    0.00 /
      DATA B(26521), B(26522), B(26523) /    -0.05,  -22.98,    0.00 /
      DATA B(26860), B(26861), B(26862) /    -0.18,  -22.85,    0.00 /
      DATA B(27199), B(27200), B(27201) /    -0.30,  -22.73,    0.00 /
      DATA B(   82), B(   83), B(   84) /    24.79,  -45.47,    0.00 /
      DATA B(  421), B(  422), B(  423) /    24.78,  -45.40,    0.00 /
      DATA B(  760), B(  761), B(  762) /    24.78,  -45.33,    0.00 /
      DATA B( 1099), B( 1100), B( 1101) /    24.78,  -45.26,    0.00 /
      DATA B( 1438), B( 1439), B( 1440) /    24.77,  -45.19,    0.00 /
      DATA B( 1777), B( 1778), B( 1779) /    24.77,  -45.12,    0.00 /
      DATA B( 2116), B( 2117), B( 2118) /    24.76,  -45.04,    0.00 /
      DATA B( 2455), B( 2456), B( 2457) /    24.76,  -44.97,    0.00 /
      DATA B( 2794), B( 2795), B( 2796) /    24.76,  -44.90,    0.00 /
      DATA B( 3133), B( 3134), B( 3135) /    24.75,  -44.82,    0.00 /
      DATA B( 3472), B( 3473), B( 3474) /    24.75,  -44.75,    0.00 /
      DATA B( 3811), B( 3812), B( 3813) /    24.74,  -44.68,    0.00 /
      DATA B( 4150), B( 4151), B( 4152) /    24.74,  -44.60,    0.00 /
      DATA B( 4489), B( 4490), B( 4491) /    24.73,  -44.53,    0.00 /
      DATA B( 4828), B( 4829), B( 4830) /    24.73,  -44.45,    0.00 /
      DATA B( 5167), B( 5168), B( 5169) /    24.72,  -44.37,    0.00 /
      DATA B( 5506), B( 5507), B( 5508) /    24.72,  -44.29,    0.00 /
      DATA B( 5845), B( 5846), B( 5847) /    24.71,  -44.22,    0.00 /
      DATA B( 6184), B( 6185), B( 6186) /    24.70,  -44.14,    0.00 /
      DATA B( 6523), B( 6524), B( 6525) /    24.70,  -44.06,    0.00 /
      DATA B( 6862), B( 6863), B( 6864) /    24.69,  -43.97,    0.00 /
      DATA B( 7201), B( 7202), B( 7203) /    24.68,  -43.89,    0.00 /
      DATA B( 7540), B( 7541), B( 7542) /    24.68,  -43.81,    0.00 /
      DATA B( 7879), B( 7880), B( 7881) /    24.67,  -43.72,    0.00 /
      DATA B( 8218), B( 8219), B( 8220) /    24.66,  -43.63,    0.00 /
      DATA B( 8557), B( 8558), B( 8559) /    24.65,  -43.55,    0.00 /
      DATA B( 8896), B( 8897), B( 8898) /    24.64,  -43.45,    0.00 /
      DATA B( 9235), B( 9236), B( 9237) /    24.63,  -43.36,    0.00 /
      DATA B( 9574), B( 9575), B( 9576) /    24.62,  -43.27,    0.00 /
      DATA B( 9913), B( 9914), B( 9915) /    24.61,  -43.17,    0.00 /
      DATA B(10252), B(10253), B(10254) /    24.59,  -43.07,    0.00 /
      DATA B(10591), B(10592), B(10593) /    24.58,  -42.97,    0.00 /
      DATA B(10930), B(10931), B(10932) /    24.56,  -42.86,    0.00 /
      DATA B(11269), B(11270), B(11271) /    24.55,  -42.75,    0.00 /
      DATA B(11608), B(11609), B(11610) /    24.53,  -42.64,    0.00 /
      DATA B(11947), B(11948), B(11949) /    24.51,  -42.51,    0.00 /
      DATA B(12286), B(12287), B(12288) /    24.48,  -42.38,    0.00 /
      DATA B(12625), B(12626), B(12627) /    24.46,  -42.24,    0.00 /
      DATA B(12964), B(12965), B(12966) /    24.43,  -42.09,    0.00 /
      DATA B(13303), B(13304), B(13305) /    24.39,  -41.91,    0.00 /
      DATA B(13642), B(13643), B(13644) /    24.35,  -41.71,    0.00 /
      DATA B(13981), B(13982), B(13983) /    24.30,  -41.47,    0.00 /
      DATA B(14320), B(14321), B(14322) /    24.22,  -41.18,    0.00 /
      DATA B(14659), B(14660), B(14661) /    24.12,  -40.81,    0.00 /
      DATA B(14998), B(14999), B(15000) /    23.95,  -40.32,    0.00 /
      DATA B(15337), B(15338), B(15339) /    23.66,  -39.62,    0.00 /
      DATA B(15676), B(15677), B(15678) /    23.07,  -38.59,    0.00 /
      DATA B(16015), B(16016), B(16017) /    22.14,  -36.34,    0.00 /
      DATA B(16354), B(16355), B(16356) /    23.03,  -40.69,    0.00 /
      DATA B(16693), B(16694), B(16695) /    22.14,  -40.26,    0.00 /
      DATA B(17032), B(17033), B(17034) /    21.18,  -40.16,    0.00 /
      DATA B(17371), B(17372), B(17373) /    20.26,  -40.16,    0.00 /
      DATA B(17710), B(17711), B(17712) /    19.37,  -40.19,    0.00 /
      DATA B(18049), B(18050), B(18051) /    18.51,  -40.23,    0.00 /
      DATA B(18388), B(18389), B(18390) /    17.65,  -40.26,    0.00 /
      DATA B(18727), B(18728), B(18729) /    16.78,  -40.28,    0.00 /
      DATA B(19066), B(19067), B(19068) /    15.89,  -40.27,    0.00 /
      DATA B(19405), B(19406), B(19407) /    14.94,  -40.22,    0.00 /
      DATA B(19744), B(19745), B(19746) /    13.96,  -40.20,    0.00 /
      DATA B(20083), B(20084), B(20085) /    13.41,  -37.89,    0.00 /
      DATA B(20422), B(20423), B(20424) /    12.69,  -37.05,    0.00 /
      DATA B(20761), B(20762), B(20763) /    11.41,  -36.01,    0.00 /
      DATA B(21100), B(21101), B(21102) /     9.54,  -34.06,    0.00 /
      DATA B(21439), B(21440), B(21441) /    11.16,  -32.50,    0.00 /
      DATA B(21778), B(21779), B(21780) /     8.60,  -30.10,    0.00 /
      DATA B(22117), B(22118), B(22119) /     6.68,  -28.54,    0.00 /
      DATA B(22456), B(22457), B(22458) /     5.10,  -27.32,    0.00 /
      DATA B(22795), B(22796), B(22797) /     3.93,  -26.38,    0.00 /
      DATA B(23134), B(23135), B(23136) /     3.07,  -25.66,    0.00 /
      DATA B(23473), B(23474), B(23475) /     2.41,  -25.12,    0.00 /
      DATA B(23812), B(23813), B(23814) /     1.90,  -24.69,    0.00 /
      DATA B(24151), B(24152), B(24153) /     1.50,  -24.34,    0.00 /
      DATA B(24490), B(24491), B(24492) /     1.16,  -24.05,    0.00 /
      DATA B(24829), B(24830), B(24831) /     0.88,  -23.80,    0.00 /
      DATA B(25168), B(25169), B(25170) /     0.64,  -23.58,    0.00 /
      DATA B(25507), B(25508), B(25509) /     0.43,  -23.38,    0.00 /
      DATA B(25846), B(25847), B(25848) /     0.25,  -23.21,    0.00 /
      DATA B(26185), B(26186), B(26187) /     0.09,  -23.05,    0.00 /
      DATA B(26524), B(26525), B(26526) /    -0.05,  -22.92,    0.00 /
      DATA B(26863), B(26864), B(26865) /    -0.19,  -22.80,    0.00 /
      DATA B(27202), B(27203), B(27204) /    -0.30,  -22.69,    0.00 /
      DATA B(   85), B(   86), B(   87) /    24.76,  -45.45,    0.00 /
      DATA B(  424), B(  425), B(  426) /    24.75,  -45.38,    0.00 /
      DATA B(  763), B(  764), B(  765) /    24.75,  -45.31,    0.00 /
      DATA B( 1102), B( 1103), B( 1104) /    24.75,  -45.24,    0.00 /
      DATA B( 1441), B( 1442), B( 1443) /    24.74,  -45.16,    0.00 /
      DATA B( 1780), B( 1781), B( 1782) /    24.74,  -45.09,    0.00 /
      DATA B( 2119), B( 2120), B( 2121) /    24.73,  -45.02,    0.00 /
      DATA B( 2458), B( 2459), B( 2460) /    24.73,  -44.95,    0.00 /
      DATA B( 2797), B( 2798), B( 2799) /    24.72,  -44.87,    0.00 /
      DATA B( 3136), B( 3137), B( 3138) /    24.72,  -44.80,    0.00 /
      DATA B( 3475), B( 3476), B( 3477) /    24.72,  -44.73,    0.00 /
      DATA B( 3814), B( 3815), B( 3816) /    24.71,  -44.65,    0.00 /
      DATA B( 4153), B( 4154), B( 4155) /    24.71,  -44.57,    0.00 /
      DATA B( 4492), B( 4493), B( 4494) /    24.70,  -44.50,    0.00 /
      DATA B( 4831), B( 4832), B( 4833) /    24.69,  -44.42,    0.00 /
      DATA B( 5170), B( 5171), B( 5172) /    24.69,  -44.34,    0.00 /
      DATA B( 5509), B( 5510), B( 5511) /    24.68,  -44.26,    0.00 /
      DATA B( 5848), B( 5849), B( 5850) /    24.68,  -44.19,    0.00 /
      DATA B( 6187), B( 6188), B( 6189) /    24.67,  -44.10,    0.00 /
      DATA B( 6526), B( 6527), B( 6528) /    24.66,  -44.02,    0.00 /
      DATA B( 6865), B( 6866), B( 6867) /    24.66,  -43.94,    0.00 /
      DATA B( 7204), B( 7205), B( 7206) /    24.65,  -43.86,    0.00 /
      DATA B( 7543), B( 7544), B( 7545) /    24.64,  -43.77,    0.00 /
      DATA B( 7882), B( 7883), B( 7884) /    24.63,  -43.68,    0.00 /
      DATA B( 8221), B( 8222), B( 8223) /    24.62,  -43.59,    0.00 /
      DATA B( 8560), B( 8561), B( 8562) /    24.61,  -43.50,    0.00 /
      DATA B( 8899), B( 8900), B( 8901) /    24.60,  -43.41,    0.00 /
      DATA B( 9238), B( 9239), B( 9240) /    24.59,  -43.32,    0.00 /
      DATA B( 9577), B( 9578), B( 9579) /    24.58,  -43.22,    0.00 /
      DATA B( 9916), B( 9917), B( 9918) /    24.57,  -43.12,    0.00 /
      DATA B(10255), B(10256), B(10257) /    24.55,  -43.01,    0.00 /
      DATA B(10594), B(10595), B(10596) /    24.53,  -42.91,    0.00 /
      DATA B(10933), B(10934), B(10935) /    24.52,  -42.80,    0.00 /
      DATA B(11272), B(11273), B(11274) /    24.50,  -42.68,    0.00 /
      DATA B(11611), B(11612), B(11613) /    24.48,  -42.56,    0.00 /
      DATA B(11950), B(11951), B(11952) /    24.45,  -42.43,    0.00 /
      DATA B(12289), B(12290), B(12291) /    24.42,  -42.29,    0.00 /
      DATA B(12628), B(12629), B(12630) /    24.39,  -42.14,    0.00 /
      DATA B(12967), B(12968), B(12969) /    24.36,  -41.97,    0.00 /
      DATA B(13306), B(13307), B(13308) /    24.32,  -41.77,    0.00 /
      DATA B(13645), B(13646), B(13647) /    24.26,  -41.55,    0.00 /
      DATA B(13984), B(13985), B(13986) /    24.19,  -41.27,    0.00 /
      DATA B(14323), B(14324), B(14325) /    24.08,  -40.93,    0.00 /
      DATA B(14662), B(14663), B(14664) /    23.92,  -40.48,    0.00 /
      DATA B(15001), B(15002), B(15003) /    23.65,  -39.88,    0.00 /
      DATA B(15340), B(15341), B(15342) /    23.14,  -39.06,    0.00 /
      DATA B(15679), B(15680), B(15681) /    22.24,  -37.52,    0.00 /
      DATA B(16018), B(16019), B(16020) /    21.73,  -36.32,    0.00 /
      DATA B(16357), B(16358), B(16359) /    22.50,  -40.64,    0.00 /
      DATA B(16696), B(16697), B(16698) /    21.67,  -40.17,    0.00 /
      DATA B(17035), B(17036), B(17037) /    20.80,  -40.03,    0.00 /
      DATA B(17374), B(17375), B(17376) /    19.92,  -40.01,    0.00 /
      DATA B(17713), B(17714), B(17715) /    19.05,  -40.03,    0.00 /
      DATA B(18052), B(18053), B(18054) /    18.19,  -40.07,    0.00 /
      DATA B(18391), B(18392), B(18393) /    17.35,  -40.09,    0.00 /
      DATA B(18730), B(18731), B(18732) /    16.50,  -40.10,    0.00 /
      DATA B(19069), B(19070), B(19071) /    15.64,  -40.08,    0.00 /
      DATA B(19408), B(19409), B(19410) /    14.77,  -40.04,    0.00 /
      DATA B(19747), B(19748), B(19749) /    13.83,  -40.03,    0.00 /
      DATA B(20086), B(20087), B(20088) /    12.49,  -40.00,    0.00 /
      DATA B(20425), B(20426), B(20427) /    11.92,  -36.33,    0.00 /
      DATA B(20764), B(20765), B(20766) /    10.36,  -35.04,    0.00 /
      DATA B(21103), B(21104), B(21105) /     8.51,  -32.65,    0.00 /
      DATA B(21442), B(21443), B(21444) /    10.13,  -30.92,    0.00 /
      DATA B(21781), B(21782), B(21783) /     8.00,  -29.02,    0.00 /
      DATA B(22120), B(22121), B(22122) /     6.46,  -27.97,    0.00 /
      DATA B(22459), B(22460), B(22461) /     5.07,  -27.02,    0.00 /
      DATA B(22798), B(22799), B(22800) /     3.91,  -26.14,    0.00 /
      DATA B(23137), B(23138), B(23139) /     3.03,  -25.45,    0.00 /
      DATA B(23476), B(23477), B(23478) /     2.36,  -24.93,    0.00 /
      DATA B(23815), B(23816), B(23817) /     1.85,  -24.53,    0.00 /
      DATA B(24154), B(24155), B(24156) /     1.45,  -24.20,    0.00 /
      DATA B(24493), B(24494), B(24495) /     1.12,  -23.93,    0.00 /
      DATA B(24832), B(24833), B(24834) /     0.85,  -23.69,    0.00 /
      DATA B(25171), B(25172), B(25173) /     0.62,  -23.48,    0.00 /
      DATA B(25510), B(25511), B(25512) /     0.42,  -23.30,    0.00 /
      DATA B(25849), B(25850), B(25851) /     0.24,  -23.14,    0.00 /
      DATA B(26188), B(26189), B(26190) /     0.08,  -22.99,    0.00 /
      DATA B(26527), B(26528), B(26529) /    -0.06,  -22.86,    0.00 /
      DATA B(26866), B(26867), B(26868) /    -0.19,  -22.74,    0.00 /
      DATA B(27205), B(27206), B(27207) /    -0.30,  -22.64,    0.00 /
      DATA B(   88), B(   89), B(   90) /    24.73,  -45.43,    0.00 /
      DATA B(  427), B(  428), B(  429) /    24.72,  -45.36,    0.00 /
      DATA B(  766), B(  767), B(  768) /    24.72,  -45.29,    0.00 /
      DATA B( 1105), B( 1106), B( 1107) /    24.72,  -45.21,    0.00 /
      DATA B( 1444), B( 1445), B( 1446) /    24.71,  -45.14,    0.00 /
      DATA B( 1783), B( 1784), B( 1785) /    24.71,  -45.07,    0.00 /
      DATA B( 2122), B( 2123), B( 2124) /    24.70,  -45.00,    0.00 /
      DATA B( 2461), B( 2462), B( 2463) /    24.70,  -44.92,    0.00 /
      DATA B( 2800), B( 2801), B( 2802) /    24.69,  -44.85,    0.00 /
      DATA B( 3139), B( 3140), B( 3141) /    24.69,  -44.77,    0.00 /
      DATA B( 3478), B( 3479), B( 3480) /    24.68,  -44.70,    0.00 /
      DATA B( 3817), B( 3818), B( 3819) /    24.68,  -44.62,    0.00 /
      DATA B( 4156), B( 4157), B( 4158) /    24.67,  -44.55,    0.00 /
      DATA B( 4495), B( 4496), B( 4497) /    24.67,  -44.47,    0.00 /
      DATA B( 4834), B( 4835), B( 4836) /    24.66,  -44.39,    0.00 /
      DATA B( 5173), B( 5174), B( 5175) /    24.66,  -44.31,    0.00 /
      DATA B( 5512), B( 5513), B( 5514) /    24.65,  -44.23,    0.00 /
      DATA B( 5851), B( 5852), B( 5853) /    24.64,  -44.15,    0.00 /
      DATA B( 6190), B( 6191), B( 6192) /    24.64,  -44.07,    0.00 /
      DATA B( 6529), B( 6530), B( 6531) /    24.63,  -43.99,    0.00 /
      DATA B( 6868), B( 6869), B( 6870) /    24.62,  -43.90,    0.00 /
      DATA B( 7207), B( 7208), B( 7209) /    24.62,  -43.82,    0.00 /
      DATA B( 7546), B( 7547), B( 7548) /    24.61,  -43.73,    0.00 /
      DATA B( 7885), B( 7886), B( 7887) /    24.60,  -43.64,    0.00 /
      DATA B( 8224), B( 8225), B( 8226) /    24.59,  -43.55,    0.00 /
      DATA B( 8563), B( 8564), B( 8565) /    24.58,  -43.46,    0.00 /
      DATA B( 8902), B( 8903), B( 8904) /    24.57,  -43.36,    0.00 /
      DATA B( 9241), B( 9242), B( 9243) /    24.55,  -43.27,    0.00 /
      DATA B( 9580), B( 9581), B( 9582) /    24.54,  -43.16,    0.00 /
      DATA B( 9919), B( 9920), B( 9921) /    24.53,  -43.06,    0.00 /
      DATA B(10258), B(10259), B(10260) /    24.51,  -42.95,    0.00 /
      DATA B(10597), B(10598), B(10599) /    24.49,  -42.84,    0.00 /
      DATA B(10936), B(10937), B(10938) /    24.47,  -42.73,    0.00 /
      DATA B(11275), B(11276), B(11277) /    24.45,  -42.60,    0.00 /
      DATA B(11614), B(11615), B(11616) /    24.42,  -42.47,    0.00 /
      DATA B(11953), B(11954), B(11955) /    24.39,  -42.34,    0.00 /
      DATA B(12292), B(12293), B(12294) /    24.36,  -42.19,    0.00 /
      DATA B(12631), B(12632), B(12633) /    24.33,  -42.02,    0.00 /
      DATA B(12970), B(12971), B(12972) /    24.29,  -41.83,    0.00 /
      DATA B(13309), B(13310), B(13311) /    24.23,  -41.61,    0.00 /
      DATA B(13648), B(13649), B(13650) /    24.17,  -41.35,    0.00 /
      DATA B(13987), B(13988), B(13989) /    24.07,  -41.03,    0.00 /
      DATA B(14326), B(14327), B(14328) /    23.92,  -40.62,    0.00 /
      DATA B(14665), B(14666), B(14667) /    23.68,  -40.09,    0.00 /
      DATA B(15004), B(15005), B(15006) /    23.26,  -39.38,    0.00 /
      DATA B(15343), B(15344), B(15345) /    22.43,  -38.09,    0.00 /
      DATA B(15682), B(15683), B(15684) /    21.77,  -37.25,    0.00 /
      DATA B(16021), B(16022), B(16023) /    21.41,  -36.38,    0.00 /
      DATA B(16360), B(16361), B(16362) /    22.08,  -40.42,    0.00 /
      DATA B(16699), B(16700), B(16701) /    21.25,  -40.05,    0.00 /
      DATA B(17038), B(17039), B(17040) /    20.41,  -39.90,    0.00 /
      DATA B(17377), B(17378), B(17379) /    19.56,  -39.87,    0.00 /
      DATA B(17716), B(17717), B(17718) /    18.71,  -39.89,    0.00 /
      DATA B(18055), B(18056), B(18057) /    17.87,  -39.91,    0.00 /
      DATA B(18394), B(18395), B(18396) /    17.03,  -39.92,    0.00 /
      DATA B(18733), B(18734), B(18735) /    16.19,  -39.92,    0.00 /
      DATA B(19072), B(19073), B(19074) /    15.34,  -39.88,    0.00 /
      DATA B(19411), B(19412), B(19413) /    14.47,  -39.81,    0.00 /
      DATA B(19750), B(19751), B(19752) /    13.48,  -39.68,    0.00 /
      DATA B(20089), B(20090), B(20091) /    12.15,  -39.34,    0.00 /
      DATA B(20428), B(20429), B(20430) /    11.38,  -35.49,    0.00 /
      DATA B(20767), B(20768), B(20769) /     9.84,  -33.86,    0.00 /
      DATA B(21106), B(21107), B(21108) /    10.41,  -32.10,    0.00 /
      DATA B(21445), B(21446), B(21447) /     9.18,  -29.62,    0.00 /
      DATA B(21784), B(21785), B(21786) /     7.83,  -28.27,    0.00 /
      DATA B(22123), B(22124), B(22125) /     6.20,  -27.43,    0.00 /
      DATA B(22462), B(22463), B(22464) /     5.12,  -26.77,    0.00 /
      DATA B(22801), B(22802), B(22803) /     3.99,  -25.94,    0.00 /
      DATA B(23140), B(23141), B(23142) /     3.05,  -25.27,    0.00 /
      DATA B(23479), B(23480), B(23481) /     2.35,  -24.77,    0.00 /
      DATA B(23818), B(23819), B(23820) /     1.83,  -24.39,    0.00 /
      DATA B(24157), B(24158), B(24159) /     1.43,  -24.08,    0.00 /
      DATA B(24496), B(24497), B(24498) /     1.11,  -23.82,    0.00 /
      DATA B(24835), B(24836), B(24837) /     0.84,  -23.59,    0.00 /
      DATA B(25174), B(25175), B(25176) /     0.61,  -23.40,    0.00 /
      DATA B(25513), B(25514), B(25515) /     0.41,  -23.22,    0.00 /
      DATA B(25852), B(25853), B(25854) /     0.24,  -23.07,    0.00 /
      DATA B(26191), B(26192), B(26193) /     0.08,  -22.93,    0.00 /
      DATA B(26530), B(26531), B(26532) /    -0.06,  -22.80,    0.00 /
      DATA B(26869), B(26870), B(26871) /    -0.18,  -22.69,    0.00 /
      DATA B(27208), B(27209), B(27210) /    -0.30,  -22.59,    0.00 /
      DATA B(   91), B(   92), B(   93) /    24.70,  -45.41,    0.00 /
      DATA B(  430), B(  431), B(  432) /    24.69,  -45.34,    0.00 /
      DATA B(  769), B(  770), B(  771) /    24.69,  -45.26,    0.00 /
      DATA B( 1108), B( 1109), B( 1110) /    24.69,  -45.19,    0.00 /
      DATA B( 1447), B( 1448), B( 1449) /    24.68,  -45.12,    0.00 /
      DATA B( 1786), B( 1787), B( 1788) /    24.68,  -45.05,    0.00 /
      DATA B( 2125), B( 2126), B( 2127) /    24.67,  -44.97,    0.00 /
      DATA B( 2464), B( 2465), B( 2466) /    24.67,  -44.90,    0.00 /
      DATA B( 2803), B( 2804), B( 2805) /    24.66,  -44.82,    0.00 /
      DATA B( 3142), B( 3143), B( 3144) /    24.66,  -44.75,    0.00 /
      DATA B( 3481), B( 3482), B( 3483) /    24.65,  -44.67,    0.00 /
      DATA B( 3820), B( 3821), B( 3822) /    24.65,  -44.60,    0.00 /
      DATA B( 4159), B( 4160), B( 4161) /    24.64,  -44.52,    0.00 /
      DATA B( 4498), B( 4499), B( 4500) /    24.64,  -44.44,    0.00 /
      DATA B( 4837), B( 4838), B( 4839) /    24.63,  -44.36,    0.00 /
      DATA B( 5176), B( 5177), B( 5178) /    24.62,  -44.28,    0.00 /
      DATA B( 5515), B( 5516), B( 5517) /    24.62,  -44.20,    0.00 /
      DATA B( 5854), B( 5855), B( 5856) /    24.61,  -44.12,    0.00 /
      DATA B( 6193), B( 6194), B( 6195) /    24.60,  -44.04,    0.00 /
      DATA B( 6532), B( 6533), B( 6534) /    24.60,  -43.95,    0.00 /
      DATA B( 6871), B( 6872), B( 6873) /    24.59,  -43.87,    0.00 /
      DATA B( 7210), B( 7211), B( 7212) /    24.58,  -43.78,    0.00 /
      DATA B( 7549), B( 7550), B( 7551) /    24.57,  -43.69,    0.00 /
      DATA B( 7888), B( 7889), B( 7890) /    24.56,  -43.60,    0.00 /
      DATA B( 8227), B( 8228), B( 8229) /    24.55,  -43.51,    0.00 /
      DATA B( 8566), B( 8567), B( 8568) /    24.54,  -43.41,    0.00 /
      DATA B( 8905), B( 8906), B( 8907) /    24.53,  -43.31,    0.00 /
      DATA B( 9244), B( 9245), B( 9246) /    24.52,  -43.21,    0.00 /
      DATA B( 9583), B( 9584), B( 9585) /    24.50,  -43.11,    0.00 /
      DATA B( 9922), B( 9923), B( 9924) /    24.48,  -43.00,    0.00 /
      DATA B(10261), B(10262), B(10263) /    24.47,  -42.89,    0.00 /
      DATA B(10600), B(10601), B(10602) /    24.45,  -42.77,    0.00 /
      DATA B(10939), B(10940), B(10941) /    24.42,  -42.65,    0.00 /
      DATA B(11278), B(11279), B(11280) /    24.40,  -42.52,    0.00 /
      DATA B(11617), B(11618), B(11619) /    24.37,  -42.38,    0.00 /
      DATA B(11956), B(11957), B(11958) /    24.34,  -42.23,    0.00 /
      DATA B(12295), B(12296), B(12297) /    24.30,  -42.07,    0.00 /
      DATA B(12634), B(12635), B(12636) /    24.26,  -41.89,    0.00 /
      DATA B(12973), B(12974), B(12975) /    24.21,  -41.68,    0.00 /
      DATA B(13312), B(13313), B(13314) /    24.15,  -41.43,    0.00 /
      DATA B(13651), B(13652), B(13653) /    24.06,  -41.12,    0.00 /
      DATA B(13990), B(13991), B(13992) /    23.93,  -40.74,    0.00 /
      DATA B(14329), B(14330), B(14331) /    23.72,  -40.25,    0.00 /
      DATA B(14668), B(14669), B(14670) /    23.36,  -39.62,    0.00 /
      DATA B(15007), B(15008), B(15009) /    22.63,  -38.47,    0.00 /
      DATA B(15346), B(15347), B(15348) /    21.94,  -37.79,    0.00 /
      DATA B(15685), B(15686), B(15687) /    21.44,  -37.12,    0.00 /
      DATA B(16024), B(16025), B(16026) /    21.18,  -36.49,    0.00 /
      DATA B(16363), B(16364), B(16365) /    21.72,  -40.17,    0.00 /
      DATA B(16702), B(16703), B(16704) /    20.87,  -39.88,    0.00 /
      DATA B(17041), B(17042), B(17043) /    20.03,  -39.76,    0.00 /
      DATA B(17380), B(17381), B(17382) /    19.20,  -39.73,    0.00 /
      DATA B(17719), B(17720), B(17721) /    18.37,  -39.74,    0.00 /
      DATA B(18058), B(18059), B(18060) /    17.53,  -39.75,    0.00 /
      DATA B(18397), B(18398), B(18399) /    16.69,  -39.75,    0.00 /
      DATA B(18736), B(18737), B(18738) /    15.84,  -39.73,    0.00 /
      DATA B(19075), B(19076), B(19077) /    14.98,  -39.66,    0.00 /
      DATA B(19414), B(19415), B(19416) /    14.08,  -39.53,    0.00 /
      DATA B(19753), B(19754), B(19755) /    13.06,  -39.27,    0.00 /
      DATA B(20092), B(20093), B(20094) /    11.75,  -38.70,    0.00 /
      DATA B(20431), B(20432), B(20433) /     9.92,  -37.59,    0.00 /
      DATA B(20770), B(20771), B(20772) /     9.64,  -32.73,    0.00 /
      DATA B(21109), B(21110), B(21111) /     9.02,  -30.81,    0.00 /
      DATA B(21448), B(21449), B(21450) /     8.37,  -28.74,    0.00 /
      DATA B(21787), B(21788), B(21789) /     7.26,  -27.59,    0.00 /
      DATA B(22126), B(22127), B(22128) /     6.34,  -27.16,    0.00 /
      DATA B(22465), B(22466), B(22467) /     5.13,  -26.49,    0.00 /
      DATA B(22804), B(22805), B(22806) /     4.08,  -25.74,    0.00 /
      DATA B(23143), B(23144), B(23145) /     3.10,  -25.11,    0.00 /
      DATA B(23482), B(23483), B(23484) /     2.37,  -24.63,    0.00 /
      DATA B(23821), B(23822), B(23823) /     1.84,  -24.26,    0.00 /
      DATA B(24160), B(24161), B(24162) /     1.43,  -23.96,    0.00 /
      DATA B(24499), B(24500), B(24501) /     1.10,  -23.72,    0.00 /
      DATA B(24838), B(24839), B(24840) /     0.83,  -23.50,    0.00 /
      DATA B(25177), B(25178), B(25179) /     0.61,  -23.31,    0.00 /
      DATA B(25516), B(25517), B(25518) /     0.41,  -23.15,    0.00 /
      DATA B(25855), B(25856), B(25857) /     0.24,  -23.00,    0.00 /
      DATA B(26194), B(26195), B(26196) /     0.09,  -22.87,    0.00 /
      DATA B(26533), B(26534), B(26535) /    -0.05,  -22.75,    0.00 /
      DATA B(26872), B(26873), B(26874) /    -0.17,  -22.64,    0.00 /
      DATA B(27211), B(27212), B(27213) /    -0.29,  -22.54,    0.00 /
      DATA B(   94), B(   95), B(   96) /    24.67,  -45.39,    0.00 /
      DATA B(  433), B(  434), B(  435) /    24.66,  -45.31,    0.00 /
      DATA B(  772), B(  773), B(  774) /    24.66,  -45.24,    0.00 /
      DATA B( 1111), B( 1112), B( 1113) /    24.66,  -45.17,    0.00 /
      DATA B( 1450), B( 1451), B( 1452) /    24.65,  -45.10,    0.00 /
      DATA B( 1789), B( 1790), B( 1791) /    24.65,  -45.02,    0.00 /
      DATA B( 2128), B( 2129), B( 2130) /    24.64,  -44.95,    0.00 /
      DATA B( 2467), B( 2468), B( 2469) /    24.64,  -44.87,    0.00 /
      DATA B( 2806), B( 2807), B( 2808) /    24.63,  -44.80,    0.00 /
      DATA B( 3145), B( 3146), B( 3147) /    24.63,  -44.72,    0.00 /
      DATA B( 3484), B( 3485), B( 3486) /    24.62,  -44.65,    0.00 /
      DATA B( 3823), B( 3824), B( 3825) /    24.62,  -44.57,    0.00 /
      DATA B( 4162), B( 4163), B( 4164) /    24.61,  -44.49,    0.00 /
      DATA B( 4501), B( 4502), B( 4503) /    24.60,  -44.41,    0.00 /
      DATA B( 4840), B( 4841), B( 4842) /    24.60,  -44.33,    0.00 /
      DATA B( 5179), B( 5180), B( 5181) /    24.59,  -44.25,    0.00 /
      DATA B( 5518), B( 5519), B( 5520) /    24.58,  -44.17,    0.00 /
      DATA B( 5857), B( 5858), B( 5859) /    24.58,  -44.09,    0.00 /
      DATA B( 6196), B( 6197), B( 6198) /    24.57,  -44.00,    0.00 /
      DATA B( 6535), B( 6536), B( 6537) /    24.56,  -43.92,    0.00 /
      DATA B( 6874), B( 6875), B( 6876) /    24.55,  -43.83,    0.00 /
      DATA B( 7213), B( 7214), B( 7215) /    24.55,  -43.74,    0.00 /
      DATA B( 7552), B( 7553), B( 7554) /    24.54,  -43.65,    0.00 /
      DATA B( 7891), B( 7892), B( 7893) /    24.53,  -43.56,    0.00 /
      DATA B( 8230), B( 8231), B( 8232) /    24.52,  -43.46,    0.00 /
      DATA B( 8569), B( 8570), B( 8571) /    24.50,  -43.36,    0.00 /
      DATA B( 8908), B( 8909), B( 8910) /    24.49,  -43.26,    0.00 /
      DATA B( 9247), B( 9248), B( 9249) /    24.48,  -43.16,    0.00 /
      DATA B( 9586), B( 9587), B( 9588) /    24.46,  -43.05,    0.00 /
      DATA B( 9925), B( 9926), B( 9927) /    24.44,  -42.93,    0.00 /
      DATA B(10264), B(10265), B(10266) /    24.42,  -42.81,    0.00 /
      DATA B(10603), B(10604), B(10605) /    24.40,  -42.69,    0.00 /
      DATA B(10942), B(10943), B(10944) /    24.37,  -42.56,    0.00 /
      DATA B(11281), B(11282), B(11283) /    24.34,  -42.42,    0.00 /
      DATA B(11620), B(11621), B(11622) /    24.31,  -42.27,    0.00 /
      DATA B(11959), B(11960), B(11961) /    24.28,  -42.11,    0.00 /
      DATA B(12298), B(12299), B(12300) /    24.23,  -41.93,    0.00 /
      DATA B(12637), B(12638), B(12639) /    24.19,  -41.73,    0.00 /
      DATA B(12976), B(12977), B(12978) /    24.12,  -41.49,    0.00 /
      DATA B(13315), B(13316), B(13317) /    24.05,  -41.20,    0.00 /
      DATA B(13654), B(13655), B(13656) /    23.93,  -40.84,    0.00 /
      DATA B(13993), B(13994), B(13995) /    23.75,  -40.39,    0.00 /
      DATA B(14332), B(14333), B(14334) /    23.44,  -39.81,    0.00 /
      DATA B(14671), B(14672), B(14673) /    22.82,  -38.76,    0.00 /
      DATA B(15010), B(15011), B(15012) /    22.12,  -38.16,    0.00 /
      DATA B(15349), B(15350), B(15351) /    21.59,  -37.59,    0.00 /
      DATA B(15688), B(15689), B(15690) /    21.18,  -37.08,    0.00 /
      DATA B(16027), B(16028), B(16029) /    20.93,  -36.65,    0.00 /
      DATA B(16366), B(16367), B(16368) /    21.36,  -39.87,    0.00 /
      DATA B(16705), B(16706), B(16707) /    20.52,  -39.69,    0.00 /
      DATA B(17044), B(17045), B(17046) /    19.68,  -39.61,    0.00 /
      DATA B(17383), B(17384), B(17385) /    18.85,  -39.59,    0.00 /
      DATA B(17722), B(17723), B(17724) /    18.02,  -39.59,    0.00 /
      DATA B(18061), B(18062), B(18063) /    17.18,  -39.59,    0.00 /
      DATA B(18400), B(18401), B(18402) /    16.33,  -39.58,    0.00 /
      DATA B(18739), B(18740), B(18741) /    15.47,  -39.53,    0.00 /
      DATA B(19078), B(19079), B(19080) /    14.58,  -39.42,    0.00 /
      DATA B(19417), B(19418), B(19419) /    13.63,  -39.22,    0.00 /
      DATA B(19756), B(19757), B(19758) /    12.56,  -38.84,    0.00 /
      DATA B(20095), B(20096), B(20097) /    11.26,  -38.08,    0.00 /
      DATA B(20434), B(20435), B(20436) /     9.60,  -36.65,    0.00 /
      DATA B(20773), B(20774), B(20775) /     9.24,  -31.37,    0.00 /
      DATA B(21112), B(21113), B(21114) /     8.58,  -29.66,    0.00 /
      DATA B(21451), B(21452), B(21453) /     7.95,  -28.02,    0.00 /
      DATA B(21790), B(21791), B(21792) /     6.89,  -27.06,    0.00 /
      DATA B(22129), B(22130), B(22131) /     5.98,  -26.64,    0.00 /
      DATA B(22468), B(22469), B(22470) /     4.74,  -26.16,    0.00 /
      DATA B(22807), B(22808), B(22809) /     4.09,  -25.56,    0.00 /
      DATA B(23146), B(23147), B(23148) /     3.16,  -24.97,    0.00 /
      DATA B(23485), B(23486), B(23487) /     2.41,  -24.51,    0.00 /
      DATA B(23824), B(23825), B(23826) /     1.86,  -24.15,    0.00 /
      DATA B(24163), B(24164), B(24165) /     1.44,  -23.87,    0.00 /
      DATA B(24502), B(24503), B(24504) /     1.11,  -23.62,    0.00 /
      DATA B(24841), B(24842), B(24843) /     0.84,  -23.42,    0.00 /
      DATA B(25180), B(25181), B(25182) /     0.61,  -23.24,    0.00 /
      DATA B(25519), B(25520), B(25521) /     0.42,  -23.08,    0.00 /
      DATA B(25858), B(25859), B(25860) /     0.25,  -22.94,    0.00 /
      DATA B(26197), B(26198), B(26199) /     0.09,  -22.81,    0.00 /
      DATA B(26536), B(26537), B(26538) /    -0.04,  -22.69,    0.00 /
      DATA B(26875), B(26876), B(26877) /    -0.17,  -22.59,    0.00 /
      DATA B(27214), B(27215), B(27216) /    -0.28,  -22.49,    0.00 /
      DATA B(   97), B(   98), B(   99) /    24.64,  -45.36,    0.00 /
      DATA B(  436), B(  437), B(  438) /    24.63,  -45.29,    0.00 /
      DATA B(  775), B(  776), B(  777) /    24.63,  -45.22,    0.00 /
      DATA B( 1114), B( 1115), B( 1116) /    24.63,  -45.14,    0.00 /
      DATA B( 1453), B( 1454), B( 1455) /    24.62,  -45.07,    0.00 /
      DATA B( 1792), B( 1793), B( 1794) /    24.62,  -45.00,    0.00 /
      DATA B( 2131), B( 2132), B( 2133) /    24.61,  -44.92,    0.00 /
      DATA B( 2470), B( 2471), B( 2472) /    24.61,  -44.85,    0.00 /
      DATA B( 2809), B( 2810), B( 2811) /    24.60,  -44.77,    0.00 /
      DATA B( 3148), B( 3149), B( 3150) /    24.60,  -44.70,    0.00 /
      DATA B( 3487), B( 3488), B( 3489) /    24.59,  -44.62,    0.00 /
      DATA B( 3826), B( 3827), B( 3828) /    24.58,  -44.54,    0.00 /
      DATA B( 4165), B( 4166), B( 4167) /    24.58,  -44.46,    0.00 /
      DATA B( 4504), B( 4505), B( 4506) /    24.57,  -44.38,    0.00 /
      DATA B( 4843), B( 4844), B( 4845) /    24.57,  -44.30,    0.00 /
      DATA B( 5182), B( 5183), B( 5184) /    24.56,  -44.22,    0.00 /
      DATA B( 5521), B( 5522), B( 5523) /    24.55,  -44.14,    0.00 /
      DATA B( 5860), B( 5861), B( 5862) /    24.54,  -44.05,    0.00 /
      DATA B( 6199), B( 6200), B( 6201) /    24.54,  -43.97,    0.00 /
      DATA B( 6538), B( 6539), B( 6540) /    24.53,  -43.88,    0.00 /
      DATA B( 6877), B( 6878), B( 6879) /    24.52,  -43.79,    0.00 /
      DATA B( 7216), B( 7217), B( 7218) /    24.51,  -43.70,    0.00 /
      DATA B( 7555), B( 7556), B( 7557) /    24.50,  -43.61,    0.00 /
      DATA B( 7894), B( 7895), B( 7896) /    24.49,  -43.51,    0.00 /
      DATA B( 8233), B( 8234), B( 8235) /    24.48,  -43.41,    0.00 /
      DATA B( 8572), B( 8573), B( 8574) /    24.47,  -43.31,    0.00 /
      DATA B( 8911), B( 8912), B( 8913) /    24.45,  -43.20,    0.00 /
      DATA B( 9250), B( 9251), B( 9252) /    24.44,  -43.09,    0.00 /
      DATA B( 9589), B( 9590), B( 9591) /    24.42,  -42.98,    0.00 /
      DATA B( 9928), B( 9929), B( 9930) /    24.40,  -42.86,    0.00 /
      DATA B(10267), B(10268), B(10269) /    24.38,  -42.73,    0.00 /
      DATA B(10606), B(10607), B(10608) /    24.35,  -42.60,    0.00 /
      DATA B(10945), B(10946), B(10947) /    24.33,  -42.46,    0.00 /
      DATA B(11284), B(11285), B(11286) /    24.29,  -42.31,    0.00 /
      DATA B(11623), B(11624), B(11625) /    24.25,  -42.15,    0.00 /
      DATA B(11962), B(11963), B(11964) /    24.21,  -41.97,    0.00 /
      DATA B(12301), B(12302), B(12303) /    24.16,  -41.78,    0.00 /
      DATA B(12640), B(12641), B(12642) /    24.10,  -41.55,    0.00 /
      DATA B(12979), B(12980), B(12981) /    24.03,  -41.27,    0.00 /
      DATA B(13318), B(13319), B(13320) /    23.93,  -40.93,    0.00 /
      DATA B(13657), B(13658), B(13659) /    23.76,  -40.51,    0.00 /
      DATA B(13996), B(13997), B(13998) /    23.49,  -39.98,    0.00 /
      DATA B(14335), B(14336), B(14337) /    22.77,  -38.85,    0.00 /
      DATA B(14674), B(14675), B(14676) /    22.28,  -38.45,    0.00 /
      DATA B(15013), B(15014), B(15015) /    21.75,  -37.92,    0.00 /
      DATA B(15352), B(15353), B(15354) /    21.32,  -37.47,    0.00 /
      DATA B(15691), B(15692), B(15693) /    20.97,  -37.10,    0.00 /
      DATA B(16030), B(16031), B(16032) /    20.77,  -36.81,    0.00 /
      DATA B(16369), B(16370), B(16371) /    21.05,  -39.58,    0.00 /
      DATA B(16708), B(16709), B(16710) /    20.18,  -39.48,    0.00 /
      DATA B(17047), B(17048), B(17049) /    19.34,  -39.44,    0.00 /
      DATA B(17386), B(17387), B(17388) /    18.50,  -39.44,    0.00 /
      DATA B(17725), B(17726), B(17727) /    17.67,  -39.44,    0.00 /
      DATA B(18064), B(18065), B(18066) /    16.82,  -39.43,    0.00 /
      DATA B(18403), B(18404), B(18405) /    15.96,  -39.39,    0.00 /
      DATA B(18742), B(18743), B(18744) /    15.07,  -39.31,    0.00 /
      DATA B(19081), B(19082), B(19083) /    14.13,  -39.15,    0.00 /
      DATA B(19420), B(19421), B(19422) /    13.11,  -38.86,    0.00 /
      DATA B(19759), B(19760), B(19761) /    11.93,  -38.36,    0.00 /
      DATA B(20098), B(20099), B(20100) /    10.52,  -37.43,    0.00 /
      DATA B(20437), B(20438), B(20439) /     8.79,  -35.70,    0.00 /
      DATA B(20776), B(20777), B(20778) /     7.13,  -32.65,    0.00 /
      DATA B(21115), B(21116), B(21117) /     8.83,  -28.89,    0.00 /
      DATA B(21454), B(21455), B(21456) /     7.68,  -27.26,    0.00 /
      DATA B(21793), B(21794), B(21795) /     6.56,  -26.52,    0.00 /
      DATA B(22132), B(22133), B(22134) /     5.63,  -26.23,    0.00 /
      DATA B(22471), B(22472), B(22473) /    -0.55,  -23.08,    0.00 /
      DATA B(22810), B(22811), B(22812) /     4.08,  -25.42,    0.00 /
      DATA B(23149), B(23150), B(23151) /     3.22,  -24.87,    0.00 /
      DATA B(23488), B(23489), B(23490) /     2.45,  -24.42,    0.00 /
      DATA B(23827), B(23828), B(23829) /     1.89,  -24.07,    0.00 /
      DATA B(24166), B(24167), B(24168) /     1.46,  -23.78,    0.00 /
      DATA B(24505), B(24506), B(24507) /     1.12,  -23.54,    0.00 /
      DATA B(24844), B(24845), B(24846) /     0.85,  -23.34,    0.00 /
      DATA B(25183), B(25184), B(25185) /     0.62,  -23.17,    0.00 /
      DATA B(25522), B(25523), B(25524) /     0.43,  -23.01,    0.00 /
      DATA B(25861), B(25862), B(25863) /     0.26,  -22.87,    0.00 /
      DATA B(26200), B(26201), B(26202) /     0.10,  -22.75,    0.00 /
      DATA B(26539), B(26540), B(26541) /    -0.03,  -22.64,    0.00 /
      DATA B(26878), B(26879), B(26880) /    -0.15,  -22.54,    0.00 /
      DATA B(27217), B(27218), B(27219) /    -0.27,  -22.45,    0.00 /
      DATA B(  100), B(  101), B(  102) /    24.61,  -45.34,    0.00 /
      DATA B(  439), B(  440), B(  441) /    24.61,  -45.27,    0.00 /
      DATA B(  778), B(  779), B(  780) /    24.60,  -45.19,    0.00 /
      DATA B( 1117), B( 1118), B( 1119) /    24.60,  -45.12,    0.00 /
      DATA B( 1456), B( 1457), B( 1458) /    24.59,  -45.05,    0.00 /
      DATA B( 1795), B( 1796), B( 1797) /    24.59,  -44.97,    0.00 /
      DATA B( 2134), B( 2135), B( 2136) /    24.58,  -44.90,    0.00 /
      DATA B( 2473), B( 2474), B( 2475) /    24.58,  -44.82,    0.00 /
      DATA B( 2812), B( 2813), B( 2814) /    24.57,  -44.74,    0.00 /
      DATA B( 3151), B( 3152), B( 3153) /    24.56,  -44.67,    0.00 /
      DATA B( 3490), B( 3491), B( 3492) /    24.56,  -44.59,    0.00 /
      DATA B( 3829), B( 3830), B( 3831) /    24.55,  -44.51,    0.00 /
      DATA B( 4168), B( 4169), B( 4170) /    24.55,  -44.43,    0.00 /
      DATA B( 4507), B( 4508), B( 4509) /    24.54,  -44.35,    0.00 /
      DATA B( 4846), B( 4847), B( 4848) /    24.53,  -44.27,    0.00 /
      DATA B( 5185), B( 5186), B( 5187) /    24.53,  -44.19,    0.00 /
      DATA B( 5524), B( 5525), B( 5526) /    24.52,  -44.10,    0.00 /
      DATA B( 5863), B( 5864), B( 5865) /    24.51,  -44.02,    0.00 /
      DATA B( 6202), B( 6203), B( 6204) /    24.50,  -43.93,    0.00 /
      DATA B( 6541), B( 6542), B( 6543) /    24.49,  -43.84,    0.00 /
      DATA B( 6880), B( 6881), B( 6882) /    24.49,  -43.75,    0.00 /
      DATA B( 7219), B( 7220), B( 7221) /    24.48,  -43.66,    0.00 /
      DATA B( 7558), B( 7559), B( 7560) /    24.47,  -43.56,    0.00 /
      DATA B( 7897), B( 7898), B( 7899) /    24.46,  -43.46,    0.00 /
      DATA B( 8236), B( 8237), B( 8238) /    24.44,  -43.36,    0.00 /
      DATA B( 8575), B( 8576), B( 8577) /    24.43,  -43.25,    0.00 /
      DATA B( 8914), B( 8915), B( 8916) /    24.42,  -43.14,    0.00 /
      DATA B( 9253), B( 9254), B( 9255) /    24.40,  -43.03,    0.00 /
      DATA B( 9592), B( 9593), B( 9594) /    24.38,  -42.91,    0.00 /
      DATA B( 9931), B( 9932), B( 9933) /    24.36,  -42.78,    0.00 /
      DATA B(10270), B(10271), B(10272) /    24.34,  -42.64,    0.00 /
      DATA B(10609), B(10610), B(10611) /    24.31,  -42.50,    0.00 /
      DATA B(10948), B(10949), B(10950) /    24.28,  -42.35,    0.00 /
      DATA B(11287), B(11288), B(11289) /    24.24,  -42.18,    0.00 /
      DATA B(11626), B(11627), B(11628) /    24.19,  -42.01,    0.00 /
      DATA B(11965), B(11966), B(11967) /    24.14,  -41.81,    0.00 /
      DATA B(12304), B(12305), B(12306) /    24.08,  -41.59,    0.00 /
      DATA B(12643), B(12644), B(12645) /    24.01,  -41.33,    0.00 /
      DATA B(12982), B(12983), B(12984) /    23.91,  -41.01,    0.00 /
      DATA B(13321), B(13322), B(13323) /    23.77,  -40.61,    0.00 /
      DATA B(13660), B(13661), B(13662) /    23.52,  -40.12,    0.00 /
      DATA B(13999), B(14000), B(14001) /    23.10,  -39.51,    0.00 /
      DATA B(14338), B(14339), B(14340) /    22.42,  -38.70,    0.00 /
      DATA B(14677), B(14678), B(14679) /    21.88,  -38.20,    0.00 /
      DATA B(15016), B(15017), B(15018) /    21.46,  -37.77,    0.00 /
      DATA B(15355), B(15356), B(15357) /    21.10,  -37.43,    0.00 /
      DATA B(15694), B(15695), B(15696) /    20.77,  -37.17,    0.00 /
      DATA B(16033), B(16034), B(16035) /    20.54,  -36.99,    0.00 /
      DATA B(16372), B(16373), B(16374) /    20.69,  -39.27,    0.00 /
      DATA B(16711), B(16712), B(16713) /    19.85,  -39.26,    0.00 /
      DATA B(17050), B(17051), B(17052) /    19.00,  -39.27,    0.00 /
      DATA B(17389), B(17390), B(17391) /    18.16,  -39.28,    0.00 /
      DATA B(17728), B(17729), B(17730) /    17.32,  -39.28,    0.00 /
      DATA B(18067), B(18068), B(18069) /    16.46,  -39.25,    0.00 /
      DATA B(18406), B(18407), B(18408) /    15.58,  -39.19,    0.00 /
      DATA B(18745), B(18746), B(18747) /    14.65,  -39.07,    0.00 /
      DATA B(19084), B(19085), B(19086) /    13.65,  -38.85,    0.00 /
      DATA B(19423), B(19424), B(19425) /    12.54,  -38.46,    0.00 /
      DATA B(19762), B(19763), B(19764) /    11.22,  -37.79,    0.00 /
      DATA B(20101), B(20102), B(20103) /     9.56,  -36.62,    0.00 /
      DATA B(20440), B(20441), B(20442) /     7.37,  -34.55,    0.00 /
      DATA B(20779), B(20780), B(20781) /     9.12,  -32.28,    0.00 /
      DATA B(21118), B(21119), B(21120) /     8.07,  -27.91,    0.00 /
      DATA B(21457), B(21458), B(21459) /     7.15,  -26.46,    0.00 /
      DATA B(21796), B(21797), B(21798) /     6.15,  -25.94,    0.00 /
      DATA B(22135), B(22136), B(22137) /     5.29,  -25.76,    0.00 /
      DATA B(22474), B(22475), B(22476) /     4.66,  -25.75,    0.00 /
      DATA B(22813), B(22814), B(22815) /     4.00,  -25.27,    0.00 /
      DATA B(23152), B(23153), B(23154) /     3.27,  -24.80,    0.00 /
      DATA B(23491), B(23492), B(23493) /     2.52,  -24.36,    0.00 /
      DATA B(23830), B(23831), B(23832) /     1.93,  -24.00,    0.00 /
      DATA B(24169), B(24170), B(24171) /     1.49,  -23.71,    0.00 /
      DATA B(24508), B(24509), B(24510) /     1.15,  -23.47,    0.00 /
      DATA B(24847), B(24848), B(24849) /     0.87,  -23.27,    0.00 /
      DATA B(25186), B(25187), B(25188) /     0.64,  -23.10,    0.00 /
      DATA B(25525), B(25526), B(25527) /     0.44,  -22.95,    0.00 /
      DATA B(25864), B(25865), B(25866) /     0.27,  -22.81,    0.00 /
      DATA B(26203), B(26204), B(26205) /     0.12,  -22.69,    0.00 /
      DATA B(26542), B(26543), B(26544) /    -0.02,  -22.58,    0.00 /
      DATA B(26881), B(26882), B(26883) /    -0.14,  -22.49,    0.00 /
      DATA B(27220), B(27221), B(27222) /    -0.25,  -22.40,    0.00 /
      DATA B(  103), B(  104), B(  105) /    24.58,  -45.32,    0.00 /
      DATA B(  442), B(  443), B(  444) /    24.58,  -45.24,    0.00 /
      DATA B(  781), B(  782), B(  783) /    24.57,  -45.17,    0.00 /
      DATA B( 1120), B( 1121), B( 1122) /    24.57,  -45.10,    0.00 /
      DATA B( 1459), B( 1460), B( 1461) /    24.56,  -45.02,    0.00 /
      DATA B( 1798), B( 1799), B( 1800) /    24.56,  -44.95,    0.00 /
      DATA B( 2137), B( 2138), B( 2139) /    24.55,  -44.87,    0.00 /
      DATA B( 2476), B( 2477), B( 2478) /    24.54,  -44.79,    0.00 /
      DATA B( 2815), B( 2816), B( 2817) /    24.54,  -44.72,    0.00 /
      DATA B( 3154), B( 3155), B( 3156) /    24.53,  -44.64,    0.00 /
      DATA B( 3493), B( 3494), B( 3495) /    24.53,  -44.56,    0.00 /
      DATA B( 3832), B( 3833), B( 3834) /    24.52,  -44.48,    0.00 /
      DATA B( 4171), B( 4172), B( 4173) /    24.51,  -44.40,    0.00 /
      DATA B( 4510), B( 4511), B( 4512) /    24.51,  -44.32,    0.00 /
      DATA B( 4849), B( 4850), B( 4851) /    24.50,  -44.24,    0.00 /
      DATA B( 5188), B( 5189), B( 5190) /    24.49,  -44.15,    0.00 /
      DATA B( 5527), B( 5528), B( 5529) /    24.49,  -44.07,    0.00 /
      DATA B( 5866), B( 5867), B( 5868) /    24.48,  -43.98,    0.00 /
      DATA B( 6205), B( 6206), B( 6207) /    24.47,  -43.89,    0.00 /
      DATA B( 6544), B( 6545), B( 6546) /    24.46,  -43.80,    0.00 /
      DATA B( 6883), B( 6884), B( 6885) /    24.45,  -43.71,    0.00 /
      DATA B( 7222), B( 7223), B( 7224) /    24.44,  -43.61,    0.00 /
      DATA B( 7561), B( 7562), B( 7563) /    24.43,  -43.51,    0.00 /
      DATA B( 7900), B( 7901), B( 7902) /    24.42,  -43.41,    0.00 /
      DATA B( 8239), B( 8240), B( 8241) /    24.41,  -43.30,    0.00 /
      DATA B( 8578), B( 8579), B( 8580) /    24.39,  -43.19,    0.00 /
      DATA B( 8917), B( 8918), B( 8919) /    24.38,  -43.08,    0.00 /
      DATA B( 9256), B( 9257), B( 9258) /    24.36,  -42.95,    0.00 /
      DATA B( 9595), B( 9596), B( 9597) /    24.34,  -42.82,    0.00 /
      DATA B( 9934), B( 9935), B( 9936) /    24.32,  -42.69,    0.00 /
      DATA B(10273), B(10274), B(10275) /    24.29,  -42.54,    0.00 /
      DATA B(10612), B(10613), B(10614) /    24.26,  -42.38,    0.00 /
      DATA B(10951), B(10952), B(10953) /    24.23,  -42.22,    0.00 /
      DATA B(11290), B(11291), B(11292) /    24.18,  -42.03,    0.00 /
      DATA B(11629), B(11630), B(11631) /    24.13,  -41.84,    0.00 /
      DATA B(11968), B(11969), B(11970) /    24.07,  -41.62,    0.00 /
      DATA B(12307), B(12308), B(12309) /    23.99,  -41.36,    0.00 /
      DATA B(12646), B(12647), B(12648) /    23.89,  -41.06,    0.00 /
      DATA B(12985), B(12986), B(12987) /    23.76,  -40.69,    0.00 /
      DATA B(13324), B(13325), B(13326) /    23.54,  -40.24,    0.00 /
      DATA B(13663), B(13664), B(13665) /    23.17,  -39.68,    0.00 /
      DATA B(14002), B(14003), B(14004) /    22.54,  -38.93,    0.00 /
      DATA B(14341), B(14342), B(14343) /    21.99,  -38.44,    0.00 /
      DATA B(14680), B(14681), B(14682) /    21.57,  -38.02,    0.00 /
      DATA B(15019), B(15020), B(15021) /    21.22,  -37.69,    0.00 /
      DATA B(15358), B(15359), B(15360) /    20.90,  -37.43,    0.00 /
      DATA B(15697), B(15698), B(15699) /    20.60,  -37.25,    0.00 /
      DATA B(16036), B(16037), B(16038) /    20.40,  -37.16,    0.00 /
      DATA B(16375), B(16376), B(16377) /    20.42,  -38.97,    0.00 /
      DATA B(16714), B(16715), B(16716) /    19.54,  -39.04,    0.00 /
      DATA B(17053), B(17054), B(17055) /    18.68,  -39.09,    0.00 /
      DATA B(17392), B(17393), B(17394) /    17.83,  -39.12,    0.00 /
      DATA B(17731), B(17732), B(17733) /    16.97,  -39.11,    0.00 /
      DATA B(18070), B(18071), B(18072) /    16.10,  -39.07,    0.00 /
      DATA B(18409), B(18410), B(18411) /    15.18,  -38.98,    0.00 /
      DATA B(18748), B(18749), B(18750) /    14.22,  -38.81,    0.00 /
      DATA B(19087), B(19088), B(19089) /    13.17,  -38.51,    0.00 /
      DATA B(19426), B(19427), B(19428) /    11.96,  -38.00,    0.00 /
      DATA B(19765), B(19766), B(19767) /    10.50,  -37.12,    0.00 /
      DATA B(20104), B(20105), B(20106) /     8.62,  -35.62,    0.00 /
      DATA B(20443), B(20444), B(20445) /     9.72,  -34.90,    0.00 /
      DATA B(20782), B(20783), B(20784) /     8.94,  -28.87,    0.00 /
      DATA B(21121), B(21122), B(21123) /     7.28,  -27.14,    0.00 /
      DATA B(21460), B(21461), B(21462) /     6.48,  -25.81,    0.00 /
      DATA B(21799), B(21800), B(21801) /     5.69,  -25.40,    0.00 /
      DATA B(22138), B(22139), B(22140) /     4.99,  -25.30,    0.00 /
      DATA B(22477), B(22478), B(22479) /     4.48,  -25.34,    0.00 /
      DATA B(22816), B(22817), B(22818) /     3.75,  -25.12,    0.00 /
      DATA B(23155), B(23156), B(23157) /     3.30,  -24.77,    0.00 /
      DATA B(23494), B(23495), B(23496) /     2.60,  -24.33,    0.00 /
      DATA B(23833), B(23834), B(23835) /     2.00,  -23.95,    0.00 /
      DATA B(24172), B(24173), B(24174) /     1.54,  -23.65,    0.00 /
      DATA B(24511), B(24512), B(24513) /     1.18,  -23.41,    0.00 /
      DATA B(24850), B(24851), B(24852) /     0.90,  -23.20,    0.00 /
      DATA B(25189), B(25190), B(25191) /     0.66,  -23.03,    0.00 /
      DATA B(25528), B(25529), B(25530) /     0.46,  -22.88,    0.00 /
      DATA B(25867), B(25868), B(25869) /     0.28,  -22.75,    0.00 /
      DATA B(26206), B(26207), B(26208) /     0.13,  -22.64,    0.00 /
      DATA B(26545), B(26546), B(26547) /     0.00,  -22.53,    0.00 /
      DATA B(26884), B(26885), B(26886) /    -0.13,  -22.44,    0.00 /
      DATA B(27223), B(27224), B(27225) /    -0.24,  -22.35,    0.00 /
      DATA B(  106), B(  107), B(  108) /    24.55,  -45.29,    0.00 /
      DATA B(  445), B(  446), B(  447) /    24.55,  -45.22,    0.00 /
      DATA B(  784), B(  785), B(  786) /    24.54,  -45.15,    0.00 /
      DATA B( 1123), B( 1124), B( 1125) /    24.54,  -45.07,    0.00 /
      DATA B( 1462), B( 1463), B( 1464) /    24.53,  -45.00,    0.00 /
      DATA B( 1801), B( 1802), B( 1803) /    24.53,  -44.92,    0.00 /
      DATA B( 2140), B( 2141), B( 2142) /    24.52,  -44.84,    0.00 /
      DATA B( 2479), B( 2480), B( 2481) /    24.51,  -44.77,    0.00 /
      DATA B( 2818), B( 2819), B( 2820) /    24.51,  -44.69,    0.00 /
      DATA B( 3157), B( 3158), B( 3159) /    24.50,  -44.61,    0.00 /
      DATA B( 3496), B( 3497), B( 3498) /    24.50,  -44.53,    0.00 /
      DATA B( 3835), B( 3836), B( 3837) /    24.49,  -44.45,    0.00 /
      DATA B( 4174), B( 4175), B( 4176) /    24.48,  -44.37,    0.00 /
      DATA B( 4513), B( 4514), B( 4515) /    24.47,  -44.29,    0.00 /
      DATA B( 4852), B( 4853), B( 4854) /    24.47,  -44.20,    0.00 /
      DATA B( 5191), B( 5192), B( 5193) /    24.46,  -44.12,    0.00 /
      DATA B( 5530), B( 5531), B( 5532) /    24.45,  -44.03,    0.00 /
      DATA B( 5869), B( 5870), B( 5871) /    24.44,  -43.94,    0.00 /
      DATA B( 6208), B( 6209), B( 6210) /    24.43,  -43.85,    0.00 /
      DATA B( 6547), B( 6548), B( 6549) /    24.43,  -43.76,    0.00 /
      DATA B( 6886), B( 6887), B( 6888) /    24.42,  -43.66,    0.00 /
      DATA B( 7225), B( 7226), B( 7227) /    24.41,  -43.56,    0.00 /
      DATA B( 7564), B( 7565), B( 7566) /    24.40,  -43.46,    0.00 /
      DATA B( 7903), B( 7904), B( 7905) /    24.38,  -43.35,    0.00 /
      DATA B( 8242), B( 8243), B( 8244) /    24.37,  -43.24,    0.00 /
      DATA B( 8581), B( 8582), B( 8583) /    24.36,  -43.13,    0.00 /
      DATA B( 8920), B( 8921), B( 8922) /    24.34,  -43.00,    0.00 /
      DATA B( 9259), B( 9260), B( 9261) /    24.32,  -42.87,    0.00 /
      DATA B( 9598), B( 9599), B( 9600) /    24.30,  -42.73,    0.00 /
      DATA B( 9937), B( 9938), B( 9939) /    24.28,  -42.58,    0.00 /
      DATA B(10276), B(10277), B(10278) /    24.25,  -42.42,    0.00 /
      DATA B(10615), B(10616), B(10617) /    24.22,  -42.25,    0.00 /
      DATA B(10954), B(10955), B(10956) /    24.17,  -42.06,    0.00 /
      DATA B(11293), B(11294), B(11295) /    24.12,  -41.86,    0.00 /
      DATA B(11632), B(11633), B(11634) /    24.06,  -41.63,    0.00 /
      DATA B(11971), B(11972), B(11973) /    23.97,  -41.38,    0.00 /
      DATA B(12310), B(12311), B(12312) /    23.87,  -41.09,    0.00 /
      DATA B(12649), B(12650), B(12651) /    23.74,  -40.75,    0.00 /
      DATA B(12988), B(12989), B(12990) /    23.54,  -40.33,    0.00 /
      DATA B(13327), B(13328), B(13329) /    23.21,  -39.82,    0.00 /
      DATA B(13666), B(13667), B(13668) /    22.65,  -39.13,    0.00 /
      DATA B(14005), B(14006), B(14007) /    22.08,  -38.67,    0.00 /
      DATA B(14344), B(14345), B(14346) /    21.65,  -38.25,    0.00 /
      DATA B(14683), B(14684), B(14685) /    21.32,  -37.92,    0.00 /
      DATA B(15022), B(15023), B(15024) /    21.02,  -37.66,    0.00 /
      DATA B(15361), B(15362), B(15363) /    20.73,  -37.47,    0.00 /
      DATA B(15700), B(15701), B(15702) /    20.44,  -37.34,    0.00 /
      DATA B(16039), B(16040), B(16041) /    20.19,  -37.33,    0.00 /
      DATA B(16378), B(16379), B(16380) /    20.06,  -38.65,    0.00 /
      DATA B(16717), B(16718), B(16719) /    19.24,  -38.83,    0.00 /
      DATA B(17056), B(17057), B(17058) /    18.38,  -38.92,    0.00 /
      DATA B(17395), B(17396), B(17397) /    17.52,  -38.95,    0.00 /
      DATA B(17734), B(17735), B(17736) /    16.63,  -38.94,    0.00 /
      DATA B(18073), B(18074), B(18075) /    15.73,  -38.88,    0.00 /
      DATA B(18412), B(18413), B(18414) /    14.79,  -38.76,    0.00 /
      DATA B(18751), B(18752), B(18753) /    13.79,  -38.54,    0.00 /
      DATA B(19090), B(19091), B(19092) /    12.68,  -38.15,    0.00 /
      DATA B(19429), B(19430), B(19431) /    11.40,  -37.49,    0.00 /
      DATA B(19768), B(19769), B(19770) /     9.83,  -36.36,    0.00 /
      DATA B(20107), B(20108), B(20109) /    10.61,  -36.07,    0.00 /
      DATA B(20446), B(20447), B(20448) /     9.07,  -33.48,    0.00 /
      DATA B(20785), B(20786), B(20787) /     8.46,  -27.92,    0.00 /
      DATA B(21124), B(21125), B(21126) /     6.55,  -26.23,    0.00 /
      DATA B(21463), B(21464), B(21465) /     5.87,  -25.19,    0.00 /
      DATA B(21802), B(21803), B(21804) /     5.23,  -24.89,    0.00 /
      DATA B(22141), B(22142), B(22143) /     4.69,  -24.89,    0.00 /
      DATA B(22480), B(22481), B(22482) /     4.22,  -24.96,    0.00 /
      DATA B(22819), B(22820), B(22821) /     3.97,  -25.17,    0.00 /
      DATA B(23158), B(23159), B(23160) /     3.29,  -24.72,    0.00 /
      DATA B(23497), B(23498), B(23499) /     2.71,  -24.34,    0.00 /
      DATA B(23836), B(23837), B(23838) /     2.09,  -23.93,    0.00 /
      DATA B(24175), B(24176), B(24177) /     1.61,  -23.61,    0.00 /
      DATA B(24514), B(24515), B(24516) /     1.23,  -23.35,    0.00 /
      DATA B(24853), B(24854), B(24855) /     0.93,  -23.15,    0.00 /
      DATA B(25192), B(25193), B(25194) /     0.68,  -22.97,    0.00 /
      DATA B(25531), B(25532), B(25533) /     0.48,  -22.82,    0.00 /
      DATA B(25870), B(25871), B(25872) /     0.30,  -22.69,    0.00 /
      DATA B(26209), B(26210), B(26211) /     0.15,  -22.58,    0.00 /
      DATA B(26548), B(26549), B(26550) /     0.01,  -22.48,    0.00 /
      DATA B(26887), B(26888), B(26889) /    -0.11,  -22.38,    0.00 /
      DATA B(27226), B(27227), B(27228) /    -0.23,  -22.30,    0.00 /
      DATA B(  109), B(  110), B(  111) /    24.52,  -45.27,    0.00 /
      DATA B(  448), B(  449), B(  450) /    24.52,  -45.19,    0.00 /
      DATA B(  787), B(  788), B(  789) /    24.51,  -45.12,    0.00 /
      DATA B( 1126), B( 1127), B( 1128) /    24.51,  -45.04,    0.00 /
      DATA B( 1465), B( 1466), B( 1467) /    24.50,  -44.97,    0.00 /
      DATA B( 1804), B( 1805), B( 1806) /    24.49,  -44.89,    0.00 /
      DATA B( 2143), B( 2144), B( 2145) /    24.49,  -44.82,    0.00 /
      DATA B( 2482), B( 2483), B( 2484) /    24.48,  -44.74,    0.00 /
      DATA B( 2821), B( 2822), B( 2823) /    24.48,  -44.66,    0.00 /
      DATA B( 3160), B( 3161), B( 3162) /    24.47,  -44.58,    0.00 /
      DATA B( 3499), B( 3500), B( 3501) /    24.46,  -44.50,    0.00 /
      DATA B( 3838), B( 3839), B( 3840) /    24.46,  -44.42,    0.00 /
      DATA B( 4177), B( 4178), B( 4179) /    24.45,  -44.34,    0.00 /
      DATA B( 4516), B( 4517), B( 4518) /    24.44,  -44.25,    0.00 /
      DATA B( 4855), B( 4856), B( 4857) /    24.43,  -44.17,    0.00 /
      DATA B( 5194), B( 5195), B( 5196) /    24.43,  -44.08,    0.00 /
      DATA B( 5533), B( 5534), B( 5535) /    24.42,  -43.99,    0.00 /
      DATA B( 5872), B( 5873), B( 5874) /    24.41,  -43.90,    0.00 /
      DATA B( 6211), B( 6212), B( 6213) /    24.40,  -43.81,    0.00 /
      DATA B( 6550), B( 6551), B( 6552) /    24.39,  -43.71,    0.00 /
      DATA B( 6889), B( 6890), B( 6891) /    24.38,  -43.61,    0.00 /
      DATA B( 7228), B( 7229), B( 7230) /    24.37,  -43.51,    0.00 /
      DATA B( 7567), B( 7568), B( 7569) /    24.36,  -43.40,    0.00 /
      DATA B( 7906), B( 7907), B( 7908) /    24.35,  -43.29,    0.00 /
      DATA B( 8245), B( 8246), B( 8247) /    24.33,  -43.18,    0.00 /
      DATA B( 8584), B( 8585), B( 8586) /    24.32,  -43.05,    0.00 /
      DATA B( 8923), B( 8924), B( 8925) /    24.31,  -42.92,    0.00 /
      DATA B( 9262), B( 9263), B( 9264) /    24.29,  -42.78,    0.00 /
      DATA B( 9601), B( 9602), B( 9603) /    24.27,  -42.63,    0.00 /
      DATA B( 9940), B( 9941), B( 9942) /    24.24,  -42.47,    0.00 /
      DATA B(10279), B(10280), B(10281) /    24.21,  -42.29,    0.00 /
      DATA B(10618), B(10619), B(10620) /    24.17,  -42.09,    0.00 /
      DATA B(10957), B(10958), B(10959) /    24.12,  -41.87,    0.00 /
      DATA B(11296), B(11297), B(11298) /    24.06,  -41.64,    0.00 /
      DATA B(11635), B(11636), B(11637) /    23.97,  -41.38,    0.00 /
      DATA B(11974), B(11975), B(11976) /    23.86,  -41.09,    0.00 /
      DATA B(12313), B(12314), B(12315) /    23.72,  -40.76,    0.00 /
      DATA B(12652), B(12653), B(12654) /    23.52,  -40.38,    0.00 /
      DATA B(12991), B(12992), B(12993) /    23.22,  -39.92,    0.00 /
      DATA B(13330), B(13331), B(13332) /    22.73,  -39.29,    0.00 /
      DATA B(13669), B(13670), B(13671) /    22.15,  -38.88,    0.00 /
      DATA B(14008), B(14009), B(14010) /    21.71,  -38.47,    0.00 /
      DATA B(14347), B(14348), B(14349) /    21.37,  -38.13,    0.00 /
      DATA B(14686), B(14687), B(14688) /    21.09,  -37.87,    0.00 /
      DATA B(15025), B(15026), B(15027) /    20.82,  -37.67,    0.00 /
      DATA B(15364), B(15365), B(15366) /    20.55,  -37.53,    0.00 /
      DATA B(15703), B(15704), B(15705) /    20.29,  -37.44,    0.00 /
      DATA B(16042), B(16043), B(16044) /    20.09,  -37.45,    0.00 /
      DATA B(16381), B(16382), B(16383) /    19.83,  -38.37,    0.00 /
      DATA B(16720), B(16721), B(16722) /    18.99,  -38.65,    0.00 /
      DATA B(17059), B(17060), B(17061) /    18.11,  -38.76,    0.00 /
      DATA B(17398), B(17399), B(17400) /    17.21,  -38.78,    0.00 /
      DATA B(17737), B(17738), B(17739) /    16.30,  -38.76,    0.00 /
      DATA B(18076), B(18077), B(18078) /    15.37,  -38.68,    0.00 /
      DATA B(18415), B(18416), B(18417) /    14.40,  -38.53,    0.00 /
      DATA B(18754), B(18755), B(18756) /    13.36,  -38.25,    0.00 /
      DATA B(19093), B(19094), B(19095) /    12.20,  -37.77,    0.00 /
      DATA B(19432), B(19433), B(19434) /    10.84,  -36.93,    0.00 /
      DATA B(19771), B(19772), B(19773) /    11.18,  -36.90,    0.00 /
      DATA B(20110), B(20111), B(20112) /    10.06,  -34.84,    0.00 /
      DATA B(20449), B(20450), B(20451) /     8.77,  -30.78,    0.00 /
      DATA B(20788), B(20789), B(20790) /     7.80,  -27.13,    0.00 /
      DATA B(21127), B(21128), B(21129) /     6.45,  -24.72,    0.00 /
      DATA B(21466), B(21467), B(21468) /     5.25,  -24.60,    0.00 /
      DATA B(21805), B(21806), B(21807) /     4.79,  -24.42,    0.00 /
      DATA B(22144), B(22145), B(22146) /     4.37,  -24.49,    0.00 /
      DATA B(22483), B(22484), B(22485) /     4.00,  -24.62,    0.00 /
      DATA B(22822), B(22823), B(22824) /     3.73,  -24.80,    0.00 /
      DATA B(23161), B(23162), B(23163) /     3.20,  -24.64,    0.00 /
      DATA B(23500), B(23501), B(23502) /     2.81,  -24.34,    0.00 /
      DATA B(23839), B(23840), B(23841) /     2.21,  -23.94,    0.00 /
      DATA B(24178), B(24179), B(24180) /     1.69,  -23.58,    0.00 /
      DATA B(24517), B(24518), B(24519) /     1.29,  -23.31,    0.00 /
      DATA B(24856), B(24857), B(24858) /     0.97,  -23.09,    0.00 /
      DATA B(25195), B(25196), B(25197) /     0.71,  -22.91,    0.00 /
      DATA B(25534), B(25535), B(25536) /     0.50,  -22.76,    0.00 /
      DATA B(25873), B(25874), B(25875) /     0.32,  -22.64,    0.00 /
      DATA B(26212), B(26213), B(26214) /     0.16,  -22.52,    0.00 /
      DATA B(26551), B(26552), B(26553) /     0.03,  -22.42,    0.00 /
      DATA B(26890), B(26891), B(26892) /    -0.10,  -22.33,    0.00 /
      DATA B(27229), B(27230), B(27231) /    -0.21,  -22.25,    0.00 /
      DATA B(  112), B(  113), B(  114) /    24.49,  -45.24,    0.00 /
      DATA B(  451), B(  452), B(  453) /    24.49,  -45.17,    0.00 /
      DATA B(  790), B(  791), B(  792) /    24.48,  -45.09,    0.00 /
      DATA B( 1129), B( 1130), B( 1131) /    24.48,  -45.02,    0.00 /
      DATA B( 1468), B( 1469), B( 1470) /    24.47,  -44.94,    0.00 /
      DATA B( 1807), B( 1808), B( 1809) /    24.46,  -44.86,    0.00 /
      DATA B( 2146), B( 2147), B( 2148) /    24.46,  -44.79,    0.00 /
      DATA B( 2485), B( 2486), B( 2487) /    24.45,  -44.71,    0.00 /
      DATA B( 2824), B( 2825), B( 2826) /    24.44,  -44.63,    0.00 /
      DATA B( 3163), B( 3164), B( 3165) /    24.44,  -44.55,    0.00 /
      DATA B( 3502), B( 3503), B( 3504) /    24.43,  -44.47,    0.00 /
      DATA B( 3841), B( 3842), B( 3843) /    24.42,  -44.38,    0.00 /
      DATA B( 4180), B( 4181), B( 4182) /    24.42,  -44.30,    0.00 /
      DATA B( 4519), B( 4520), B( 4521) /    24.41,  -44.22,    0.00 /
      DATA B( 4858), B( 4859), B( 4860) /    24.40,  -44.13,    0.00 /
      DATA B( 5197), B( 5198), B( 5199) /    24.39,  -44.04,    0.00 /
      DATA B( 5536), B( 5537), B( 5538) /    24.38,  -43.95,    0.00 /
      DATA B( 5875), B( 5876), B( 5877) /    24.38,  -43.86,    0.00 /
      DATA B( 6214), B( 6215), B( 6216) /    24.37,  -43.76,    0.00 /
      DATA B( 6553), B( 6554), B( 6555) /    24.36,  -43.66,    0.00 /
      DATA B( 6892), B( 6893), B( 6894) /    24.35,  -43.56,    0.00 /
      DATA B( 7231), B( 7232), B( 7233) /    24.34,  -43.46,    0.00 /
      DATA B( 7570), B( 7571), B( 7572) /    24.32,  -43.35,    0.00 /
      DATA B( 7909), B( 7910), B( 7911) /    24.31,  -43.23,    0.00 /
      DATA B( 8248), B( 8249), B( 8250) /    24.30,  -43.11,    0.00 /
      DATA B( 8587), B( 8588), B( 8589) /    24.28,  -42.97,    0.00 /
      DATA B( 8926), B( 8927), B( 8928) /    24.27,  -42.83,    0.00 /
      DATA B( 9265), B( 9266), B( 9267) /    24.25,  -42.68,    0.00 /
      DATA B( 9604), B( 9605), B( 9606) /    24.23,  -42.52,    0.00 /
      DATA B( 9943), B( 9944), B( 9945) /    24.20,  -42.33,    0.00 /
      DATA B(10282), B(10283), B(10284) /    24.17,  -42.13,    0.00 /
      DATA B(10621), B(10622), B(10623) /    24.13,  -41.90,    0.00 /
      DATA B(10960), B(10961), B(10962) /    24.07,  -41.65,    0.00 /
      DATA B(11299), B(11300), B(11301) /    23.98,  -41.37,    0.00 /
      DATA B(11638), B(11639), B(11640) /    23.87,  -41.07,    0.00 /
      DATA B(11977), B(11978), B(11979) /    23.71,  -40.74,    0.00 /
      DATA B(12316), B(12317), B(12318) /    23.50,  -40.37,    0.00 /
      DATA B(12655), B(12656), B(12657) /    23.19,  -39.97,    0.00 /
      DATA B(12994), B(12995), B(12996) /    22.74,  -39.41,    0.00 /
      DATA B(13333), B(13334), B(13335) /    22.19,  -39.06,    0.00 /
      DATA B(13672), B(13673), B(13674) /    21.74,  -38.67,    0.00 /
      DATA B(14011), B(14012), B(14013) /    21.41,  -38.34,    0.00 /
      DATA B(14350), B(14351), B(14352) /    21.13,  -38.07,    0.00 /
      DATA B(14689), B(14690), B(14691) /    20.87,  -37.87,    0.00 /
      DATA B(15028), B(15029), B(15030) /    20.62,  -37.72,    0.00 /
      DATA B(15367), B(15368), B(15369) /    20.36,  -37.61,    0.00 /
      DATA B(15706), B(15707), B(15708) /    20.09,  -37.54,    0.00 /
      DATA B(16045), B(16046), B(16047) /    19.86,  -37.57,    0.00 /
      DATA B(16384), B(16385), B(16386) /    19.70,  -38.21,    0.00 /
      DATA B(16723), B(16724), B(16725) /    18.79,  -38.48,    0.00 /
      DATA B(17062), B(17063), B(17064) /    17.85,  -38.58,    0.00 /
      DATA B(17401), B(17402), B(17403) /    16.91,  -38.60,    0.00 /
      DATA B(17740), B(17741), B(17742) /    15.97,  -38.57,    0.00 /
      DATA B(18079), B(18080), B(18081) /    15.00,  -38.47,    0.00 /
      DATA B(18418), B(18419), B(18420) /    14.00,  -38.29,    0.00 /
      DATA B(18757), B(18758), B(18759) /    12.93,  -37.96,    0.00 /
      DATA B(19096), B(19097), B(19098) /    11.72,  -37.37,    0.00 /
      DATA B(19435), B(19436), B(19437) /    11.66,  -37.40,    0.00 /
      DATA B(19774), B(19775), B(19776) /    10.79,  -35.82,    0.00 /
      DATA B(20113), B(20114), B(20115) /     9.58,  -33.60,    0.00 /
      DATA B(20452), B(20453), B(20454) /     8.71,  -29.24,    0.00 /
      DATA B(20791), B(20792), B(20793) /     7.26,  -26.42,    0.00 /
      DATA B(21130), B(21131), B(21132) /     6.07,  -24.40,    0.00 /
      DATA B(21469), B(21470), B(21471) /     4.72,  -24.07,    0.00 /
      DATA B(21808), B(21809), B(21810) /     4.37,  -23.95,    0.00 /
      DATA B(22147), B(22148), B(22149) /     4.06,  -24.10,    0.00 /
      DATA B(22486), B(22487), B(22488) /     3.77,  -24.29,    0.00 /
      DATA B(22825), B(22826), B(22827) /     3.50,  -24.47,    0.00 /
      DATA B(23164), B(23165), B(23166) /     3.48,  -24.79,    0.00 /
      DATA B(23503), B(23504), B(23505) /     2.83,  -24.32,    0.00 /
      DATA B(23842), B(23843), B(23844) /     2.34,  -23.95,    0.00 /
      DATA B(24181), B(24182), B(24183) /     1.79,  -23.57,    0.00 /
      DATA B(24520), B(24521), B(24522) /     1.35,  -23.27,    0.00 /
      DATA B(24859), B(24860), B(24861) /     1.01,  -23.04,    0.00 /
      DATA B(25198), B(25199), B(25200) /     0.75,  -22.86,    0.00 /
      DATA B(25537), B(25538), B(25539) /     0.53,  -22.71,    0.00 /
      DATA B(25876), B(25877), B(25878) /     0.34,  -22.58,    0.00 /
      DATA B(26215), B(26216), B(26217) /     0.18,  -22.47,    0.00 /
      DATA B(26554), B(26555), B(26556) /     0.04,  -22.37,    0.00 /
      DATA B(26893), B(26894), B(26895) /    -0.09,  -22.28,    0.00 /
      DATA B(27232), B(27233), B(27234) /    -0.20,  -22.20,    0.00 /
      DATA B(  115), B(  116), B(  117) /    24.46,  -45.22,    0.00 /
      DATA B(  454), B(  455), B(  456) /    24.46,  -45.14,    0.00 /
      DATA B(  793), B(  794), B(  795) /    24.45,  -45.07,    0.00 /
      DATA B( 1132), B( 1133), B( 1134) /    24.44,  -44.99,    0.00 /
      DATA B( 1471), B( 1472), B( 1473) /    24.44,  -44.91,    0.00 /
      DATA B( 1810), B( 1811), B( 1812) /    24.43,  -44.84,    0.00 /
      DATA B( 2149), B( 2150), B( 2151) /    24.43,  -44.76,    0.00 /
      DATA B( 2488), B( 2489), B( 2490) /    24.42,  -44.68,    0.00 /
      DATA B( 2827), B( 2828), B( 2829) /    24.41,  -44.60,    0.00 /
      DATA B( 3166), B( 3167), B( 3168) /    24.41,  -44.52,    0.00 /
      DATA B( 3505), B( 3506), B( 3507) /    24.40,  -44.43,    0.00 /
      DATA B( 3844), B( 3845), B( 3846) /    24.39,  -44.35,    0.00 /
      DATA B( 4183), B( 4184), B( 4185) /    24.38,  -44.27,    0.00 /
      DATA B( 4522), B( 4523), B( 4524) /    24.38,  -44.18,    0.00 /
      DATA B( 4861), B( 4862), B( 4863) /    24.37,  -44.09,    0.00 /
      DATA B( 5200), B( 5201), B( 5202) /    24.36,  -44.00,    0.00 /
      DATA B( 5539), B( 5540), B( 5541) /    24.35,  -43.91,    0.00 /
      DATA B( 5878), B( 5879), B( 5880) /    24.34,  -43.81,    0.00 /
      DATA B( 6217), B( 6218), B( 6219) /    24.33,  -43.71,    0.00 /
      DATA B( 6556), B( 6557), B( 6558) /    24.32,  -43.61,    0.00 /
      DATA B( 6895), B( 6896), B( 6897) /    24.31,  -43.51,    0.00 /
      DATA B( 7234), B( 7235), B( 7236) /    24.30,  -43.40,    0.00 /
      DATA B( 7573), B( 7574), B( 7575) /    24.29,  -43.28,    0.00 /
      DATA B( 7912), B( 7913), B( 7914) /    24.28,  -43.16,    0.00 /
      DATA B( 8251), B( 8252), B( 8253) /    24.26,  -43.03,    0.00 /
      DATA B( 8590), B( 8591), B( 8592) /    24.25,  -42.89,    0.00 /
      DATA B( 8929), B( 8930), B( 8931) /    24.23,  -42.73,    0.00 /
      DATA B( 9268), B( 9269), B( 9270) /    24.21,  -42.57,    0.00 /
      DATA B( 9607), B( 9608), B( 9609) /    24.19,  -42.38,    0.00 /
      DATA B( 9946), B( 9947), B( 9948) /    24.16,  -42.18,    0.00 /
      DATA B(10285), B(10286), B(10287) /    24.13,  -41.94,    0.00 /
      DATA B(10624), B(10625), B(10626) /    24.08,  -41.67,    0.00 /
      DATA B(10963), B(10964), B(10965) /    24.00,  -41.38,    0.00 /
      DATA B(11302), B(11303), B(11304) /    23.88,  -41.05,    0.00 /
      DATA B(11641), B(11642), B(11643) /    23.72,  -40.70,    0.00 /
      DATA B(11980), B(11981), B(11982) /    23.49,  -40.34,    0.00 /
      DATA B(12319), B(12320), B(12321) /    23.17,  -39.97,    0.00 /
      DATA B(12658), B(12659), B(12660) /    22.76,  -39.57,    0.00 /
      DATA B(12997), B(12998), B(12999) /    22.21,  -39.22,    0.00 /
      DATA B(13336), B(13337), B(13338) /    21.75,  -38.86,    0.00 /
      DATA B(13675), B(13676), B(13677) /    21.41,  -38.53,    0.00 /
      DATA B(14014), B(14015), B(14016) /    21.14,  -38.26,    0.00 /
      DATA B(14353), B(14354), B(14355) /    20.90,  -38.06,    0.00 /
      DATA B(14692), B(14693), B(14694) /    20.66,  -37.90,    0.00 /
      DATA B(15031), B(15032), B(15033) /    20.41,  -37.79,    0.00 /
      DATA B(15370), B(15371), B(15372) /    20.14,  -37.69,    0.00 /
      DATA B(15709), B(15710), B(15711) /    19.86,  -37.61,    0.00 /
      DATA B(16048), B(16049), B(16050) /    19.52,  -37.52,    0.00 /
      DATA B(16387), B(16388), B(16389) /    19.60,  -37.97,    0.00 /
      DATA B(16726), B(16727), B(16728) /    18.60,  -38.30,    0.00 /
      DATA B(17065), B(17066), B(17067) /    17.58,  -38.40,    0.00 /
      DATA B(17404), B(17405), B(17406) /    16.60,  -38.41,    0.00 /
      DATA B(17743), B(17744), B(17745) /    15.62,  -38.36,    0.00 /
      DATA B(18082), B(18083), B(18084) /    14.64,  -38.26,    0.00 /
      DATA B(18421), B(18422), B(18423) /    13.61,  -38.05,    0.00 /
      DATA B(18760), B(18761), B(18762) /    12.50,  -37.67,    0.00 /
      DATA B(19099), B(19100), B(19101) /    11.27,  -36.90,    0.00 /
      DATA B(19438), B(19439), B(19440) /    11.25,  -36.56,    0.00 /
      DATA B(19777), B(19778), B(19779) /    10.35,  -34.79,    0.00 /
      DATA B(20116), B(20117), B(20118) /     9.08,  -32.31,    0.00 /
      DATA B(20455), B(20456), B(20457) /     8.08,  -28.35,    0.00 /
      DATA B(20794), B(20795), B(20796) /     6.77,  -25.81,    0.00 /
      DATA B(21133), B(21134), B(21135) /     5.73,  -24.09,    0.00 /
      DATA B(21472), B(21473), B(21474) /     4.14,  -23.55,    0.00 /
      DATA B(21811), B(21812), B(21813) /     3.95,  -23.51,    0.00 /
      DATA B(22150), B(22151), B(22152) /     3.75,  -23.70,    0.00 /
      DATA B(22489), B(22490), B(22491) /     3.53,  -23.96,    0.00 /
      DATA B(22828), B(22829), B(22830) /     3.30,  -24.19,    0.00 /
      DATA B(23167), B(23168), B(23169) /     3.14,  -24.42,    0.00 /
      DATA B(23506), B(23507), B(23508) /     2.78,  -24.28,    0.00 /
      DATA B(23845), B(23846), B(23847) /     2.44,  -23.97,    0.00 /
      DATA B(24184), B(24185), B(24186) /     1.91,  -23.57,    0.00 /
      DATA B(24523), B(24524), B(24525) /     1.43,  -23.24,    0.00 /
      DATA B(24862), B(24863), B(24864) /     1.07,  -22.99,    0.00 /
      DATA B(25201), B(25202), B(25203) /     0.78,  -22.80,    0.00 /
      DATA B(25540), B(25541), B(25542) /     0.55,  -22.65,    0.00 /
      DATA B(25879), B(25880), B(25881) /     0.36,  -22.52,    0.00 /
      DATA B(26218), B(26219), B(26220) /     0.20,  -22.41,    0.00 /
      DATA B(26557), B(26558), B(26559) /     0.06,  -22.31,    0.00 /
      DATA B(26896), B(26897), B(26898) /    -0.07,  -22.23,    0.00 /
      DATA B(27235), B(27236), B(27237) /    -0.19,  -22.15,    0.00 /
      DATA B(  118), B(  119), B(  120) /    24.43,  -45.19,    0.00 /
      DATA B(  457), B(  458), B(  459) /    24.43,  -45.12,    0.00 /
      DATA B(  796), B(  797), B(  798) /    24.42,  -45.04,    0.00 /
      DATA B( 1135), B( 1136), B( 1137) /    24.41,  -44.96,    0.00 /
      DATA B( 1474), B( 1475), B( 1476) /    24.41,  -44.89,    0.00 /
      DATA B( 1813), B( 1814), B( 1815) /    24.40,  -44.81,    0.00 /
      DATA B( 2152), B( 2153), B( 2154) /    24.40,  -44.73,    0.00 /
      DATA B( 2491), B( 2492), B( 2493) /    24.39,  -44.65,    0.00 /
      DATA B( 2830), B( 2831), B( 2832) /    24.38,  -44.56,    0.00 /
      DATA B( 3169), B( 3170), B( 3171) /    24.37,  -44.48,    0.00 /
      DATA B( 3508), B( 3509), B( 3510) /    24.37,  -44.40,    0.00 /
      DATA B( 3847), B( 3848), B( 3849) /    24.36,  -44.31,    0.00 /
      DATA B( 4186), B( 4187), B( 4188) /    24.35,  -44.23,    0.00 /
      DATA B( 4525), B( 4526), B( 4527) /    24.34,  -44.14,    0.00 /
      DATA B( 4864), B( 4865), B( 4866) /    24.33,  -44.05,    0.00 /
      DATA B( 5203), B( 5204), B( 5205) /    24.33,  -43.96,    0.00 /
      DATA B( 5542), B( 5543), B( 5544) /    24.32,  -43.86,    0.00 /
      DATA B( 5881), B( 5882), B( 5883) /    24.31,  -43.76,    0.00 /
      DATA B( 6220), B( 6221), B( 6222) /    24.30,  -43.66,    0.00 /
      DATA B( 6559), B( 6560), B( 6561) /    24.29,  -43.56,    0.00 /
      DATA B( 6898), B( 6899), B( 6900) /    24.28,  -43.45,    0.00 /
      DATA B( 7237), B( 7238), B( 7239) /    24.26,  -43.33,    0.00 /
      DATA B( 7576), B( 7577), B( 7578) /    24.25,  -43.21,    0.00 /
      DATA B( 7915), B( 7916), B( 7917) /    24.24,  -43.08,    0.00 /
      DATA B( 8254), B( 8255), B( 8256) /    24.23,  -42.94,    0.00 /
      DATA B( 8593), B( 8594), B( 8595) /    24.21,  -42.79,    0.00 /
      DATA B( 8932), B( 8933), B( 8934) /    24.19,  -42.62,    0.00 /
      DATA B( 9271), B( 9272), B( 9273) /    24.17,  -42.44,    0.00 /
      DATA B( 9610), B( 9611), B( 9612) /    24.15,  -42.23,    0.00 /
      DATA B( 9949), B( 9950), B( 9951) /    24.12,  -41.99,    0.00 /
      DATA B(10288), B(10289), B(10290) /    24.08,  -41.72,    0.00 /
      DATA B(10627), B(10628), B(10629) /    24.01,  -41.40,    0.00 /
      DATA B(10966), B(10967), B(10968) /    23.90,  -41.05,    0.00 /
      DATA B(11305), B(11306), B(11307) /    23.73,  -40.68,    0.00 /
      DATA B(11644), B(11645), B(11646) /    23.49,  -40.31,    0.00 /
      DATA B(11983), B(11984), B(11985) /    23.14,  -39.97,    0.00 /
      DATA B(12322), B(12323), B(12324) /    22.73,  -39.62,    0.00 /
      DATA B(12661), B(12662), B(12663) /    22.18,  -39.38,    0.00 /
      DATA B(13000), B(13001), B(13002) /    21.73,  -39.04,    0.00 /
      DATA B(13339), B(13340), B(13341) /    21.40,  -38.71,    0.00 /
      DATA B(13678), B(13679), B(13680) /    21.14,  -38.44,    0.00 /
      DATA B(14017), B(14018), B(14019) /    20.90,  -38.23,    0.00 /
      DATA B(14356), B(14357), B(14358) /    20.67,  -38.08,    0.00 /
      DATA B(14695), B(14696), B(14697) /    20.43,  -37.96,    0.00 /
      DATA B(15034), B(15035), B(15036) /    20.18,  -37.86,    0.00 /
      DATA B(15373), B(15374), B(15375) /    19.92,  -37.77,    0.00 /
      DATA B(15712), B(15713), B(15714) /    19.65,  -37.64,    0.00 /
      DATA B(16051), B(16052), B(16053) /    19.14,  -37.62,    0.00 /
      DATA B(16390), B(16391), B(16392) /    18.44,  -37.88,    0.00 /
      DATA B(16729), B(16730), B(16731) /    18.29,  -38.12,    0.00 /
      DATA B(17068), B(17069), B(17070) /    17.25,  -38.21,    0.00 /
      DATA B(17407), B(17408), B(17409) /    16.26,  -38.21,    0.00 /
      DATA B(17746), B(17747), B(17748) /    15.27,  -38.15,    0.00 /
      DATA B(18085), B(18086), B(18087) /    14.26,  -38.03,    0.00 /
      DATA B(18424), B(18425), B(18426) /    13.22,  -37.80,    0.00 /
      DATA B(18763), B(18764), B(18765) /    12.10,  -37.36,    0.00 /
      DATA B(19102), B(19103), B(19104) /    11.48,  -37.07,    0.00 /
      DATA B(19441), B(19442), B(19443) /    10.89,  -35.75,    0.00 /
      DATA B(19780), B(19781), B(19782) /     9.96,  -33.73,    0.00 /
      DATA B(20119), B(20120), B(20121) /     8.88,  -30.46,    0.00 /
      DATA B(20458), B(20459), B(20460) /     7.53,  -27.48,    0.00 /
      DATA B(20797), B(20798), B(20799) /     6.37,  -25.29,    0.00 /
      DATA B(21136), B(21137), B(21138) /     5.46,  -23.83,    0.00 /
      DATA B(21475), B(21476), B(21477) /     4.68,  -22.86,    0.00 /
      DATA B(21814), B(21815), B(21816) /     3.58,  -23.08,    0.00 /
      DATA B(22153), B(22154), B(22155) /     3.43,  -23.30,    0.00 /
      DATA B(22492), B(22493), B(22494) /     3.28,  -23.61,    0.00 /
      DATA B(22831), B(22832), B(22833) /     3.10,  -23.90,    0.00 /
      DATA B(23170), B(23171), B(23172) /     2.94,  -24.14,    0.00 /
      DATA B(23509), B(23510), B(23511) /     2.98,  -24.44,    0.00 /
      DATA B(23848), B(23849), B(23850) /     2.48,  -23.98,    0.00 /
      DATA B(24187), B(24188), B(24189) /     2.02,  -23.57,    0.00 /
      DATA B(24526), B(24527), B(24528) /     1.52,  -23.21,    0.00 /
      DATA B(24865), B(24866), B(24867) /     1.12,  -22.95,    0.00 /
      DATA B(25204), B(25205), B(25206) /     0.82,  -22.75,    0.00 /
      DATA B(25543), B(25544), B(25545) /     0.58,  -22.59,    0.00 /
      DATA B(25882), B(25883), B(25884) /     0.39,  -22.46,    0.00 /
      DATA B(26221), B(26222), B(26223) /     0.22,  -22.35,    0.00 /
      DATA B(26560), B(26561), B(26562) /     0.07,  -22.26,    0.00 /
      DATA B(26899), B(26900), B(26901) /    -0.06,  -22.18,    0.00 /
      DATA B(27238), B(27239), B(27240) /    -0.17,  -22.10,    0.00 /
      DATA B(  121), B(  122), B(  123) /    24.40,  -45.17,    0.00 /
      DATA B(  460), B(  461), B(  462) /    24.40,  -45.09,    0.00 /
      DATA B(  799), B(  800), B(  801) /    24.39,  -45.01,    0.00 /
      DATA B( 1138), B( 1139), B( 1140) /    24.38,  -44.93,    0.00 /
      DATA B( 1477), B( 1478), B( 1479) /    24.38,  -44.86,    0.00 /
      DATA B( 1816), B( 1817), B( 1818) /    24.37,  -44.78,    0.00 /
      DATA B( 2155), B( 2156), B( 2157) /    24.36,  -44.70,    0.00 /
      DATA B( 2494), B( 2495), B( 2496) /    24.36,  -44.61,    0.00 /
      DATA B( 2833), B( 2834), B( 2835) /    24.35,  -44.53,    0.00 /
      DATA B( 3172), B( 3173), B( 3174) /    24.34,  -44.45,    0.00 /
      DATA B( 3511), B( 3512), B( 3513) /    24.33,  -44.36,    0.00 /
      DATA B( 3850), B( 3851), B( 3852) /    24.33,  -44.28,    0.00 /
      DATA B( 4189), B( 4190), B( 4191) /    24.32,  -44.19,    0.00 /
      DATA B( 4528), B( 4529), B( 4530) /    24.31,  -44.10,    0.00 /
      DATA B( 4867), B( 4868), B( 4869) /    24.30,  -44.01,    0.00 /
      DATA B( 5206), B( 5207), B( 5208) /    24.29,  -43.91,    0.00 /
      DATA B( 5545), B( 5546), B( 5547) /    24.28,  -43.81,    0.00 /
      DATA B( 5884), B( 5885), B( 5886) /    24.27,  -43.71,    0.00 /
      DATA B( 6223), B( 6224), B( 6225) /    24.26,  -43.61,    0.00 /
      DATA B( 6562), B( 6563), B( 6564) /    24.25,  -43.50,    0.00 /
      DATA B( 6901), B( 6902), B( 6903) /    24.24,  -43.38,    0.00 /
      DATA B( 7240), B( 7241), B( 7242) /    24.23,  -43.26,    0.00 /
      DATA B( 7579), B( 7580), B( 7581) /    24.22,  -43.13,    0.00 /
      DATA B( 7918), B( 7919), B( 7920) /    24.20,  -42.99,    0.00 /
      DATA B( 8257), B( 8258), B( 8259) /    24.19,  -42.84,    0.00 /
      DATA B( 8596), B( 8597), B( 8598) /    24.17,  -42.68,    0.00 /
      DATA B( 8935), B( 8936), B( 8937) /    24.15,  -42.49,    0.00 /
      DATA B( 9274), B( 9275), B( 9276) /    24.13,  -42.28,    0.00 /
      DATA B( 9613), B( 9614), B( 9615) /    24.10,  -42.05,    0.00 /
      DATA B( 9952), B( 9953), B( 9954) /    24.07,  -41.77,    0.00 /
      DATA B(10291), B(10292), B(10293) /    24.01,  -41.45,    0.00 /
      DATA B(10630), B(10631), B(10632) /    23.91,  -41.08,    0.00 /
      DATA B(10969), B(10970), B(10971) /    23.75,  -40.69,    0.00 /
      DATA B(11308), B(11309), B(11310) /    23.48,  -40.30,    0.00 /
      DATA B(11647), B(11648), B(11649) /    23.13,  -39.97,    0.00 /
      DATA B(11986), B(11987), B(11988) /    22.65,  -39.71,    0.00 /
      DATA B(12325), B(12326), B(12327) /    22.16,  -39.49,    0.00 /
      DATA B(12664), B(12665), B(12666) /    21.72,  -39.21,    0.00 /
      DATA B(13003), B(13004), B(13005) /    21.38,  -38.90,    0.00 /
      DATA B(13342), B(13343), B(13344) /    21.12,  -38.62,    0.00 /
      DATA B(13681), B(13682), B(13683) /    20.90,  -38.40,    0.00 /
      DATA B(14020), B(14021), B(14022) /    20.67,  -38.24,    0.00 /
      DATA B(14359), B(14360), B(14361) /    20.44,  -38.13,    0.00 /
      DATA B(14698), B(14699), B(14700) /    20.20,  -38.03,    0.00 /
      DATA B(15037), B(15038), B(15039) /    19.94,  -37.95,    0.00 /
      DATA B(15376), B(15377), B(15378) /    19.68,  -37.84,    0.00 /
      DATA B(15715), B(15716), B(15717) /    19.31,  -37.73,    0.00 /
      DATA B(16054), B(16055), B(16056) /    18.78,  -37.80,    0.00 /
      DATA B(16393), B(16394), B(16395) /    18.20,  -37.90,    0.00 /
      DATA B(16732), B(16733), B(16734) /    17.75,  -38.00,    0.00 /
      DATA B(17071), B(17072), B(17073) /    16.85,  -38.04,    0.00 /
      DATA B(17410), B(17411), B(17412) /    15.89,  -38.02,    0.00 /
      DATA B(17749), B(17750), B(17751) /    14.90,  -37.94,    0.00 /
      DATA B(18088), B(18089), B(18090) /    13.89,  -37.79,    0.00 /
      DATA B(18427), B(18428), B(18429) /    12.82,  -37.56,    0.00 /
      DATA B(18766), B(18767), B(18768) /    11.70,  -37.34,    0.00 /
      DATA B(19105), B(19106), B(19107) /    11.25,  -36.44,    0.00 /
      DATA B(19444), B(19445), B(19446) /    10.55,  -34.93,    0.00 /
      DATA B(19783), B(19784), B(19785) /     9.61,  -32.57,    0.00 /
      DATA B(20122), B(20123), B(20124) /     8.37,  -29.41,    0.00 /
      DATA B(20461), B(20462), B(20463) /     7.08,  -26.75,    0.00 /
      DATA B(20800), B(20801), B(20802) /     6.06,  -24.86,    0.00 /
      DATA B(21139), B(21140), B(21141) /     5.25,  -23.61,    0.00 /
      DATA B(21478), B(21479), B(21480) /     4.56,  -22.76,    0.00 /
      DATA B(21817), B(21818), B(21819) /     3.13,  -22.67,    0.00 /
      DATA B(22156), B(22157), B(22158) /     3.12,  -22.90,    0.00 /
      DATA B(22495), B(22496), B(22497) /     3.02,  -23.24,    0.00 /
      DATA B(22834), B(22835), B(22836) /     2.90,  -23.60,    0.00 /
      DATA B(23173), B(23174), B(23175) /     2.76,  -23.89,    0.00 /
      DATA B(23512), B(23513), B(23514) /     2.67,  -24.14,    0.00 /
      DATA B(23851), B(23852), B(23853) /     2.42,  -23.93,    0.00 /
      DATA B(24190), B(24191), B(24192) /     2.10,  -23.56,    0.00 /
      DATA B(24529), B(24530), B(24531) /     1.60,  -23.19,    0.00 /
      DATA B(24868), B(24869), B(24870) /     1.18,  -22.90,    0.00 /
      DATA B(25207), B(25208), B(25209) /     0.86,  -22.70,    0.00 /
      DATA B(25546), B(25547), B(25548) /     0.61,  -22.53,    0.00 /
      DATA B(25885), B(25886), B(25887) /     0.41,  -22.40,    0.00 /
      DATA B(26224), B(26225), B(26226) /     0.24,  -22.30,    0.00 /
      DATA B(26563), B(26564), B(26565) /     0.09,  -22.21,    0.00 /
      DATA B(26902), B(26903), B(26904) /    -0.04,  -22.13,    0.00 /
      DATA B(27241), B(27242), B(27243) /    -0.16,  -22.05,    0.00 /
      DATA B(  124), B(  125), B(  126) /    24.37,  -45.14,    0.00 /
      DATA B(  463), B(  464), B(  465) /    24.37,  -45.06,    0.00 /
      DATA B(  802), B(  803), B(  804) /    24.36,  -44.98,    0.00 /
      DATA B( 1141), B( 1142), B( 1143) /    24.35,  -44.90,    0.00 /
      DATA B( 1480), B( 1481), B( 1482) /    24.35,  -44.82,    0.00 /
      DATA B( 1819), B( 1820), B( 1821) /    24.34,  -44.74,    0.00 /
      DATA B( 2158), B( 2159), B( 2160) /    24.33,  -44.66,    0.00 /
      DATA B( 2497), B( 2498), B( 2499) /    24.33,  -44.58,    0.00 /
      DATA B( 2836), B( 2837), B( 2838) /    24.32,  -44.50,    0.00 /
      DATA B( 3175), B( 3176), B( 3177) /    24.31,  -44.41,    0.00 /
      DATA B( 3514), B( 3515), B( 3516) /    24.30,  -44.32,    0.00 /
      DATA B( 3853), B( 3854), B( 3855) /    24.29,  -44.24,    0.00 /
      DATA B( 4192), B( 4193), B( 4194) /    24.29,  -44.15,    0.00 /
      DATA B( 4531), B( 4532), B( 4533) /    24.28,  -44.06,    0.00 /
      DATA B( 4870), B( 4871), B( 4872) /    24.27,  -43.96,    0.00 /
      DATA B( 5209), B( 5210), B( 5211) /    24.26,  -43.86,    0.00 /
      DATA B( 5548), B( 5549), B( 5550) /    24.25,  -43.76,    0.00 /
      DATA B( 5887), B( 5888), B( 5889) /    24.24,  -43.66,    0.00 /
      DATA B( 6226), B( 6227), B( 6228) /    24.23,  -43.55,    0.00 /
      DATA B( 6565), B( 6566), B( 6567) /    24.22,  -43.44,    0.00 /
      DATA B( 6904), B( 6905), B( 6906) /    24.20,  -43.31,    0.00 /
      DATA B( 7243), B( 7244), B( 7245) /    24.19,  -43.19,    0.00 /
      DATA B( 7582), B( 7583), B( 7584) /    24.18,  -43.05,    0.00 /
      DATA B( 7921), B( 7922), B( 7923) /    24.16,  -42.90,    0.00 /
      DATA B( 8260), B( 8261), B( 8262) /    24.15,  -42.73,    0.00 /
      DATA B( 8599), B( 8600), B( 8601) /    24.13,  -42.55,    0.00 /
      DATA B( 8938), B( 8939), B( 8940) /    24.11,  -42.34,    0.00 /
      DATA B( 9277), B( 9278), B( 9279) /    24.08,  -42.10,    0.00 /
      DATA B( 9616), B( 9617), B( 9618) /    24.05,  -41.83,    0.00 /
      DATA B( 9955), B( 9956), B( 9957) /    23.99,  -41.51,    0.00 /
      DATA B(10294), B(10295), B(10296) /    23.90,  -41.14,    0.00 /
      DATA B(10633), B(10634), B(10635) /    23.73,  -40.73,    0.00 /
      DATA B(10972), B(10973), B(10974) /    23.46,  -40.36,    0.00 /
      DATA B(11311), B(11312), B(11313) /    23.09,  -39.98,    0.00 /
      DATA B(11650), B(11651), B(11652) /    22.58,  -39.78,    0.00 /
      DATA B(11989), B(11990), B(11991) /    22.11,  -39.57,    0.00 /
      DATA B(12328), B(12329), B(12330) /    21.71,  -39.32,    0.00 /
      DATA B(12667), B(12668), B(12669) /    21.38,  -39.05,    0.00 /
      DATA B(13006), B(13007), B(13008) /    21.12,  -38.79,    0.00 /
      DATA B(13345), B(13346), B(13347) /    20.89,  -38.57,    0.00 /
      DATA B(13684), B(13685), B(13686) /    20.67,  -38.40,    0.00 /
      DATA B(14023), B(14024), B(14025) /    20.45,  -38.28,    0.00 /
      DATA B(14362), B(14363), B(14364) /    20.21,  -38.19,    0.00 /
      DATA B(14701), B(14702), B(14703) /    19.95,  -38.11,    0.00 /
      DATA B(15040), B(15041), B(15042) /    19.68,  -38.03,    0.00 /
      DATA B(15379), B(15380), B(15381) /    19.44,  -37.89,    0.00 /
      DATA B(15718), B(15719), B(15720) /    18.88,  -37.90,    0.00 /
      DATA B(16057), B(16058), B(16059) /    18.31,  -37.99,    0.00 /
      DATA B(16396), B(16397), B(16398) /    17.69,  -38.04,    0.00 /
      DATA B(16735), B(16736), B(16737) /    17.30,  -37.94,    0.00 /
      DATA B(17074), B(17075), B(17076) /    16.43,  -37.91,    0.00 /
      DATA B(17413), B(17414), B(17415) /    15.49,  -37.83,    0.00 /
      DATA B(17752), B(17753), B(17754) /    14.52,  -37.72,    0.00 /
      DATA B(18091), B(18092), B(18093) /    13.51,  -37.55,    0.00 /
      DATA B(18430), B(18431), B(18432) /    11.89,  -37.57,    0.00 /
      DATA B(18769), B(18770), B(18771) /    11.54,  -36.90,    0.00 /
      DATA B(19108), B(19109), B(19110) /    10.99,  -35.80,    0.00 /
      DATA B(19447), B(19448), B(19449) /    10.21,  -34.05,    0.00 /
      DATA B(19786), B(19787), B(19788) /     9.22,  -31.39,    0.00 /
      DATA B(20125), B(20126), B(20127) /     7.92,  -28.47,    0.00 /
      DATA B(20464), B(20465), B(20466) /     6.74,  -26.11,    0.00 /
      DATA B(20803), B(20804), B(20805) /     5.81,  -24.50,    0.00 /
      DATA B(21142), B(21143), B(21144) /     5.08,  -23.43,    0.00 /
      DATA B(21481), B(21482), B(21483) /     4.47,  -22.69,    0.00 /
      DATA B(21820), B(21821), B(21822) /     3.87,  -22.12,    0.00 /
      DATA B(22159), B(22160), B(22161) /     2.79,  -22.50,    0.00 /
      DATA B(22498), B(22499), B(22500) /     2.76,  -22.87,    0.00 /
      DATA B(22837), B(22838), B(22839) /     2.68,  -23.27,    0.00 /
      DATA B(23176), B(23177), B(23178) /     2.57,  -23.62,    0.00 /
      DATA B(23515), B(23516), B(23517) /     2.48,  -23.92,    0.00 /
      DATA B(23854), B(23855), B(23856) /     2.29,  -23.96,    0.00 /
      DATA B(24193), B(24194), B(24195) /     2.12,  -23.57,    0.00 /
      DATA B(24532), B(24533), B(24534) /     1.66,  -23.17,    0.00 /
      DATA B(24871), B(24872), B(24873) /     1.23,  -22.87,    0.00 /
      DATA B(25210), B(25211), B(25212) /     0.90,  -22.64,    0.00 /
      DATA B(25549), B(25550), B(25551) /     0.64,  -22.48,    0.00 /
      DATA B(25888), B(25889), B(25890) /     0.43,  -22.35,    0.00 /
      DATA B(26227), B(26228), B(26229) /     0.26,  -22.24,    0.00 /
      DATA B(26566), B(26567), B(26568) /     0.11,  -22.15,    0.00 /
      DATA B(26905), B(26906), B(26907) /    -0.03,  -22.07,    0.00 /
      DATA B(27244), B(27245), B(27246) /    -0.15,  -22.00,    0.00 /
      DATA B(  127), B(  128), B(  129) /    24.34,  -45.11,    0.00 /
      DATA B(  466), B(  467), B(  468) /    24.34,  -45.03,    0.00 /
      DATA B(  805), B(  806), B(  807) /    24.33,  -44.95,    0.00 /
      DATA B( 1144), B( 1145), B( 1146) /    24.32,  -44.87,    0.00 /
      DATA B( 1483), B( 1484), B( 1485) /    24.32,  -44.79,    0.00 /
      DATA B( 1822), B( 1823), B( 1824) /    24.31,  -44.71,    0.00 /
      DATA B( 2161), B( 2162), B( 2163) /    24.30,  -44.63,    0.00 /
      DATA B( 2500), B( 2501), B( 2502) /    24.29,  -44.54,    0.00 /
      DATA B( 2839), B( 2840), B( 2841) /    24.29,  -44.46,    0.00 /
      DATA B( 3178), B( 3179), B( 3180) /    24.28,  -44.37,    0.00 /
      DATA B( 3517), B( 3518), B( 3519) /    24.27,  -44.29,    0.00 /
      DATA B( 3856), B( 3857), B( 3858) /    24.26,  -44.20,    0.00 /
      DATA B( 4195), B( 4196), B( 4197) /    24.25,  -44.10,    0.00 /
      DATA B( 4534), B( 4535), B( 4536) /    24.24,  -44.01,    0.00 /
      DATA B( 4873), B( 4874), B( 4875) /    24.23,  -43.91,    0.00 /
      DATA B( 5212), B( 5213), B( 5214) /    24.22,  -43.81,    0.00 /
      DATA B( 5551), B( 5552), B( 5553) /    24.21,  -43.71,    0.00 /
      DATA B( 5890), B( 5891), B( 5892) /    24.20,  -43.60,    0.00 /
      DATA B( 6229), B( 6230), B( 6231) /    24.19,  -43.49,    0.00 /
      DATA B( 6568), B( 6569), B( 6570) /    24.18,  -43.37,    0.00 /
      DATA B( 6907), B( 6908), B( 6909) /    24.17,  -43.24,    0.00 /
      DATA B( 7246), B( 7247), B( 7248) /    24.16,  -43.10,    0.00 /
      DATA B( 7585), B( 7586), B( 7587) /    24.14,  -42.95,    0.00 /
      DATA B( 7924), B( 7925), B( 7926) /    24.13,  -42.79,    0.00 /
      DATA B( 8263), B( 8264), B( 8265) /    24.11,  -42.60,    0.00 /
      DATA B( 8602), B( 8603), B( 8604) /    24.09,  -42.40,    0.00 /
      DATA B( 8941), B( 8942), B( 8943) /    24.06,  -42.16,    0.00 /
      DATA B( 9280), B( 9281), B( 9282) /    24.02,  -41.89,    0.00 /
      DATA B( 9619), B( 9620), B( 9621) /    23.96,  -41.56,    0.00 /
      DATA B( 9958), B( 9959), B( 9960) /    23.87,  -41.20,    0.00 /
      DATA B(10297), B(10298), B(10299) /    23.70,  -40.79,    0.00 /
      DATA B(10636), B(10637), B(10638) /    23.43,  -40.38,    0.00 /
      DATA B(10975), B(10976), B(10977) /    23.01,  -39.98,    0.00 /
      DATA B(11314), B(11315), B(11316) /    22.51,  -39.84,    0.00 /
      DATA B(11653), B(11654), B(11655) /    22.07,  -39.62,    0.00 /
      DATA B(11992), B(11993), B(11994) /    21.71,  -39.38,    0.00 /
      DATA B(12331), B(12332), B(12333) /    21.40,  -39.14,    0.00 /
      DATA B(12670), B(12671), B(12672) /    21.14,  -38.91,    0.00 /
      DATA B(13009), B(13010), B(13011) /    20.90,  -38.71,    0.00 /
      DATA B(13348), B(13349), B(13350) /    20.68,  -38.55,    0.00 /
      DATA B(13687), B(13688), B(13689) /    20.46,  -38.43,    0.00 /
      DATA B(14026), B(14027), B(14028) /    20.22,  -38.33,    0.00 /
      DATA B(14365), B(14366), B(14367) /    19.97,  -38.26,    0.00 /
      DATA B(14704), B(14705), B(14706) /    19.69,  -38.19,    0.00 /
      DATA B(15043), B(15044), B(15045) /    19.41,  -38.09,    0.00 /
      DATA B(15382), B(15383), B(15384) /    18.98,  -38.01,    0.00 /
      DATA B(15721), B(15722), B(15723) /    18.38,  -38.10,    0.00 /
      DATA B(16060), B(16061), B(16062) /    17.76,  -38.19,    0.00 /
      DATA B(16399), B(16400), B(16401) /    17.13,  -38.25,    0.00 /
      DATA B(16738), B(16739), B(16740) /    16.89,  -37.94,    0.00 /
      DATA B(17077), B(17078), B(17079) /    16.00,  -37.77,    0.00 /
      DATA B(17416), B(17417), B(17418) /    15.08,  -37.65,    0.00 /
      DATA B(17755), B(17756), B(17757) /    14.12,  -37.49,    0.00 /
      DATA B(18094), B(18095), B(18096) /    13.10,  -37.29,    0.00 /
      DATA B(18433), B(18434), B(18435) /    11.77,  -37.23,    0.00 /
      DATA B(18772), B(18773), B(18774) /    11.35,  -36.40,    0.00 /
      DATA B(19111), B(19112), B(19113) /    10.72,  -35.12,    0.00 /
      DATA B(19450), B(19451), B(19452) /     9.86,  -33.10,    0.00 /
      DATA B(19789), B(19790), B(19791) /     8.80,  -30.29,    0.00 /
      DATA B(20128), B(20129), B(20130) /     7.54,  -27.60,    0.00 /
      DATA B(20467), B(20468), B(20469) /     6.46,  -25.55,    0.00 /
      DATA B(20806), B(20807), B(20808) /     5.61,  -24.19,    0.00 /
      DATA B(21145), B(21146), B(21147) /     4.95,  -23.27,    0.00 /
      DATA B(21484), B(21485), B(21486) /     4.39,  -22.63,    0.00 /
      DATA B(21823), B(21824), B(21825) /     3.87,  -22.15,    0.00 /
      DATA B(22162), B(22163), B(22164) /     2.43,  -22.10,    0.00 /
      DATA B(22501), B(22502), B(22503) /     2.50,  -22.49,    0.00 /
      DATA B(22840), B(22841), B(22842) /     2.46,  -22.91,    0.00 /
      DATA B(23179), B(23180), B(23181) /     2.39,  -23.33,    0.00 /
      DATA B(23518), B(23519), B(23520) /     2.30,  -23.68,    0.00 /
      DATA B(23857), B(23858), B(23859) /     2.38,  -24.00,    0.00 /
      DATA B(24196), B(24197), B(24198) /     2.05,  -23.57,    0.00 /
      DATA B(24535), B(24536), B(24537) /     1.72,  -23.17,    0.00 /
      DATA B(24874), B(24875), B(24876) /     1.29,  -22.84,    0.00 /
      DATA B(25213), B(25214), B(25215) /     0.94,  -22.59,    0.00 /
      DATA B(25552), B(25553), B(25554) /     0.67,  -22.42,    0.00 /
      DATA B(25891), B(25892), B(25893) /     0.45,  -22.29,    0.00 /
      DATA B(26230), B(26231), B(26232) /     0.28,  -22.18,    0.00 /
      DATA B(26569), B(26570), B(26571) /     0.12,  -22.09,    0.00 /
      DATA B(26908), B(26909), B(26910) /    -0.01,  -22.02,    0.00 /
      DATA B(27247), B(27248), B(27249) /    -0.14,  -21.95,    0.00 /
      DATA B(  130), B(  131), B(  132) /    24.31,  -45.08,    0.00 /
      DATA B(  469), B(  470), B(  471) /    24.31,  -45.00,    0.00 /
      DATA B(  808), B(  809), B(  810) /    24.30,  -44.92,    0.00 /
      DATA B( 1147), B( 1148), B( 1149) /    24.29,  -44.84,    0.00 /
      DATA B( 1486), B( 1487), B( 1488) /    24.29,  -44.76,    0.00 /
      DATA B( 1825), B( 1826), B( 1827) /    24.28,  -44.68,    0.00 /
      DATA B( 2164), B( 2165), B( 2166) /    24.27,  -44.59,    0.00 /
      DATA B( 2503), B( 2504), B( 2505) /    24.26,  -44.51,    0.00 /
      DATA B( 2842), B( 2843), B( 2844) /    24.25,  -44.42,    0.00 /
      DATA B( 3181), B( 3182), B( 3183) /    24.25,  -44.33,    0.00 /
      DATA B( 3520), B( 3521), B( 3522) /    24.24,  -44.24,    0.00 /
      DATA B( 3859), B( 3860), B( 3861) /    24.23,  -44.15,    0.00 /
      DATA B( 4198), B( 4199), B( 4200) /    24.22,  -44.06,    0.00 /
      DATA B( 4537), B( 4538), B( 4539) /    24.21,  -43.96,    0.00 /
      DATA B( 4876), B( 4877), B( 4878) /    24.20,  -43.86,    0.00 /
      DATA B( 5215), B( 5216), B( 5217) /    24.19,  -43.76,    0.00 /
      DATA B( 5554), B( 5555), B( 5556) /    24.18,  -43.65,    0.00 /
      DATA B( 5893), B( 5894), B( 5895) /    24.17,  -43.54,    0.00 /
      DATA B( 6232), B( 6233), B( 6234) /    24.16,  -43.42,    0.00 /
      DATA B( 6571), B( 6572), B( 6573) /    24.14,  -43.29,    0.00 /
      DATA B( 6910), B( 6911), B( 6912) /    24.13,  -43.15,    0.00 /
      DATA B( 7249), B( 7250), B( 7251) /    24.12,  -43.00,    0.00 /
      DATA B( 7588), B( 7589), B( 7590) /    24.10,  -42.84,    0.00 /
      DATA B( 7927), B( 7928), B( 7929) /    24.08,  -42.66,    0.00 /
      DATA B( 8266), B( 8267), B( 8268) /    24.06,  -42.45,    0.00 /
      DATA B( 8605), B( 8606), B( 8607) /    24.04,  -42.22,    0.00 /
      DATA B( 8944), B( 8945), B( 8946) /    24.00,  -41.94,    0.00 /
      DATA B( 9283), B( 9284), B( 9285) /    23.94,  -41.62,    0.00 /
      DATA B( 9622), B( 9623), B( 9624) /    23.84,  -41.25,    0.00 /
      DATA B( 9961), B( 9962), B( 9963) /    23.66,  -40.84,    0.00 /
      DATA B(10300), B(10301), B(10302) /    23.38,  -40.42,    0.00 /
      DATA B(10639), B(10640), B(10641) /    22.95,  -40.06,    0.00 /
      DATA B(10978), B(10979), B(10980) /    22.46,  -39.85,    0.00 /
      DATA B(11317), B(11318), B(11319) /    22.05,  -39.63,    0.00 /
      DATA B(11656), B(11657), B(11658) /    21.71,  -39.41,    0.00 /
      DATA B(11995), B(11996), B(11997) /    21.42,  -39.19,    0.00 /
      DATA B(12334), B(12335), B(12336) /    21.17,  -39.00,    0.00 /
      DATA B(12673), B(12674), B(12675) /    20.93,  -38.82,    0.00 /
      DATA B(13012), B(13013), B(13014) /    20.71,  -38.68,    0.00 /
      DATA B(13351), B(13352), B(13353) /    20.48,  -38.56,    0.00 /
      DATA B(13690), B(13691), B(13692) /    20.25,  -38.47,    0.00 /
      DATA B(14029), B(14030), B(14031) /    20.00,  -38.39,    0.00 /
      DATA B(14368), B(14369), B(14370) /    19.72,  -38.33,    0.00 /
      DATA B(14707), B(14708), B(14709) /    19.43,  -38.24,    0.00 /
      DATA B(15046), B(15047), B(15048) /    19.15,  -38.12,    0.00 /
      DATA B(15385), B(15386), B(15387) /    18.45,  -38.19,    0.00 /
      DATA B(15724), B(15725), B(15726) /    17.82,  -38.29,    0.00 /
      DATA B(16063), B(16064), B(16065) /    17.15,  -38.41,    0.00 /
      DATA B(16402), B(16403), B(16404) /    16.29,  -37.56,    0.00 /
      DATA B(16741), B(16742), B(16743) /    15.97,  -37.14,    0.00 /
      DATA B(17080), B(17081), B(17082) /    15.53,  -37.65,    0.00 /
      DATA B(17419), B(17420), B(17421) /    14.67,  -37.47,    0.00 /
      DATA B(17758), B(17759), B(17760) /    13.72,  -37.23,    0.00 /
      DATA B(18097), B(18098), B(18099) /    11.96,  -37.50,    0.00 /
      DATA B(18436), B(18437), B(18438) /    11.64,  -36.83,    0.00 /
      DATA B(18775), B(18776), B(18777) /    11.16,  -35.88,    0.00 /
      DATA B(19114), B(19115), B(19116) /    10.46,  -34.40,    0.00 /
      DATA B(19453), B(19454), B(19455) /     9.57,  -32.11,    0.00 /
      DATA B(19792), B(19793), B(19794) /     8.42,  -29.30,    0.00 /
      DATA B(20131), B(20132), B(20133) /     7.22,  -26.84,    0.00 /
      DATA B(20470), B(20471), B(20472) /     6.22,  -25.08,    0.00 /
      DATA B(20809), B(20810), B(20811) /     5.45,  -23.92,    0.00 /
      DATA B(21148), B(21149), B(21150) /     4.84,  -23.13,    0.00 /
      DATA B(21487), B(21488), B(21489) /     4.33,  -22.57,    0.00 /
      DATA B(21826), B(21827), B(21828) /     3.86,  -22.16,    0.00 /
      DATA B(22165), B(22166), B(22167) /     3.38,  -21.82,    0.00 /
      DATA B(22504), B(22505), B(22506) /     2.19,  -22.10,    0.00 /
      DATA B(22843), B(22844), B(22845) /     2.23,  -22.55,    0.00 /
      DATA B(23182), B(23183), B(23184) /     2.20,  -23.01,    0.00 /
      DATA B(23521), B(23522), B(23523) /     2.14,  -23.43,    0.00 /
      DATA B(23860), B(23861), B(23862) /     2.12,  -23.79,    0.00 /
      DATA B(24199), B(24200), B(24201) /     2.01,  -23.62,    0.00 /
      DATA B(24538), B(24539), B(24540) /     1.76,  -23.18,    0.00 /
      DATA B(24877), B(24878), B(24879) /     1.34,  -22.81,    0.00 /
      DATA B(25216), B(25217), B(25218) /     0.98,  -22.54,    0.00 /
      DATA B(25555), B(25556), B(25557) /     0.69,  -22.36,    0.00 /
      DATA B(25894), B(25895), B(25896) /     0.47,  -22.22,    0.00 /
      DATA B(26233), B(26234), B(26235) /     0.30,  -22.12,    0.00 /
      DATA B(26572), B(26573), B(26574) /     0.14,  -22.04,    0.00 /
      DATA B(26911), B(26912), B(26913) /     0.00,  -21.96,    0.00 /
      DATA B(27250), B(27251), B(27252) /    -0.13,  -21.90,    0.00 /
      DATA B(  133), B(  134), B(  135) /    24.28,  -45.05,    0.00 /
      DATA B(  472), B(  473), B(  474) /    24.28,  -44.97,    0.00 /
      DATA B(  811), B(  812), B(  813) /    24.27,  -44.89,    0.00 /
      DATA B( 1150), B( 1151), B( 1152) /    24.26,  -44.81,    0.00 /
      DATA B( 1489), B( 1490), B( 1491) /    24.25,  -44.73,    0.00 /
      DATA B( 1828), B( 1829), B( 1830) /    24.25,  -44.64,    0.00 /
      DATA B( 2167), B( 2168), B( 2169) /    24.24,  -44.56,    0.00 /
      DATA B( 2506), B( 2507), B( 2508) /    24.23,  -44.47,    0.00 /
      DATA B( 2845), B( 2846), B( 2847) /    24.22,  -44.38,    0.00 /
      DATA B( 3184), B( 3185), B( 3186) /    24.21,  -44.29,    0.00 /
      DATA B( 3523), B( 3524), B( 3525) /    24.20,  -44.20,    0.00 /
      DATA B( 3862), B( 3863), B( 3864) /    24.19,  -44.10,    0.00 /
      DATA B( 4201), B( 4202), B( 4203) /    24.18,  -44.01,    0.00 /
      DATA B( 4540), B( 4541), B( 4542) /    24.17,  -43.91,    0.00 /
      DATA B( 4879), B( 4880), B( 4881) /    24.16,  -43.81,    0.00 /
      DATA B( 5218), B( 5219), B( 5220) /    24.15,  -43.70,    0.00 /
      DATA B( 5557), B( 5558), B( 5559) /    24.14,  -43.58,    0.00 /
      DATA B( 5896), B( 5897), B( 5898) /    24.13,  -43.47,    0.00 /
      DATA B( 6235), B( 6236), B( 6237) /    24.12,  -43.34,    0.00 /
      DATA B( 6574), B( 6575), B( 6576) /    24.11,  -43.20,    0.00 /
      DATA B( 6913), B( 6914), B( 6915) /    24.09,  -43.05,    0.00 /
      DATA B( 7252), B( 7253), B( 7254) /    24.08,  -42.89,    0.00 /
      DATA B( 7591), B( 7592), B( 7593) /    24.06,  -42.71,    0.00 /
      DATA B( 7930), B( 7931), B( 7932) /    24.04,  -42.51,    0.00 /
      DATA B( 8269), B( 8270), B( 8271) /    24.01,  -42.27,    0.00 /
      DATA B( 8608), B( 8609), B( 8610) /    23.97,  -42.00,    0.00 /
      DATA B( 8947), B( 8948), B( 8949) /    23.91,  -41.68,    0.00 /
      DATA B( 9286), B( 9287), B( 9288) /    23.81,  -41.31,    0.00 /
      DATA B( 9625), B( 9626), B( 9627) /    23.63,  -40.90,    0.00 /
      DATA B( 9964), B( 9965), B( 9966) /    23.34,  -40.47,    0.00 /
      DATA B(10303), B(10304), B(10305) /    22.90,  -40.10,    0.00 /
      DATA B(10642), B(10643), B(10644) /    22.41,  -39.87,    0.00 /
      DATA B(10981), B(10982), B(10983) /    22.01,  -39.64,    0.00 /
      DATA B(11320), B(11321), B(11322) /    21.70,  -39.42,    0.00 /
      DATA B(11659), B(11660), B(11661) /    21.43,  -39.22,    0.00 /
      DATA B(11998), B(11999), B(12000) /    21.19,  -39.05,    0.00 /
      DATA B(12337), B(12338), B(12339) /    20.96,  -38.90,    0.00 /
      DATA B(12676), B(12677), B(12678) /    20.74,  -38.78,    0.00 /
      DATA B(13015), B(13016), B(13017) /    20.51,  -38.67,    0.00 /
      DATA B(13354), B(13355), B(13356) /    20.28,  -38.59,    0.00 /
      DATA B(13693), B(13694), B(13695) /    20.04,  -38.52,    0.00 /
      DATA B(14032), B(14033), B(14034) /    19.77,  -38.45,    0.00 /
      DATA B(14371), B(14372), B(14373) /    19.50,  -38.36,    0.00 /
      DATA B(14710), B(14711), B(14712) /    19.11,  -38.28,    0.00 /
      DATA B(15049), B(15050), B(15051) /    18.51,  -38.32,    0.00 /
      DATA B(15388), B(15389), B(15390) /    17.90,  -38.39,    0.00 /
      DATA B(15727), B(15728), B(15729) /    17.24,  -38.50,    0.00 /
      DATA B(16066), B(16067), B(16068) /    16.43,  -37.67,    0.00 /
      DATA B(16405), B(16406), B(16407) /    15.96,  -37.44,    0.00 /
      DATA B(16744), B(16745), B(16746) /    15.52,  -37.16,    0.00 /
      DATA B(17083), B(17084), B(17085) /    15.11,  -37.53,    0.00 /
      DATA B(17422), B(17423), B(17424) /    14.25,  -37.30,    0.00 /
      DATA B(17761), B(17762), B(17763) /    13.28,  -36.91,    0.00 /
      DATA B(18100), B(18101), B(18102) /    11.85,  -37.14,    0.00 /
      DATA B(18439), B(18440), B(18441) /    11.52,  -36.40,    0.00 /
      DATA B(18778), B(18779), B(18780) /    10.98,  -35.32,    0.00 /
      DATA B(19117), B(19118), B(19119) /    10.21,  -33.62,    0.00 /
      DATA B(19456), B(19457), B(19458) /     9.20,  -31.12,    0.00 /
      DATA B(19795), B(19796), B(19797) /     8.07,  -28.39,    0.00 /
      DATA B(20134), B(20135), B(20136) /     6.94,  -26.18,    0.00 /
      DATA B(20473), B(20474), B(20475) /     6.02,  -24.68,    0.00 /
      DATA B(20812), B(20813), B(20814) /     5.31,  -23.70,    0.00 /
      DATA B(21151), B(21152), B(21153) /     4.75,  -23.02,    0.00 /
      DATA B(21490), B(21491), B(21492) /     4.28,  -22.53,    0.00 /
      DATA B(21829), B(21830), B(21831) /     3.85,  -22.16,    0.00 /
      DATA B(22168), B(22169), B(22170) /     3.42,  -21.87,    0.00 /
      DATA B(22507), B(22508), B(22509) /     2.95,  -21.61,    0.00 /
      DATA B(22846), B(22847), B(22848) /     1.99,  -22.17,    0.00 /
      DATA B(23185), B(23186), B(23187) /     2.00,  -22.66,    0.00 /
      DATA B(23524), B(23525), B(23526) /     1.97,  -23.15,    0.00 /
      DATA B(23863), B(23864), B(23865) /     1.96,  -23.56,    0.00 /
      DATA B(24202), B(24203), B(24204) /     1.84,  -23.65,    0.00 /
      DATA B(24541), B(24542), B(24543) /     1.77,  -23.22,    0.00 /
      DATA B(24880), B(24881), B(24882) /     1.39,  -22.78,    0.00 /
      DATA B(25219), B(25220), B(25221) /     1.01,  -22.48,    0.00 /
      DATA B(25558), B(25559), B(25560) /     0.71,  -22.29,    0.00 /
      DATA B(25897), B(25898), B(25899) /     0.49,  -22.16,    0.00 /
      DATA B(26236), B(26237), B(26238) /     0.32,  -22.06,    0.00 /
      DATA B(26575), B(26576), B(26577) /     0.16,  -21.98,    0.00 /
      DATA B(26914), B(26915), B(26916) /     0.02,  -21.91,    0.00 /
      DATA B(27253), B(27254), B(27255) /    -0.11,  -21.85,    0.00 /
      DATA B(  136), B(  137), B(  138) /    24.25,  -45.02,    0.00 /
      DATA B(  475), B(  476), B(  477) /    24.25,  -44.94,    0.00 /
      DATA B(  814), B(  815), B(  816) /    24.24,  -44.86,    0.00 /
      DATA B( 1153), B( 1154), B( 1155) /    24.23,  -44.77,    0.00 /
      DATA B( 1492), B( 1493), B( 1494) /    24.22,  -44.69,    0.00 /
      DATA B( 1831), B( 1832), B( 1833) /    24.22,  -44.60,    0.00 /
      DATA B( 2170), B( 2171), B( 2172) /    24.21,  -44.52,    0.00 /
      DATA B( 2509), B( 2510), B( 2511) /    24.20,  -44.43,    0.00 /
      DATA B( 2848), B( 2849), B( 2850) /    24.19,  -44.34,    0.00 /
      DATA B( 3187), B( 3188), B( 3189) /    24.18,  -44.25,    0.00 /
      DATA B( 3526), B( 3527), B( 3528) /    24.17,  -44.15,    0.00 /
      DATA B( 3865), B( 3866), B( 3867) /    24.16,  -44.05,    0.00 /
      DATA B( 4204), B( 4205), B( 4206) /    24.15,  -43.96,    0.00 /
      DATA B( 4543), B( 4544), B( 4545) /    24.14,  -43.85,    0.00 /
      DATA B( 4882), B( 4883), B( 4884) /    24.13,  -43.74,    0.00 /
      DATA B( 5221), B( 5222), B( 5223) /    24.12,  -43.63,    0.00 /
      DATA B( 5560), B( 5561), B( 5562) /    24.11,  -43.51,    0.00 /
      DATA B( 5899), B( 5900), B( 5901) /    24.09,  -43.39,    0.00 /
      DATA B( 6238), B( 6239), B( 6240) /    24.08,  -43.25,    0.00 /
      DATA B( 6577), B( 6578), B( 6579) /    24.07,  -43.11,    0.00 /
      DATA B( 6916), B( 6917), B( 6918) /    24.05,  -42.94,    0.00 /
      DATA B( 7255), B( 7256), B( 7257) /    24.04,  -42.76,    0.00 /
      DATA B( 7594), B( 7595), B( 7596) /    24.02,  -42.56,    0.00 /
      DATA B( 7933), B( 7934), B( 7935) /    23.99,  -42.33,    0.00 /
      DATA B( 8272), B( 8273), B( 8274) /    23.95,  -42.06,    0.00 /
      DATA B( 8611), B( 8612), B( 8613) /    23.89,  -41.74,    0.00 /
      DATA B( 8950), B( 8951), B( 8952) /    23.79,  -41.37,    0.00 /
      DATA B( 9289), B( 9290), B( 9291) /    23.61,  -40.96,    0.00 /
      DATA B( 9628), B( 9629), B( 9630) /    23.31,  -40.53,    0.00 /
      DATA B( 9967), B( 9968), B( 9969) /    22.87,  -40.16,    0.00 /
      DATA B(10306), B(10307), B(10308) /    22.38,  -39.91,    0.00 /
      DATA B(10645), B(10646), B(10647) /    21.98,  -39.66,    0.00 /
      DATA B(10984), B(10985), B(10986) /    21.68,  -39.43,    0.00 /
      DATA B(11323), B(11324), B(11325) /    21.44,  -39.24,    0.00 /
      DATA B(11662), B(11663), B(11664) /    21.21,  -39.09,    0.00 /
      DATA B(12001), B(12002), B(12003) /    20.99,  -38.96,    0.00 /
      DATA B(12340), B(12341), B(12342) /    20.77,  -38.85,    0.00 /
      DATA B(12679), B(12680), B(12681) /    20.55,  -38.77,    0.00 /
      DATA B(13018), B(13019), B(13020) /    20.32,  -38.69,    0.00 /
      DATA B(13357), B(13358), B(13359) /    20.08,  -38.62,    0.00 /
      DATA B(13696), B(13697), B(13698) /    19.83,  -38.56,    0.00 /
      DATA B(14035), B(14036), B(14037) /    19.56,  -38.47,    0.00 /
      DATA B(14374), B(14375), B(14376) /    19.11,  -38.43,    0.00 /
      DATA B(14713), B(14714), B(14715) /    18.53,  -38.47,    0.00 /
      DATA B(15052), B(15053), B(15054) /    17.95,  -38.52,    0.00 /
      DATA B(15391), B(15392), B(15393) /    17.33,  -38.61,    0.00 /
      DATA B(15730), B(15731), B(15732) /    16.61,  -37.74,    0.00 /
      DATA B(16069), B(16070), B(16071) /    16.17,  -37.53,    0.00 /
      DATA B(16408), B(16409), B(16410) /    15.69,  -37.30,    0.00 /
      DATA B(16747), B(16748), B(16749) /    15.15,  -37.12,    0.00 /
      DATA B(17086), B(17087), B(17088) /    14.54,  -37.38,    0.00 /
      DATA B(17425), B(17426), B(17427) /    13.78,  -37.24,    0.00 /
      DATA B(17764), B(17765), B(17766) /    12.01,  -37.26,    0.00 /
      DATA B(18103), B(18104), B(18105) /    11.83,  -36.76,    0.00 /
      DATA B(18442), B(18443), B(18444) /    11.45,  -35.96,    0.00 /
      DATA B(18781), B(18782), B(18783) /    10.82,  -34.71,    0.00 /
      DATA B(19120), B(19121), B(19122) /     9.98,  -32.79,    0.00 /
      DATA B(19459), B(19460), B(19461) /     8.97,  -30.09,    0.00 /
      DATA B(19798), B(19799), B(19800) /     7.75,  -27.57,    0.00 /
      DATA B(20137), B(20138), B(20139) /     6.68,  -25.62,    0.00 /
      DATA B(20476), B(20477), B(20478) /     5.84,  -24.35,    0.00 /
      DATA B(20815), B(20816), B(20817) /     5.18,  -23.51,    0.00 /
      DATA B(21154), B(21155), B(21156) /     4.67,  -22.92,    0.00 /
      DATA B(21493), B(21494), B(21495) /     4.23,  -22.49,    0.00 /
      DATA B(21832), B(21833), B(21834) /     3.83,  -22.17,    0.00 /
      DATA B(22171), B(22172), B(22173) /     3.44,  -21.91,    0.00 /
      DATA B(22510), B(22511), B(22512) /     3.02,  -21.68,    0.00 /
      DATA B(22849), B(22850), B(22851) /     1.69,  -21.79,    0.00 /
      DATA B(23188), B(23189), B(23190) /     1.79,  -22.31,    0.00 /
      DATA B(23527), B(23528), B(23529) /     1.80,  -22.85,    0.00 /
      DATA B(23866), B(23867), B(23868) /     1.81,  -23.35,    0.00 /
      DATA B(24205), B(24206), B(24207) /     1.89,  -23.74,    0.00 /
      DATA B(24544), B(24545), B(24546) /     1.78,  -23.25,    0.00 /
      DATA B(24883), B(24884), B(24885) /     1.43,  -22.72,    0.00 /
      DATA B(25222), B(25223), B(25224) /     1.02,  -22.40,    0.00 /
      DATA B(25561), B(25562), B(25563) /     0.72,  -22.22,    0.00 /
      DATA B(25900), B(25901), B(25902) /     0.51,  -22.10,    0.00 /
      DATA B(26239), B(26240), B(26241) /     0.34,  -22.00,    0.00 /
      DATA B(26578), B(26579), B(26580) /     0.19,  -21.92,    0.00 /
      DATA B(26917), B(26918), B(26919) /     0.05,  -21.85,    0.00 /
      DATA B(27256), B(27257), B(27258) /    -0.09,  -21.79,    0.00 /
      DATA B(  139), B(  140), B(  141) /    24.22,  -44.99,    0.00 /
      DATA B(  478), B(  479), B(  480) /    24.21,  -44.91,    0.00 /
      DATA B(  817), B(  818), B(  819) /    24.21,  -44.82,    0.00 /
      DATA B( 1156), B( 1157), B( 1158) /    24.20,  -44.74,    0.00 /
      DATA B( 1495), B( 1496), B( 1497) /    24.19,  -44.65,    0.00 /
      DATA B( 1834), B( 1835), B( 1836) /    24.18,  -44.56,    0.00 /
      DATA B( 2173), B( 2174), B( 2175) /    24.18,  -44.48,    0.00 /
      DATA B( 2512), B( 2513), B( 2514) /    24.17,  -44.38,    0.00 /
      DATA B( 2851), B( 2852), B( 2853) /    24.16,  -44.29,    0.00 /
      DATA B( 3190), B( 3191), B( 3192) /    24.15,  -44.20,    0.00 /
      DATA B( 3529), B( 3530), B( 3531) /    24.14,  -44.10,    0.00 /
      DATA B( 3868), B( 3869), B( 3870) /    24.13,  -44.00,    0.00 /
      DATA B( 4207), B( 4208), B( 4209) /    24.12,  -43.90,    0.00 /
      DATA B( 4546), B( 4547), B( 4548) /    24.11,  -43.79,    0.00 /
      DATA B( 4885), B( 4886), B( 4887) /    24.09,  -43.68,    0.00 /
      DATA B( 5224), B( 5225), B( 5226) /    24.08,  -43.56,    0.00 /
      DATA B( 5563), B( 5564), B( 5565) /    24.07,  -43.44,    0.00 /
      DATA B( 5902), B( 5903), B( 5904) /    24.06,  -43.30,    0.00 /
      DATA B( 6241), B( 6242), B( 6243) /    24.04,  -43.16,    0.00 /
      DATA B( 6580), B( 6581), B( 6582) /    24.03,  -43.00,    0.00 /
      DATA B( 6919), B( 6920), B( 6921) /    24.01,  -42.82,    0.00 /
      DATA B( 7258), B( 7259), B( 7260) /    23.99,  -42.61,    0.00 /
      DATA B( 7597), B( 7598), B( 7599) /    23.97,  -42.38,    0.00 /
      DATA B( 7936), B( 7937), B( 7938) /    23.93,  -42.11,    0.00 /
      DATA B( 8275), B( 8276), B( 8277) /    23.87,  -41.79,    0.00 /
      DATA B( 8614), B( 8615), B( 8616) /    23.76,  -41.43,    0.00 /
      DATA B( 8953), B( 8954), B( 8955) /    23.58,  -41.01,    0.00 /
      DATA B( 9292), B( 9293), B( 9294) /    23.29,  -40.59,    0.00 /
      DATA B( 9631), B( 9632), B( 9633) /    22.85,  -40.22,    0.00 /
      DATA B( 9970), B( 9971), B( 9972) /    22.35,  -39.97,    0.00 /
      DATA B(10309), B(10310), B(10311) /    21.96,  -39.71,    0.00 /
      DATA B(10648), B(10649), B(10650) /    21.67,  -39.48,    0.00 /
      DATA B(10987), B(10988), B(10989) /    21.43,  -39.28,    0.00 /
      DATA B(11326), B(11327), B(11328) /    21.22,  -39.13,    0.00 /
      DATA B(11665), B(11666), B(11667) /    21.01,  -39.01,    0.00 /
      DATA B(12004), B(12005), B(12006) /    20.80,  -38.92,    0.00 /
      DATA B(12343), B(12344), B(12345) /    20.59,  -38.84,    0.00 /
      DATA B(12682), B(12683), B(12684) /    20.36,  -38.78,    0.00 /
      DATA B(13021), B(13022), B(13023) /    20.13,  -38.72,    0.00 /
      DATA B(13360), B(13361), B(13362) /    19.88,  -38.65,    0.00 /
      DATA B(13699), B(13700), B(13701) /    19.63,  -38.57,    0.00 /
      DATA B(14038), B(14039), B(14040) /    19.12,  -38.58,    0.00 /
      DATA B(14377), B(14378), B(14379) /    18.57,  -38.61,    0.00 /
      DATA B(14716), B(14717), B(14718) /    18.00,  -38.67,    0.00 /
      DATA B(15055), B(15056), B(15057) /    17.40,  -38.74,    0.00 /
      DATA B(15394), B(15395), B(15396) /    16.76,  -37.83,    0.00 /
      DATA B(15733), B(15734), B(15735) /    16.38,  -37.61,    0.00 /
      DATA B(16072), B(16073), B(16074) /    15.96,  -37.38,    0.00 /
      DATA B(16411), B(16412), B(16413) /    15.47,  -37.15,    0.00 /
      DATA B(16750), B(16751), B(16752) /    14.90,  -36.95,    0.00 /
      DATA B(17089), B(17090), B(17091) /    14.18,  -36.98,    0.00 /
      DATA B(17428), B(17429), B(17430) /    13.48,  -35.92,    0.00 /
      DATA B(17767), B(17768), B(17769) /    12.54,  -36.83,    0.00 /
      DATA B(18106), B(18107), B(18108) /    12.03,  -36.35,    0.00 /
      DATA B(18445), B(18446), B(18447) /    11.46,  -35.44,    0.00 /
      DATA B(18784), B(18785), B(18786) /    10.69,  -34.02,    0.00 /
      DATA B(19123), B(19124), B(19125) /     9.73,  -31.88,    0.00 /
      DATA B(19462), B(19463), B(19464) /     8.63,  -29.19,    0.00 /
      DATA B(19801), B(19802), B(19803) /     7.44,  -26.82,    0.00 /
      DATA B(20140), B(20141), B(20142) /     6.44,  -25.15,    0.00 /
      DATA B(20479), B(20480), B(20481) /     5.67,  -24.07,    0.00 /
      DATA B(20818), B(20819), B(20820) /     5.07,  -23.35,    0.00 /
      DATA B(21157), B(21158), B(21159) /     4.59,  -22.84,    0.00 /
      DATA B(21496), B(21497), B(21498) /     4.18,  -22.47,    0.00 /
      DATA B(21835), B(21836), B(21837) /     3.81,  -22.18,    0.00 /
      DATA B(22174), B(22175), B(22176) /     3.44,  -21.94,    0.00 /
      DATA B(22513), B(22514), B(22515) /     3.07,  -21.74,    0.00 /
      DATA B(22852), B(22853), B(22854) /     2.65,  -21.54,    0.00 /
      DATA B(23191), B(23192), B(23193) /     1.56,  -21.92,    0.00 /
      DATA B(23530), B(23531), B(23532) /     1.64,  -22.54,    0.00 /
      DATA B(23869), B(23870), B(23871) /     1.69,  -23.13,    0.00 /
      DATA B(24208), B(24209), B(24210) /     1.78,  -23.61,    0.00 /
      DATA B(24547), B(24548), B(24549) /     1.71,  -23.33,    0.00 /
      DATA B(24886), B(24887), B(24888) /     1.37,  -22.59,    0.00 /
      DATA B(25225), B(25226), B(25227) /     0.98,  -22.31,    0.00 /
      DATA B(25564), B(25565), B(25566) /     0.73,  -22.16,    0.00 /
      DATA B(25903), B(25904), B(25905) /     0.53,  -22.04,    0.00 /
      DATA B(26242), B(26243), B(26244) /     0.37,  -21.95,    0.00 /
      DATA B(26581), B(26582), B(26583) /     0.22,  -21.86,    0.00 /
      DATA B(26920), B(26921), B(26922) /     0.08,  -21.79,    0.00 /
      DATA B(27259), B(27260), B(27261) /    -0.06,  -21.73,    0.00 /
      DATA B(  142), B(  143), B(  144) /    24.19,  -44.96,    0.00 /
      DATA B(  481), B(  482), B(  483) /    24.18,  -44.87,    0.00 /
      DATA B(  820), B(  821), B(  822) /    24.18,  -44.79,    0.00 /
      DATA B( 1159), B( 1160), B( 1161) /    24.17,  -44.70,    0.00 /
      DATA B( 1498), B( 1499), B( 1500) /    24.16,  -44.61,    0.00 /
      DATA B( 1837), B( 1838), B( 1839) /    24.15,  -44.52,    0.00 /
      DATA B( 2176), B( 2177), B( 2178) /    24.14,  -44.43,    0.00 /
      DATA B( 2515), B( 2516), B( 2517) /    24.14,  -44.34,    0.00 /
      DATA B( 2854), B( 2855), B( 2856) /    24.13,  -44.24,    0.00 /
      DATA B( 3193), B( 3194), B( 3195) /    24.12,  -44.15,    0.00 /
      DATA B( 3532), B( 3533), B( 3534) /    24.11,  -44.05,    0.00 /
      DATA B( 3871), B( 3872), B( 3873) /    24.09,  -43.94,    0.00 /
      DATA B( 4210), B( 4211), B( 4212) /    24.08,  -43.84,    0.00 /
      DATA B( 4549), B( 4550), B( 4551) /    24.07,  -43.72,    0.00 /
      DATA B( 4888), B( 4889), B( 4890) /    24.06,  -43.61,    0.00 /
      DATA B( 5227), B( 5228), B( 5229) /    24.05,  -43.48,    0.00 /
      DATA B( 5566), B( 5567), B( 5568) /    24.03,  -43.35,    0.00 /
      DATA B( 5905), B( 5906), B( 5907) /    24.02,  -43.20,    0.00 /
      DATA B( 6244), B( 6245), B( 6246) /    24.01,  -43.04,    0.00 /
      DATA B( 6583), B( 6584), B( 6585) /    23.99,  -42.87,    0.00 /
      DATA B( 6922), B( 6923), B( 6924) /    23.97,  -42.67,    0.00 /
      DATA B( 7261), B( 7262), B( 7263) /    23.94,  -42.44,    0.00 /
      DATA B( 7600), B( 7601), B( 7602) /    23.90,  -42.17,    0.00 /
      DATA B( 7939), B( 7940), B( 7941) /    23.84,  -41.85,    0.00 /
      DATA B( 8278), B( 8279), B( 8280) /    23.74,  -41.48,    0.00 /
      DATA B( 8617), B( 8618), B( 8619) /    23.56,  -41.07,    0.00 /
      DATA B( 8956), B( 8957), B( 8958) /    23.27,  -40.65,    0.00 /
      DATA B( 9295), B( 9296), B( 9297) /    22.83,  -40.28,    0.00 /
      DATA B( 9634), B( 9635), B( 9636) /    22.34,  -40.03,    0.00 /
      DATA B( 9973), B( 9974), B( 9975) /    21.94,  -39.77,    0.00 /
      DATA B(10312), B(10313), B(10314) /    21.65,  -39.53,    0.00 /
      DATA B(10651), B(10652), B(10653) /    21.42,  -39.33,    0.00 /
      DATA B(10990), B(10991), B(10992) /    21.22,  -39.18,    0.00 /
      DATA B(11329), B(11330), B(11331) /    21.02,  -39.07,    0.00 /
      DATA B(11668), B(11669), B(11670) /    20.82,  -38.98,    0.00 /
      DATA B(12007), B(12008), B(12009) /    20.62,  -38.91,    0.00 /
      DATA B(12346), B(12347), B(12348) /    20.40,  -38.85,    0.00 /
      DATA B(12685), B(12686), B(12687) /    20.18,  -38.80,    0.00 /
      DATA B(13024), B(13025), B(13026) /    19.95,  -38.74,    0.00 /
      DATA B(13363), B(13364), B(13365) /    19.68,  -38.67,    0.00 /
      DATA B(13702), B(13703), B(13704) /    19.14,  -38.71,    0.00 /
      DATA B(14041), B(14042), B(14043) /    18.60,  -38.75,    0.00 /
      DATA B(14380), B(14381), B(14382) /    18.04,  -38.82,    0.00 /
      DATA B(14719), B(14720), B(14721) /    17.46,  -38.89,    0.00 /
      DATA B(15058), B(15059), B(15060) /    16.90,  -37.96,    0.00 /
      DATA B(15397), B(15398), B(15399) /    16.56,  -37.71,    0.00 /
      DATA B(15736), B(15737), B(15738) /    16.19,  -37.47,    0.00 /
      DATA B(16075), B(16076), B(16077) /    15.77,  -37.23,    0.00 /
      DATA B(16414), B(16415), B(16416) /    15.30,  -36.99,    0.00 /
      DATA B(16753), B(16754), B(16755) /    14.75,  -36.78,    0.00 /
      DATA B(17092), B(17093), B(17094) /    13.88,  -36.44,    0.00 /
      DATA B(17431), B(17432), B(17433) /    13.40,  -35.94,    0.00 /
      DATA B(17770), B(17771), B(17772) /    12.97,  -36.09,    0.00 /
      DATA B(18109), B(18110), B(18111) /    12.27,  -35.77,    0.00 /
      DATA B(18448), B(18449), B(18450) /    11.48,  -34.82,    0.00 /
      DATA B(18787), B(18788), B(18789) /    10.57,  -33.24,    0.00 /
      DATA B(19126), B(19127), B(19128) /     9.52,  -30.89,    0.00 /
      DATA B(19465), B(19466), B(19467) /     8.29,  -28.30,    0.00 /
      DATA B(19804), B(19805), B(19806) /     7.14,  -26.18,    0.00 /
      DATA B(20143), B(20144), B(20145) /     6.22,  -24.75,    0.00 /
      DATA B(20482), B(20483), B(20484) /     5.51,  -23.84,    0.00 /
      DATA B(20821), B(20822), B(20823) /     4.96,  -23.22,    0.00 /
      DATA B(21160), B(21161), B(21162) /     4.51,  -22.78,    0.00 /
      DATA B(21499), B(21500), B(21501) /     4.13,  -22.45,    0.00 /
      DATA B(21838), B(21839), B(21840) /     3.78,  -22.19,    0.00 /
      DATA B(22177), B(22178), B(22179) /     3.44,  -21.98,    0.00 /
      DATA B(22516), B(22517), B(22518) /     3.09,  -21.79,    0.00 /
      DATA B(22855), B(22856), B(22857) /     2.72,  -21.62,    0.00 /
      DATA B(23194), B(23195), B(23196) /     1.30,  -21.52,    0.00 /
      DATA B(23533), B(23534), B(23535) /     1.53,  -22.22,    0.00 /
      DATA B(23872), B(23873), B(23874) /     1.62,  -22.89,    0.00 /
      DATA B(24211), B(24212), B(24213) /     1.72,  -23.47,    0.00 /
      DATA B(24550), B(24551), B(24552) /     1.71,  -23.51,    0.00 /
      DATA B(24889), B(24890), B(24891) /     1.10,  -22.41,    0.00 /
      DATA B(25228), B(25229), B(25230) /     0.92,  -22.24,    0.00 /
      DATA B(25567), B(25568), B(25569) /     0.73,  -22.11,    0.00 /
      DATA B(25906), B(25907), B(25908) /     0.56,  -21.99,    0.00 /
      DATA B(26245), B(26246), B(26247) /     0.41,  -21.89,    0.00 /
      DATA B(26584), B(26585), B(26586) /     0.26,  -21.81,    0.00 /
      DATA B(26923), B(26924), B(26925) /     0.13,  -21.73,    0.00 /
      DATA B(27262), B(27263), B(27264) /    -0.01,  -21.67,    0.00 /
      DATA B(  145), B(  146), B(  147) /    24.16,  -44.92,    0.00 /
      DATA B(  484), B(  485), B(  486) /    24.15,  -44.83,    0.00 /
      DATA B(  823), B(  824), B(  825) /    24.15,  -44.75,    0.00 /
      DATA B( 1162), B( 1163), B( 1164) /    24.14,  -44.66,    0.00 /
      DATA B( 1501), B( 1502), B( 1503) /    24.13,  -44.57,    0.00 /
      DATA B( 1840), B( 1841), B( 1842) /    24.12,  -44.48,    0.00 /
      DATA B( 2179), B( 2180), B( 2181) /    24.11,  -44.38,    0.00 /
      DATA B( 2518), B( 2519), B( 2520) /    24.10,  -44.29,    0.00 /
      DATA B( 2857), B( 2858), B( 2859) /    24.09,  -44.19,    0.00 /
      DATA B( 3196), B( 3197), B( 3198) /    24.08,  -44.09,    0.00 /
      DATA B( 3535), B( 3536), B( 3537) /    24.07,  -43.99,    0.00 /
      DATA B( 3874), B( 3875), B( 3876) /    24.06,  -43.88,    0.00 /
      DATA B( 4213), B( 4214), B( 4215) /    24.05,  -43.77,    0.00 /
      DATA B( 4552), B( 4553), B( 4554) /    24.04,  -43.65,    0.00 /
      DATA B( 4891), B( 4892), B( 4893) /    24.02,  -43.53,    0.00 /
      DATA B( 5230), B( 5231), B( 5232) /    24.01,  -43.39,    0.00 /
      DATA B( 5569), B( 5570), B( 5571) /    24.00,  -43.25,    0.00 /
      DATA B( 5908), B( 5909), B( 5910) /    23.98,  -43.09,    0.00 /
      DATA B( 6247), B( 6248), B( 6249) /    23.96,  -42.92,    0.00 /
      DATA B( 6586), B( 6587), B( 6588) /    23.94,  -42.72,    0.00 /
      DATA B( 6925), B( 6926), B( 6927) /    23.92,  -42.49,    0.00 /
      DATA B( 7264), B( 7265), B( 7266) /    23.88,  -42.22,    0.00 /
      DATA B( 7603), B( 7604), B( 7605) /    23.82,  -41.91,    0.00 /
      DATA B( 7942), B( 7943), B( 7944) /    23.72,  -41.54,    0.00 /
      DATA B( 8281), B( 8282), B( 8283) /    23.54,  -41.13,    0.00 /
      DATA B( 8620), B( 8621), B( 8622) /    23.25,  -40.71,    0.00 /
      DATA B( 8959), B( 8960), B( 8961) /    22.81,  -40.34,    0.00 /
      DATA B( 9298), B( 9299), B( 9300) /    22.32,  -40.10,    0.00 /
      DATA B( 9637), B( 9638), B( 9639) /    21.93,  -39.84,    0.00 /
      DATA B( 9976), B( 9977), B( 9978) /    21.64,  -39.60,    0.00 /
      DATA B(10315), B(10316), B(10317) /    21.41,  -39.40,    0.00 /
      DATA B(10654), B(10655), B(10656) /    21.21,  -39.24,    0.00 /
      DATA B(10993), B(10994), B(10995) /    21.02,  -39.13,    0.00 /
      DATA B(11332), B(11333), B(11334) /    20.83,  -39.05,    0.00 /
      DATA B(11671), B(11672), B(11673) /    20.64,  -38.98,    0.00 /
      DATA B(12010), B(12011), B(12012) /    20.44,  -38.93,    0.00 /
      DATA B(12349), B(12350), B(12351) /    20.22,  -38.88,    0.00 /
      DATA B(12688), B(12689), B(12690) /    20.01,  -38.81,    0.00 /
      DATA B(13027), B(13028), B(13029) /    19.67,  -38.78,    0.00 /
      DATA B(13366), B(13367), B(13368) /    19.15,  -38.84,    0.00 /
      DATA B(13705), B(13706), B(13707) /    18.63,  -38.89,    0.00 /
      DATA B(14044), B(14045), B(14046) /    18.09,  -38.96,    0.00 /
      DATA B(14383), B(14384), B(14385) /    17.53,  -39.04,    0.00 /
      DATA B(14722), B(14723), B(14724) /    17.02,  -38.09,    0.00 /
      DATA B(15061), B(15062), B(15063) /    16.70,  -37.84,    0.00 /
      DATA B(15400), B(15401), B(15402) /    16.38,  -37.59,    0.00 /
      DATA B(15739), B(15740), B(15741) /    16.02,  -37.33,    0.00 /
      DATA B(16078), B(16079), B(16080) /    15.61,  -37.07,    0.00 /
      DATA B(16417), B(16418), B(16419) /    15.13,  -36.81,    0.00 /
      DATA B(16756), B(16757), B(16758) /    14.56,  -36.57,    0.00 /
      DATA B(17095), B(17096), B(17097) /    13.69,  -36.09,    0.00 /
      DATA B(17434), B(17435), B(17436) /    13.28,  -35.73,    0.00 /
      DATA B(17773), B(17774), B(17775) /    12.96,  -35.57,    0.00 /
      DATA B(18112), B(18113), B(18114) /    12.31,  -35.13,    0.00 /
      DATA B(18451), B(18452), B(18453) /    11.43,  -34.11,    0.00 /
      DATA B(18790), B(18791), B(18792) /    10.38,  -32.36,    0.00 /
      DATA B(19129), B(19130), B(19131) /     9.40,  -29.44,    0.00 /
      DATA B(19468), B(19469), B(19470) /     7.94,  -27.46,    0.00 /
      DATA B(19807), B(19808), B(19809) /     6.85,  -25.62,    0.00 /
      DATA B(20146), B(20147), B(20148) /     6.01,  -24.42,    0.00 /
      DATA B(20485), B(20486), B(20487) /     5.37,  -23.64,    0.00 /
      DATA B(20824), B(20825), B(20826) /     4.86,  -23.11,    0.00 /
      DATA B(21163), B(21164), B(21165) /     4.44,  -22.72,    0.00 /
      DATA B(21502), B(21503), B(21504) /     4.08,  -22.43,    0.00 /
      DATA B(21841), B(21842), B(21843) /     3.74,  -22.20,    0.00 /
      DATA B(22180), B(22181), B(22182) /     3.42,  -22.01,    0.00 /
      DATA B(22519), B(22520), B(22521) /     3.09,  -21.84,    0.00 /
      DATA B(22858), B(22859), B(22860) /     2.75,  -21.67,    0.00 /
      DATA B(23197), B(23198), B(23199) /     2.35,  -21.47,    0.00 /
      DATA B(23536), B(23537), B(23538) /     0.69,  -20.55,    0.00 /
      DATA B(23875), B(23876), B(23877) /     0.35,  -20.72,    0.00 /
      DATA B(24214), B(24215), B(24216) /     0.04,  -20.82,    0.00 /
      DATA B(24553), B(24554), B(24555) /    -0.01,  -21.24,    0.00 /
      DATA B(24892), B(24893), B(24894) /     1.05,  -22.40,    0.00 /
      DATA B(25231), B(25232), B(25233) /     0.94,  -22.23,    0.00 /
      DATA B(25570), B(25571), B(25572) /     0.79,  -22.08,    0.00 /
      DATA B(25909), B(25910), B(25911) /     0.62,  -21.95,    0.00 /
      DATA B(26248), B(26249), B(26250) /     0.46,  -21.84,    0.00 /
      DATA B(26587), B(26588), B(26589) /     0.31,  -21.75,    0.00 /
      DATA B(26926), B(26927), B(26928) /     0.18,  -21.67,    0.00 /
      DATA B(27265), B(27266), B(27267) /     0.05,  -21.61,    0.00 /
      DATA B(  148), B(  149), B(  150) /    24.13,  -44.88,    0.00 /
      DATA B(  487), B(  488), B(  489) /    24.13,  -44.80,    0.00 /
      DATA B(  826), B(  827), B(  828) /    24.12,  -44.71,    0.00 /
      DATA B( 1165), B( 1166), B( 1167) /    24.11,  -44.62,    0.00 /
      DATA B( 1504), B( 1505), B( 1506) /    24.10,  -44.52,    0.00 /
      DATA B( 1843), B( 1844), B( 1845) /    24.09,  -44.43,    0.00 /
      DATA B( 2182), B( 2183), B( 2184) /    24.08,  -44.33,    0.00 /
      DATA B( 2521), B( 2522), B( 2523) /    24.07,  -44.24,    0.00 /
      DATA B( 2860), B( 2861), B( 2862) /    24.06,  -44.14,    0.00 /
      DATA B( 3199), B( 3200), B( 3201) /    24.05,  -44.03,    0.00 /
      DATA B( 3538), B( 3539), B( 3540) /    24.04,  -43.92,    0.00 /
      DATA B( 3877), B( 3878), B( 3879) /    24.03,  -43.81,    0.00 /
      DATA B( 4216), B( 4217), B( 4218) /    24.01,  -43.69,    0.00 /
      DATA B( 4555), B( 4556), B( 4557) /    24.00,  -43.57,    0.00 /
      DATA B( 4894), B( 4895), B( 4896) /    23.99,  -43.44,    0.00 /
      DATA B( 5233), B( 5234), B( 5235) /    23.97,  -43.29,    0.00 /
      DATA B( 5572), B( 5573), B( 5574) /    23.96,  -43.14,    0.00 /
      DATA B( 5911), B( 5912), B( 5913) /    23.94,  -42.96,    0.00 /
      DATA B( 6250), B( 6251), B( 6252) /    23.92,  -42.77,    0.00 /
      DATA B( 6589), B( 6590), B( 6591) /    23.89,  -42.54,    0.00 /
      DATA B( 6928), B( 6929), B( 6930) /    23.86,  -42.27,    0.00 /
      DATA B( 7267), B( 7268), B( 7269) /    23.80,  -41.96,    0.00 /
      DATA B( 7606), B( 7607), B( 7608) /    23.70,  -41.60,    0.00 /
      DATA B( 7945), B( 7946), B( 7947) /    23.52,  -41.19,    0.00 /
      DATA B( 8284), B( 8285), B( 8286) /    23.23,  -40.77,    0.00 /
      DATA B( 8623), B( 8624), B( 8625) /    22.80,  -40.41,    0.00 /
      DATA B( 8962), B( 8963), B( 8964) /    22.31,  -40.16,    0.00 /
      DATA B( 9301), B( 9302), B( 9303) /    21.92,  -39.90,    0.00 /
      DATA B( 9640), B( 9641), B( 9642) /    21.63,  -39.66,    0.00 /
      DATA B( 9979), B( 9980), B( 9981) /    21.41,  -39.46,    0.00 /
      DATA B(10318), B(10319), B(10320) /    21.21,  -39.31,    0.00 /
      DATA B(10657), B(10658), B(10659) /    21.02,  -39.20,    0.00 /
      DATA B(10996), B(10997), B(10998) /    20.84,  -39.12,    0.00 /
      DATA B(11335), B(11336), B(11337) /    20.65,  -39.06,    0.00 /
      DATA B(11674), B(11675), B(11676) /    20.46,  -39.01,    0.00 /
      DATA B(12013), B(12014), B(12015) /    20.26,  -38.96,    0.00 /
      DATA B(12352), B(12353), B(12354) /    20.06,  -38.89,    0.00 /
      DATA B(12691), B(12692), B(12693) /    19.68,  -38.90,    0.00 /
      DATA B(13030), B(13031), B(13032) /    19.18,  -38.96,    0.00 /
      DATA B(13369), B(13370), B(13371) /    18.67,  -39.02,    0.00 /
      DATA B(13708), B(13709), B(13710) /    18.14,  -39.10,    0.00 /
      DATA B(14047), B(14048), B(14049) /    17.59,  -39.18,    0.00 /
      DATA B(14386), B(14387), B(14388) /    17.13,  -38.23,    0.00 /
      DATA B(14725), B(14726), B(14727) /    16.84,  -37.97,    0.00 /
      DATA B(15064), B(15065), B(15066) /    16.54,  -37.71,    0.00 /
      DATA B(15403), B(15404), B(15405) /    16.21,  -37.45,    0.00 /
      DATA B(15742), B(15743), B(15744) /    15.86,  -37.18,    0.00 /
      DATA B(16081), B(16082), B(16083) /    15.44,  -36.89,    0.00 /
      DATA B(16420), B(16421), B(16422) /    14.95,  -36.60,    0.00 /
      DATA B(16759), B(16760), B(16761) /    14.14,  -36.09,    0.00 /
      DATA B(17098), B(17099), B(17100) /    13.53,  -35.79,    0.00 /
      DATA B(17437), B(17438), B(17439) /    13.17,  -35.48,    0.00 /
      DATA B(17776), B(17777), B(17778) /    12.87,  -35.14,    0.00 /
      DATA B(18115), B(18116), B(18117) /    12.21,  -34.52,    0.00 /
      DATA B(18454), B(18455), B(18456) /    11.27,  -33.34,    0.00 /
      DATA B(18793), B(18794), B(18795) /    10.14,  -31.40,    0.00 /
      DATA B(19132), B(19133), B(19134) /     8.86,  -28.90,    0.00 /
      DATA B(19471), B(19472), B(19473) /     7.57,  -26.73,    0.00 /
      DATA B(19810), B(19811), B(19812) /     6.57,  -25.15,    0.00 /
      DATA B(20149), B(20150), B(20151) /     5.81,  -24.14,    0.00 /
      DATA B(20488), B(20489), B(20490) /     5.23,  -23.48,    0.00 /
      DATA B(20827), B(20828), B(20829) /     4.76,  -23.02,    0.00 /
      DATA B(21166), B(21167), B(21168) /     4.37,  -22.68,    0.00 /
      DATA B(21505), B(21506), B(21507) /     4.02,  -22.42,    0.00 /
      DATA B(21844), B(21845), B(21846) /     3.70,  -22.21,    0.00 /
      DATA B(22183), B(22184), B(22185) /     3.39,  -22.03,    0.00 /
      DATA B(22522), B(22523), B(22524) /     3.08,  -21.88,    0.00 /
      DATA B(22861), B(22862), B(22863) /     2.74,  -21.72,    0.00 /
      DATA B(23200), B(23201), B(23202) /     2.38,  -21.54,    0.00 /
      DATA B(23539), B(23540), B(23541) /     1.16,  -20.69,    0.00 /
      DATA B(23878), B(23879), B(23880) /     0.69,  -20.65,    0.00 /
      DATA B(24217), B(24218), B(24219) /     0.43,  -20.92,    0.00 /
      DATA B(24556), B(24557), B(24558) /     0.24,  -21.18,    0.00 /
      DATA B(24895), B(24896), B(24897) /    -0.11,  -21.21,    0.00 /
      DATA B(25234), B(25235), B(25236) /     1.10,  -22.21,    0.00 /
      DATA B(25573), B(25574), B(25575) /     0.89,  -22.05,    0.00 /
      DATA B(25912), B(25913), B(25914) /     0.70,  -21.91,    0.00 /
      DATA B(26251), B(26252), B(26253) /     0.53,  -21.79,    0.00 /
      DATA B(26590), B(26591), B(26592) /     0.37,  -21.69,    0.00 /
      DATA B(26929), B(26930), B(26931) /     0.24,  -21.61,    0.00 /
      DATA B(27268), B(27269), B(27270) /     0.11,  -21.55,    0.00 /
      DATA B(  151), B(  152), B(  153) /    24.10,  -44.84,    0.00 /
      DATA B(  490), B(  491), B(  492) /    24.10,  -44.75,    0.00 /
      DATA B(  829), B(  830), B(  831) /    24.09,  -44.66,    0.00 /
      DATA B( 1168), B( 1169), B( 1170) /    24.08,  -44.57,    0.00 /
      DATA B( 1507), B( 1508), B( 1509) /    24.07,  -44.48,    0.00 /
      DATA B( 1846), B( 1847), B( 1848) /    24.06,  -44.38,    0.00 /
      DATA B( 2185), B( 2186), B( 2187) /    24.05,  -44.28,    0.00 /
      DATA B( 2524), B( 2525), B( 2526) /    24.04,  -44.18,    0.00 /
      DATA B( 2863), B( 2864), B( 2865) /    24.03,  -44.07,    0.00 /
      DATA B( 3202), B( 3203), B( 3204) /    24.02,  -43.97,    0.00 /
      DATA B( 3541), B( 3542), B( 3543) /    24.01,  -43.85,    0.00 /
      DATA B( 3880), B( 3881), B( 3882) /    23.99,  -43.73,    0.00 /
      DATA B( 4219), B( 4220), B( 4221) /    23.98,  -43.61,    0.00 /
      DATA B( 4558), B( 4559), B( 4560) /    23.97,  -43.47,    0.00 /
      DATA B( 4897), B( 4898), B( 4899) /    23.95,  -43.33,    0.00 /
      DATA B( 5236), B( 5237), B( 5238) /    23.93,  -43.18,    0.00 /
      DATA B( 5575), B( 5576), B( 5577) /    23.91,  -43.00,    0.00 /
      DATA B( 5914), B( 5915), B( 5916) /    23.89,  -42.81,    0.00 /
      DATA B( 6253), B( 6254), B( 6255) /    23.87,  -42.59,    0.00 /
      DATA B( 6592), B( 6593), B( 6594) /    23.83,  -42.32,    0.00 /
      DATA B( 6931), B( 6932), B( 6933) /    23.77,  -42.01,    0.00 /
      DATA B( 7270), B( 7271), B( 7272) /    23.67,  -41.65,    0.00 /
      DATA B( 7609), B( 7610), B( 7611) /    23.50,  -41.25,    0.00 /
      DATA B( 7948), B( 7949), B( 7950) /    23.21,  -40.83,    0.00 /
      DATA B( 8287), B( 8288), B( 8289) /    22.78,  -40.47,    0.00 /
      DATA B( 8626), B( 8627), B( 8628) /    22.30,  -40.23,    0.00 /
      DATA B( 8965), B( 8966), B( 8967) /    21.91,  -39.97,    0.00 /
      DATA B( 9304), B( 9305), B( 9306) /    21.62,  -39.73,    0.00 /
      DATA B( 9643), B( 9644), B( 9645) /    21.40,  -39.53,    0.00 /
      DATA B( 9982), B( 9983), B( 9984) /    21.20,  -39.38,    0.00 /
      DATA B(10321), B(10322), B(10323) /    21.02,  -39.27,    0.00 /
      DATA B(10660), B(10661), B(10662) /    20.84,  -39.19,    0.00 /
      DATA B(10999), B(11000), B(11001) /    20.66,  -39.13,    0.00 /
      DATA B(11338), B(11339), B(11340) /    20.47,  -39.09,    0.00 /
      DATA B(11677), B(11678), B(11679) /    20.28,  -39.04,    0.00 /
      DATA B(12016), B(12017), B(12018) /    20.09,  -38.98,    0.00 /
      DATA B(12355), B(12356), B(12357) /    19.71,  -39.01,    0.00 /
      DATA B(12694), B(12695), B(12696) /    19.22,  -39.08,    0.00 /
      DATA B(13033), B(13034), B(13035) /    18.71,  -39.15,    0.00 /
      DATA B(13372), B(13373), B(13374) /    18.19,  -39.23,    0.00 /
      DATA B(13711), B(13712), B(13713) /    17.66,  -39.32,    0.00 /
      DATA B(14050), B(14051), B(14052) /    17.12,  -39.41,    0.00 /
      DATA B(14389), B(14390), B(14391) /    16.97,  -38.10,    0.00 /
      DATA B(14728), B(14729), B(14730) /    16.68,  -37.85,    0.00 /
      DATA B(15067), B(15068), B(15069) /    16.39,  -37.58,    0.00 /
      DATA B(15406), B(15407), B(15408) /    16.07,  -37.30,    0.00 /
      DATA B(15745), B(15746), B(15747) /    15.70,  -37.01,    0.00 /
      DATA B(16084), B(16085), B(16086) /    15.28,  -36.70,    0.00 /
      DATA B(16423), B(16424), B(16425) /    14.55,  -36.14,    0.00 /
      DATA B(16762), B(16763), B(16764) /    14.02,  -35.73,    0.00 /
      DATA B(17101), B(17102), B(17103) /    13.43,  -35.43,    0.00 /
      DATA B(17440), B(17441), B(17442) /    13.12,  -35.15,    0.00 /
      DATA B(17779), B(17780), B(17781) /    12.76,  -34.69,    0.00 /
      DATA B(18118), B(18119), B(18120) /    12.04,  -33.88,    0.00 /
      DATA B(18457), B(18458), B(18459) /    11.03,  -32.50,    0.00 /
      DATA B(18796), B(18797), B(18798) /     9.84,  -30.38,    0.00 /
      DATA B(19135), B(19136), B(19137) /     8.44,  -28.03,    0.00 /
      DATA B(19474), B(19475), B(19476) /     7.23,  -26.09,    0.00 /
      DATA B(19813), B(19814), B(19815) /     6.32,  -24.77,    0.00 /
      DATA B(20152), B(20153), B(20154) /     5.63,  -23.91,    0.00 /
      DATA B(20491), B(20492), B(20493) /     5.10,  -23.34,    0.00 /
      DATA B(20830), B(20831), B(20832) /     4.66,  -22.94,    0.00 /
      DATA B(21169), B(21170), B(21171) /     4.29,  -22.64,    0.00 /
      DATA B(21508), B(21509), B(21510) /     3.96,  -22.41,    0.00 /
      DATA B(21847), B(21848), B(21849) /     3.65,  -22.22,    0.00 /
      DATA B(22186), B(22187), B(22188) /     3.35,  -22.06,    0.00 /
      DATA B(22525), B(22526), B(22527) /     3.04,  -21.91,    0.00 /
      DATA B(22864), B(22865), B(22866) /     2.72,  -21.76,    0.00 /
      DATA B(23203), B(23204), B(23205) /     2.36,  -21.58,    0.00 /
      DATA B(23542), B(23543), B(23544) /     1.98,  -21.33,    0.00 /
      DATA B(23881), B(23882), B(23883) /     0.89,  -20.65,    0.00 /
      DATA B(24220), B(24221), B(24222) /     0.70,  -20.90,    0.00 /
      DATA B(24559), B(24560), B(24561) /     0.46,  -21.10,    0.00 /
      DATA B(24898), B(24899), B(24900) /     0.10,  -21.08,    0.00 /
      DATA B(25237), B(25238), B(25239) /    -0.36,  -20.88,    0.00 /
      DATA B(25576), B(25577), B(25578) /     1.03,  -22.01,    0.00 /
      DATA B(25915), B(25916), B(25917) /     0.80,  -21.86,    0.00 /
      DATA B(26254), B(26255), B(26256) /     0.60,  -21.73,    0.00 /
      DATA B(26593), B(26594), B(26595) /     0.43,  -21.63,    0.00 /
      DATA B(26932), B(26933), B(26934) /     0.29,  -21.55,    0.00 /
      DATA B(27271), B(27272), B(27273) /     0.17,  -21.48,    0.00 /
      DATA B(  154), B(  155), B(  156) /    24.07,  -44.80,    0.00 /
      DATA B(  493), B(  494), B(  495) /    24.07,  -44.71,    0.00 /
      DATA B(  832), B(  833), B(  834) /    24.06,  -44.62,    0.00 /
      DATA B( 1171), B( 1172), B( 1173) /    24.05,  -44.52,    0.00 /
      DATA B( 1510), B( 1511), B( 1512) /    24.04,  -44.43,    0.00 /
      DATA B( 1849), B( 1850), B( 1851) /    24.03,  -44.33,    0.00 /
      DATA B( 2188), B( 2189), B( 2190) /    24.02,  -44.22,    0.00 /
      DATA B( 2527), B( 2528), B( 2529) /    24.01,  -44.12,    0.00 /
      DATA B( 2866), B( 2867), B( 2868) /    24.00,  -44.01,    0.00 /
      DATA B( 3205), B( 3206), B( 3207) /    23.99,  -43.89,    0.00 /
      DATA B( 3544), B( 3545), B( 3546) /    23.97,  -43.77,    0.00 /
      DATA B( 3883), B( 3884), B( 3885) /    23.96,  -43.65,    0.00 /
      DATA B( 4222), B( 4223), B( 4224) /    23.94,  -43.51,    0.00 /
      DATA B( 4561), B( 4562), B( 4563) /    23.93,  -43.37,    0.00 /
      DATA B( 4900), B( 4901), B( 4902) /    23.91,  -43.21,    0.00 /
      DATA B( 5239), B( 5240), B( 5241) /    23.89,  -43.04,    0.00 /
      DATA B( 5578), B( 5579), B( 5580) /    23.87,  -42.85,    0.00 /
      DATA B( 5917), B( 5918), B( 5919) /    23.84,  -42.63,    0.00 /
      DATA B( 6256), B( 6257), B( 6258) /    23.80,  -42.37,    0.00 /
      DATA B( 6595), B( 6596), B( 6597) /    23.75,  -42.06,    0.00 /
      DATA B( 6934), B( 6935), B( 6936) /    23.65,  -41.71,    0.00 /
      DATA B( 7273), B( 7274), B( 7275) /    23.48,  -41.30,    0.00 /
      DATA B( 7612), B( 7613), B( 7614) /    23.19,  -40.88,    0.00 /
      DATA B( 7951), B( 7952), B( 7953) /    22.77,  -40.54,    0.00 /
      DATA B( 8290), B( 8291), B( 8292) /    22.28,  -40.29,    0.00 /
      DATA B( 8629), B( 8630), B( 8631) /    21.90,  -40.04,    0.00 /
      DATA B( 8968), B( 8969), B( 8970) /    21.61,  -39.80,    0.00 /
      DATA B( 9307), B( 9308), B( 9309) /    21.39,  -39.60,    0.00 /
      DATA B( 9646), B( 9647), B( 9648) /    21.20,  -39.45,    0.00 /
      DATA B( 9985), B( 9986), B( 9987) /    21.02,  -39.34,    0.00 /
      DATA B(10324), B(10325), B(10326) /    20.84,  -39.26,    0.00 /
      DATA B(10663), B(10664), B(10665) /    20.66,  -39.21,    0.00 /
      DATA B(11002), B(11003), B(11004) /    20.48,  -39.17,    0.00 /
      DATA B(11341), B(11342), B(11343) /    20.30,  -39.13,    0.00 /
      DATA B(11680), B(11681), B(11682) /    20.11,  -39.07,    0.00 /
      DATA B(12019), B(12020), B(12021) /    19.75,  -39.09,    0.00 /
      DATA B(12358), B(12359), B(12360) /    19.27,  -39.18,    0.00 /
      DATA B(12697), B(12698), B(12699) /    18.77,  -39.27,    0.00 /
      DATA B(13036), B(13037), B(13038) /    18.25,  -39.36,    0.00 /
      DATA B(13375), B(13376), B(13377) /    17.73,  -39.45,    0.00 /
      DATA B(13714), B(13715), B(13716) /    17.18,  -39.55,    0.00 /
      DATA B(14053), B(14054), B(14055) /    17.09,  -38.23,    0.00 /
      DATA B(14392), B(14393), B(14394) /    16.82,  -37.98,    0.00 /
      DATA B(14731), B(14732), B(14733) /    16.54,  -37.71,    0.00 /
      DATA B(15070), B(15071), B(15072) /    16.25,  -37.43,    0.00 /
      DATA B(15409), B(15410), B(15411) /    15.92,  -37.14,    0.00 /
      DATA B(15748), B(15749), B(15750) /    15.54,  -36.83,    0.00 /
      DATA B(16087), B(16088), B(16089) /    15.12,  -36.49,    0.00 /
      DATA B(16426), B(16427), B(16428) /    14.42,  -35.82,    0.00 /
      DATA B(16765), B(16766), B(16767) /    13.91,  -35.37,    0.00 /
      DATA B(17104), B(17105), B(17106) /    13.37,  -35.24,    0.00 /
      DATA B(17443), B(17444), B(17445) /    13.03,  -34.78,    0.00 /
      DATA B(17782), B(17783), B(17784) /    12.65,  -34.18,    0.00 /
      DATA B(18121), B(18122), B(18123) /    11.84,  -33.13,    0.00 /
      DATA B(18460), B(18461), B(18462) /    10.71,  -31.55,    0.00 /
      DATA B(18799), B(18800), B(18801) /     9.44,  -29.33,    0.00 /
      DATA B(19138), B(19139), B(19140) /     8.05,  -27.22,    0.00 /
      DATA B(19477), B(19478), B(19479) /     6.93,  -25.56,    0.00 /
      DATA B(19816), B(19817), B(19818) /     6.10,  -24.45,    0.00 /
      DATA B(20155), B(20156), B(20157) /     5.47,  -23.72,    0.00 /
      DATA B(20494), B(20495), B(20496) /     4.98,  -23.23,    0.00 /
      DATA B(20833), B(20834), B(20835) /     4.57,  -22.88,    0.00 /
      DATA B(21172), B(21173), B(21174) /     4.21,  -22.61,    0.00 /
      DATA B(21511), B(21512), B(21513) /     3.89,  -22.40,    0.00 /
      DATA B(21850), B(21851), B(21852) /     3.59,  -22.23,    0.00 /
      DATA B(22189), B(22190), B(22191) /     3.30,  -22.08,    0.00 /
      DATA B(22528), B(22529), B(22530) /     3.00,  -21.94,    0.00 /
      DATA B(22867), B(22868), B(22869) /     2.68,  -21.79,    0.00 /
      DATA B(23206), B(23207), B(23208) /     2.33,  -21.62,    0.00 /
      DATA B(23545), B(23546), B(23547) /     1.94,  -21.40,    0.00 /
      DATA B(23884), B(23885), B(23886) /     1.48,  -20.99,    0.00 /
      DATA B(24223), B(24224), B(24225) /     0.84,  -20.82,    0.00 /
      DATA B(24562), B(24563), B(24564) /     0.62,  -20.98,    0.00 /
      DATA B(24901), B(24902), B(24903) /     0.28,  -20.93,    0.00 /
      DATA B(25240), B(25241), B(25242) /    -0.21,  -20.74,    0.00 /
      DATA B(25579), B(25580), B(25581) /    -0.73,  -20.51,    0.00 /
      DATA B(25918), B(25919), B(25920) /     0.91,  -21.79,    0.00 /
      DATA B(26257), B(26258), B(26259) /     0.68,  -21.67,    0.00 /
      DATA B(26596), B(26597), B(26598) /     0.49,  -21.56,    0.00 /
      DATA B(26935), B(26936), B(26937) /     0.34,  -21.48,    0.00 /
      DATA B(27274), B(27275), B(27276) /     0.21,  -21.42,    0.00 /
      DATA B(  157), B(  158), B(  159) /    24.04,  -44.76,    0.00 /
      DATA B(  496), B(  497), B(  498) /    24.04,  -44.66,    0.00 /
      DATA B(  835), B(  836), B(  837) /    24.03,  -44.57,    0.00 /
      DATA B( 1174), B( 1175), B( 1176) /    24.02,  -44.47,    0.00 /
      DATA B( 1513), B( 1514), B( 1515) /    24.01,  -44.37,    0.00 /
      DATA B( 1852), B( 1853), B( 1854) /    24.00,  -44.27,    0.00 /
      DATA B( 2191), B( 2192), B( 2193) /    23.99,  -44.16,    0.00 /
      DATA B( 2530), B( 2531), B( 2532) /    23.98,  -44.05,    0.00 /
      DATA B( 2869), B( 2870), B( 2871) /    23.97,  -43.93,    0.00 /
      DATA B( 3208), B( 3209), B( 3210) /    23.95,  -43.81,    0.00 /
      DATA B( 3547), B( 3548), B( 3549) /    23.94,  -43.68,    0.00 /
      DATA B( 3886), B( 3887), B( 3888) /    23.93,  -43.55,    0.00 /
      DATA B( 4225), B( 4226), B( 4227) /    23.91,  -43.40,    0.00 /
      DATA B( 4564), B( 4565), B( 4566) /    23.89,  -43.24,    0.00 /
      DATA B( 4903), B( 4904), B( 4905) /    23.87,  -43.07,    0.00 /
      DATA B( 5242), B( 5243), B( 5244) /    23.85,  -42.88,    0.00 /
      DATA B( 5581), B( 5582), B( 5583) /    23.81,  -42.66,    0.00 /
      DATA B( 5920), B( 5921), B( 5922) /    23.78,  -42.41,    0.00 /
      DATA B( 6259), B( 6260), B( 6261) /    23.72,  -42.11,    0.00 /
      DATA B( 6598), B( 6599), B( 6600) /    23.62,  -41.76,    0.00 /
      DATA B( 6937), B( 6938), B( 6939) /    23.45,  -41.36,    0.00 /
      DATA B( 7276), B( 7277), B( 7278) /    23.17,  -40.94,    0.00 /
      DATA B( 7615), B( 7616), B( 7617) /    22.75,  -40.61,    0.00 /
      DATA B( 7954), B( 7955), B( 7956) /    22.26,  -40.36,    0.00 /
      DATA B( 8293), B( 8294), B( 8295) /    21.88,  -40.10,    0.00 /
      DATA B( 8632), B( 8633), B( 8634) /    21.60,  -39.87,    0.00 /
      DATA B( 8971), B( 8972), B( 8973) /    21.38,  -39.67,    0.00 /
      DATA B( 9310), B( 9311), B( 9312) /    21.19,  -39.52,    0.00 /
      DATA B( 9649), B( 9650), B( 9651) /    21.01,  -39.41,    0.00 /
      DATA B( 9988), B( 9989), B( 9990) /    20.84,  -39.34,    0.00 /
      DATA B(10327), B(10328), B(10329) /    20.67,  -39.29,    0.00 /
      DATA B(10666), B(10667), B(10668) /    20.49,  -39.25,    0.00 /
      DATA B(11005), B(11006), B(11007) /    20.31,  -39.21,    0.00 /
      DATA B(11344), B(11345), B(11346) /    20.13,  -39.16,    0.00 /
      DATA B(11683), B(11684), B(11685) /    19.80,  -39.18,    0.00 /
      DATA B(12022), B(12023), B(12024) /    19.32,  -39.28,    0.00 /
      DATA B(12361), B(12362), B(12363) /    18.82,  -39.37,    0.00 /
      DATA B(12700), B(12701), B(12702) /    18.32,  -39.47,    0.00 /
      DATA B(13039), B(13040), B(13041) /    17.80,  -39.58,    0.00 /
      DATA B(13378), B(13379), B(13380) /    17.26,  -39.68,    0.00 /
      DATA B(13717), B(13718), B(13719) /    17.22,  -38.35,    0.00 /
      DATA B(14056), B(14057), B(14058) /    16.96,  -38.10,    0.00 /
      DATA B(14395), B(14396), B(14397) /    16.69,  -37.84,    0.00 /
      DATA B(14734), B(14735), B(14736) /    16.42,  -37.56,    0.00 /
      DATA B(15073), B(15074), B(15075) /    16.11,  -37.28,    0.00 /
      DATA B(15412), B(15413), B(15414) /    15.77,  -36.97,    0.00 /
      DATA B(15751), B(15752), B(15753) /    15.37,  -36.63,    0.00 /
      DATA B(16090), B(16091), B(16092) /    14.71,  -35.98,    0.00 /
      DATA B(16429), B(16430), B(16431) /    14.26,  -35.51,    0.00 /
      DATA B(16768), B(16769), B(16770) /    13.74,  -35.02,    0.00 /
      DATA B(17107), B(17108), B(17109) /    13.18,  -34.53,    0.00 /
      DATA B(17446), B(17447), B(17448) /    12.92,  -34.38,    0.00 /
      DATA B(17785), B(17786), B(17787) /    12.54,  -33.57,    0.00 /
      DATA B(18124), B(18125), B(18126) /    11.62,  -32.20,    0.00 /
      DATA B(18463), B(18464), B(18465) /    10.34,  -30.47,    0.00 /
      DATA B(18802), B(18803), B(18804) /     8.97,  -28.42,    0.00 /
      DATA B(19141), B(19142), B(19143) /     7.68,  -26.52,    0.00 /
      DATA B(19480), B(19481), B(19482) /     6.66,  -25.11,    0.00 /
      DATA B(19819), B(19820), B(19821) /     5.90,  -24.18,    0.00 /
      DATA B(20158), B(20159), B(20160) /     5.32,  -23.56,    0.00 /
      DATA B(20497), B(20498), B(20499) /     4.86,  -23.14,    0.00 /
      DATA B(20836), B(20837), B(20838) /     4.47,  -22.83,    0.00 /
      DATA B(21175), B(21176), B(21177) /     4.13,  -22.59,    0.00 /
      DATA B(21514), B(21515), B(21516) /     3.82,  -22.40,    0.00 /
      DATA B(21853), B(21854), B(21855) /     3.53,  -22.24,    0.00 /
      DATA B(22192), B(22193), B(22194) /     3.24,  -22.10,    0.00 /
      DATA B(22531), B(22532), B(22533) /     2.95,  -21.96,    0.00 /
      DATA B(22870), B(22871), B(22872) /     2.64,  -21.82,    0.00 /
      DATA B(23209), B(23210), B(23211) /     2.29,  -21.65,    0.00 /
      DATA B(23548), B(23549), B(23550) /     1.89,  -21.43,    0.00 /
      DATA B(23887), B(23888), B(23889) /     1.46,  -21.14,    0.00 /
      DATA B(24226), B(24227), B(24228) /     1.14,  -20.83,    0.00 /
      DATA B(24565), B(24566), B(24567) /     0.69,  -20.80,    0.00 /
      DATA B(24904), B(24905), B(24906) /     0.38,  -20.75,    0.00 /
      DATA B(25243), B(25244), B(25245) /    -0.10,  -20.57,    0.00 /
      DATA B(25582), B(25583), B(25584) /    -0.65,  -20.35,    0.00 /
      DATA B(25921), B(25922), B(25923) /    -1.16,  -20.14,    0.00 /
      DATA B(26260), B(26261), B(26262) /    -1.61,  -19.95,    0.00 /
      DATA B(26599), B(26600), B(26601) /    -2.00,  -19.79,    0.00 /
      DATA B(26938), B(26939), B(26940) /    -2.36,  -19.64,    0.00 /
      DATA B(27277), B(27278), B(27279) /    -2.68,  -19.52,    0.00 /
      DATA B(  160), B(  161), B(  162) /    24.01,  -44.71,    0.00 /
      DATA B(  499), B(  500), B(  501) /    24.01,  -44.61,    0.00 /
      DATA B(  838), B(  839), B(  840) /    24.00,  -44.52,    0.00 /
      DATA B( 1177), B( 1178), B( 1179) /    23.99,  -44.41,    0.00 /
      DATA B( 1516), B( 1517), B( 1518) /    23.98,  -44.31,    0.00 /
      DATA B( 1855), B( 1856), B( 1857) /    23.97,  -44.20,    0.00 /
      DATA B( 2194), B( 2195), B( 2196) /    23.96,  -44.09,    0.00 /
      DATA B( 2533), B( 2534), B( 2535) /    23.95,  -43.97,    0.00 /
      DATA B( 2872), B( 2873), B( 2874) /    23.94,  -43.85,    0.00 /
      DATA B( 3211), B( 3212), B( 3213) /    23.92,  -43.72,    0.00 /
      DATA B( 3550), B( 3551), B( 3552) /    23.91,  -43.58,    0.00 /
      DATA B( 3889), B( 3890), B( 3891) /    23.89,  -43.43,    0.00 /
      DATA B( 4228), B( 4229), B( 4230) /    23.87,  -43.27,    0.00 /
      DATA B( 4567), B( 4568), B( 4569) /    23.85,  -43.10,    0.00 /
      DATA B( 4906), B( 4907), B( 4908) /    23.83,  -42.90,    0.00 /
      DATA B( 5245), B( 5246), B( 5247) /    23.79,  -42.68,    0.00 /
      DATA B( 5584), B( 5585), B( 5586) /    23.75,  -42.43,    0.00 /
      DATA B( 5923), B( 5924), B( 5925) /    23.69,  -42.14,    0.00 /
      DATA B( 6262), B( 6263), B( 6264) /    23.59,  -41.80,    0.00 /
      DATA B( 6601), B( 6602), B( 6603) /    23.42,  -41.41,    0.00 /
      DATA B( 6940), B( 6941), B( 6942) /    23.14,  -40.99,    0.00 /
      DATA B( 7279), B( 7280), B( 7281) /    22.73,  -40.66,    0.00 /
      DATA B( 7618), B( 7619), B( 7620) /    22.25,  -40.42,    0.00 /
      DATA B( 7957), B( 7958), B( 7959) /    21.87,  -40.17,    0.00 /
      DATA B( 8296), B( 8297), B( 8298) /    21.59,  -39.93,    0.00 /
      DATA B( 8635), B( 8636), B( 8637) /    21.37,  -39.74,    0.00 /
      DATA B( 8974), B( 8975), B( 8976) /    21.18,  -39.59,    0.00 /
      DATA B( 9313), B( 9314), B( 9315) /    21.01,  -39.48,    0.00 /
      DATA B( 9652), B( 9653), B( 9654) /    20.84,  -39.41,    0.00 /
      DATA B( 9991), B( 9992), B( 9993) /    20.67,  -39.36,    0.00 /
      DATA B(10330), B(10331), B(10332) /    20.49,  -39.33,    0.00 /
      DATA B(10669), B(10670), B(10671) /    20.32,  -39.30,    0.00 /
      DATA B(11008), B(11009), B(11010) /    20.15,  -39.26,    0.00 /
      DATA B(11347), B(11348), B(11349) /    19.83,  -39.28,    0.00 /
      DATA B(11686), B(11687), B(11688) /    19.36,  -39.37,    0.00 /
      DATA B(12025), B(12026), B(12027) /    18.88,  -39.47,    0.00 /
      DATA B(12364), B(12365), B(12366) /    18.38,  -39.58,    0.00 /
      DATA B(12703), B(12704), B(12705) /    17.86,  -39.69,    0.00 /
      DATA B(13042), B(13043), B(13044) /    17.34,  -39.81,    0.00 /
      DATA B(13381), B(13382), B(13383) /    17.35,  -38.45,    0.00 /
      DATA B(13720), B(13721), B(13722) /    17.10,  -38.21,    0.00 /
      DATA B(14059), B(14060), B(14061) /    16.84,  -37.96,    0.00 /
      DATA B(14398), B(14399), B(14400) /    16.58,  -37.69,    0.00 /
      DATA B(14737), B(14738), B(14739) /    16.29,  -37.40,    0.00 /
      DATA B(15076), B(15077), B(15078) /    15.97,  -37.10,    0.00 /
      DATA B(15415), B(15416), B(15417) /    15.60,  -36.78,    0.00 /
      DATA B(15754), B(15755), B(15756) /    14.96,  -36.15,    0.00 /
      DATA B(16093), B(16094), B(16095) /    14.54,  -35.69,    0.00 /
      DATA B(16432), B(16433), B(16434) /    14.07,  -35.20,    0.00 /
      DATA B(16771), B(16772), B(16773) /    13.56,  -34.66,    0.00 /
      DATA B(17110), B(17111), B(17112) /    13.02,  -34.10,    0.00 /
      DATA B(17449), B(17450), B(17451) /    12.80,  -33.98,    0.00 /
      DATA B(17788), B(17789), B(17790) /    12.43,  -32.83,    0.00 /
      DATA B(18127), B(18128), B(18129) /    11.38,  -30.93,    0.00 /
      DATA B(18466), B(18467), B(18468) /     9.92,  -29.36,    0.00 /
      DATA B(18805), B(18806), B(18807) /     8.59,  -27.62,    0.00 /
      DATA B(19144), B(19145), B(19146) /     7.37,  -25.92,    0.00 /
      DATA B(19483), B(19484), B(19485) /     6.42,  -24.72,    0.00 /
      DATA B(19822), B(19823), B(19824) /     5.71,  -23.94,    0.00 /
      DATA B(20161), B(20162), B(20163) /     5.17,  -23.42,    0.00 /
      DATA B(20500), B(20501), B(20502) /     4.73,  -23.05,    0.00 /
      DATA B(20839), B(20840), B(20841) /     4.37,  -22.78,    0.00 /
      DATA B(21178), B(21179), B(21180) /     4.04,  -22.57,    0.00 /
      DATA B(21517), B(21518), B(21519) /     3.74,  -22.39,    0.00 /
      DATA B(21856), B(21857), B(21858) /     3.46,  -22.24,    0.00 /
      DATA B(22195), B(22196), B(22197) /     3.17,  -22.11,    0.00 /
      DATA B(22534), B(22535), B(22536) /     2.89,  -21.97,    0.00 /
      DATA B(22873), B(22874), B(22875) /     2.58,  -21.83,    0.00 /
      DATA B(23212), B(23213), B(23214) /     2.24,  -21.66,    0.00 /
      DATA B(23551), B(23552), B(23553) /     1.86,  -21.45,    0.00 /
      DATA B(23890), B(23891), B(23892) /     1.43,  -21.17,    0.00 /
      DATA B(24229), B(24230), B(24231) /     0.98,  -20.78,    0.00 /
      DATA B(24568), B(24569), B(24570) /     0.64,  -20.65,    0.00 /
      DATA B(24907), B(24908), B(24909) /     0.38,  -20.54,    0.00 /
      DATA B(25246), B(25247), B(25248) /    -0.05,  -20.38,    0.00 /
      DATA B(25585), B(25586), B(25587) /    -0.60,  -20.17,    0.00 /
      DATA B(25924), B(25925), B(25926) /    -1.14,  -19.96,    0.00 /
      DATA B(26263), B(26264), B(26265) /    -1.62,  -19.78,    0.00 /
      DATA B(26602), B(26603), B(26604) /    -2.03,  -19.61,    0.00 /
      DATA B(26941), B(26942), B(26943) /    -2.40,  -19.47,    0.00 /
      DATA B(27280), B(27281), B(27282) /    -2.74,  -19.35,    0.00 /
      DATA B(  163), B(  164), B(  165) /    23.99,  -44.66,    0.00 /
      DATA B(  502), B(  503), B(  504) /    23.98,  -44.56,    0.00 /
      DATA B(  841), B(  842), B(  843) /    23.97,  -44.46,    0.00 /
      DATA B( 1180), B( 1181), B( 1182) /    23.96,  -44.35,    0.00 /
      DATA B( 1519), B( 1520), B( 1521) /    23.95,  -44.24,    0.00 /
      DATA B( 1858), B( 1859), B( 1860) /    23.94,  -44.13,    0.00 /
      DATA B( 2197), B( 2198), B( 2199) /    23.93,  -44.01,    0.00 /
      DATA B( 2536), B( 2537), B( 2538) /    23.92,  -43.89,    0.00 /
      DATA B( 2875), B( 2876), B( 2877) /    23.91,  -43.76,    0.00 /
      DATA B( 3214), B( 3215), B( 3216) /    23.89,  -43.61,    0.00 /
      DATA B( 3553), B( 3554), B( 3555) /    23.88,  -43.46,    0.00 /
      DATA B( 3892), B( 3893), B( 3894) /    23.86,  -43.30,    0.00 /
      DATA B( 4231), B( 4232), B( 4233) /    23.84,  -43.12,    0.00 /
      DATA B( 4570), B( 4571), B( 4572) /    23.81,  -42.92,    0.00 /
      DATA B( 4909), B( 4910), B( 4911) /    23.78,  -42.70,    0.00 /
      DATA B( 5248), B( 5249), B( 5250) /    23.73,  -42.44,    0.00 /
      DATA B( 5587), B( 5588), B( 5589) /    23.66,  -42.15,    0.00 /
      DATA B( 5926), B( 5927), B( 5928) /    23.56,  -41.82,    0.00 /
      DATA B( 6265), B( 6266), B( 6267) /    23.38,  -41.45,    0.00 /
      DATA B( 6604), B( 6605), B( 6606) /    23.11,  -41.04,    0.00 /
      DATA B( 6943), B( 6944), B( 6945) /    22.71,  -40.71,    0.00 /
      DATA B( 7282), B( 7283), B( 7284) /    22.22,  -40.49,    0.00 /
      DATA B( 7621), B( 7622), B( 7623) /    21.85,  -40.24,    0.00 /
      DATA B( 7960), B( 7961), B( 7962) /    21.57,  -40.00,    0.00 /
      DATA B( 8299), B( 8300), B( 8301) /    21.36,  -39.81,    0.00 /
      DATA B( 8638), B( 8639), B( 8640) /    21.18,  -39.66,    0.00 /
      DATA B( 8977), B( 8978), B( 8979) /    21.00,  -39.55,    0.00 /
      DATA B( 9316), B( 9317), B( 9318) /    20.84,  -39.48,    0.00 /
      DATA B( 9655), B( 9656), B( 9657) /    20.67,  -39.44,    0.00 /
      DATA B( 9994), B( 9995), B( 9996) /    20.49,  -39.41,    0.00 /
      DATA B(10333), B(10334), B(10335) /    20.32,  -39.38,    0.00 /
      DATA B(10672), B(10673), B(10674) /    20.16,  -39.35,    0.00 /
      DATA B(11011), B(11012), B(11013) /    19.87,  -39.37,    0.00 /
      DATA B(11350), B(11351), B(11352) /    19.41,  -39.47,    0.00 /
      DATA B(11689), B(11690), B(11691) /    18.93,  -39.57,    0.00 /
      DATA B(12028), B(12029), B(12030) /    18.44,  -39.68,    0.00 /
      DATA B(12367), B(12368), B(12369) /    17.93,  -39.80,    0.00 /
      DATA B(12706), B(12707), B(12708) /    17.41,  -39.92,    0.00 /
      DATA B(13045), B(13046), B(13047) /    17.49,  -38.54,    0.00 /
      DATA B(13384), B(13385), B(13386) /    17.24,  -38.32,    0.00 /
      DATA B(13723), B(13724), B(13725) /    17.00,  -38.07,    0.00 /
      DATA B(14062), B(14063), B(14064) /    16.74,  -37.80,    0.00 /
      DATA B(14401), B(14402), B(14403) /    16.47,  -37.52,    0.00 /
      DATA B(14740), B(14741), B(14742) /    16.17,  -37.23,    0.00 /
      DATA B(15079), B(15080), B(15081) /    15.83,  -36.91,    0.00 /
      DATA B(15418), B(15419), B(15420) /    15.44,  -36.56,    0.00 /
      DATA B(15757), B(15758), B(15759) /    14.80,  -35.85,    0.00 /
      DATA B(16096), B(16097), B(16098) /    14.36,  -35.39,    0.00 /
      DATA B(16435), B(16436), B(16437) /    13.87,  -34.88,    0.00 /
      DATA B(16774), B(16775), B(16776) /    13.32,  -34.30,    0.00 /
      DATA B(17113), B(17114), B(17115) /    12.74,  -33.59,    0.00 /
      DATA B(17452), B(17453), B(17454) /    12.45,  -33.47,    0.00 /
      DATA B(17791), B(17792), B(17793) /    12.03,  -32.01,    0.00 /
      DATA B(18130), B(18131), B(18132) /    11.05,  -29.28,    0.00 /
      DATA B(18469), B(18470), B(18471) /     9.84,  -28.73,    0.00 /
      DATA B(18808), B(18809), B(18810) /     8.39,  -26.92,    0.00 /
      DATA B(19147), B(19148), B(19149) /     7.09,  -25.39,    0.00 /
      DATA B(19486), B(19487), B(19488) /     6.17,  -24.39,    0.00 /
      DATA B(19825), B(19826), B(19827) /     5.51,  -23.74,    0.00 /
      DATA B(20164), B(20165), B(20166) /     5.01,  -23.30,    0.00 /
      DATA B(20503), B(20504), B(20505) /     4.60,  -22.98,    0.00 /
      DATA B(20842), B(20843), B(20844) /     4.26,  -22.74,    0.00 /
      DATA B(21181), B(21182), B(21183) /     3.94,  -22.54,    0.00 /
      DATA B(21520), B(21521), B(21522) /     3.65,  -22.38,    0.00 /
      DATA B(21859), B(21860), B(21861) /     3.38,  -22.24,    0.00 /
      DATA B(22198), B(22199), B(22200) /     3.10,  -22.11,    0.00 /
      DATA B(22537), B(22538), B(22539) /     2.81,  -21.98,    0.00 /
      DATA B(22876), B(22877), B(22878) /     2.51,  -21.84,    0.00 /
      DATA B(23215), B(23216), B(23217) /     2.18,  -21.67,    0.00 /
      DATA B(23554), B(23555), B(23556) /     1.81,  -21.46,    0.00 /
      DATA B(23893), B(23894), B(23895) /     1.40,  -21.20,    0.00 /
      DATA B(24232), B(24233), B(24234) /     0.96,  -20.84,    0.00 /
      DATA B(24571), B(24572), B(24573) /     0.57,  -20.48,    0.00 /
      DATA B(24910), B(24911), B(24912) /     0.30,  -20.31,    0.00 /
      DATA B(25249), B(25250), B(25251) /    -0.05,  -20.17,    0.00 /
      DATA B(25588), B(25589), B(25590) /    -0.59,  -19.97,    0.00 /
      DATA B(25927), B(25928), B(25929) /    -1.15,  -19.77,    0.00 /
      DATA B(26266), B(26267), B(26268) /    -1.65,  -19.59,    0.00 /
      DATA B(26605), B(26606), B(26607) /    -2.09,  -19.43,    0.00 /
      DATA B(26944), B(26945), B(26946) /    -2.47,  -19.28,    0.00 /
      DATA B(27283), B(27284), B(27285) /    -2.83,  -19.15,    0.00 /
      DATA B(  166), B(  167), B(  168) /    23.96,  -44.61,    0.00 /
      DATA B(  505), B(  506), B(  507) /    23.95,  -44.50,    0.00 /
      DATA B(  844), B(  845), B(  846) /    23.94,  -44.40,    0.00 /
      DATA B( 1183), B( 1184), B( 1185) /    23.93,  -44.29,    0.00 /
      DATA B( 1522), B( 1523), B( 1524) /    23.92,  -44.17,    0.00 /
      DATA B( 1861), B( 1862), B( 1863) /    23.91,  -44.05,    0.00 /
      DATA B( 2200), B( 2201), B( 2202) /    23.90,  -43.92,    0.00 /
      DATA B( 2539), B( 2540), B( 2541) /    23.89,  -43.79,    0.00 /
      DATA B( 2878), B( 2879), B( 2880) /    23.88,  -43.65,    0.00 /
      DATA B( 3217), B( 3218), B( 3219) /    23.86,  -43.49,    0.00 /
      DATA B( 3556), B( 3557), B( 3558) /    23.84,  -43.33,    0.00 /
      DATA B( 3895), B( 3896), B( 3897) /    23.82,  -43.14,    0.00 /
      DATA B( 4234), B( 4235), B( 4236) /    23.80,  -42.94,    0.00 /
      DATA B( 4573), B( 4574), B( 4575) /    23.76,  -42.71,    0.00 /
      DATA B( 4912), B( 4913), B( 4914) /    23.71,  -42.45,    0.00 /
      DATA B( 5251), B( 5252), B( 5253) /    23.64,  -42.15,    0.00 /
      DATA B( 5590), B( 5591), B( 5592) /    23.53,  -41.82,    0.00 /
      DATA B( 5929), B( 5930), B( 5931) /    23.35,  -41.46,    0.00 /
      DATA B( 6268), B( 6269), B( 6270) /    23.07,  -41.08,    0.00 /
      DATA B( 6607), B( 6608), B( 6609) /    22.67,  -40.77,    0.00 /
      DATA B( 6946), B( 6947), B( 6948) /    22.20,  -40.55,    0.00 /
      DATA B( 7285), B( 7286), B( 7287) /    21.83,  -40.30,    0.00 /
      DATA B( 7624), B( 7625), B( 7626) /    21.56,  -40.07,    0.00 /
      DATA B( 7963), B( 7964), B( 7965) /    21.35,  -39.88,    0.00 /
      DATA B( 8302), B( 8303), B( 8304) /    21.17,  -39.73,    0.00 /
      DATA B( 8641), B( 8642), B( 8643) /    21.00,  -39.62,    0.00 /
      DATA B( 8980), B( 8981), B( 8982) /    20.83,  -39.55,    0.00 /
      DATA B( 9319), B( 9320), B( 9321) /    20.66,  -39.51,    0.00 /
      DATA B( 9658), B( 9659), B( 9660) /    20.50,  -39.48,    0.00 /
      DATA B( 9997), B( 9998), B( 9999) /    20.33,  -39.46,    0.00 /
      DATA B(10336), B(10337), B(10338) /    20.17,  -39.43,    0.00 /
      DATA B(10675), B(10676), B(10677) /    19.90,  -39.47,    0.00 /
      DATA B(11014), B(11015), B(11016) /    19.44,  -39.56,    0.00 /
      DATA B(11353), B(11354), B(11355) /    18.97,  -39.67,    0.00 /
      DATA B(11692), B(11693), B(11694) /    18.49,  -39.79,    0.00 /
      DATA B(12031), B(12032), B(12033) /    17.99,  -39.91,    0.00 /
      DATA B(12370), B(12371), B(12372) /    17.48,  -40.03,    0.00 /
      DATA B(12709), B(12710), B(12711) /    17.62,  -38.63,    0.00 /
      DATA B(13048), B(13049), B(13050) /    17.38,  -38.41,    0.00 /
      DATA B(13387), B(13388), B(13389) /    17.14,  -38.17,    0.00 /
      DATA B(13726), B(13727), B(13728) /    16.90,  -37.91,    0.00 /
      DATA B(14065), B(14066), B(14067) /    16.65,  -37.64,    0.00 /
      DATA B(14404), B(14405), B(14406) /    16.36,  -37.35,    0.00 /
      DATA B(14743), B(14744), B(14745) /    16.04,  -37.03,    0.00 /
      DATA B(15082), B(15083), B(15084) /    15.68,  -36.69,    0.00 /
      DATA B(15421), B(15422), B(15423) /    15.05,  -36.00,    0.00 /
      DATA B(15760), B(15761), B(15762) /    14.64,  -35.55,    0.00 /
      DATA B(16099), B(16100), B(16101) /    14.17,  -35.07,    0.00 /
      DATA B(16438), B(16439), B(16440) /    13.64,  -34.55,    0.00 /
      DATA B(16777), B(16778), B(16779) /    13.02,  -33.91,    0.00 /
      DATA B(17116), B(17117), B(17118) /    12.34,  -33.09,    0.00 /
      DATA B(17455), B(17456), B(17457) /    11.82,  -32.96,    0.00 /
      DATA B(17794), B(17795), B(17796) /    11.02,  -31.14,    0.00 /
      DATA B(18133), B(18134), B(18135) /     9.04,  -27.22,    0.00 /
      DATA B(18472), B(18473), B(18474) /     9.65,  -28.23,    0.00 /
      DATA B(18811), B(18812), B(18813) /     7.91,  -26.15,    0.00 /
      DATA B(19150), B(19151), B(19152) /     6.70,  -24.90,    0.00 /
      DATA B(19489), B(19490), B(19491) /     5.88,  -24.10,    0.00 /
      DATA B(19828), B(19829), B(19830) /     5.29,  -23.56,    0.00 /
      DATA B(20167), B(20168), B(20169) /     4.84,  -23.19,    0.00 /
      DATA B(20506), B(20507), B(20508) /     4.46,  -22.91,    0.00 /
      DATA B(20845), B(20846), B(20847) /     4.14,  -22.70,    0.00 /
      DATA B(21184), B(21185), B(21186) /     3.84,  -22.52,    0.00 /
      DATA B(21523), B(21524), B(21525) /     3.56,  -22.37,    0.00 /
      DATA B(21862), B(21863), B(21864) /     3.28,  -22.24,    0.00 /
      DATA B(22201), B(22202), B(22203) /     3.01,  -22.11,    0.00 /
      DATA B(22540), B(22541), B(22542) /     2.72,  -21.97,    0.00 /
      DATA B(22879), B(22880), B(22881) /     2.42,  -21.83,    0.00 /
      DATA B(23218), B(23219), B(23220) /     2.09,  -21.66,    0.00 /
      DATA B(23557), B(23558), B(23559) /     1.72,  -21.45,    0.00 /
      DATA B(23896), B(23897), B(23898) /     1.31,  -21.19,    0.00 /
      DATA B(24235), B(24236), B(24237) /     0.87,  -20.84,    0.00 /
      DATA B(24574), B(24575), B(24576) /     0.46,  -20.35,    0.00 /
      DATA B(24913), B(24914), B(24915) /     0.17,  -20.07,    0.00 /
      DATA B(25252), B(25253), B(25254) /    -0.11,  -19.96,    0.00 /
      DATA B(25591), B(25592), B(25593) /    -0.63,  -19.76,    0.00 /
      DATA B(25930), B(25931), B(25932) /    -1.21,  -19.56,    0.00 /
      DATA B(26269), B(26270), B(26271) /    -1.73,  -19.39,    0.00 /
      DATA B(26608), B(26609), B(26610) /    -2.17,  -19.23,    0.00 /
      DATA B(26947), B(26948), B(26949) /    -2.57,  -19.08,    0.00 /
      DATA B(27286), B(27287), B(27288) /    -2.93,  -18.94,    0.00 /
      DATA B(  169), B(  170), B(  171) /    23.93,  -44.55,    0.00 /
      DATA B(  508), B(  509), B(  510) /    23.92,  -44.44,    0.00 /
      DATA B(  847), B(  848), B(  849) /    23.91,  -44.33,    0.00 /
      DATA B( 1186), B( 1187), B( 1188) /    23.90,  -44.21,    0.00 /
      DATA B( 1525), B( 1526), B( 1527) /    23.89,  -44.09,    0.00 /
      DATA B( 1864), B( 1865), B( 1866) /    23.88,  -43.96,    0.00 /
      DATA B( 2203), B( 2204), B( 2205) /    23.87,  -43.83,    0.00 /
      DATA B( 2542), B( 2543), B( 2544) /    23.86,  -43.68,    0.00 /
      DATA B( 2881), B( 2882), B( 2883) /    23.85,  -43.52,    0.00 /
      DATA B( 3220), B( 3221), B( 3222) /    23.83,  -43.35,    0.00 /
      DATA B( 3559), B( 3560), B( 3561) /    23.81,  -43.16,    0.00 /
      DATA B( 3898), B( 3899), B( 3900) /    23.78,  -42.95,    0.00 /
      DATA B( 4237), B( 4238), B( 4239) /    23.75,  -42.72,    0.00 /
      DATA B( 4576), B( 4577), B( 4578) /    23.70,  -42.45,    0.00 /
      DATA B( 4915), B( 4916), B( 4917) /    23.63,  -42.15,    0.00 /
      DATA B( 5254), B( 5255), B( 5256) /    23.51,  -41.81,    0.00 /
      DATA B( 5593), B( 5594), B( 5595) /    23.31,  -41.46,    0.00 /
      DATA B( 5932), B( 5933), B( 5934) /    23.02,  -41.11,    0.00 /
      DATA B( 6271), B( 6272), B( 6273) /    22.61,  -40.82,    0.00 /
      DATA B( 6610), B( 6611), B( 6612) /    22.16,  -40.60,    0.00 /
      DATA B( 6949), B( 6950), B( 6951) /    21.80,  -40.37,    0.00 /
      DATA B( 7288), B( 7289), B( 7290) /    21.53,  -40.14,    0.00 /
      DATA B( 7627), B( 7628), B( 7629) /    21.33,  -39.95,    0.00 /
      DATA B( 7966), B( 7967), B( 7968) /    21.15,  -39.80,    0.00 /
      DATA B( 8305), B( 8306), B( 8307) /    20.99,  -39.70,    0.00 /
      DATA B( 8644), B( 8645), B( 8646) /    20.82,  -39.62,    0.00 /
      DATA B( 8983), B( 8984), B( 8985) /    20.66,  -39.58,    0.00 /
      DATA B( 9322), B( 9323), B( 9324) /    20.50,  -39.55,    0.00 /
      DATA B( 9661), B( 9662), B( 9663) /    20.33,  -39.53,    0.00 /
      DATA B(10000), B(10001), B(10002) /    20.18,  -39.51,    0.00 /
      DATA B(10339), B(10340), B(10341) /    19.93,  -39.56,    0.00 /
      DATA B(10678), B(10679), B(10680) /    19.48,  -39.66,    0.00 /
      DATA B(11017), B(11018), B(11019) /    19.01,  -39.77,    0.00 /
      DATA B(11356), B(11357), B(11358) /    18.53,  -39.89,    0.00 /
      DATA B(11695), B(11696), B(11697) /    18.04,  -40.02,    0.00 /
      DATA B(12034), B(12035), B(12036) /    17.54,  -40.15,    0.00 /
      DATA B(12373), B(12374), B(12375) /    17.74,  -38.72,    0.00 /
      DATA B(12712), B(12713), B(12714) /    17.51,  -38.50,    0.00 /
      DATA B(13051), B(13052), B(13053) /    17.29,  -38.27,    0.00 /
      DATA B(13390), B(13391), B(13392) /    17.06,  -38.01,    0.00 /
      DATA B(13729), B(13730), B(13731) /    16.81,  -37.74,    0.00 /
      DATA B(14068), B(14069), B(14070) /    16.55,  -37.46,    0.00 /
      DATA B(14407), B(14408), B(14409) /    16.25,  -37.15,    0.00 /
      DATA B(14746), B(14747), B(14748) /    15.90,  -36.82,    0.00 /
      DATA B(15085), B(15086), B(15087) /    15.29,  -36.13,    0.00 /
      DATA B(15424), B(15425), B(15426) /    14.91,  -35.69,    0.00 /
      DATA B(15763), B(15764), B(15765) /    14.48,  -35.23,    0.00 /
      DATA B(16102), B(16103), B(16104) /    14.00,  -34.73,    0.00 /
      DATA B(16441), B(16442), B(16443) /    13.41,  -34.17,    0.00 /
      DATA B(16780), B(16781), B(16782) /    12.70,  -33.49,    0.00 /
      DATA B(17119), B(17120), B(17121) /    11.88,  -32.56,    0.00 /
      DATA B(17458), B(17459), B(17460) /    11.28,  -32.29,    0.00 /
      DATA B(17797), B(17798), B(17799) /     9.57,  -30.15,    0.00 /
      DATA B(18136), B(18137), B(18138) /     9.80,  -30.89,    0.00 /
      DATA B(18475), B(18476), B(18477) /     8.01,  -27.59,    0.00 /
      DATA B(18814), B(18815), B(18816) /     6.97,  -25.59,    0.00 /
      DATA B(19153), B(19154), B(19155) /     6.15,  -24.53,    0.00 /
      DATA B(19492), B(19493), B(19494) /     5.53,  -23.87,    0.00 /
      DATA B(19831), B(19832), B(19833) /     5.05,  -23.42,    0.00 /
      DATA B(20170), B(20171), B(20172) /     4.65,  -23.10,    0.00 /
      DATA B(20509), B(20510), B(20511) /     4.31,  -22.86,    0.00 /
      DATA B(20848), B(20849), B(20850) /     4.00,  -22.66,    0.00 /
      DATA B(21187), B(21188), B(21189) /     3.72,  -22.50,    0.00 /
      DATA B(21526), B(21527), B(21528) /     3.44,  -22.36,    0.00 /
      DATA B(21865), B(21866), B(21867) /     3.17,  -22.22,    0.00 /
      DATA B(22204), B(22205), B(22206) /     2.90,  -22.09,    0.00 /
      DATA B(22543), B(22544), B(22545) /     2.61,  -21.95,    0.00 /
      DATA B(22882), B(22883), B(22884) /     2.30,  -21.80,    0.00 /
      DATA B(23221), B(23222), B(23223) /     1.96,  -21.62,    0.00 /
      DATA B(23560), B(23561), B(23562) /     1.58,  -21.41,    0.00 /
      DATA B(23899), B(23900), B(23901) /     1.14,  -21.14,    0.00 /
      DATA B(24238), B(24239), B(24240) /     0.64,  -20.81,    0.00 /
      DATA B(24577), B(24578), B(24579) /     0.22,  -20.25,    0.00 /
      DATA B(24916), B(24917), B(24918) /     0.13,  -20.01,    0.00 /
      DATA B(25255), B(25256), B(25257) /    -0.19,  -19.73,    0.00 /
      DATA B(25594), B(25595), B(25596) /    -0.76,  -19.51,    0.00 /
      DATA B(25933), B(25934), B(25935) /    -1.35,  -19.34,    0.00 /
      DATA B(26272), B(26273), B(26274) /    -1.85,  -19.18,    0.00 /
      DATA B(26611), B(26612), B(26613) /    -2.30,  -19.02,    0.00 /
      DATA B(26950), B(26951), B(26952) /    -2.70,  -18.86,    0.00 /
      DATA B(27289), B(27290), B(27291) /    -3.07,  -18.71,    0.00 /
      DATA B(  172), B(  173), B(  174) /    23.90,  -44.48,    0.00 /
      DATA B(  511), B(  512), B(  513) /    23.89,  -44.37,    0.00 /
      DATA B(  850), B(  851), B(  852) /    23.88,  -44.25,    0.00 /
      DATA B( 1189), B( 1190), B( 1191) /    23.87,  -44.13,    0.00 /
      DATA B( 1528), B( 1529), B( 1530) /    23.87,  -44.00,    0.00 /
      DATA B( 1867), B( 1868), B( 1869) /    23.86,  -43.86,    0.00 /
      DATA B( 2206), B( 2207), B( 2208) /    23.84,  -43.71,    0.00 /
      DATA B( 2545), B( 2546), B( 2547) /    23.83,  -43.55,    0.00 /
      DATA B( 2884), B( 2885), B( 2886) /    23.82,  -43.38,    0.00 /
      DATA B( 3223), B( 3224), B( 3225) /    23.80,  -43.18,    0.00 /
      DATA B( 3562), B( 3563), B( 3564) /    23.77,  -42.97,    0.00 /
      DATA B( 3901), B( 3902), B( 3903) /    23.74,  -42.72,    0.00 /
      DATA B( 4240), B( 4241), B( 4242) /    23.69,  -42.45,    0.00 /
      DATA B( 4579), B( 4580), B( 4581) /    23.61,  -42.14,    0.00 /
      DATA B( 4918), B( 4919), B( 4920) /    23.48,  -41.80,    0.00 /
      DATA B( 5257), B( 5258), B( 5259) /    23.28,  -41.45,    0.00 /
      DATA B( 5596), B( 5597), B( 5598) /    22.98,  -41.11,    0.00 /
      DATA B( 5935), B( 5936), B( 5937) /    22.55,  -40.84,    0.00 /
      DATA B( 6274), B( 6275), B( 6276) /    22.11,  -40.66,    0.00 /
      DATA B( 6613), B( 6614), B( 6615) /    21.76,  -40.43,    0.00 /
      DATA B( 6952), B( 6953), B( 6954) /    21.51,  -40.21,    0.00 /
      DATA B( 7291), B( 7292), B( 7293) /    21.31,  -40.02,    0.00 /
      DATA B( 7630), B( 7631), B( 7632) /    21.14,  -39.87,    0.00 /
      DATA B( 7969), B( 7970), B( 7971) /    20.97,  -39.77,    0.00 /
      DATA B( 8308), B( 8309), B( 8310) /    20.81,  -39.69,    0.00 /
      DATA B( 8647), B( 8648), B( 8649) /    20.65,  -39.65,    0.00 /
      DATA B( 8986), B( 8987), B( 8988) /    20.49,  -39.62,    0.00 /
      DATA B( 9325), B( 9326), B( 9327) /    20.33,  -39.60,    0.00 /
      DATA B( 9664), B( 9665), B( 9666) /    20.18,  -39.57,    0.00 /
      DATA B(10003), B(10004), B(10005) /    19.96,  -39.67,    0.00 /
      DATA B(10342), B(10343), B(10344) /    19.51,  -39.77,    0.00 /
      DATA B(10681), B(10682), B(10683) /    19.05,  -39.88,    0.00 /
      DATA B(11020), B(11021), B(11022) /    18.57,  -40.00,    0.00 /
      DATA B(11359), B(11360), B(11361) /    18.08,  -40.13,    0.00 /
      DATA B(11698), B(11699), B(11700) /    18.09,  -38.97,    0.00 /
      DATA B(12037), B(12038), B(12039) /    17.87,  -38.79,    0.00 /
      DATA B(12376), B(12377), B(12378) /    17.65,  -38.59,    0.00 /
      DATA B(12715), B(12716), B(12717) /    17.43,  -38.36,    0.00 /
      DATA B(13054), B(13055), B(13056) /    17.21,  -38.11,    0.00 /
      DATA B(13393), B(13394), B(13395) /    16.97,  -37.85,    0.00 /
      DATA B(13732), B(13733), B(13734) /    16.72,  -37.57,    0.00 /
      DATA B(14071), B(14072), B(14073) /    16.44,  -37.27,    0.00 /
      DATA B(14410), B(14411), B(14412) /    16.12,  -36.94,    0.00 /
      DATA B(14749), B(14750), B(14751) /    15.52,  -36.27,    0.00 /
      DATA B(15088), B(15089), B(15090) /    15.17,  -35.82,    0.00 /
      DATA B(15427), B(15428), B(15429) /    14.78,  -35.36,    0.00 /
      DATA B(15766), B(15767), B(15768) /    14.35,  -34.89,    0.00 /
      DATA B(16105), B(16106), B(16107) /    13.84,  -34.36,    0.00 /
      DATA B(16444), B(16445), B(16446) /    13.22,  -33.76,    0.00 /
      DATA B(16783), B(16784), B(16785) /    12.42,  -33.00,    0.00 /
      DATA B(17122), B(17123), B(17124) /    11.43,  -32.04,    0.00 /
      DATA B(17461), B(17462), B(17463) /    10.80,  -31.70,    0.00 /
      DATA B(17800), B(17801), B(17802) /    10.50,  -31.77,    0.00 /
      DATA B(18139), B(18140), B(18141) /     7.94,  -29.25,    0.00 /
      DATA B(18478), B(18479), B(18480) /     6.77,  -26.90,    0.00 /
      DATA B(18817), B(18818), B(18819) /     6.11,  -25.24,    0.00 /
      DATA B(19156), B(19157), B(19158) /     5.61,  -24.29,    0.00 /
      DATA B(19495), B(19496), B(19497) /     5.17,  -23.70,    0.00 /
      DATA B(19834), B(19835), B(19836) /     4.79,  -23.31,    0.00 /
      DATA B(20173), B(20174), B(20175) /     4.45,  -23.03,    0.00 /
      DATA B(20512), B(20513), B(20514) /     4.15,  -22.81,    0.00 /
      DATA B(20851), B(20852), B(20853) /     3.86,  -22.63,    0.00 /
      DATA B(21190), B(21191), B(21192) /     3.59,  -22.47,    0.00 /
      DATA B(21529), B(21530), B(21531) /     3.32,  -22.33,    0.00 /
      DATA B(21868), B(21869), B(21870) /     3.04,  -22.19,    0.00 /
      DATA B(22207), B(22208), B(22209) /     2.76,  -22.05,    0.00 /
      DATA B(22546), B(22547), B(22548) /     2.46,  -21.91,    0.00 /
      DATA B(22885), B(22886), B(22887) /     2.14,  -21.74,    0.00 /
      DATA B(23224), B(23225), B(23226) /     1.78,  -21.55,    0.00 /
      DATA B(23563), B(23564), B(23565) /     1.37,  -21.32,    0.00 /
      DATA B(23902), B(23903), B(23904) /     0.89,  -21.03,    0.00 /
      DATA B(24241), B(24242), B(24243) /     0.37,  -20.67,    0.00 /
      DATA B(24580), B(24581), B(24582) /    -1.50,  -19.13,    0.00 /
      DATA B(24919), B(24920), B(24921) /     0.05,  -19.88,    0.00 /
      DATA B(25258), B(25259), B(25260) /    -0.52,  -19.50,    0.00 /
      DATA B(25597), B(25598), B(25599) /    -1.04,  -19.30,    0.00 /
      DATA B(25936), B(25937), B(25938) /    -1.56,  -19.14,    0.00 /
      DATA B(26275), B(26276), B(26277) /    -2.04,  -18.97,    0.00 /
      DATA B(26614), B(26615), B(26616) /    -2.48,  -18.80,    0.00 /
      DATA B(26953), B(26954), B(26955) /    -2.88,  -18.62,    0.00 /
      DATA B(27292), B(27293), B(27294) /    -3.26,  -18.45,    0.00 /
      DATA B(  175), B(  176), B(  177) /    23.87,  -44.41,    0.00 /
      DATA B(  514), B(  515), B(  516) /    23.86,  -44.29,    0.00 /
      DATA B(  853), B(  854), B(  855) /    23.86,  -44.17,    0.00 /
      DATA B( 1192), B( 1193), B( 1194) /    23.85,  -44.04,    0.00 /
      DATA B( 1531), B( 1532), B( 1533) /    23.84,  -43.89,    0.00 /
      DATA B( 1870), B( 1871), B( 1872) /    23.83,  -43.74,    0.00 /
      DATA B( 2209), B( 2210), B( 2211) /    23.82,  -43.58,    0.00 /
      DATA B( 2548), B( 2549), B( 2550) /    23.80,  -43.40,    0.00 /
      DATA B( 2887), B( 2888), B( 2889) /    23.78,  -43.20,    0.00 /
      DATA B( 3226), B( 3227), B( 3228) /    23.76,  -42.98,    0.00 /
      DATA B( 3565), B( 3566), B( 3567) /    23.72,  -42.73,    0.00 /
      DATA B( 3904), B( 3905), B( 3906) /    23.67,  -42.44,    0.00 /
      DATA B( 4243), B( 4244), B( 4245) /    23.59,  -42.13,    0.00 /
      DATA B( 4582), B( 4583), B( 4584) /    23.45,  -41.79,    0.00 /
      DATA B( 4921), B( 4922), B( 4923) /    23.24,  -41.44,    0.00 /
      DATA B( 5260), B( 5261), B( 5262) /    22.92,  -41.13,    0.00 /
      DATA B( 5599), B( 5600), B( 5601) /    22.48,  -40.89,    0.00 /
      DATA B( 5938), B( 5939), B( 5940) /    22.06,  -40.70,    0.00 /
      DATA B( 6277), B( 6278), B( 6279) /    21.73,  -40.49,    0.00 /
      DATA B( 6616), B( 6617), B( 6618) /    21.48,  -40.28,    0.00 /
      DATA B( 6955), B( 6956), B( 6957) /    21.28,  -40.09,    0.00 /
      DATA B( 7294), B( 7295), B( 7296) /    21.12,  -39.95,    0.00 /
      DATA B( 7633), B( 7634), B( 7635) /    20.96,  -39.84,    0.00 /
      DATA B( 7972), B( 7973), B( 7974) /    20.80,  -39.77,    0.00 /
      DATA B( 8311), B( 8312), B( 8313) /    20.64,  -39.72,    0.00 /
      DATA B( 8650), B( 8651), B( 8652) /    20.49,  -39.69,    0.00 /
      DATA B( 8989), B( 8990), B( 8991) /    20.33,  -39.66,    0.00 /
      DATA B( 9328), B( 9329), B( 9330) /    20.18,  -39.64,    0.00 /
      DATA B( 9667), B( 9668), B( 9669) /    19.98,  -39.79,    0.00 /
      DATA B(10006), B(10007), B(10008) /    19.53,  -39.88,    0.00 /
      DATA B(10345), B(10346), B(10347) /    19.07,  -39.99,    0.00 /
      DATA B(10684), B(10685), B(10686) /    18.60,  -40.12,    0.00 /
      DATA B(11023), B(11024), B(11025) /    18.11,  -40.25,    0.00 /
      DATA B(11362), B(11363), B(11364) /    18.21,  -39.03,    0.00 /
      DATA B(11701), B(11702), B(11703) /    18.00,  -38.86,    0.00 /
      DATA B(12040), B(12041), B(12042) /    17.78,  -38.67,    0.00 /
      DATA B(12379), B(12380), B(12381) /    17.57,  -38.45,    0.00 /
      DATA B(12718), B(12719), B(12720) /    17.35,  -38.21,    0.00 /
      DATA B(13057), B(13058), B(13059) /    17.13,  -37.95,    0.00 /
      DATA B(13396), B(13397), B(13398) /    16.89,  -37.68,    0.00 /
      DATA B(13735), B(13736), B(13737) /    16.62,  -37.38,    0.00 /
      DATA B(14074), B(14075), B(14076) /    16.33,  -37.06,    0.00 /
      DATA B(14413), B(14414), B(14415) /    15.99,  -36.71,    0.00 /
      DATA B(14752), B(14753), B(14754) /    15.40,  -35.95,    0.00 /
      DATA B(15091), B(15092), B(15093) /    15.04,  -35.50,    0.00 /
      DATA B(15430), B(15431), B(15432) /    14.66,  -35.03,    0.00 /
      DATA B(15769), B(15770), B(15771) /    14.22,  -34.53,    0.00 /
      DATA B(16108), B(16109), B(16110) /    13.70,  -33.96,    0.00 /
      DATA B(16447), B(16448), B(16449) /    13.06,  -33.29,    0.00 /
      DATA B(16786), B(16787), B(16788) /    12.25,  -32.46,    0.00 /
      DATA B(17125), B(17126), B(17127) /    11.29,  -31.49,    0.00 /
      DATA B(17464), B(17465), B(17466) /     9.67,  -30.48,    0.00 /
      DATA B(17803), B(17804), B(17805) /     7.97,  -29.40,    0.00 /
      DATA B(18142), B(18143), B(18144) /     6.87,  -27.91,    0.00 /
      DATA B(18481), B(18482), B(18483) /     6.01,  -26.25,    0.00 /
      DATA B(18820), B(18821), B(18822) /     5.52,  -24.95,    0.00 /
      DATA B(19159), B(19160), B(19161) /     5.17,  -24.12,    0.00 /
      DATA B(19498), B(19499), B(19500) /     4.85,  -23.59,    0.00 /
      DATA B(19837), B(19838), B(19839) /     4.54,  -23.23,    0.00 /
      DATA B(20176), B(20177), B(20178) /     4.25,  -22.97,    0.00 /
      DATA B(20515), B(20516), B(20517) /     3.97,  -22.77,    0.00 /
      DATA B(20854), B(20855), B(20856) /     3.70,  -22.59,    0.00 /
      DATA B(21193), B(21194), B(21195) /     3.44,  -22.44,    0.00 /
      DATA B(21532), B(21533), B(21534) /     3.17,  -22.29,    0.00 /
      DATA B(21871), B(21872), B(21873) /     2.89,  -22.15,    0.00 /
      DATA B(22210), B(22211), B(22212) /     2.59,  -21.99,    0.00 /
      DATA B(22549), B(22550), B(22551) /     2.27,  -21.83,    0.00 /
      DATA B(22888), B(22889), B(22890) /     1.91,  -21.64,    0.00 /
      DATA B(23227), B(23228), B(23229) /     1.50,  -21.42,    0.00 /
      DATA B(23566), B(23567), B(23568) /     1.04,  -21.16,    0.00 /
      DATA B(23905), B(23906), B(23907) /     0.51,  -20.86,    0.00 /
      DATA B(24244), B(24245), B(24246) /    -1.21,  -19.43,    0.00 /
      DATA B(24583), B(24584), B(24585) /    -1.71,  -19.02,    0.00 /
      DATA B(24922), B(24923), B(24924) /    -0.49,  -19.91,    0.00 /
      DATA B(25261), B(25262), B(25263) /    -0.95,  -19.44,    0.00 /
      DATA B(25600), B(25601), B(25602) /    -1.39,  -19.17,    0.00 /
      DATA B(25939), B(25940), B(25941) /    -1.84,  -18.97,    0.00 /
      DATA B(26278), B(26279), B(26280) /    -2.29,  -18.76,    0.00 /
      DATA B(26617), B(26618), B(26619) /    -2.73,  -18.57,    0.00 /
      DATA B(26956), B(26957), B(26958) /    -3.13,  -18.37,    0.00 /
      DATA B(27295), B(27296), B(27297) /    -3.52,  -18.18,    0.00 /
      DATA B(  178), B(  179), B(  180) /    23.84,  -44.33,    0.00 /
      DATA B(  517), B(  518), B(  519) /    23.84,  -44.21,    0.00 /
      DATA B(  856), B(  857), B(  858) /    23.83,  -44.07,    0.00 /
      DATA B( 1195), B( 1196), B( 1197) /    23.82,  -43.93,    0.00 /
      DATA B( 1534), B( 1535), B( 1536) /    23.81,  -43.77,    0.00 /
      DATA B( 1873), B( 1874), B( 1875) /    23.80,  -43.61,    0.00 /
      DATA B( 2212), B( 2213), B( 2214) /    23.79,  -43.42,    0.00 /
      DATA B( 2551), B( 2552), B( 2553) /    23.77,  -43.22,    0.00 /
      DATA B( 2890), B( 2891), B( 2892) /    23.74,  -42.99,    0.00 /
      DATA B( 3229), B( 3230), B( 3231) /    23.71,  -42.73,    0.00 /
      DATA B( 3568), B( 3569), B( 3570) /    23.66,  -42.44,    0.00 /
      DATA B( 3907), B( 3908), B( 3909) /    23.57,  -42.11,    0.00 /
      DATA B( 4246), B( 4247), B( 4248) /    23.42,  -41.77,    0.00 /
      DATA B( 4585), B( 4586), B( 4587) /    23.19,  -41.43,    0.00 /
      DATA B( 4924), B( 4925), B( 4926) /    22.86,  -41.08,    0.00 /
      DATA B( 5263), B( 5264), B( 5265) /    22.40,  -40.93,    0.00 /
      DATA B( 5602), B( 5603), B( 5604) /    22.00,  -40.74,    0.00 /
      DATA B( 5941), B( 5942), B( 5943) /    21.69,  -40.53,    0.00 /
      DATA B( 6280), B( 6281), B( 6282) /    21.46,  -40.33,    0.00 /
      DATA B( 6619), B( 6620), B( 6621) /    21.26,  -40.16,    0.00 /
      DATA B( 6958), B( 6959), B( 6960) /    21.10,  -40.02,    0.00 /
      DATA B( 7297), B( 7298), B( 7299) /    20.94,  -39.92,    0.00 /
      DATA B( 7636), B( 7637), B( 7638) /    20.79,  -39.84,    0.00 /
      DATA B( 7975), B( 7976), B( 7977) /    20.63,  -39.79,    0.00 /
      DATA B( 8314), B( 8315), B( 8316) /    20.47,  -39.76,    0.00 /
      DATA B( 8653), B( 8654), B( 8655) /    20.32,  -39.73,    0.00 /
      DATA B( 8992), B( 8993), B( 8994) /    20.16,  -39.71,    0.00 /
      DATA B( 9331), B( 9332), B( 9333) /    20.00,  -39.92,    0.00 /
      DATA B( 9670), B( 9671), B( 9672) /    19.55,  -40.01,    0.00 /
      DATA B(10009), B(10010), B(10011) /    19.09,  -40.11,    0.00 /
      DATA B(10348), B(10349), B(10350) /    18.62,  -40.23,    0.00 /
      DATA B(10687), B(10688), B(10689) /    18.14,  -40.37,    0.00 /
      DATA B(11026), B(11027), B(11028) /    18.33,  -39.09,    0.00 /
      DATA B(11365), B(11366), B(11367) /    18.12,  -38.92,    0.00 /
      DATA B(11704), B(11705), B(11706) /    17.91,  -38.73,    0.00 /
      DATA B(12043), B(12044), B(12045) /    17.71,  -38.53,    0.00 /
      DATA B(12382), B(12383), B(12384) /    17.50,  -38.30,    0.00 /
      DATA B(12721), B(12722), B(12723) /    17.28,  -38.05,    0.00 /
      DATA B(13060), B(13061), B(13062) /    17.05,  -37.79,    0.00 /
      DATA B(13399), B(13400), B(13401) /    16.80,  -37.50,    0.00 /
      DATA B(13738), B(13739), B(13740) /    16.51,  -37.18,    0.00 /
      DATA B(14077), B(14078), B(14079) /    16.19,  -36.84,    0.00 /
      DATA B(14416), B(14417), B(14418) /    15.61,  -36.08,    0.00 /
      DATA B(14755), B(14756), B(14757) /    15.28,  -35.63,    0.00 /
      DATA B(15094), B(15095), B(15096) /    14.92,  -35.16,    0.00 /
      DATA B(15433), B(15434), B(15435) /    14.53,  -34.67,    0.00 /
      DATA B(15772), B(15773), B(15774) /    14.09,  -34.14,    0.00 /
      DATA B(16111), B(16112), B(16113) /    13.55,  -33.52,    0.00 /
      DATA B(16450), B(16451), B(16452) /    12.89,  -32.79,    0.00 /
      DATA B(16789), B(16790), B(16791) /    12.12,  -31.92,    0.00 /
      DATA B(17128), B(17129), B(17130) /    10.05,  -29.72,    0.00 /
      DATA B(17467), B(17468), B(17469) /     9.19,  -29.69,    0.00 /
      DATA B(17806), B(17807), B(17808) /     7.21,  -28.23,    0.00 /
      DATA B(18145), B(18146), B(18147) /     6.22,  -26.92,    0.00 /
      DATA B(18484), B(18485), B(18486) /     5.56,  -25.66,    0.00 /
      DATA B(18823), B(18824), B(18825) /     5.15,  -24.66,    0.00 /
      DATA B(19162), B(19163), B(19164) /     4.85,  -23.97,    0.00 /
      DATA B(19501), B(19502), B(19503) /     4.58,  -23.50,    0.00 /
      DATA B(19840), B(19841), B(19842) /     4.32,  -23.17,    0.00 /
      DATA B(20179), B(20180), B(20181) /     4.06,  -22.92,    0.00 /
      DATA B(20518), B(20519), B(20520) /     3.80,  -22.72,    0.00 /
      DATA B(20857), B(20858), B(20859) /     3.53,  -22.55,    0.00 /
      DATA B(21196), B(21197), B(21198) /     3.27,  -22.39,    0.00 /
      DATA B(21535), B(21536), B(21537) /     2.99,  -22.23,    0.00 /
      DATA B(21874), B(21875), B(21876) /     2.69,  -22.07,    0.00 /
      DATA B(22213), B(22214), B(22215) /     2.37,  -21.89,    0.00 /
      DATA B(22552), B(22553), B(22554) /     2.00,  -21.70,    0.00 /
      DATA B(22891), B(22892), B(22893) /     1.59,  -21.47,    0.00 /
      DATA B(23230), B(23231), B(23232) /     1.11,  -21.21,    0.00 /
      DATA B(23569), B(23570), B(23571) /     0.54,  -20.95,    0.00 /
      DATA B(23908), B(23909), B(23910) /    -1.06,  -19.62,    0.00 /
      DATA B(24247), B(24248), B(24249) /    -1.73,  -19.13,    0.00 /
      DATA B(24586), B(24587), B(24588) /    -2.20,  -18.80,    0.00 /
      DATA B(24925), B(24926), B(24927) /    -0.80,  -19.73,    0.00 /
      DATA B(25264), B(25265), B(25266) /    -1.29,  -19.37,    0.00 /
      DATA B(25603), B(25604), B(25605) /    -1.72,  -19.07,    0.00 /
      DATA B(25942), B(25943), B(25944) /    -2.17,  -18.80,    0.00 /
      DATA B(26281), B(26282), B(26283) /    -2.62,  -18.54,    0.00 /
      DATA B(26620), B(26621), B(26622) /    -3.07,  -18.32,    0.00 /
      DATA B(26959), B(26960), B(26961) /    -3.49,  -18.12,    0.00 /
      DATA B(27298), B(27299), B(27300) /    -3.89,  -17.91,    0.00 /
      DATA B(  181), B(  182), B(  183) /    23.82,  -44.24,    0.00 /
      DATA B(  520), B(  521), B(  522) /    23.81,  -44.11,    0.00 /
      DATA B(  859), B(  860), B(  861) /    23.80,  -43.96,    0.00 /
      DATA B( 1198), B( 1199), B( 1200) /    23.79,  -43.80,    0.00 /
      DATA B( 1537), B( 1538), B( 1539) /    23.78,  -43.63,    0.00 /
      DATA B( 1876), B( 1877), B( 1878) /    23.77,  -43.44,    0.00 /
      DATA B( 2215), B( 2216), B( 2217) /    23.75,  -43.24,    0.00 /
      DATA B( 2554), B( 2555), B( 2556) /    23.73,  -43.00,    0.00 /
      DATA B( 2893), B( 2894), B( 2895) /    23.70,  -42.73,    0.00 /
      DATA B( 3232), B( 3233), B( 3234) /    23.64,  -42.43,    0.00 /
      DATA B( 3571), B( 3572), B( 3573) /    23.54,  -42.10,    0.00 /
      DATA B( 3910), B( 3911), B( 3912) /    23.38,  -41.75,    0.00 /
      DATA B( 4249), B( 4250), B( 4251) /    23.13,  -41.42,    0.00 /
      DATA B( 4588), B( 4589), B( 4590) /    22.77,  -41.12,    0.00 /
      DATA B( 4927), B( 4928), B( 4929) /    22.33,  -40.96,    0.00 /
      DATA B( 5266), B( 5267), B( 5268) /    21.95,  -40.77,    0.00 /
      DATA B( 5605), B( 5606), B( 5607) /    21.66,  -40.56,    0.00 /
      DATA B( 5944), B( 5945), B( 5946) /    21.44,  -40.38,    0.00 /
      DATA B( 6283), B( 6284), B( 6285) /    21.25,  -40.22,    0.00 /
      DATA B( 6622), B( 6623), B( 6624) /    21.08,  -40.09,    0.00 /
      DATA B( 6961), B( 6962), B( 6963) /    20.92,  -40.00,    0.00 /
      DATA B( 7300), B( 7301), B( 7302) /    20.77,  -39.92,    0.00 /
      DATA B( 7639), B( 7640), B( 7641) /    20.62,  -39.87,    0.00 /
      DATA B( 7978), B( 7979), B( 7980) /    20.46,  -39.83,    0.00 /
      DATA B( 8317), B( 8318), B( 8319) /    20.30,  -39.81,    0.00 /
      DATA B( 8656), B( 8657), B( 8658) /    20.15,  -39.79,    0.00 /
      DATA B( 8995), B( 8996), B( 8997) /    20.00,  -40.05,    0.00 /
      DATA B( 9334), B( 9335), B( 9336) /    19.55,  -40.14,    0.00 /
      DATA B( 9673), B( 9674), B( 9675) /    19.09,  -40.25,    0.00 /
      DATA B(10012), B(10013), B(10014) /    18.63,  -40.36,    0.00 /
      DATA B(10351), B(10352), B(10353) /    18.66,  -39.30,    0.00 /
      DATA B(10690), B(10691), B(10692) /    18.45,  -39.15,    0.00 /
      DATA B(11029), B(11030), B(11031) /    18.24,  -38.98,    0.00 /
      DATA B(11368), B(11369), B(11370) /    18.04,  -38.80,    0.00 /
      DATA B(11707), B(11708), B(11709) /    17.84,  -38.60,    0.00 /
      DATA B(12046), B(12047), B(12048) /    17.63,  -38.38,    0.00 /
      DATA B(12385), B(12386), B(12387) /    17.42,  -38.14,    0.00 /
      DATA B(12724), B(12725), B(12726) /    17.20,  -37.89,    0.00 /
      DATA B(13063), B(13064), B(13065) /    16.96,  -37.61,    0.00 /
      DATA B(13402), B(13403), B(13404) /    16.69,  -37.30,    0.00 /
      DATA B(13741), B(13742), B(13743) /    16.38,  -36.96,    0.00 /
      DATA B(14080), B(14081), B(14082) /    15.81,  -36.22,    0.00 /
      DATA B(14419), B(14420), B(14421) /    15.49,  -35.76,    0.00 /
      DATA B(14758), B(14759), B(14760) /    15.15,  -35.29,    0.00 /
      DATA B(15097), B(15098), B(15099) /    14.79,  -34.81,    0.00 /
      DATA B(15436), B(15437), B(15438) /    14.39,  -34.29,    0.00 /
      DATA B(15775), B(15776), B(15777) /    13.91,  -33.70,    0.00 /
      DATA B(16114), B(16115), B(16116) /    13.33,  -33.02,    0.00 /
      DATA B(16453), B(16454), B(16455) /    12.63,  -32.22,    0.00 /
      DATA B(16792), B(16793), B(16794) /    10.50,  -29.98,    0.00 /
      DATA B(17131), B(17132), B(17133) /     9.51,  -29.27,    0.00 /
      DATA B(17470), B(17471), B(17472) /     8.49,  -28.70,    0.00 /
      DATA B(17809), B(17810), B(17811) /     6.80,  -27.04,    0.00 /
      DATA B(18148), B(18149), B(18150) /     5.88,  -26.08,    0.00 /
      DATA B(18487), B(18488), B(18489) /     5.29,  -25.15,    0.00 /
      DATA B(18826), B(18827), B(18828) /     4.90,  -24.39,    0.00 /
      DATA B(19165), B(19166), B(19167) /     4.61,  -23.82,    0.00 /
      DATA B(19504), B(19505), B(19506) /     4.36,  -23.41,    0.00 /
      DATA B(19843), B(19844), B(19845) /     4.11,  -23.11,    0.00 /
      DATA B(20182), B(20183), B(20184) /     3.86,  -22.87,    0.00 /
      DATA B(20521), B(20522), B(20523) /     3.61,  -22.67,    0.00 /
      DATA B(20860), B(20861), B(20862) /     3.35,  -22.50,    0.00 /
      DATA B(21199), B(21200), B(21201) /     3.07,  -22.32,    0.00 /
      DATA B(21538), B(21539), B(21540) /     2.77,  -22.14,    0.00 /
      DATA B(21877), B(21878), B(21879) /     2.44,  -21.95,    0.00 /
      DATA B(22216), B(22217), B(22218) /     2.07,  -21.74,    0.00 /
      DATA B(22555), B(22556), B(22557) /     1.64,  -21.50,    0.00 /
      DATA B(22894), B(22895), B(22896) /     1.14,  -21.22,    0.00 /
      DATA B(23233), B(23234), B(23235) /     0.53,  -20.96,    0.00 /
      DATA B(23572), B(23573), B(23574) /    -0.96,  -19.62,    0.00 /
      DATA B(23911), B(23912), B(23913) /    -1.70,  -19.24,    0.00 /
      DATA B(24250), B(24251), B(24252) /    -2.26,  -18.86,    0.00 /
      DATA B(24589), B(24590), B(24591) /    -2.71,  -18.64,    0.00 /
      DATA B(24928), B(24929), B(24930) /    -1.12,  -19.57,    0.00 /
      DATA B(25267), B(25268), B(25269) /    -1.62,  -19.27,    0.00 /
      DATA B(25606), B(25607), B(25608) /    -2.08,  -18.95,    0.00 /
      DATA B(25945), B(25946), B(25947) /    -2.56,  -18.60,    0.00 /
      DATA B(26284), B(26285), B(26286) /    -3.07,  -18.29,    0.00 /
      DATA B(26623), B(26624), B(26625) /    -3.55,  -18.04,    0.00 /
      DATA B(26962), B(26963), B(26964) /    -4.00,  -17.86,    0.00 /
      DATA B(27301), B(27302), B(27303) /    -4.39,  -17.58,    0.00 /
      DATA B(  184), B(  185), B(  186) /    23.79,  -44.14,    0.00 /
      DATA B(  523), B(  524), B(  525) /    23.78,  -43.99,    0.00 /
      DATA B(  862), B(  863), B(  864) /    23.77,  -43.83,    0.00 /
      DATA B( 1201), B( 1202), B( 1203) /    23.76,  -43.66,    0.00 /
      DATA B( 1540), B( 1541), B( 1542) /    23.75,  -43.47,    0.00 /
      DATA B( 1879), B( 1880), B( 1881) /    23.74,  -43.25,    0.00 /
      DATA B( 2218), B( 2219), B( 2220) /    23.71,  -43.01,    0.00 /
      DATA B( 2557), B( 2558), B( 2559) /    23.68,  -42.73,    0.00 /
      DATA B( 2896), B( 2897), B( 2898) /    23.62,  -42.42,    0.00 /
      DATA B( 3235), B( 3236), B( 3237) /    23.51,  -42.09,    0.00 /
      DATA B( 3574), B( 3575), B( 3576) /    23.34,  -41.74,    0.00 /
      DATA B( 3913), B( 3914), B( 3915) /    23.07,  -41.41,    0.00 /
      DATA B( 4252), B( 4253), B( 4254) /    22.68,  -41.15,    0.00 /
      DATA B( 4591), B( 4592), B( 4593) /    22.25,  -40.98,    0.00 /
      DATA B( 4930), B( 4931), B( 4932) /    21.90,  -40.79,    0.00 /
      DATA B( 5269), B( 5270), B( 5271) /    21.63,  -40.59,    0.00 /
      DATA B( 5608), B( 5609), B( 5610) /    21.42,  -40.41,    0.00 /
      DATA B( 5947), B( 5948), B( 5949) /    21.23,  -40.26,    0.00 /
      DATA B( 6286), B( 6287), B( 6288) /    21.07,  -40.15,    0.00 /
      DATA B( 6625), B( 6626), B( 6627) /    20.91,  -40.07,    0.00 /
      DATA B( 6964), B( 6965), B( 6966) /    20.76,  -40.00,    0.00 /
      DATA B( 7303), B( 7304), B( 7305) /    20.60,  -39.96,    0.00 /
      DATA B( 7642), B( 7643), B( 7644) /    20.45,  -39.92,    0.00 /
      DATA B( 7981), B( 7982), B( 7983) /    20.29,  -39.88,    0.00 /
      DATA B( 8320), B( 8321), B( 8322) /    20.13,  -39.86,    0.00 /
      DATA B( 8659), B( 8660), B( 8661) /    20.00,  -40.19,    0.00 /
      DATA B( 8998), B( 8999), B( 9000) /    19.55,  -40.27,    0.00 /
      DATA B( 9337), B( 9338), B( 9339) /    19.08,  -40.39,    0.00 /
      DATA B( 9676), B( 9677), B( 9678) /    18.98,  -39.50,    0.00 /
      DATA B(10015), B(10016), B(10017) /    18.78,  -39.35,    0.00 /
      DATA B(10354), B(10355), B(10356) /    18.57,  -39.20,    0.00 /
      DATA B(10693), B(10694), B(10695) /    18.37,  -39.04,    0.00 /
      DATA B(11032), B(11033), B(11034) /    18.17,  -38.86,    0.00 /
      DATA B(11371), B(11372), B(11373) /    17.97,  -38.66,    0.00 /
      DATA B(11710), B(11711), B(11712) /    17.77,  -38.45,    0.00 /
      DATA B(12049), B(12050), B(12051) /    17.56,  -38.23,    0.00 /
      DATA B(12388), B(12389), B(12390) /    17.34,  -37.98,    0.00 /
      DATA B(12727), B(12728), B(12729) /    17.11,  -37.72,    0.00 /
      DATA B(13066), B(13067), B(13068) /    16.85,  -37.42,    0.00 /
      DATA B(13405), B(13406), B(13407) /    16.56,  -37.09,    0.00 /
      DATA B(13744), B(13745), B(13746) /    16.24,  -36.73,    0.00 /
      DATA B(14083), B(14084), B(14085) /    15.68,  -35.90,    0.00 /
      DATA B(14422), B(14423), B(14424) /    15.35,  -35.43,    0.00 /
      DATA B(14761), B(14762), B(14763) /    15.01,  -34.94,    0.00 /
      DATA B(15100), B(15101), B(15102) /    14.64,  -34.43,    0.00 /
      DATA B(15439), B(15440), B(15441) /    14.20,  -33.85,    0.00 /
      DATA B(15778), B(15779), B(15780) /    13.67,  -33.20,    0.00 /
      DATA B(16117), B(16118), B(16119) /    13.01,  -32.44,    0.00 /
      DATA B(16456), B(16457), B(16458) /    10.89,  -30.20,    0.00 /
      DATA B(16795), B(16796), B(16797) /     9.87,  -29.42,    0.00 /
      DATA B(17134), B(17135), B(17136) /     8.88,  -28.62,    0.00 /
      DATA B(17473), B(17474), B(17475) /     7.31,  -26.84,    0.00 /
      DATA B(17812), B(17813), B(17814) /     6.39,  -26.12,    0.00 /
      DATA B(18151), B(18152), B(18153) /     5.63,  -25.39,    0.00 /
      DATA B(18490), B(18491), B(18492) /     5.10,  -24.71,    0.00 /
      DATA B(18829), B(18830), B(18831) /     4.72,  -24.13,    0.00 /
      DATA B(19168), B(19169), B(19170) /     4.42,  -23.67,    0.00 /
      DATA B(19507), B(19508), B(19509) /     4.16,  -23.31,    0.00 /
      DATA B(19846), B(19847), B(19848) /     3.92,  -23.03,    0.00 /
      DATA B(20185), B(20186), B(20187) /     3.67,  -22.80,    0.00 /
      DATA B(20524), B(20525), B(20526) /     3.40,  -22.61,    0.00 /
      DATA B(20863), B(20864), B(20865) /     3.13,  -22.42,    0.00 /
      DATA B(21202), B(21203), B(21204) /     2.83,  -22.23,    0.00 /
      DATA B(21541), B(21542), B(21543) /     2.50,  -22.01,    0.00 /
      DATA B(21880), B(21881), B(21882) /     2.12,  -21.77,    0.00 /
      DATA B(22219), B(22220), B(22221) /     1.66,  -21.50,    0.00 /
      DATA B(22558), B(22559), B(22560) /     1.14,  -21.19,    0.00 /
      DATA B(22897), B(22898), B(22899) /     0.50,  -20.91,    0.00 /
      DATA B(23236), B(23237), B(23238) /    -0.81,  -19.64,    0.00 /
      DATA B(23575), B(23576), B(23577) /    -1.65,  -19.29,    0.00 /
      DATA B(23914), B(23915), B(23916) /    -2.27,  -18.89,    0.00 /
      DATA B(24253), B(24254), B(24255) /    -2.79,  -18.64,    0.00 /
      DATA B(24592), B(24593), B(24594) /    -3.21,  -18.50,    0.00 /
      DATA B(24931), B(24932), B(24933) /    -1.45,  -19.41,    0.00 /
      DATA B(25270), B(25271), B(25272) /    -1.99,  -19.15,    0.00 /
      DATA B(25609), B(25610), B(25611) /    -2.49,  -18.79,    0.00 /
      DATA B(25948), B(25949), B(25950) /    -3.05,  -18.35,    0.00 /
      DATA B(26287), B(26288), B(26289) /    -3.63,  -18.00,    0.00 /
      DATA B(26626), B(26627), B(26628) /    -4.17,  -17.74,    0.00 /
      DATA B(26965), B(26966), B(26967) /    -4.56,  -17.58,    0.00 /
      DATA B(27304), B(27305), B(27306) /    -4.89,  -17.44,    0.00 /
      DATA B(  187), B(  188), B(  189) /    23.76,  -44.02,    0.00 /
      DATA B(  526), B(  527), B(  528) /    23.75,  -43.86,    0.00 /
      DATA B(  865), B(  866), B(  867) /    23.75,  -43.68,    0.00 /
      DATA B( 1204), B( 1205), B( 1206) /    23.74,  -43.49,    0.00 /
      DATA B( 1543), B( 1544), B( 1545) /    23.72,  -43.26,    0.00 /
      DATA B( 1882), B( 1883), B( 1884) /    23.70,  -43.01,    0.00 /
      DATA B( 2221), B( 2222), B( 2223) /    23.66,  -42.73,    0.00 /
      DATA B( 2560), B( 2561), B( 2562) /    23.59,  -42.41,    0.00 /
      DATA B( 2899), B( 2900), B( 2901) /    23.48,  -42.07,    0.00 /
      DATA B( 3238), B( 3239), B( 3240) /    23.29,  -41.72,    0.00 /
      DATA B( 3577), B( 3578), B( 3579) /    23.00,  -41.42,    0.00 /
      DATA B( 3916), B( 3917), B( 3918) /    22.59,  -41.18,    0.00 /
      DATA B( 4255), B( 4256), B( 4257) /    22.18,  -41.01,    0.00 /
      DATA B( 4594), B( 4595), B( 4596) /    21.85,  -40.81,    0.00 /
      DATA B( 4933), B( 4934), B( 4935) /    21.60,  -40.61,    0.00 /
      DATA B( 5272), B( 5273), B( 5274) /    21.40,  -40.44,    0.00 /
      DATA B( 5611), B( 5612), B( 5613) /    21.22,  -40.30,    0.00 /
      DATA B( 5950), B( 5951), B( 5952) /    21.06,  -40.19,    0.00 /
      DATA B( 6289), B( 6290), B( 6291) /    20.90,  -40.12,    0.00 /
      DATA B( 6628), B( 6629), B( 6630) /    20.74,  -40.07,    0.00 /
      DATA B( 6967), B( 6968), B( 6969) /    20.59,  -40.04,    0.00 /
      DATA B( 7306), B( 7307), B( 7308) /    20.43,  -40.01,    0.00 /
      DATA B( 7645), B( 7646), B( 7647) /    20.27,  -39.97,    0.00 /
      DATA B( 7984), B( 7985), B( 7986) /    20.11,  -39.94,    0.00 /
      DATA B( 8323), B( 8324), B( 8325) /    20.00,  -40.32,    0.00 /
      DATA B( 8662), B( 8663), B( 8664) /    19.54,  -40.42,    0.00 /
      DATA B( 9001), B( 9002), B( 9003) /    19.30,  -39.70,    0.00 /
      DATA B( 9340), B( 9341), B( 9342) /    19.10,  -39.54,    0.00 /
      DATA B( 9679), B( 9680), B( 9681) /    18.90,  -39.40,    0.00 /
      DATA B(10018), B(10019), B(10020) /    18.70,  -39.25,    0.00 /
      DATA B(10357), B(10358), B(10359) /    18.50,  -39.08,    0.00 /
      DATA B(10696), B(10697), B(10698) /    18.30,  -38.91,    0.00 /
      DATA B(11035), B(11036), B(11037) /    18.10,  -38.72,    0.00 /
      DATA B(11374), B(11375), B(11376) /    17.89,  -38.52,    0.00 /
      DATA B(11713), B(11714), B(11715) /    17.69,  -38.31,    0.00 /
      DATA B(12052), B(12053), B(12054) /    17.47,  -38.07,    0.00 /
      DATA B(12391), B(12392), B(12393) /    17.25,  -37.82,    0.00 /
      DATA B(12730), B(12731), B(12732) /    17.00,  -37.54,    0.00 /
      DATA B(13069), B(13070), B(13071) /    16.73,  -37.22,    0.00 /
      DATA B(13408), B(13409), B(13410) /    16.42,  -36.86,    0.00 /
      DATA B(13747), B(13748), B(13749) /    15.85,  -36.04,    0.00 /
      DATA B(14086), B(14087), B(14088) /    15.53,  -35.57,    0.00 /
      DATA B(14425), B(14426), B(14427) /    15.20,  -35.08,    0.00 /
      DATA B(14764), B(14765), B(14766) /    14.85,  -34.56,    0.00 /
      DATA B(15103), B(15104), B(15105) /    14.44,  -34.00,    0.00 /
      DATA B(15442), B(15443), B(15444) /    13.94,  -33.35,    0.00 /
      DATA B(15781), B(15782), B(15783) /    13.31,  -32.61,    0.00 /
      DATA B(16120), B(16121), B(16122) /    12.54,  -31.79,    0.00 /
      DATA B(16459), B(16460), B(16461) /    10.21,  -29.61,    0.00 /
      DATA B(16798), B(16799), B(16800) /     9.21,  -28.81,    0.00 /
      DATA B(17137), B(17138), B(17139) /     8.17,  -27.99,    0.00 /
      DATA B(17476), B(17477), B(17478) /     6.80,  -26.12,    0.00 /
      DATA B(17815), B(17816), B(17817) /     6.03,  -25.44,    0.00 /
      DATA B(18154), B(18155), B(18156) /     5.41,  -24.85,    0.00 /
      DATA B(18493), B(18494), B(18495) /     4.93,  -24.34,    0.00 /
      DATA B(18832), B(18833), B(18834) /     4.56,  -23.89,    0.00 /
      DATA B(19171), B(19172), B(19173) /     4.25,  -23.51,    0.00 /
      DATA B(19510), B(19511), B(19512) /     3.98,  -23.20,    0.00 /
      DATA B(19849), B(19850), B(19851) /     3.72,  -22.94,    0.00 /
      DATA B(20188), B(20189), B(20190) /     3.45,  -22.72,    0.00 /
      DATA B(20527), B(20528), B(20529) /     3.17,  -22.51,    0.00 /
      DATA B(20866), B(20867), B(20868) /     2.87,  -22.31,    0.00 /
      DATA B(21205), B(21206), B(21207) /     2.53,  -22.08,    0.00 /
      DATA B(21544), B(21545), B(21546) /     2.13,  -21.82,    0.00 /
      DATA B(21883), B(21884), B(21885) /     1.67,  -21.51,    0.00 /
      DATA B(22222), B(22223), B(22224) /     1.10,  -21.16,    0.00 /
      DATA B(22561), B(22562), B(22563) /     0.44,  -20.83,    0.00 /
      DATA B(22900), B(22901), B(22902) /    -0.90,  -19.91,    0.00 /
      DATA B(23239), B(23240), B(23241) /    -1.61,  -19.30,    0.00 /
      DATA B(23578), B(23579), B(23580) /    -2.26,  -18.89,    0.00 /
      DATA B(23917), B(23918), B(23919) /    -2.80,  -18.60,    0.00 /
      DATA B(24256), B(24257), B(24258) /    -3.26,  -18.44,    0.00 /
      DATA B(24595), B(24596), B(24597) /    -3.67,  -18.37,    0.00 /
      DATA B(24934), B(24935), B(24936) /    -4.06,  -18.34,    0.00 /
      DATA B(25273), B(25274), B(25275) /    -2.36,  -18.97,    0.00 /
      DATA B(25612), B(25613), B(25614) /    -3.00,  -18.57,    0.00 /
      DATA B(25951), B(25952), B(25953) /    -3.70,  -18.00,    0.00 /
      DATA B(26290), B(26291), B(26292) /    -4.25,  -17.64,    0.00 /
      DATA B(26629), B(26630), B(26631) /    -4.70,  -17.40,    0.00 /
      DATA B(26968), B(26969), B(26970) /    -5.05,  -17.25,    0.00 /
      DATA B(27307), B(27308), B(27309) /    -5.37,  -17.12,    0.00 /
      DATA B(  190), B(  191), B(  192) /    23.73,  -43.88,    0.00 /
      DATA B(  529), B(  530), B(  531) /    23.73,  -43.70,    0.00 /
      DATA B(  868), B(  869), B(  870) /    23.72,  -43.50,    0.00 /
      DATA B( 1207), B( 1208), B( 1209) /    23.70,  -43.28,    0.00 /
      DATA B( 1546), B( 1547), B( 1548) /    23.68,  -43.02,    0.00 /
      DATA B( 1885), B( 1886), B( 1887) /    23.64,  -42.73,    0.00 /
      DATA B( 2224), B( 2225), B( 2226) /    23.57,  -42.40,    0.00 /
      DATA B( 2563), B( 2564), B( 2565) /    23.44,  -42.06,    0.00 /
      DATA B( 2902), B( 2903), B( 2904) /    23.24,  -41.71,    0.00 /
      DATA B( 3241), B( 3242), B( 3243) /    22.92,  -41.39,    0.00 /
      DATA B( 3580), B( 3581), B( 3582) /    22.50,  -41.21,    0.00 /
      DATA B( 3919), B( 3920), B( 3921) /    22.11,  -41.03,    0.00 /
      DATA B( 4258), B( 4259), B( 4260) /    21.81,  -40.83,    0.00 /
      DATA B( 4597), B( 4598), B( 4599) /    21.58,  -40.63,    0.00 /
      DATA B( 4936), B( 4937), B( 4938) /    21.38,  -40.46,    0.00 /
      DATA B( 5275), B( 5276), B( 5277) /    21.22,  -40.33,    0.00 /
      DATA B( 5614), B( 5615), B( 5616) /    21.06,  -40.23,    0.00 /
      DATA B( 5953), B( 5954), B( 5955) /    20.90,  -40.17,    0.00 /
      DATA B( 6292), B( 6293), B( 6294) /    20.74,  -40.13,    0.00 /
      DATA B( 6631), B( 6632), B( 6633) /    20.58,  -40.11,    0.00 /
      DATA B( 6970), B( 6971), B( 6972) /    20.42,  -40.10,    0.00 /
      DATA B( 7309), B( 7310), B( 7311) /    20.25,  -40.08,    0.00 /
      DATA B( 7648), B( 7649), B( 7650) /    20.08,  -40.02,    0.00 /
      DATA B( 7987), B( 7988), B( 7989) /    19.99,  -40.44,    0.00 /
      DATA B( 8326), B( 8327), B( 8328) /    19.61,  -39.89,    0.00 /
      DATA B( 8665), B( 8666), B( 8667) /    19.41,  -39.74,    0.00 /
      DATA B( 9004), B( 9005), B( 9006) /    19.21,  -39.59,    0.00 /
      DATA B( 9343), B( 9344), B( 9345) /    19.01,  -39.44,    0.00 /
      DATA B( 9682), B( 9683), B( 9684) /    18.82,  -39.28,    0.00 /
      DATA B(10021), B(10022), B(10023) /    18.62,  -39.12,    0.00 /
      DATA B(10360), B(10361), B(10362) /    18.42,  -38.96,    0.00 /
      DATA B(10699), B(10700), B(10701) /    18.22,  -38.78,    0.00 /
      DATA B(11038), B(11039), B(11040) /    18.02,  -38.59,    0.00 /
      DATA B(11377), B(11378), B(11379) /    17.81,  -38.38,    0.00 /
      DATA B(11716), B(11717), B(11718) /    17.60,  -38.16,    0.00 /
      DATA B(12055), B(12056), B(12057) /    17.38,  -37.92,    0.00 /
      DATA B(12394), B(12395), B(12396) /    17.14,  -37.65,    0.00 /
      DATA B(12733), B(12734), B(12735) /    16.88,  -37.34,    0.00 /
      DATA B(13072), B(13073), B(13074) /    16.58,  -37.00,    0.00 /
      DATA B(13411), B(13412), B(13413) /    16.01,  -36.18,    0.00 /
      DATA B(13750), B(13751), B(13752) /    15.70,  -35.71,    0.00 /
      DATA B(14089), B(14090), B(14091) /    15.37,  -35.22,    0.00 /
      DATA B(14428), B(14429), B(14430) /    15.03,  -34.70,    0.00 /
      DATA B(14767), B(14768), B(14769) /    14.65,  -34.14,    0.00 /
      DATA B(15106), B(15107), B(15108) /    14.18,  -33.50,    0.00 /
      DATA B(15445), B(15446), B(15447) /    13.58,  -32.77,    0.00 /
      DATA B(15784), B(15785), B(15786) /    12.84,  -31.93,    0.00 /
      DATA B(16123), B(16124), B(16125) /    10.51,  -29.73,    0.00 /
      DATA B(16462), B(16463), B(16464) /     9.52,  -29.01,    0.00 /
      DATA B(16801), B(16802), B(16803) /     8.57,  -28.20,    0.00 /
      DATA B(17140), B(17141), B(17142) /     7.17,  -26.33,    0.00 /
      DATA B(17479), B(17480), B(17481) /     6.37,  -25.54,    0.00 /
      DATA B(17818), B(17819), B(17820) /     5.73,  -24.91,    0.00 /
      DATA B(18157), B(18158), B(18159) /     5.20,  -24.43,    0.00 /
      DATA B(18496), B(18497), B(18498) /     4.76,  -24.02,    0.00 /
      DATA B(18835), B(18836), B(18837) /     4.40,  -23.66,    0.00 /
      DATA B(19174), B(19175), B(19176) /     4.08,  -23.34,    0.00 /
      DATA B(19513), B(19514), B(19515) /     3.79,  -23.07,    0.00 /
      DATA B(19852), B(19853), B(19854) /     3.51,  -22.83,    0.00 /
      DATA B(20191), B(20192), B(20193) /     3.21,  -22.60,    0.00 /
      DATA B(20530), B(20531), B(20532) /     2.90,  -22.38,    0.00 /
      DATA B(20869), B(20870), B(20871) /     2.54,  -22.15,    0.00 /
      DATA B(21208), B(21209), B(21210) /     2.13,  -21.87,    0.00 /
      DATA B(21547), B(21548), B(21549) /     1.64,  -21.55,    0.00 /
      DATA B(21886), B(21887), B(21888) /     1.05,  -21.15,    0.00 /
      DATA B(22225), B(22226), B(22227) /     0.37,  -20.72,    0.00 /
      DATA B(22564), B(22565), B(22566) /    -0.88,  -19.96,    0.00 /
      DATA B(22903), B(22904), B(22905) /    -1.58,  -19.30,    0.00 /
      DATA B(23242), B(23243), B(23244) /    -2.26,  -18.87,    0.00 /
      DATA B(23581), B(23582), B(23583) /    -2.81,  -18.55,    0.00 /
      DATA B(23920), B(23921), B(23922) /    -3.27,  -18.36,    0.00 /
      DATA B(24259), B(24260), B(24261) /    -3.68,  -18.26,    0.00 /
      DATA B(24598), B(24599), B(24600) /    -4.09,  -18.23,    0.00 /
      DATA B(24937), B(24938), B(24939) /    -4.49,  -18.21,    0.00 /
      DATA B(25276), B(25277), B(25278) /    -2.65,  -18.72,    0.00 /
      DATA B(25615), B(25616), B(25617) /    -3.91,  -18.09,    0.00 /
      DATA B(25954), B(25955), B(25956) /    -4.40,  -17.57,    0.00 /
      DATA B(26293), B(26294), B(26295) /    -4.83,  -17.27,    0.00 /
      DATA B(26632), B(26633), B(26634) /    -5.20,  -17.08,    0.00 /
      DATA B(26971), B(26972), B(26973) /    -5.50,  -16.94,    0.00 /
      DATA B(27310), B(27311), B(27312) /    -5.77,  -16.82,    0.00 /
      DATA B(  193), B(  194), B(  195) /    23.70,  -43.72,    0.00 /
      DATA B(  532), B(  533), B(  534) /    23.69,  -43.52,    0.00 /
      DATA B(  871), B(  872), B(  873) /    23.68,  -43.28,    0.00 /
      DATA B( 1210), B( 1211), B( 1212) /    23.66,  -43.02,    0.00 /
      DATA B( 1549), B( 1550), B( 1551) /    23.62,  -42.72,    0.00 /
      DATA B( 1888), B( 1889), B( 1890) /    23.54,  -42.39,    0.00 /
      DATA B( 2227), B( 2228), B( 2229) /    23.40,  -42.04,    0.00 /
      DATA B( 2566), B( 2567), B( 2568) /    23.17,  -41.70,    0.00 /
      DATA B( 2905), B( 2906), B( 2907) /    22.85,  -41.40,    0.00 /
      DATA B( 3244), B( 3245), B( 3246) /    22.42,  -41.24,    0.00 /
      DATA B( 3583), B( 3584), B( 3585) /    22.05,  -41.05,    0.00 /
      DATA B( 3922), B( 3923), B( 3924) /    21.77,  -40.85,    0.00 /
      DATA B( 4261), B( 4262), B( 4263) /    21.55,  -40.65,    0.00 /
      DATA B( 4600), B( 4601), B( 4602) /    21.37,  -40.49,    0.00 /
      DATA B( 4939), B( 4940), B( 4941) /    21.21,  -40.36,    0.00 /
      DATA B( 5278), B( 5279), B( 5280) /    21.05,  -40.27,    0.00 /
      DATA B( 5617), B( 5618), B( 5619) /    20.90,  -40.21,    0.00 /
      DATA B( 5956), B( 5957), B( 5958) /    20.75,  -40.17,    0.00 /
      DATA B( 6295), B( 6296), B( 6297) /    20.59,  -40.16,    0.00 /
      DATA B( 6634), B( 6635), B( 6636) /    20.43,  -40.16,    0.00 /
      DATA B( 6973), B( 6974), B( 6975) /    20.26,  -40.16,    0.00 /
      DATA B( 7312), B( 7313), B( 7314) /    20.09,  -40.16,    0.00 /
      DATA B( 7651), B( 7652), B( 7653) /    19.90,  -40.11,    0.00 /
      DATA B( 7990), B( 7991), B( 7992) /    19.71,  -39.94,    0.00 /
      DATA B( 8329), B( 8330), B( 8331) /    19.52,  -39.78,    0.00 /
      DATA B( 8668), B( 8669), B( 8670) /    19.32,  -39.63,    0.00 /
      DATA B( 9007), B( 9008), B( 9009) /    19.13,  -39.47,    0.00 /
      DATA B( 9346), B( 9347), B( 9348) /    18.93,  -39.32,    0.00 /
      DATA B( 9685), B( 9686), B( 9687) /    18.74,  -39.16,    0.00 /
      DATA B(10024), B(10025), B(10026) /    18.54,  -39.00,    0.00 /
      DATA B(10363), B(10364), B(10365) /    18.34,  -38.83,    0.00 /
      DATA B(10702), B(10703), B(10704) /    18.14,  -38.65,    0.00 /
      DATA B(11041), B(11042), B(11043) /    17.94,  -38.45,    0.00 /
      DATA B(11380), B(11381), B(11382) /    17.73,  -38.24,    0.00 /
      DATA B(11719), B(11720), B(11721) /    17.51,  -38.01,    0.00 /
      DATA B(12058), B(12059), B(12060) /    17.28,  -37.75,    0.00 /
      DATA B(12397), B(12398), B(12399) /    17.02,  -37.46,    0.00 /
      DATA B(12736), B(12737), B(12738) /    16.74,  -37.13,    0.00 /
      DATA B(13075), B(13076), B(13077) /    16.41,  -36.76,    0.00 /
      DATA B(13414), B(13415), B(13416) /    15.85,  -35.85,    0.00 /
      DATA B(13753), B(13754), B(13755) /    15.53,  -35.36,    0.00 /
      DATA B(14092), B(14093), B(14094) /    15.20,  -34.85,    0.00 /
      DATA B(14431), B(14432), B(14433) /    14.83,  -34.29,    0.00 /
      DATA B(14770), B(14771), B(14772) /    14.38,  -33.65,    0.00 /
      DATA B(15109), B(15110), B(15111) /    13.82,  -32.92,    0.00 /
      DATA B(15448), B(15449), B(15450) /    13.19,  -32.06,    0.00 /
      DATA B(15787), B(15788), B(15789) /    10.77,  -29.80,    0.00 /
      DATA B(16126), B(16127), B(16128) /     9.80,  -29.12,    0.00 /
      DATA B(16465), B(16466), B(16467) /     8.88,  -28.42,    0.00 /
      DATA B(16804), B(16805), B(16806) /     8.02,  -27.61,    0.00 /
      DATA B(17143), B(17144), B(17145) /     6.70,  -25.79,    0.00 /
      DATA B(17482), B(17483), B(17484) /     6.02,  -25.04,    0.00 /
      DATA B(17821), B(17822), B(17823) /     5.46,  -24.50,    0.00 /
      DATA B(18160), B(18161), B(18162) /     4.99,  -24.08,    0.00 /
      DATA B(18499), B(18500), B(18501) /     4.58,  -23.74,    0.00 /
      DATA B(18838), B(18839), B(18840) /     4.22,  -23.44,    0.00 /
      DATA B(19177), B(19178), B(19179) /     3.89,  -23.16,    0.00 /
      DATA B(19516), B(19517), B(19518) /     3.58,  -22.92,    0.00 /
      DATA B(19855), B(19856), B(19857) /     3.26,  -22.68,    0.00 /
      DATA B(20194), B(20195), B(20196) /     2.93,  -22.45,    0.00 /
      DATA B(20533), B(20534), B(20535) /     2.55,  -22.20,    0.00 /
      DATA B(20872), B(20873), B(20874) /     2.12,  -21.91,    0.00 /
      DATA B(21211), B(21212), B(21213) /     1.60,  -21.57,    0.00 /
      DATA B(21550), B(21551), B(21552) /     0.96,  -21.15,    0.00 /
      DATA B(21889), B(21890), B(21891) /     0.20,  -20.67,    0.00 /
      DATA B(22228), B(22229), B(22230) /    -0.74,  -19.99,    0.00 /
      DATA B(22567), B(22568), B(22569) /    -1.56,  -19.30,    0.00 /
      DATA B(22906), B(22907), B(22908) /    -2.28,  -18.85,    0.00 /
      DATA B(23245), B(23246), B(23247) /    -2.83,  -18.51,    0.00 /
      DATA B(23584), B(23585), B(23586) /    -3.27,  -18.28,    0.00 /
      DATA B(23923), B(23924), B(23925) /    -3.65,  -18.14,    0.00 /
      DATA B(24262), B(24263), B(24264) /    -4.02,  -18.07,    0.00 /
      DATA B(24601), B(24602), B(24603) /    -4.41,  -18.07,    0.00 /
      DATA B(24940), B(24941), B(24942) /    -4.80,  -18.08,    0.00 /
      DATA B(25279), B(25280), B(25281) /    -2.67,  -18.35,    0.00 /
      DATA B(25618), B(25619), B(25620) /    -4.67,  -17.56,    0.00 /
      DATA B(25957), B(25958), B(25959) /    -5.05,  -17.19,    0.00 /
      DATA B(26296), B(26297), B(26298) /    -5.36,  -16.95,    0.00 /
      DATA B(26635), B(26636), B(26637) /    -5.64,  -16.78,    0.00 /
      DATA B(26974), B(26975), B(26976) /    -5.88,  -16.65,    0.00 /
      DATA B(27313), B(27314), B(27315) /    -6.11,  -16.54,    0.00 /
      DATA B(  196), B(  197), B(  198) /    23.67,  -43.52,    0.00 /
      DATA B(  535), B(  536), B(  537) /    23.66,  -43.29,    0.00 /
      DATA B(  874), B(  875), B(  876) /    23.63,  -43.02,    0.00 /
      DATA B( 1213), B( 1214), B( 1215) /    23.59,  -42.71,    0.00 /
      DATA B( 1552), B( 1553), B( 1554) /    23.50,  -42.38,    0.00 /
      DATA B( 1891), B( 1892), B( 1893) /    23.35,  -42.03,    0.00 /
      DATA B( 2230), B( 2231), B( 2232) /    23.10,  -41.70,    0.00 /
      DATA B( 2569), B( 2570), B( 2571) /    22.76,  -41.43,    0.00 /
      DATA B( 2908), B( 2909), B( 2910) /    22.34,  -41.27,    0.00 /
      DATA B( 3247), B( 3248), B( 3249) /    21.99,  -41.07,    0.00 /
      DATA B( 3586), B( 3587), B( 3588) /    21.73,  -40.87,    0.00 /
      DATA B( 3925), B( 3926), B( 3927) /    21.53,  -40.67,    0.00 /
      DATA B( 4264), B( 4265), B( 4266) /    21.35,  -40.52,    0.00 /
      DATA B( 4603), B( 4604), B( 4605) /    21.20,  -40.39,    0.00 /
      DATA B( 4942), B( 4943), B( 4944) /    21.05,  -40.30,    0.00 /
      DATA B( 5281), B( 5282), B( 5283) /    20.91,  -40.25,    0.00 /
      DATA B( 5620), B( 5621), B( 5622) /    20.76,  -40.21,    0.00 /
      DATA B( 5959), B( 5960), B( 5961) /    20.61,  -40.20,    0.00 /
      DATA B( 6298), B( 6299), B( 6300) /    20.46,  -40.20,    0.00 /
      DATA B( 6637), B( 6638), B( 6639) /    20.30,  -40.22,    0.00 /
      DATA B( 6976), B( 6977), B( 6978) /    20.08,  -40.30,    0.00 /
      DATA B( 7315), B( 7316), B( 7317) /    19.96,  -40.12,    0.00 /
      DATA B( 7654), B( 7655), B( 7656) /    19.78,  -39.98,    0.00 /
      DATA B( 7993), B( 7994), B( 7995) /    19.61,  -39.82,    0.00 /
      DATA B( 8332), B( 8333), B( 8334) /    19.42,  -39.66,    0.00 /
      DATA B( 8671), B( 8672), B( 8673) /    19.23,  -39.51,    0.00 /
      DATA B( 9010), B( 9011), B( 9012) /    19.04,  -39.36,    0.00 /
      DATA B( 9349), B( 9350), B( 9351) /    18.85,  -39.20,    0.00 /
      DATA B( 9688), B( 9689), B( 9690) /    18.66,  -39.04,    0.00 /
      DATA B(10027), B(10028), B(10029) /    18.46,  -38.88,    0.00 /
      DATA B(10366), B(10367), B(10368) /    18.26,  -38.70,    0.00 /
      DATA B(10705), B(10706), B(10707) /    18.06,  -38.51,    0.00 /
      DATA B(11044), B(11045), B(11046) /    17.85,  -38.31,    0.00 /
      DATA B(11383), B(11384), B(11385) /    17.63,  -38.09,    0.00 /
      DATA B(11722), B(11723), B(11724) /    17.40,  -37.85,    0.00 /
      DATA B(12061), B(12062), B(12063) /    17.16,  -37.57,    0.00 /
      DATA B(12400), B(12401), B(12402) /    16.88,  -37.26,    0.00 /
      DATA B(12739), B(12740), B(12741) /    16.57,  -36.90,    0.00 /
      DATA B(13078), B(13079), B(13080) /    16.00,  -36.00,    0.00 /
      DATA B(13417), B(13418), B(13419) /    15.68,  -35.51,    0.00 /
      DATA B(13756), B(13757), B(13758) /    15.35,  -35.00,    0.00 /
      DATA B(14095), B(14096), B(14097) /    14.99,  -34.45,    0.00 /
      DATA B(14434), B(14435), B(14436) /    14.56,  -33.82,    0.00 /
      DATA B(14773), B(14774), B(14775) /    14.03,  -33.08,    0.00 /
      DATA B(15112), B(15113), B(15114) /    13.37,  -32.22,    0.00 /
      DATA B(15451), B(15452), B(15453) /    11.04,  -29.80,    0.00 /
      DATA B(15790), B(15791), B(15792) /    10.09,  -29.13,    0.00 /
      DATA B(16129), B(16130), B(16131) /     9.17,  -28.51,    0.00 /
      DATA B(16468), B(16469), B(16470) /     8.31,  -27.84,    0.00 /
      DATA B(16807), B(16808), B(16809) /     7.02,  -26.12,    0.00 /
      DATA B(17146), B(17147), B(17148) /     6.34,  -25.28,    0.00 /
      DATA B(17485), B(17486), B(17487) /     5.73,  -24.62,    0.00 /
      DATA B(17824), B(17825), B(17826) /     5.23,  -24.14,    0.00 /
      DATA B(18163), B(18164), B(18165) /     4.79,  -23.78,    0.00 /
      DATA B(18502), B(18503), B(18504) /     4.39,  -23.48,    0.00 /
      DATA B(18841), B(18842), B(18843) /     4.02,  -23.21,    0.00 /
      DATA B(19180), B(19181), B(19182) /     3.67,  -22.96,    0.00 /
      DATA B(19519), B(19520), B(19521) /     3.32,  -22.73,    0.00 /
      DATA B(19858), B(19859), B(19860) /     2.96,  -22.49,    0.00 /
      DATA B(20197), B(20198), B(20199) /     2.57,  -22.23,    0.00 /
      DATA B(20536), B(20537), B(20538) /     2.11,  -21.94,    0.00 /
      DATA B(20875), B(20876), B(20877) /     1.56,  -21.58,    0.00 /
      DATA B(21214), B(21215), B(21216) /     0.89,  -21.15,    0.00 /
      DATA B(21553), B(21554), B(21555) /     0.12,  -20.62,    0.00 /
      DATA B(21892), B(21893), B(21894) /    -0.81,  -20.01,    0.00 /
      DATA B(22231), B(22232), B(22233) /    -1.64,  -19.33,    0.00 /
      DATA B(22570), B(22571), B(22572) /    -2.34,  -18.81,    0.00 /
      DATA B(22909), B(22910), B(22911) /    -2.89,  -18.46,    0.00 /
      DATA B(23248), B(23249), B(23250) /    -3.32,  -18.22,    0.00 /
      DATA B(23587), B(23588), B(23589) /    -3.67,  -18.06,    0.00 /
      DATA B(23926), B(23927), B(23928) /    -3.97,  -17.96,    0.00 /
      DATA B(24265), B(24266), B(24267) /    -4.26,  -17.90,    0.00 /
      DATA B(24604), B(24605), B(24606) /    -4.60,  -17.89,    0.00 /
      DATA B(24943), B(24944), B(24945) /    -5.02,  -17.97,    0.00 /
      DATA B(25282), B(25283), B(25284) /    -4.96,  -17.63,    0.00 /
      DATA B(25621), B(25622), B(25623) /    -5.41,  -17.16,    0.00 /
      DATA B(25960), B(25961), B(25962) /    -5.62,  -16.87,    0.00 /
      DATA B(26299), B(26300), B(26301) /    -5.83,  -16.67,    0.00 /
      DATA B(26638), B(26639), B(26640) /    -6.03,  -16.51,    0.00 /
      DATA B(26977), B(26978), B(26979) /    -6.23,  -16.38,    0.00 /
      DATA B(27316), B(27317), B(27318) /    -6.43,  -16.27,    0.00 /
      DATA B(  199), B(  200), B(  201) /    23.63,  -43.28,    0.00 /
      DATA B(  538), B(  539), B(  540) /    23.60,  -43.01,    0.00 /
      DATA B(  877), B(  878), B(  879) /    23.56,  -42.70,    0.00 /
      DATA B( 1216), B( 1217), B( 1218) /    23.46,  -42.36,    0.00 /
      DATA B( 1555), B( 1556), B( 1557) /    23.30,  -42.01,    0.00 /
      DATA B( 1894), B( 1895), B( 1896) /    23.03,  -41.69,    0.00 /
      DATA B( 2233), B( 2234), B( 2235) /    22.66,  -41.47,    0.00 /
      DATA B( 2572), B( 2573), B( 2574) /    22.26,  -41.30,    0.00 /
      DATA B( 2911), B( 2912), B( 2913) /    21.93,  -41.10,    0.00 /
      DATA B( 3250), B( 3251), B( 3252) /    21.69,  -40.89,    0.00 /
      DATA B( 3589), B( 3590), B( 3591) /    21.50,  -40.70,    0.00 /
      DATA B( 3928), B( 3929), B( 3930) /    21.34,  -40.55,    0.00 /
      DATA B( 4267), B( 4268), B( 4269) /    21.19,  -40.43,    0.00 /
      DATA B( 4606), B( 4607), B( 4608) /    21.05,  -40.34,    0.00 /
      DATA B( 4945), B( 4946), B( 4947) /    20.91,  -40.28,    0.00 /
      DATA B( 5284), B( 5285), B( 5286) /    20.76,  -40.25,    0.00 /
      DATA B( 5623), B( 5624), B( 5625) /    20.62,  -40.24,    0.00 /
      DATA B( 5962), B( 5963), B( 5964) /    20.48,  -40.25,    0.00 /
      DATA B( 6301), B( 6302), B( 6303) /    20.34,  -40.26,    0.00 /
      DATA B( 6640), B( 6641), B( 6642) /    20.17,  -40.32,    0.00 /
      DATA B( 6979), B( 6980), B( 6981) /    20.02,  -40.16,    0.00 /
      DATA B( 7318), B( 7319), B( 7320) /    19.87,  -40.00,    0.00 /
      DATA B( 7657), B( 7658), B( 7659) /    19.70,  -39.86,    0.00 /
      DATA B( 7996), B( 7997), B( 7998) /    19.52,  -39.70,    0.00 /
      DATA B( 8335), B( 8336), B( 8337) /    19.33,  -39.55,    0.00 /
      DATA B( 8674), B( 8675), B( 8676) /    19.15,  -39.39,    0.00 /
      DATA B( 9013), B( 9014), B( 9015) /    18.96,  -39.24,    0.00 /
      DATA B( 9352), B( 9353), B( 9354) /    18.77,  -39.08,    0.00 /
      DATA B( 9691), B( 9692), B( 9693) /    18.57,  -38.92,    0.00 /
      DATA B(10030), B(10031), B(10032) /    18.37,  -38.75,    0.00 /
      DATA B(10369), B(10370), B(10371) /    18.17,  -38.57,    0.00 /
      DATA B(10708), B(10709), B(10710) /    17.96,  -38.38,    0.00 /
      DATA B(11047), B(11048), B(11049) /    17.75,  -38.17,    0.00 /
      DATA B(11386), B(11387), B(11388) /    17.53,  -37.94,    0.00 /
      DATA B(11725), B(11726), B(11727) /    17.29,  -37.68,    0.00 /
      DATA B(12064), B(12065), B(12066) /    17.02,  -37.38,    0.00 /
      DATA B(12403), B(12404), B(12405) /    16.72,  -37.03,    0.00 /
      DATA B(12742), B(12743), B(12744) /    16.14,  -36.16,    0.00 /
      DATA B(13081), B(13082), B(13083) /    15.81,  -35.67,    0.00 /
      DATA B(13420), B(13421), B(13422) /    15.48,  -35.15,    0.00 /
      DATA B(13759), B(13760), B(13761) /    15.13,  -34.61,    0.00 /
      DATA B(14098), B(14099), B(14100) /    14.72,  -33.99,    0.00 /
      DATA B(14437), B(14438), B(14439) /    14.22,  -33.27,    0.00 /
      DATA B(14776), B(14777), B(14778) /    13.59,  -32.41,    0.00 /
      DATA B(15115), B(15116), B(15117) /    11.30,  -29.83,    0.00 /
      DATA B(15454), B(15455), B(15456) /    10.37,  -29.10,    0.00 /
      DATA B(15793), B(15794), B(15795) /     9.46,  -28.47,    0.00 /
      DATA B(16132), B(16133), B(16134) /     8.61,  -27.90,    0.00 /
      DATA B(16471), B(16472), B(16473) /     7.83,  -27.27,    0.00 /
      DATA B(16810), B(16811), B(16812) /     6.67,  -25.60,    0.00 /
      DATA B(17149), B(17150), B(17151) /     6.02,  -24.83,    0.00 /
      DATA B(17488), B(17489), B(17490) /     5.48,  -24.25,    0.00 /
      DATA B(17827), B(17828), B(17829) /     5.00,  -23.82,    0.00 /
      DATA B(18166), B(18167), B(18168) /     4.57,  -23.49,    0.00 /
      DATA B(18505), B(18506), B(18507) /     4.17,  -23.21,    0.00 /
      DATA B(18844), B(18845), B(18846) /     3.78,  -22.96,    0.00 /
      DATA B(19183), B(19184), B(19185) /     3.40,  -22.73,    0.00 /
      DATA B(19522), B(19523), B(19524) /     3.00,  -22.49,    0.00 /
      DATA B(19861), B(19862), B(19863) /     2.58,  -22.24,    0.00 /
      DATA B(20200), B(20201), B(20202) /     2.10,  -21.94,    0.00 /
      DATA B(20539), B(20540), B(20541) /     1.53,  -21.57,    0.00 /
      DATA B(20878), B(20879), B(20880) /     0.83,  -21.13,    0.00 /
      DATA B(21217), B(21218), B(21219) /     0.02,  -20.58,    0.00 /
      DATA B(21556), B(21557), B(21558) /    -0.92,  -19.95,    0.00 /
      DATA B(21895), B(21896), B(21897) /    -1.74,  -19.31,    0.00 /
      DATA B(22234), B(22235), B(22236) /    -2.45,  -18.79,    0.00 /
      DATA B(22573), B(22574), B(22575) /    -3.00,  -18.41,    0.00 /
      DATA B(22912), B(22913), B(22914) /    -3.41,  -18.15,    0.00 /
      DATA B(23251), B(23252), B(23253) /    -3.74,  -17.98,    0.00 /
      DATA B(23590), B(23591), B(23592) /    -4.01,  -17.87,    0.00 /
      DATA B(23929), B(23930), B(23931) /    -4.24,  -17.80,    0.00 /
      DATA B(24268), B(24269), B(24270) /    -4.44,  -17.76,    0.00 /
      DATA B(24607), B(24608), B(24609) /    -4.60,  -17.76,    0.00 /
      DATA B(24946), B(24947), B(24948) /    -4.57,  -17.89,    0.00 /
      DATA B(25285), B(25286), B(25287) /    -6.10,  -17.14,    0.00 /
      DATA B(25624), B(25625), B(25626) /    -6.01,  -16.82,    0.00 /
      DATA B(25963), B(25964), B(25965) /    -6.10,  -16.60,    0.00 /
      DATA B(26302), B(26303), B(26304) /    -6.24,  -16.41,    0.00 /
      DATA B(26641), B(26642), B(26643) /    -6.39,  -16.26,    0.00 /
      DATA B(26980), B(26981), B(26982) /    -6.57,  -16.13,    0.00 /
      DATA B(27319), B(27320), B(27321) /    -6.75,  -16.01,    0.00 /
      DATA B(  202), B(  203), B(  204) /    23.57,  -42.99,    0.00 /
      DATA B(  541), B(  542), B(  543) /    23.52,  -42.68,    0.00 /
      DATA B(  880), B(  881), B(  882) /    23.41,  -42.35,    0.00 /
      DATA B( 1219), B( 1220), B( 1221) /    23.23,  -42.00,    0.00 /
      DATA B( 1558), B( 1559), B( 1560) /    22.95,  -41.68,    0.00 /
      DATA B( 1897), B( 1898), B( 1899) /    22.56,  -41.51,    0.00 /
      DATA B( 2236), B( 2237), B( 2238) /    22.18,  -41.33,    0.00 /
      DATA B( 2575), B( 2576), B( 2577) /    21.88,  -41.12,    0.00 /
      DATA B( 2914), B( 2915), B( 2916) /    21.65,  -40.91,    0.00 /
      DATA B( 3253), B( 3254), B( 3255) /    21.47,  -40.73,    0.00 /
      DATA B( 3592), B( 3593), B( 3594) /    21.32,  -40.58,    0.00 /
      DATA B( 3931), B( 3932), B( 3933) /    21.18,  -40.47,    0.00 /
      DATA B( 4270), B( 4271), B( 4272) /    21.04,  -40.39,    0.00 /
      DATA B( 4609), B( 4610), B( 4611) /    20.90,  -40.33,    0.00 /
      DATA B( 4948), B( 4949), B( 4950) /    20.77,  -40.29,    0.00 /
      DATA B( 5287), B( 5288), B( 5289) /    20.63,  -40.28,    0.00 /
      DATA B( 5626), B( 5627), B( 5628) /    20.49,  -40.29,    0.00 /
      DATA B( 5965), B( 5966), B( 5967) /    20.36,  -40.31,    0.00 /
      DATA B( 6304), B( 6305), B( 6306) /    20.26,  -40.36,    0.00 /
      DATA B( 6643), B( 6644), B( 6645) /    20.11,  -40.20,    0.00 /
      DATA B( 6982), B( 6983), B( 6984) /    19.95,  -40.04,    0.00 /
      DATA B( 7321), B( 7322), B( 7323) /    19.79,  -39.89,    0.00 /
      DATA B( 7660), B( 7661), B( 7662) /    19.61,  -39.74,    0.00 /
      DATA B( 7999), B( 8000), B( 8001) /    19.43,  -39.59,    0.00 /
      DATA B( 8338), B( 8339), B( 8340) /    19.25,  -39.43,    0.00 /
      DATA B( 8677), B( 8678), B( 8679) /    19.07,  -39.28,    0.00 /
      DATA B( 9016), B( 9017), B( 9018) /    18.88,  -39.12,    0.00 /
      DATA B( 9355), B( 9356), B( 9357) /    18.68,  -38.96,    0.00 /
      DATA B( 9694), B( 9695), B( 9696) /    18.49,  -38.80,    0.00 /
      DATA B(10033), B(10034), B(10035) /    18.28,  -38.63,    0.00 /
      DATA B(10372), B(10373), B(10374) /    18.08,  -38.44,    0.00 /
      DATA B(10711), B(10712), B(10713) /    17.87,  -38.24,    0.00 /
      DATA B(11050), B(11051), B(11052) /    17.65,  -38.02,    0.00 /
      DATA B(11389), B(11390), B(11391) /    17.41,  -37.78,    0.00 /
      DATA B(11728), B(11729), B(11730) /    17.15,  -37.49,    0.00 /
      DATA B(12067), B(12068), B(12069) /    16.86,  -37.17,    0.00 /
      DATA B(12406), B(12407), B(12408) /    16.52,  -36.79,    0.00 /
      DATA B(12745), B(12746), B(12747) /    15.95,  -35.83,    0.00 /
      DATA B(13084), B(13085), B(13086) /    15.61,  -35.31,    0.00 /
      DATA B(13423), B(13424), B(13425) /    15.26,  -34.77,    0.00 /
      DATA B(13762), B(13763), B(13764) /    14.86,  -34.17,    0.00 /
      DATA B(14101), B(14102), B(14103) /    14.39,  -33.47,    0.00 /
      DATA B(14440), B(14441), B(14442) /    13.79,  -32.64,    0.00 /
      DATA B(14779), B(14780), B(14781) /    11.53,  -29.93,    0.00 /
      DATA B(15118), B(15119), B(15120) /    10.61,  -29.13,    0.00 /
      DATA B(15457), B(15458), B(15459) /     9.73,  -28.42,    0.00 /
      DATA B(15796), B(15797), B(15798) /     8.91,  -27.82,    0.00 /
      DATA B(16135), B(16136), B(16137) /     8.10,  -27.28,    0.00 /
      DATA B(16474), B(16475), B(16476) /     7.36,  -26.70,    0.00 /
      DATA B(16813), B(16814), B(16815) /     6.31,  -25.08,    0.00 /
      DATA B(17152), B(17153), B(17154) /     5.75,  -24.41,    0.00 /
      DATA B(17491), B(17492), B(17493) /     5.24,  -23.90,    0.00 /
      DATA B(17830), B(17831), B(17832) /     4.77,  -23.51,    0.00 /
      DATA B(18169), B(18170), B(18171) /     4.34,  -23.19,    0.00 /
      DATA B(18508), B(18509), B(18510) /     3.91,  -22.92,    0.00 /
      DATA B(18847), B(18848), B(18849) /     3.48,  -22.68,    0.00 /
      DATA B(19186), B(19187), B(19188) /     3.05,  -22.44,    0.00 /
      DATA B(19525), B(19526), B(19527) /     2.59,  -22.19,    0.00 /
      DATA B(19864), B(19865), B(19866) /     2.08,  -21.90,    0.00 /
      DATA B(20203), B(20204), B(20205) /     1.47,  -21.53,    0.00 /
      DATA B(20542), B(20543), B(20544) /     0.75,  -21.07,    0.00 /
      DATA B(20881), B(20882), B(20883) /    -0.09,  -20.55,    0.00 /
      DATA B(21220), B(21221), B(21222) /    -1.03,  -19.86,    0.00 /
      DATA B(21559), B(21560), B(21561) /    -1.88,  -19.24,    0.00 /
      DATA B(21898), B(21899), B(21900) /    -2.59,  -18.73,    0.00 /
      DATA B(22237), B(22238), B(22239) /    -3.14,  -18.36,    0.00 /
      DATA B(22576), B(22577), B(22578) /    -3.55,  -18.09,    0.00 /
      DATA B(22915), B(22916), B(22917) /    -3.87,  -17.91,    0.00 /
      DATA B(23254), B(23255), B(23256) /    -4.13,  -17.79,    0.00 /
      DATA B(23593), B(23594), B(23595) /    -4.33,  -17.71,    0.00 /
      DATA B(23932), B(23933), B(23934) /    -4.50,  -17.67,    0.00 /
      DATA B(24271), B(24272), B(24273) /    -4.62,  -17.67,    0.00 /
      DATA B(24610), B(24611), B(24612) /    -4.66,  -17.72,    0.00 /
      DATA B(24949), B(24950), B(24951) /    -4.60,  -17.94,    0.00 /
      DATA B(25288), B(25289), B(25290) /    -6.35,  -16.77,    0.00 /
      DATA B(25627), B(25628), B(25629) /    -6.41,  -16.55,    0.00 /
      DATA B(25966), B(25967), B(25968) /    -6.49,  -16.34,    0.00 /
      DATA B(26305), B(26306), B(26307) /    -6.61,  -16.17,    0.00 /
      DATA B(26644), B(26645), B(26646) /    -6.75,  -16.02,    0.00 /
      DATA B(26983), B(26984), B(26985) /    -6.92,  -15.88,    0.00 /
      DATA B(27322), B(27323), B(27324) /    -7.10,  -15.77,    0.00 /
      DATA B(  205), B(  206), B(  207) /    23.47,  -42.65,    0.00 /
      DATA B(  544), B(  545), B(  546) /    23.35,  -42.32,    0.00 /
      DATA B(  883), B(  884), B(  885) /    23.16,  -41.99,    0.00 /
      DATA B( 1222), B( 1223), B( 1224) /    22.88,  -41.69,    0.00 /
      DATA B( 1561), B( 1562), B( 1563) /    22.46,  -41.54,    0.00 /
      DATA B( 1900), B( 1901), B( 1902) /    22.10,  -41.36,    0.00 /
      DATA B( 2239), B( 2240), B( 2241) /    21.82,  -41.15,    0.00 /
      DATA B( 2578), B( 2579), B( 2580) /    21.62,  -40.94,    0.00 /
      DATA B( 2917), B( 2918), B( 2919) /    21.45,  -40.77,    0.00 /
      DATA B( 3256), B( 3257), B( 3258) /    21.30,  -40.62,    0.00 /
      DATA B( 3595), B( 3596), B( 3597) /    21.16,  -40.51,    0.00 /
      DATA B( 3934), B( 3935), B( 3936) /    21.03,  -40.43,    0.00 /
      DATA B( 4273), B( 4274), B( 4275) /    20.89,  -40.37,    0.00 /
      DATA B( 4612), B( 4613), B( 4614) /    20.76,  -40.34,    0.00 /
      DATA B( 4951), B( 4952), B( 4953) /    20.63,  -40.32,    0.00 /
      DATA B( 5290), B( 5291), B( 5292) /    20.50,  -40.33,    0.00 /
      DATA B( 5629), B( 5630), B( 5631) /    20.52,  -40.59,    0.00 /
      DATA B( 5968), B( 5969), B( 5970) /    20.37,  -40.41,    0.00 /
      DATA B( 6307), B( 6308), B( 6309) /    20.21,  -40.24,    0.00 /
      DATA B( 6646), B( 6647), B( 6648) /    20.05,  -40.08,    0.00 /
      DATA B( 6985), B( 6986), B( 6987) /    19.88,  -39.92,    0.00 /
      DATA B( 7324), B( 7325), B( 7326) /    19.71,  -39.77,    0.00 /
      DATA B( 7663), B( 7664), B( 7665) /    19.54,  -39.62,    0.00 /
      DATA B( 8002), B( 8003), B( 8004) /    19.36,  -39.47,    0.00 /
      DATA B( 8341), B( 8342), B( 8343) /    19.17,  -39.32,    0.00 /
      DATA B( 8680), B( 8681), B( 8682) /    18.98,  -39.16,    0.00 /
      DATA B( 9019), B( 9020), B( 9021) /    18.79,  -39.00,    0.00 /
      DATA B( 9358), B( 9359), B( 9360) /    18.60,  -38.84,    0.00 /
      DATA B( 9697), B( 9698), B( 9699) /    18.40,  -38.67,    0.00 /
      DATA B(10036), B(10037), B(10038) /    18.19,  -38.50,    0.00 /
      DATA B(10375), B(10376), B(10377) /    17.98,  -38.31,    0.00 /
      DATA B(10714), B(10715), B(10716) /    17.76,  -38.10,    0.00 /
      DATA B(11053), B(11054), B(11055) /    17.53,  -37.87,    0.00 /
      DATA B(11392), B(11393), B(11394) /    17.28,  -37.60,    0.00 /
      DATA B(11731), B(11732), B(11733) /    17.00,  -37.29,    0.00 /
      DATA B(12070), B(12071), B(12072) /    16.68,  -36.93,    0.00 /
      DATA B(12409), B(12410), B(12411) /    16.09,  -35.98,    0.00 /
      DATA B(12748), B(12749), B(12750) /    15.74,  -35.48,    0.00 /
      DATA B(13087), B(13088), B(13089) /    15.38,  -34.94,    0.00 /
      DATA B(13426), B(13427), B(13428) /    14.99,  -34.35,    0.00 /
      DATA B(13765), B(13766), B(13767) /    14.52,  -33.68,    0.00 /
      DATA B(14104), B(14105), B(14106) /    13.95,  -32.88,    0.00 /
      DATA B(14443), B(14444), B(14445) /    13.27,  -31.92,    0.00 /
      DATA B(14782), B(14783), B(14784) /    10.79,  -29.24,    0.00 /
      DATA B(15121), B(15122), B(15123) /     9.93,  -28.46,    0.00 /
      DATA B(15460), B(15461), B(15462) /     9.16,  -27.78,    0.00 /
      DATA B(15799), B(15800), B(15801) /     8.40,  -27.15,    0.00 /
      DATA B(16138), B(16139), B(16140) /     7.63,  -26.62,    0.00 /
      DATA B(16477), B(16478), B(16479) /     6.59,  -25.32,    0.00 /
      DATA B(16816), B(16817), B(16818) /     6.02,  -24.63,    0.00 /
      DATA B(17155), B(17156), B(17157) /     5.50,  -24.02,    0.00 /
      DATA B(17494), B(17495), B(17496) /     5.00,  -23.55,    0.00 /
      DATA B(17833), B(17834), B(17835) /     4.52,  -23.16,    0.00 /
      DATA B(18172), B(18173), B(18174) /     4.05,  -22.85,    0.00 /
      DATA B(18511), B(18512), B(18513) /     3.58,  -22.57,    0.00 /
      DATA B(18850), B(18851), B(18852) /     3.09,  -22.32,    0.00 /
      DATA B(19189), B(19190), B(19191) /     2.58,  -22.07,    0.00 /
      DATA B(19528), B(19529), B(19530) /     2.03,  -21.79,    0.00 /
      DATA B(19867), B(19868), B(19869) /     1.40,  -21.44,    0.00 /
      DATA B(20206), B(20207), B(20208) /     0.65,  -20.98,    0.00 /
      DATA B(20545), B(20546), B(20547) /    -0.23,  -20.46,    0.00 /
      DATA B(20884), B(20885), B(20886) /    -1.17,  -19.75,    0.00 /
      DATA B(21223), B(21224), B(21225) /    -2.04,  -19.14,    0.00 /
      DATA B(21562), B(21563), B(21564) /    -2.75,  -18.64,    0.00 /
      DATA B(21901), B(21902), B(21903) /    -3.30,  -18.28,    0.00 /
      DATA B(22240), B(22241), B(22242) /    -3.72,  -18.01,    0.00 /
      DATA B(22579), B(22580), B(22581) /    -4.04,  -17.83,    0.00 /
      DATA B(22918), B(22919), B(22920) /    -4.29,  -17.70,    0.00 /
      DATA B(23257), B(23258), B(23259) /    -4.49,  -17.62,    0.00 /
      DATA B(23596), B(23597), B(23598) /    -4.65,  -17.57,    0.00 /
      DATA B(23935), B(23936), B(23937) /    -4.77,  -17.56,    0.00 /
      DATA B(24274), B(24275), B(24276) /    -4.86,  -17.58,    0.00 /
      DATA B(24613), B(24614), B(24615) /    -4.89,  -17.66,    0.00 /
      DATA B(24952), B(24953), B(24954) /    -4.91,  -17.80,    0.00 /
      DATA B(25291), B(25292), B(25293) /    -6.56,  -16.42,    0.00 /
      DATA B(25630), B(25631), B(25632) /    -6.69,  -16.26,    0.00 /
      DATA B(25969), B(25970), B(25971) /    -6.82,  -16.07,    0.00 /
      DATA B(26308), B(26309), B(26310) /    -6.97,  -15.92,    0.00 /
      DATA B(26647), B(26648), B(26649) /    -7.12,  -15.78,    0.00 /
      DATA B(26986), B(26987), B(26988) /    -7.29,  -15.64,    0.00 /
      DATA B(27325), B(27326), B(27327) /    -7.46,  -15.54,    0.00 /
      DATA B(  208), B(  209), B(  210) /    23.28,  -42.28,    0.00 /
      DATA B(  547), B(  548), B(  549) /    23.06,  -41.98,    0.00 /
      DATA B(  886), B(  887), B(  888) /    22.76,  -41.73,    0.00 /
      DATA B( 1225), B( 1226), B( 1227) /    22.36,  -41.58,    0.00 /
      DATA B( 1564), B( 1565), B( 1566) /    22.03,  -41.39,    0.00 /
      DATA B( 1903), B( 1904), B( 1905) /    21.77,  -41.18,    0.00 /
      DATA B( 2242), B( 2243), B( 2244) /    21.58,  -40.97,    0.00 /
      DATA B( 2581), B( 2582), B( 2583) /    21.42,  -40.80,    0.00 /
      DATA B( 2920), B( 2921), B( 2922) /    21.28,  -40.67,    0.00 /
      DATA B( 3259), B( 3260), B( 3261) /    21.15,  -40.56,    0.00 /
      DATA B( 3598), B( 3599), B( 3600) /    21.01,  -40.48,    0.00 /
      DATA B( 3937), B( 3938), B( 3939) /    20.88,  -40.43,    0.00 /
      DATA B( 4276), B( 4277), B( 4278) /    20.75,  -40.39,    0.00 /
      DATA B( 4615), B( 4616), B( 4617) /    20.62,  -40.37,    0.00 /
      DATA B( 4954), B( 4955), B( 4956) /    20.49,  -40.37,    0.00 /
      DATA B( 5293), B( 5294), B( 5295) /    20.65,  -40.63,    0.00 /
      DATA B( 5632), B( 5633), B( 5634) /    20.49,  -40.45,    0.00 /
      DATA B( 5971), B( 5972), B( 5973) /    20.32,  -40.28,    0.00 /
      DATA B( 6310), B( 6311), B( 6312) /    20.16,  -40.12,    0.00 /
      DATA B( 6649), B( 6650), B( 6651) /    19.99,  -39.96,    0.00 /
      DATA B( 6988), B( 6989), B( 6990) /    19.82,  -39.81,    0.00 /
      DATA B( 7327), B( 7328), B( 7329) /    19.64,  -39.66,    0.00 /
      DATA B( 7666), B( 7667), B( 7668) /    19.46,  -39.51,    0.00 /
      DATA B( 8005), B( 8006), B( 8007) /    19.28,  -39.35,    0.00 /
      DATA B( 8344), B( 8345), B( 8346) /    19.09,  -39.20,    0.00 /
      DATA B( 8683), B( 8684), B( 8685) /    18.90,  -39.04,    0.00 /
      DATA B( 9022), B( 9023), B( 9024) /    18.71,  -38.88,    0.00 /
      DATA B( 9361), B( 9362), B( 9363) /    18.51,  -38.72,    0.00 /
      DATA B( 9700), B( 9701), B( 9702) /    18.30,  -38.54,    0.00 /
      DATA B(10039), B(10040), B(10041) /    18.09,  -38.36,    0.00 /
      DATA B(10378), B(10379), B(10380) /    17.87,  -38.16,    0.00 /
      DATA B(10717), B(10718), B(10719) /    17.64,  -37.94,    0.00 /
      DATA B(11056), B(11057), B(11058) /    17.40,  -37.69,    0.00 /
      DATA B(11395), B(11396), B(11397) /    17.13,  -37.40,    0.00 /
      DATA B(11734), B(11735), B(11736) /    16.82,  -37.06,    0.00 /
      DATA B(12073), B(12074), B(12075) /    16.46,  -36.67,    0.00 /
      DATA B(12412), B(12413), B(12414) /    15.87,  -35.64,    0.00 /
      DATA B(12751), B(12752), B(12753) /    15.50,  -35.10,    0.00 /
      DATA B(13090), B(13091), B(13092) /    15.11,  -34.52,    0.00 /
      DATA B(13429), B(13430), B(13431) /    14.65,  -33.88,    0.00 /
      DATA B(13768), B(13769), B(13770) /    14.09,  -33.11,    0.00 /
      DATA B(14107), B(14108), B(14109) /    13.41,  -32.18,    0.00 /
      DATA B(14446), B(14447), B(14448) /    10.91,  -29.39,    0.00 /
      DATA B(14785), B(14786), B(14787) /    10.04,  -28.60,    0.00 /
      DATA B(15124), B(15125), B(15126) /     9.28,  -27.86,    0.00 /
      DATA B(15463), B(15464), B(15465) /     8.59,  -27.14,    0.00 /
      DATA B(15802), B(15803), B(15804) /     7.92,  -26.44,    0.00 /
      DATA B(16141), B(16142), B(16143) /     7.21,  -25.85,    0.00 /
      DATA B(16480), B(16481), B(16482) /     6.24,  -24.82,    0.00 /
      DATA B(16819), B(16820), B(16821) /     5.81,  -24.22,    0.00 /
      DATA B(17158), B(17159), B(17160) /     5.28,  -23.64,    0.00 /
      DATA B(17497), B(17498), B(17499) /     4.75,  -23.16,    0.00 /
      DATA B(17836), B(17837), B(17838) /     4.22,  -22.77,    0.00 /
      DATA B(18175), B(18176), B(18177) /     3.69,  -22.43,    0.00 /
      DATA B(18514), B(18515), B(18516) /     3.14,  -22.13,    0.00 /
      DATA B(18853), B(18854), B(18855) /     2.57,  -21.87,    0.00 /
      DATA B(19192), B(19193), B(19194) /     1.96,  -21.59,    0.00 /
      DATA B(19531), B(19532), B(19533) /     1.28,  -21.27,    0.00 /
      DATA B(19870), B(19871), B(19872) /     0.50,  -20.84,    0.00 /
      DATA B(20209), B(20210), B(20211) /    -0.41,  -20.32,    0.00 /
      DATA B(20548), B(20549), B(20550) /    -1.34,  -19.62,    0.00 /
      DATA B(20887), B(20888), B(20889) /    -2.22,  -19.01,    0.00 /
      DATA B(21226), B(21227), B(21228) /    -2.93,  -18.52,    0.00 /
      DATA B(21565), B(21566), B(21567) /    -3.49,  -18.17,    0.00 /
      DATA B(21904), B(21905), B(21906) /    -3.90,  -17.91,    0.00 /
      DATA B(22243), B(22244), B(22245) /    -4.23,  -17.73,    0.00 /
      DATA B(22582), B(22583), B(22584) /    -4.48,  -17.61,    0.00 /
      DATA B(22921), B(22922), B(22923) /    -4.67,  -17.52,    0.00 /
      DATA B(23260), B(23261), B(23262) /    -4.84,  -17.47,    0.00 /
      DATA B(23599), B(23600), B(23601) /    -4.97,  -17.44,    0.00 /
      DATA B(23938), B(23939), B(23940) /    -5.07,  -17.44,    0.00 /
      DATA B(24277), B(24278), B(24279) /    -5.15,  -17.47,    0.00 /
      DATA B(24616), B(24617), B(24618) /    -5.21,  -17.53,    0.00 /
      DATA B(24955), B(24956), B(24957) /    -5.28,  -17.62,    0.00 /
      DATA B(25294), B(25295), B(25296) /    -6.79,  -16.08,    0.00 /
      DATA B(25633), B(25634), B(25635) /    -6.98,  -15.93,    0.00 /
      DATA B(25972), B(25973), B(25974) /    -7.16,  -15.79,    0.00 /
      DATA B(26311), B(26312), B(26313) /    -7.33,  -15.65,    0.00 /
      DATA B(26650), B(26651), B(26652) /    -7.51,  -15.54,    0.00 /
      DATA B(26989), B(26990), B(26991) /    -8.40,  -16.02,    0.00 /
      DATA B(27328), B(27329), B(27330) /    -8.57,  -15.96,    0.00 /
      DATA B(  211), B(  212), B(  213) /    22.97,  -41.95,    0.00 /
      DATA B(  550), B(  551), B(  552) /    22.64,  -41.78,    0.00 /
      DATA B(  889), B(  890), B(  891) /    22.26,  -41.61,    0.00 /
      DATA B( 1228), B( 1229), B( 1230) /    21.95,  -41.42,    0.00 /
      DATA B( 1567), B( 1568), B( 1569) /    21.72,  -41.21,    0.00 /
      DATA B( 1906), B( 1907), B( 1908) /    21.55,  -41.01,    0.00 /
      DATA B( 2245), B( 2246), B( 2247) /    21.40,  -40.84,    0.00 /
      DATA B( 2584), B( 2585), B( 2586) /    21.26,  -40.71,    0.00 /
      DATA B( 2923), B( 2924), B( 2925) /    21.13,  -40.61,    0.00 /
      DATA B( 3262), B( 3263), B( 3264) /    21.00,  -40.54,    0.00 /
      DATA B( 3601), B( 3602), B( 3603) /    20.87,  -40.48,    0.00 /
      DATA B( 3940), B( 3941), B( 3942) /    20.74,  -40.44,    0.00 /
      DATA B( 4279), B( 4280), B( 4281) /    20.60,  -40.42,    0.00 /
      DATA B( 4618), B( 4619), B( 4620) /    20.46,  -40.41,    0.00 /
      DATA B( 4957), B( 4958), B( 4959) /    20.78,  -40.69,    0.00 /
      DATA B( 5296), B( 5297), B( 5298) /    20.61,  -40.50,    0.00 /
      DATA B( 5635), B( 5636), B( 5637) /    20.44,  -40.32,    0.00 /
      DATA B( 5974), B( 5975), B( 5976) /    20.27,  -40.16,    0.00 /
      DATA B( 6313), B( 6314), B( 6315) /    20.10,  -40.00,    0.00 /
      DATA B( 6652), B( 6653), B( 6654) /    19.93,  -39.84,    0.00 /
      DATA B( 6991), B( 6992), B( 6993) /    19.75,  -39.69,    0.00 /
      DATA B( 7330), B( 7331), B( 7332) /    19.57,  -39.54,    0.00 /
      DATA B( 7669), B( 7670), B( 7671) /    19.39,  -39.39,    0.00 /
      DATA B( 8008), B( 8009), B( 8010) /    19.20,  -39.23,    0.00 /
      DATA B( 8347), B( 8348), B( 8349) /    19.01,  -39.08,    0.00 /
      DATA B( 8686), B( 8687), B( 8688) /    18.82,  -38.92,    0.00 /
      DATA B( 9025), B( 9026), B( 9027) /    18.62,  -38.76,    0.00 /
      DATA B( 9364), B( 9365), B( 9366) /    18.41,  -38.59,    0.00 /
      DATA B( 9703), B( 9704), B( 9705) /    18.20,  -38.41,    0.00 /
      DATA B(10042), B(10043), B(10044) /    17.98,  -38.22,    0.00 /
      DATA B(10381), B(10382), B(10383) /    17.76,  -38.01,    0.00 /
      DATA B(10720), B(10721), B(10722) /    17.52,  -37.78,    0.00 /
      DATA B(11059), B(11060), B(11061) /    17.26,  -37.51,    0.00 /
      DATA B(11398), B(11399), B(11400) /    16.96,  -37.19,    0.00 /
      DATA B(11737), B(11738), B(11739) /    16.61,  -36.81,    0.00 /
      DATA B(12076), B(12077), B(12078) /    16.00,  -35.81,    0.00 /
      DATA B(12415), B(12416), B(12417) /    15.63,  -35.27,    0.00 /
      DATA B(12754), B(12755), B(12756) /    15.23,  -34.70,    0.00 /
      DATA B(13093), B(13094), B(13095) /    14.79,  -34.06,    0.00 /
      DATA B(13432), B(13433), B(13434) /    14.24,  -33.32,    0.00 /
      DATA B(13771), B(13772), B(13773) /    13.55,  -32.44,    0.00 /
      DATA B(14110), B(14111), B(14112) /    11.03,  -29.53,    0.00 /
      DATA B(14449), B(14450), B(14451) /    10.09,  -28.75,    0.00 /
      DATA B(14788), B(14789), B(14790) /     9.27,  -28.02,    0.00 /
      DATA B(15127), B(15128), B(15129) /     8.59,  -27.30,    0.00 /
      DATA B(15466), B(15467), B(15468) /     7.95,  -26.50,    0.00 /
      DATA B(15805), B(15806), B(15807) /     7.29,  -25.66,    0.00 /
      DATA B(16144), B(16145), B(16146) /     6.79,  -24.88,    0.00 /
      DATA B(16483), B(16484), B(16485) /     6.34,  -24.47,    0.00 /
      DATA B(16822), B(16823), B(16824) /     5.73,  -23.80,    0.00 /
      DATA B(17161), B(17162), B(17163) /     5.05,  -23.20,    0.00 /
      DATA B(17500), B(17501), B(17502) /     4.42,  -22.71,    0.00 /
      DATA B(17839), B(17840), B(17841) /     3.80,  -22.28,    0.00 /
      DATA B(18178), B(18179), B(18180) /     3.18,  -21.91,    0.00 /
      DATA B(18517), B(18518), B(18519) /     2.54,  -21.58,    0.00 /
      DATA B(18856), B(18857), B(18858) /     1.85,  -21.29,    0.00 /
      DATA B(19195), B(19196), B(19197) /     1.10,  -20.98,    0.00 /
      DATA B(19534), B(19535), B(19536) /     0.27,  -20.59,    0.00 /
      DATA B(19873), B(19874), B(19875) /    -0.66,  -20.11,    0.00 /
      DATA B(20212), B(20213), B(20214) /    -1.58,  -19.47,    0.00 /
      DATA B(20551), B(20552), B(20553) /    -2.44,  -18.85,    0.00 /
      DATA B(20890), B(20891), B(20892) /    -3.15,  -18.37,    0.00 /
      DATA B(21229), B(21230), B(21231) /    -3.70,  -18.03,    0.00 /
      DATA B(21568), B(21569), B(21570) /    -4.11,  -17.79,    0.00 /
      DATA B(21907), B(21908), B(21909) /    -4.43,  -17.62,    0.00 /
      DATA B(22246), B(22247), B(22248) /    -4.68,  -17.49,    0.00 /
      DATA B(22585), B(22586), B(22587) /    -4.89,  -17.41,    0.00 /
      DATA B(22924), B(22925), B(22926) /    -5.05,  -17.35,    0.00 /
      DATA B(23263), B(23264), B(23265) /    -5.19,  -17.31,    0.00 /
      DATA B(23602), B(23603), B(23604) /    -5.31,  -17.30,    0.00 /
      DATA B(23941), B(23942), B(23943) /    -5.41,  -17.30,    0.00 /
      DATA B(24280), B(24281), B(24282) /    -5.50,  -17.33,    0.00 /
      DATA B(24619), B(24620), B(24621) /    -5.59,  -17.37,    0.00 /
      DATA B(24958), B(24959), B(24960) /    -5.69,  -17.41,    0.00 /
      DATA B(25297), B(25298), B(25299) /    -7.07,  -15.75,    0.00 /
      DATA B(25636), B(25637), B(25638) /    -7.30,  -15.61,    0.00 /
      DATA B(25975), B(25976), B(25977) /    -7.51,  -15.50,    0.00 /
      DATA B(26314), B(26315), B(26316) /    -7.64,  -15.39,    0.00 /
      DATA B(26653), B(26654), B(26655) /    -8.54,  -15.98,    0.00 /
      DATA B(26992), B(26993), B(26994) /    -8.67,  -15.91,    0.00 /
      DATA B(27331), B(27332), B(27333) /    -8.79,  -15.85,    0.00 /
      DATA B(  214), B(  215), B(  216) /    22.48,  -41.80,    0.00 /
      DATA B(  553), B(  554), B(  555) /    22.14,  -41.65,    0.00 /
      DATA B(  892), B(  893), B(  894) /    21.87,  -41.45,    0.00 /
      DATA B( 1231), B( 1232), B( 1233) /    21.67,  -41.24,    0.00 /
      DATA B( 1570), B( 1571), B( 1572) /    21.51,  -41.05,    0.00 /
      DATA B( 1909), B( 1910), B( 1911) /    21.37,  -40.89,    0.00 /
      DATA B( 2248), B( 2249), B( 2250) /    21.24,  -40.76,    0.00 /
      DATA B( 2587), B( 2588), B( 2589) /    21.11,  -40.67,    0.00 /
      DATA B( 2926), B( 2927), B( 2928) /    20.98,  -40.59,    0.00 /
      DATA B( 3265), B( 3266), B( 3267) /    20.85,  -40.54,    0.00 /
      DATA B( 3604), B( 3605), B( 3606) /    20.72,  -40.50,    0.00 /
      DATA B( 3943), B( 3944), B( 3945) /    20.59,  -40.48,    0.00 /
      DATA B( 4282), B( 4283), B( 4284) /    20.45,  -40.47,    0.00 /
      DATA B( 4621), B( 4622), B( 4623) /    20.90,  -40.74,    0.00 /
      DATA B( 4960), B( 4961), B( 4962) /    20.73,  -40.55,    0.00 /
      DATA B( 5299), B( 5300), B( 5301) /    20.56,  -40.37,    0.00 /
      DATA B( 5638), B( 5639), B( 5640) /    20.39,  -40.20,    0.00 /
      DATA B( 5977), B( 5978), B( 5979) /    20.22,  -40.04,    0.00 /
      DATA B( 6316), B( 6317), B( 6318) /    20.04,  -39.88,    0.00 /
      DATA B( 6655), B( 6656), B( 6657) /    19.87,  -39.72,    0.00 /
      DATA B( 6994), B( 6995), B( 6996) /    19.69,  -39.57,    0.00 /
      DATA B( 7333), B( 7334), B( 7335) /    19.50,  -39.42,    0.00 /
      DATA B( 7672), B( 7673), B( 7674) /    19.31,  -39.26,    0.00 /
      DATA B( 8011), B( 8012), B( 8013) /    19.12,  -39.11,    0.00 /
      DATA B( 8350), B( 8351), B( 8352) /    18.93,  -38.95,    0.00 /
      DATA B( 8689), B( 8690), B( 8691) /    18.73,  -38.79,    0.00 /
      DATA B( 9028), B( 9029), B( 9030) /    18.52,  -38.62,    0.00 /
      DATA B( 9367), B( 9368), B( 9369) /    18.31,  -38.45,    0.00 /
      DATA B( 9706), B( 9707), B( 9708) /    18.10,  -38.26,    0.00 /
      DATA B(10045), B(10046), B(10047) /    17.87,  -38.06,    0.00 /
      DATA B(10384), B(10385), B(10386) /    17.63,  -37.84,    0.00 /
      DATA B(10723), B(10724), B(10725) /    17.38,  -37.59,    0.00 /
      DATA B(11062), B(11063), B(11064) /    17.09,  -37.30,    0.00 /
      DATA B(11401), B(11402), B(11403) /    16.77,  -36.94,    0.00 /
      DATA B(11740), B(11741), B(11742) /    16.16,  -36.02,    0.00 /
      DATA B(12079), B(12080), B(12081) /    15.77,  -35.44,    0.00 /
      DATA B(12418), B(12419), B(12420) /    15.37,  -34.87,    0.00 /
      DATA B(12757), B(12758), B(12759) /    14.92,  -34.25,    0.00 /
      DATA B(13096), B(13097), B(13098) /    14.39,  -33.53,    0.00 /
      DATA B(13435), B(13436), B(13437) /    13.72,  -32.67,    0.00 /
      DATA B(13774), B(13775), B(13776) /    11.18,  -29.67,    0.00 /
      DATA B(14113), B(14114), B(14115) /    10.17,  -28.86,    0.00 /
      DATA B(14452), B(14453), B(14454) /     9.25,  -28.16,    0.00 /
      DATA B(14791), B(14792), B(14793) /     8.46,  -27.50,    0.00 /
      DATA B(15130), B(15131), B(15132) /     7.79,  -26.78,    0.00 /
      DATA B(15469), B(15470), B(15471) /     7.16,  -25.79,    0.00 /
      DATA B(15808), B(15809), B(15810) /     6.32,  -24.63,    0.00 /
      DATA B(16147), B(16148), B(16149) /     7.48,  -25.22,    0.00 /
      DATA B(16486), B(16487), B(16488) /     6.60,  -23.94,    0.00 /
      DATA B(16825), B(16826), B(16827) /     5.59,  -23.23,    0.00 /
      DATA B(17164), B(17165), B(17166) /     4.70,  -22.66,    0.00 /
      DATA B(17503), B(17504), B(17505) /     3.93,  -22.17,    0.00 /
      DATA B(17842), B(17843), B(17844) /     3.19,  -21.70,    0.00 /
      DATA B(18181), B(18182), B(18183) /     2.45,  -21.29,    0.00 /
      DATA B(18520), B(18521), B(18522) /     1.68,  -20.94,    0.00 /
      DATA B(18859), B(18860), B(18861) /     0.84,  -20.62,    0.00 /
      DATA B(19198), B(19199), B(19200) /    -0.06,  -20.23,    0.00 /
      DATA B(19537), B(19538), B(19539) /    -1.00,  -19.81,    0.00 /
      DATA B(19876), B(19877), B(19878) /    -1.91,  -19.24,    0.00 /
      DATA B(20215), B(20216), B(20217) /    -2.73,  -18.65,    0.00 /
      DATA B(20554), B(20555), B(20556) /    -3.41,  -18.19,    0.00 /
      DATA B(20893), B(20894), B(20895) /    -3.94,  -17.86,    0.00 /
      DATA B(21232), B(21233), B(21234) /    -4.35,  -17.63,    0.00 /
      DATA B(21571), B(21572), B(21573) /    -4.66,  -17.47,    0.00 /
      DATA B(21910), B(21911), B(21912) /    -4.91,  -17.36,    0.00 /
      DATA B(22249), B(22250), B(22251) /    -5.12,  -17.28,    0.00 /
      DATA B(22588), B(22589), B(22590) /    -5.28,  -17.22,    0.00 /
      DATA B(22927), B(22928), B(22929) /    -5.43,  -17.18,    0.00 /
      DATA B(23266), B(23267), B(23268) /    -5.55,  -17.16,    0.00 /
      DATA B(23605), B(23606), B(23607) /    -5.67,  -17.14,    0.00 /
      DATA B(23944), B(23945), B(23946) /    -5.78,  -17.14,    0.00 /
      DATA B(24283), B(24284), B(24285) /    -5.90,  -17.15,    0.00 /
      DATA B(24622), B(24623), B(24624) /    -6.03,  -17.17,    0.00 /
      DATA B(24961), B(24962), B(24963) /    -6.17,  -17.18,    0.00 /
      DATA B(25300), B(25301), B(25302) /    -7.41,  -15.40,    0.00 /
      DATA B(25639), B(25640), B(25641) /    -7.66,  -15.31,    0.00 /
      DATA B(25978), B(25979), B(25980) /    -7.78,  -15.22,    0.00 /
      DATA B(26317), B(26318), B(26319) /    -8.63,  -15.90,    0.00 /
      DATA B(26656), B(26657), B(26658) /    -8.75,  -15.86,    0.00 /
      DATA B(26995), B(26996), B(26997) /    -8.86,  -15.81,    0.00 /
      DATA B(27334), B(27335), B(27336) /    -8.95,  -15.76,    0.00 /
      DATA B(  217), B(  218), B(  219) /    22.04,  -41.69,    0.00 /
      DATA B(  556), B(  557), B(  558) /    21.80,  -41.49,    0.00 /
      DATA B(  895), B(  896), B(  897) /    21.62,  -41.28,    0.00 /
      DATA B( 1234), B( 1235), B( 1236) /    21.47,  -41.09,    0.00 /
      DATA B( 1573), B( 1574), B( 1575) /    21.34,  -40.94,    0.00 /
      DATA B( 1912), B( 1913), B( 1914) /    21.22,  -40.82,    0.00 /
      DATA B( 2251), B( 2252), B( 2253) /    21.09,  -40.72,    0.00 /
      DATA B( 2590), B( 2591), B( 2592) /    20.97,  -40.65,    0.00 /
      DATA B( 2929), B( 2930), B( 2931) /    20.84,  -40.60,    0.00 /
      DATA B( 3268), B( 3269), B( 3270) /    20.71,  -40.56,    0.00 /
      DATA B( 3607), B( 3608), B( 3609) /    20.58,  -40.54,    0.00 /
      DATA B( 3946), B( 3947), B( 3948) /    20.45,  -40.53,    0.00 /
      DATA B( 4285), B( 4286), B( 4287) /    21.02,  -40.78,    0.00 /
      DATA B( 4624), B( 4625), B( 4626) /    20.85,  -40.59,    0.00 /
      DATA B( 4963), B( 4964), B( 4965) /    20.68,  -40.41,    0.00 /
      DATA B( 5302), B( 5303), B( 5304) /    20.51,  -40.24,    0.00 /
      DATA B( 5641), B( 5642), B( 5643) /    20.34,  -40.07,    0.00 /
      DATA B( 5980), B( 5981), B( 5982) /    20.16,  -39.91,    0.00 /
      DATA B( 6319), B( 6320), B( 6321) /    19.98,  -39.75,    0.00 /
      DATA B( 6658), B( 6659), B( 6660) /    19.80,  -39.60,    0.00 /
      DATA B( 6997), B( 6998), B( 6999) /    19.62,  -39.44,    0.00 /
      DATA B( 7336), B( 7337), B( 7338) /    19.43,  -39.29,    0.00 /
      DATA B( 7675), B( 7676), B( 7677) /    19.24,  -39.14,    0.00 /
      DATA B( 8014), B( 8015), B( 8016) /    19.04,  -38.98,    0.00 /
      DATA B( 8353), B( 8354), B( 8355) /    18.84,  -38.82,    0.00 /
      DATA B( 8692), B( 8693), B( 8694) /    18.64,  -38.65,    0.00 /
      DATA B( 9031), B( 9032), B( 9033) /    18.43,  -38.48,    0.00 /
      DATA B( 9370), B( 9371), B( 9372) /    18.21,  -38.30,    0.00 /
      DATA B( 9709), B( 9710), B( 9711) /    17.98,  -38.10,    0.00 /
      DATA B(10048), B(10049), B(10050) /    17.75,  -37.89,    0.00 /
      DATA B(10387), B(10388), B(10389) /    17.49,  -37.66,    0.00 /
      DATA B(10726), B(10727), B(10728) /    17.22,  -37.39,    0.00 /
      DATA B(11065), B(11066), B(11067) /    16.91,  -37.06,    0.00 /
      DATA B(11404), B(11405), B(11406) /    16.53,  -36.68,    0.00 /
      DATA B(11743), B(11744), B(11745) /    15.91,  -35.61,    0.00 /
      DATA B(12082), B(12083), B(12084) /    15.50,  -35.05,    0.00 /
      DATA B(12421), B(12422), B(12423) /    15.07,  -34.43,    0.00 /
      DATA B(12760), B(12761), B(12762) /    14.55,  -33.73,    0.00 /
      DATA B(13099), B(13100), B(13101) /    13.90,  -32.90,    0.00 /
      DATA B(13438), B(13439), B(13440) /    13.12,  -31.94,    0.00 /
      DATA B(13777), B(13778), B(13779) /    10.31,  -28.96,    0.00 /
      DATA B(14116), B(14117), B(14118) /     9.31,  -28.23,    0.00 /
      DATA B(14455), B(14456), B(14457) /     8.40,  -27.60,    0.00 /
      DATA B(14794), B(14795), B(14796) /     7.56,  -27.00,    0.00 /
      DATA B(15133), B(15134), B(15135) /     6.77,  -26.27,    0.00 /
      DATA B(15472), B(15473), B(15474) /     6.08,  -25.07,    0.00 /
      DATA B(15811), B(15812), B(15813) /     5.35,  -23.12,    0.00 /
      DATA B(16150), B(16151), B(16152) /     7.25,  -24.67,    0.00 /
      DATA B(16489), B(16490), B(16491) /     6.36,  -23.33,    0.00 /
      DATA B(16828), B(16829), B(16830) /     5.17,  -22.52,    0.00 /
      DATA B(17167), B(17168), B(17169) /     4.07,  -22.04,    0.00 /
      DATA B(17506), B(17507), B(17508) /     3.13,  -21.57,    0.00 /
      DATA B(17845), B(17846), B(17847) /     2.23,  -21.06,    0.00 /
      DATA B(18184), B(18185), B(18186) /     1.36,  -20.65,    0.00 /
      DATA B(18523), B(18524), B(18525) /     0.49,  -20.30,    0.00 /
      DATA B(18862), B(18863), B(18864) /    -0.46,  -19.98,    0.00 /
      DATA B(19201), B(19202), B(19203) /    -2.38,  -19.65,    0.00 /
      DATA B(19540), B(19541), B(19542) /    -2.36,  -18.96,    0.00 /
      DATA B(19879), B(19880), B(19881) /    -3.11,  -18.41,    0.00 /
      DATA B(20218), B(20219), B(20220) /    -3.74,  -17.98,    0.00 /
      DATA B(20557), B(20558), B(20559) /    -4.23,  -17.67,    0.00 /
      DATA B(20896), B(20897), B(20898) /    -4.62,  -17.45,    0.00 /
      DATA B(21235), B(21236), B(21237) /    -4.92,  -17.30,    0.00 /
      DATA B(21574), B(21575), B(21576) /    -5.17,  -17.20,    0.00 /
      DATA B(21913), B(21914), B(21915) /    -5.37,  -17.13,    0.00 /
      DATA B(22252), B(22253), B(22254) /    -5.54,  -17.08,    0.00 /
      DATA B(22591), B(22592), B(22593) /    -5.69,  -17.04,    0.00 /
      DATA B(22930), B(22931), B(22932) /    -5.82,  -17.01,    0.00 /
      DATA B(23269), B(23270), B(23271) /    -5.95,  -16.99,    0.00 /
      DATA B(23608), B(23609), B(23610) /    -6.07,  -16.97,    0.00 /
      DATA B(23947), B(23948), B(23949) /    -6.20,  -16.95,    0.00 /
      DATA B(24286), B(24287), B(24288) /    -6.35,  -16.94,    0.00 /
      DATA B(24625), B(24626), B(24627) /    -6.52,  -16.91,    0.00 /
      DATA B(24964), B(24965), B(24966) /    -6.71,  -16.87,    0.00 /
      DATA B(25303), B(25304), B(25305) /    -7.79,  -15.03,    0.00 /
      DATA B(25642), B(25643), B(25644) /    -7.90,  -15.11,    0.00 /
      DATA B(25981), B(25982), B(25983) /    -8.70,  -15.85,    0.00 /
      DATA B(26320), B(26321), B(26322) /    -8.81,  -15.80,    0.00 /
      DATA B(26659), B(26660), B(26661) /    -8.91,  -15.76,    0.00 /
      DATA B(26998), B(26999), B(27000) /    -8.99,  -15.72,    0.00 /
      DATA B(27337), B(27338), B(27339) /    -9.07,  -15.69,    0.00 /
      DATA B(  220), B(  221), B(  222) /    21.75,  -41.51,    0.00 /
      DATA B(  559), B(  560), B(  561) /    21.58,  -41.32,    0.00 /
      DATA B(  898), B(  899), B(  900) /    21.44,  -41.14,    0.00 /
      DATA B( 1237), B( 1238), B( 1239) /    21.31,  -41.00,    0.00 /
      DATA B( 1576), B( 1577), B( 1578) /    21.19,  -40.88,    0.00 /
      DATA B( 1915), B( 1916), B( 1917) /    21.07,  -40.79,    0.00 /
      DATA B( 2254), B( 2255), B( 2256) /    20.95,  -40.72,    0.00 /
      DATA B( 2593), B( 2594), B( 2595) /    20.83,  -40.67,    0.00 /
      DATA B( 2932), B( 2933), B( 2934) /    20.70,  -40.63,    0.00 /
      DATA B( 3271), B( 3272), B( 3273) /    20.57,  -40.60,    0.00 /
      DATA B( 3610), B( 3611), B( 3612) /    20.44,  -40.59,    0.00 /
      DATA B( 3949), B( 3950), B( 3951) /    21.14,  -40.82,    0.00 /
      DATA B( 4288), B( 4289), B( 4290) /    20.97,  -40.63,    0.00 /
      DATA B( 4627), B( 4628), B( 4629) /    20.80,  -40.45,    0.00 /
      DATA B( 4966), B( 4967), B( 4968) /    20.63,  -40.28,    0.00 /
      DATA B( 5305), B( 5306), B( 5307) /    20.46,  -40.11,    0.00 /
      DATA B( 5644), B( 5645), B( 5646) /    20.28,  -39.94,    0.00 /
      DATA B( 5983), B( 5984), B( 5985) /    20.11,  -39.78,    0.00 /
      DATA B( 6322), B( 6323), B( 6324) /    19.92,  -39.62,    0.00 /
      DATA B( 6661), B( 6662), B( 6663) /    19.74,  -39.47,    0.00 /
      DATA B( 7000), B( 7001), B( 7002) /    19.55,  -39.31,    0.00 /
      DATA B( 7339), B( 7340), B( 7341) /    19.36,  -39.16,    0.00 /
      DATA B( 7678), B( 7679), B( 7680) /    19.16,  -39.00,    0.00 /
      DATA B( 8017), B( 8018), B( 8019) /    18.96,  -38.84,    0.00 /
      DATA B( 8356), B( 8357), B( 8358) /    18.76,  -38.68,    0.00 /
      DATA B( 8695), B( 8696), B( 8697) /    18.54,  -38.50,    0.00 /
      DATA B( 9034), B( 9035), B( 9036) /    18.33,  -38.32,    0.00 /
      DATA B( 9373), B( 9374), B( 9375) /    18.10,  -38.13,    0.00 /
      DATA B( 9712), B( 9713), B( 9714) /    17.86,  -37.93,    0.00 /
      DATA B(10051), B(10052), B(10053) /    17.61,  -37.70,    0.00 /
      DATA B(10390), B(10391), B(10392) /    17.34,  -37.45,    0.00 /
      DATA B(10729), B(10730), B(10731) /    17.04,  -37.16,    0.00 /
      DATA B(11068), B(11069), B(11070) /    16.68,  -36.80,    0.00 /
      DATA B(11407), B(11408), B(11409) /    16.05,  -35.78,    0.00 /
      DATA B(11746), B(11747), B(11748) /    15.65,  -35.22,    0.00 /
      DATA B(12085), B(12086), B(12087) /    15.21,  -34.62,    0.00 /
      DATA B(12424), B(12425), B(12426) /    14.71,  -33.94,    0.00 /
      DATA B(12763), B(12764), B(12765) /    14.09,  -33.13,    0.00 /
      DATA B(13102), B(13103), B(13104) /    13.32,  -32.18,    0.00 /
      DATA B(13441), B(13442), B(13443) /    10.49,  -29.06,    0.00 /
      DATA B(13780), B(13781), B(13782) /     9.45,  -28.29,    0.00 /
      DATA B(14119), B(14120), B(14121) /     8.48,  -27.62,    0.00 /
      DATA B(14458), B(14459), B(14460) /     7.54,  -27.03,    0.00 /
      DATA B(14797), B(14798), B(14799) /     6.55,  -26.44,    0.00 /
      DATA B(15136), B(15137), B(15138) /     5.45,  -25.69,    0.00 /
      DATA B(15475), B(15476), B(15477) /     4.25,  -24.30,    0.00 /
      DATA B(15814), B(15815), B(15816) /     2.16,  -21.15,    0.00 /
      DATA B(16153), B(16154), B(16155) /     7.84,  -23.93,    0.00 /
      DATA B(16492), B(16493), B(16494) /     5.84,  -22.46,    0.00 /
      DATA B(16831), B(16832), B(16833) /     4.41,  -21.77,    0.00 /
      DATA B(17170), B(17171), B(17172) /     3.09,  -21.42,    0.00 /
      DATA B(17509), B(17510), B(17511) /     1.85,  -20.99,    0.00 /
      DATA B(17848), B(17849), B(17850) /     0.82,  -20.53,    0.00 /
      DATA B(18187), B(18188), B(18189) /    -0.14,  -20.09,    0.00 /
      DATA B(18526), B(18527), B(18528) /    -1.09,  -19.69,    0.00 /
      DATA B(18865), B(18866), B(18867) /    -2.02,  -19.24,    0.00 /
      DATA B(19204), B(19205), B(19206) /    -2.91,  -18.76,    0.00 /
      DATA B(19543), B(19544), B(19545) /    -3.61,  -18.19,    0.00 /
      DATA B(19882), B(19883), B(19884) /    -4.15,  -17.75,    0.00 /
      DATA B(20221), B(20222), B(20223) /    -4.58,  -17.44,    0.00 /
      DATA B(20560), B(20561), B(20562) /    -4.93,  -17.23,    0.00 /
      DATA B(20899), B(20900), B(20901) /    -5.22,  -17.10,    0.00 /
      DATA B(21238), B(21239), B(21240) /    -5.45,  -17.02,    0.00 /
      DATA B(21577), B(21578), B(21579) /    -5.65,  -16.96,    0.00 /
      DATA B(21916), B(21917), B(21918) /    -5.81,  -16.91,    0.00 /
      DATA B(22255), B(22256), B(22257) /    -5.96,  -16.88,    0.00 /
      DATA B(22594), B(22595), B(22596) /    -6.11,  -16.85,    0.00 /
      DATA B(22933), B(22934), B(22935) /    -6.24,  -16.82,    0.00 /
      DATA B(23272), B(23273), B(23274) /    -6.38,  -16.80,    0.00 /
      DATA B(23611), B(23612), B(23613) /    -6.53,  -16.77,    0.00 /
      DATA B(23950), B(23951), B(23952) /    -6.70,  -16.74,    0.00 /
      DATA B(24289), B(24290), B(24291) /    -6.88,  -16.71,    0.00 /
      DATA B(24628), B(24629), B(24630) /    -7.09,  -16.65,    0.00 /
      DATA B(24967), B(24968), B(24969) /    -7.27,  -16.53,    0.00 /
      DATA B(25306), B(25307), B(25308) /    -8.59,  -15.74,    0.00 /
      DATA B(25645), B(25646), B(25647) /    -8.67,  -15.81,    0.00 /
      DATA B(25984), B(25985), B(25986) /    -8.82,  -15.77,    0.00 /
      DATA B(26323), B(26324), B(26325) /    -8.93,  -15.72,    0.00 /
      DATA B(26662), B(26663), B(26664) /    -9.02,  -15.68,    0.00 /
      DATA B(27001), B(27002), B(27003) /    -9.09,  -15.65,    0.00 /
      DATA B(27340), B(27341), B(27342) /    -9.15,  -15.63,    0.00 /
      DATA B(  223), B(  224), B(  225) /    21.55,  -41.35,    0.00 /
      DATA B(  562), B(  563), B(  564) /    21.41,  -41.19,    0.00 /
      DATA B(  901), B(  902), B(  903) /    21.29,  -41.05,    0.00 /
      DATA B( 1240), B( 1241), B( 1242) /    21.17,  -40.94,    0.00 /
      DATA B( 1579), B( 1580), B( 1581) /    21.05,  -40.85,    0.00 /
      DATA B( 1918), B( 1919), B( 1920) /    20.94,  -40.79,    0.00 /
      DATA B( 2257), B( 2258), B( 2259) /    20.81,  -40.74,    0.00 /
      DATA B( 2596), B( 2597), B( 2598) /    20.69,  -40.70,    0.00 /
      DATA B( 2935), B( 2936), B( 2937) /    20.56,  -40.67,    0.00 /
      DATA B( 3274), B( 3275), B( 3276) /    20.43,  -40.65,    0.00 /
      DATA B( 3613), B( 3614), B( 3615) /    21.26,  -40.86,    0.00 /
      DATA B( 3952), B( 3953), B( 3954) /    21.09,  -40.68,    0.00 /
      DATA B( 4291), B( 4292), B( 4293) /    20.93,  -40.49,    0.00 /
      DATA B( 4630), B( 4631), B( 4632) /    20.76,  -40.32,    0.00 /
      DATA B( 4969), B( 4970), B( 4971) /    20.58,  -40.15,    0.00 /
      DATA B( 5308), B( 5309), B( 5310) /    20.41,  -39.98,    0.00 /
      DATA B( 5647), B( 5648), B( 5649) /    20.23,  -39.81,    0.00 /
      DATA B( 5986), B( 5987), B( 5988) /    20.05,  -39.65,    0.00 /
      DATA B( 6325), B( 6326), B( 6327) /    19.86,  -39.49,    0.00 /
      DATA B( 6664), B( 6665), B( 6666) /    19.67,  -39.33,    0.00 /
      DATA B( 7003), B( 7004), B( 7005) /    19.48,  -39.17,    0.00 /
      DATA B( 7342), B( 7343), B( 7344) /    19.28,  -39.02,    0.00 /
      DATA B( 7681), B( 7682), B( 7683) /    19.08,  -38.86,    0.00 /
      DATA B( 8020), B( 8021), B( 8022) /    18.87,  -38.69,    0.00 /
      DATA B( 8359), B( 8360), B( 8361) /    18.66,  -38.52,    0.00 /
      DATA B( 8698), B( 8699), B( 8700) /    18.44,  -38.34,    0.00 /
      DATA B( 9037), B( 9038), B( 9039) /    18.22,  -38.15,    0.00 /
      DATA B( 9376), B( 9377), B( 9378) /    17.98,  -37.95,    0.00 /
      DATA B( 9715), B( 9716), B( 9717) /    17.73,  -37.73,    0.00 /
      DATA B(10054), B(10055), B(10056) /    17.46,  -37.49,    0.00 /
      DATA B(10393), B(10394), B(10395) /    17.16,  -37.22,    0.00 /
      DATA B(10732), B(10733), B(10734) /    16.82,  -36.90,    0.00 /
      DATA B(11071), B(11072), B(11073) /    16.43,  -36.51,    0.00 /
      DATA B(11410), B(11411), B(11412) /    15.79,  -35.40,    0.00 /
      DATA B(11749), B(11750), B(11751) /    15.36,  -34.81,    0.00 /
      DATA B(12088), B(12089), B(12090) /    14.88,  -34.14,    0.00 /
      DATA B(12427), B(12428), B(12429) /    14.28,  -33.37,    0.00 /
      DATA B(12766), B(12767), B(12768) /    13.53,  -32.44,    0.00 /
      DATA B(13105), B(13106), B(13107) /    10.70,  -29.18,    0.00 /
      DATA B(13444), B(13445), B(13446) /     9.64,  -28.37,    0.00 /
      DATA B(13783), B(13784), B(13785) /     8.63,  -27.66,    0.00 /
      DATA B(14122), B(14123), B(14124) /     7.69,  -27.03,    0.00 /
      DATA B(14461), B(14462), B(14463) /     6.70,  -26.42,    0.00 /
      DATA B(14800), B(14801), B(14802) /     5.55,  -25.73,    0.00 /
      DATA B(15139), B(15140), B(15141) /     4.03,  -24.85,    0.00 /
      DATA B(15478), B(15479), B(15480) /     2.05,  -23.40,    0.00 /
      DATA B(15817), B(15818), B(15819) /     8.24,  -26.31,    0.00 /
      DATA B(16156), B(16157), B(16158) /     6.00,  -22.83,    0.00 /
      DATA B(16495), B(16496), B(16497) /     4.50,  -21.55,    0.00 /
      DATA B(16834), B(16835), B(16836) /     3.58,  -21.21,    0.00 /
      DATA B(17173), B(17174), B(17175) /     3.28,  -21.17,    0.00 /
      DATA B(17512), B(17513), B(17514) /    -0.40,  -20.40,    0.00 /
      DATA B(17851), B(17852), B(17853) /    -1.09,  -19.83,    0.00 /
      DATA B(18190), B(18191), B(18192) /    -1.89,  -19.37,    0.00 /
      DATA B(18529), B(18530), B(18531) /    -2.66,  -18.92,    0.00 /
      DATA B(18868), B(18869), B(18870) /    -3.41,  -18.46,    0.00 /
      DATA B(19207), B(19208), B(19209) /    -4.08,  -17.99,    0.00 /
      DATA B(19546), B(19547), B(19548) /    -4.60,  -17.53,    0.00 /
      DATA B(19885), B(19886), B(19887) /    -4.98,  -17.19,    0.00 /
      DATA B(20224), B(20225), B(20226) /    -5.29,  -16.98,    0.00 /
      DATA B(20563), B(20564), B(20565) /    -5.55,  -16.86,    0.00 /
      DATA B(20902), B(20903), B(20904) /    -5.77,  -16.79,    0.00 /
      DATA B(21241), B(21242), B(21243) /    -5.95,  -16.75,    0.00 /
      DATA B(21580), B(21581), B(21582) /    -6.12,  -16.73,    0.00 /
      DATA B(21919), B(21920), B(21921) /    -6.27,  -16.70,    0.00 /
      DATA B(22258), B(22259), B(22260) /    -6.42,  -16.67,    0.00 /
      DATA B(22597), B(22598), B(22599) /    -6.57,  -16.65,    0.00 /
      DATA B(22936), B(22937), B(22938) /    -6.72,  -16.62,    0.00 /
      DATA B(23275), B(23276), B(23277) /    -6.89,  -16.59,    0.00 /
      DATA B(23614), B(23615), B(23616) /    -7.08,  -16.56,    0.00 /
      DATA B(23953), B(23954), B(23955) /    -7.29,  -16.51,    0.00 /
      DATA B(24292), B(24293), B(24294) /    -7.53,  -16.48,    0.00 /
      DATA B(24631), B(24632), B(24633) /    -7.79,  -16.38,    0.00 /
      DATA B(24970), B(24971), B(24972) /    -8.08,  -16.26,    0.00 /
      DATA B(25309), B(25310), B(25311) /    -8.45,  -15.72,    0.00 /
      DATA B(25648), B(25649), B(25650) /    -8.70,  -15.69,    0.00 /
      DATA B(25987), B(25988), B(25989) /    -8.89,  -15.68,    0.00 /
      DATA B(26326), B(26327), B(26328) /    -9.01,  -15.64,    0.00 /
      DATA B(26665), B(26666), B(26667) /    -9.10,  -15.62,    0.00 /
      DATA B(27004), B(27005), B(27006) /    -9.16,  -15.59,    0.00 /
      DATA B(27343), B(27344), B(27345) /    -9.21,  -15.58,    0.00 /
      DATA B(  226), B(  227), B(  228) /    21.39,  -41.22,    0.00 /
      DATA B(  565), B(  566), B(  567) /    21.27,  -41.11,    0.00 /
      DATA B(  904), B(  905), B(  906) /    21.15,  -41.01,    0.00 /
      DATA B( 1243), B( 1244), B( 1245) /    21.04,  -40.92,    0.00 /
      DATA B( 1582), B( 1583), B( 1584) /    20.92,  -40.86,    0.00 /
      DATA B( 1921), B( 1922), B( 1923) /    20.80,  -40.81,    0.00 /
      DATA B( 2260), B( 2261), B( 2262) /    20.68,  -40.77,    0.00 /
      DATA B( 2599), B( 2600), B( 2601) /    20.55,  -40.74,    0.00 /
      DATA B( 2938), B( 2939), B( 2940) /    20.42,  -40.72,    0.00 /
      DATA B( 3277), B( 3278), B( 3279) /    21.38,  -40.91,    0.00 /
      DATA B( 3616), B( 3617), B( 3618) /    21.21,  -40.72,    0.00 /
      DATA B( 3955), B( 3956), B( 3957) /    21.05,  -40.54,    0.00 /
      DATA B( 4294), B( 4295), B( 4296) /    20.88,  -40.36,    0.00 /
      DATA B( 4633), B( 4634), B( 4635) /    20.71,  -40.18,    0.00 /
      DATA B( 4972), B( 4973), B( 4974) /    20.53,  -40.01,    0.00 /
      DATA B( 5311), B( 5312), B( 5313) /    20.35,  -39.84,    0.00 /
      DATA B( 5650), B( 5651), B( 5652) /    20.17,  -39.67,    0.00 /
      DATA B( 5989), B( 5990), B( 5991) /    19.99,  -39.51,    0.00 /
      DATA B( 6328), B( 6329), B( 6330) /    19.80,  -39.35,    0.00 /
      DATA B( 6667), B( 6668), B( 6669) /    19.61,  -39.19,    0.00 /
      DATA B( 7006), B( 7007), B( 7008) /    19.41,  -39.03,    0.00 /
      DATA B( 7345), B( 7346), B( 7347) /    19.21,  -38.86,    0.00 /
      DATA B( 7684), B( 7685), B( 7686) /    19.00,  -38.70,    0.00 /
      DATA B( 8023), B( 8024), B( 8025) /    18.78,  -38.53,    0.00 /
      DATA B( 8362), B( 8363), B( 8364) /    18.56,  -38.35,    0.00 /
      DATA B( 8701), B( 8702), B( 8703) /    18.33,  -38.16,    0.00 /
      DATA B( 9040), B( 9041), B( 9042) /    18.10,  -37.96,    0.00 /
      DATA B( 9379), B( 9380), B( 9381) /    17.85,  -37.74,    0.00 /
      DATA B( 9718), B( 9719), B( 9720) /    17.58,  -37.50,    0.00 /
      DATA B(10057), B(10058), B(10059) /    17.28,  -37.23,    0.00 /
      DATA B(10396), B(10397), B(10398) /    16.95,  -36.95,    0.00 /
      DATA B(10735), B(10736), B(10737) /    16.57,  -36.61,    0.00 /
      DATA B(11074), B(11075), B(11076) /    15.93,  -35.55,    0.00 /
      DATA B(11413), B(11414), B(11415) /    15.50,  -34.99,    0.00 /
      DATA B(11752), B(11753), B(11754) /    15.04,  -34.35,    0.00 /
      DATA B(12091), B(12092), B(12093) /    14.47,  -33.60,    0.00 /
      DATA B(12430), B(12431), B(12432) /    13.76,  -32.70,    0.00 /
      DATA B(12769), B(12770), B(12771) /    10.95,  -29.32,    0.00 /
      DATA B(13108), B(13109), B(13110) /     9.84,  -28.47,    0.00 /
      DATA B(13447), B(13448), B(13449) /     8.80,  -27.72,    0.00 /
      DATA B(13786), B(13787), B(13788) /     7.85,  -27.06,    0.00 /
      DATA B(14125), B(14126), B(14127) /     6.91,  -26.43,    0.00 /
      DATA B(14464), B(14465), B(14466) /     5.88,  -25.74,    0.00 /
      DATA B(14803), B(14804), B(14805) /     4.65,  -24.88,    0.00 /
      DATA B(15142), B(15143), B(15144) /     3.09,  -23.74,    0.00 /
      DATA B(15481), B(15482), B(15483) /     1.23,  -22.44,    0.00 /
      DATA B(15820), B(15821), B(15822) /     3.58,  -23.94,    0.00 /
      DATA B(16159), B(16160), B(16161) /     3.16,  -22.04,    0.00 /
      DATA B(16498), B(16499), B(16500) /     2.48,  -20.85,    0.00 /
      DATA B(16837), B(16838), B(16839) /     1.99,  -20.52,    0.00 /
      DATA B(17176), B(17177), B(17178) /     1.69,  -20.42,    0.00 /
      DATA B(17515), B(17516), B(17517) /    -2.16,  -19.75,    0.00 /
      DATA B(17854), B(17855), B(17856) /    -2.73,  -19.11,    0.00 /
      DATA B(18193), B(18194), B(18195) /    -3.30,  -18.57,    0.00 /
      DATA B(18532), B(18533), B(18534) /    -3.90,  -18.07,    0.00 /
      DATA B(18871), B(18872), B(18873) /    -4.47,  -17.63,    0.00 /
      DATA B(19210), B(19211), B(19212) /    -4.98,  -17.23,    0.00 /
      DATA B(19549), B(19550), B(19551) /    -5.38,  -16.91,    0.00 /
      DATA B(19888), B(19889), B(19890) /    -5.68,  -16.69,    0.00 /
      DATA B(20227), B(20228), B(20229) /    -5.92,  -16.56,    0.00 /
      DATA B(20566), B(20567), B(20568) /    -6.12,  -16.51,    0.00 /
      DATA B(20905), B(20906), B(20907) /    -6.30,  -16.49,    0.00 /
      DATA B(21244), B(21245), B(21246) /    -6.46,  -16.49,    0.00 /
      DATA B(21583), B(21584), B(21585) /    -6.61,  -16.49,    0.00 /
      DATA B(21922), B(21923), B(21924) /    -6.76,  -16.48,    0.00 /
      DATA B(22261), B(22262), B(22263) /    -6.92,  -16.46,    0.00 /
      DATA B(22600), B(22601), B(22602) /    -7.09,  -16.43,    0.00 /
      DATA B(22939), B(22940), B(22941) /    -7.28,  -16.39,    0.00 /
      DATA B(23278), B(23279), B(23280) /    -7.50,  -16.38,    0.00 /
      DATA B(23617), B(23618), B(23619) /    -7.75,  -16.31,    0.00 /
      DATA B(23956), B(23957), B(23958) /    -7.91,  -16.30,    0.00 /
      DATA B(24295), B(24296), B(24297) /    -8.08,  -16.27,    0.00 /
      DATA B(24634), B(24635), B(24636) /    -8.29,  -16.19,    0.00 /
      DATA B(24973), B(24974), B(24975) /    -8.55,  -16.01,    0.00 /
      DATA B(25312), B(25313), B(25314) /    -8.74,  -15.70,    0.00 /
      DATA B(25651), B(25652), B(25653) /    -8.86,  -15.60,    0.00 /
      DATA B(25990), B(25991), B(25992) /    -8.98,  -15.59,    0.00 /
      DATA B(26329), B(26330), B(26331) /    -9.09,  -15.57,    0.00 /
      DATA B(26668), B(26669), B(26670) /    -9.16,  -15.56,    0.00 /
      DATA B(27007), B(27008), B(27009) /    -9.21,  -15.54,    0.00 /
      DATA B(27346), B(27347), B(27348) /    -9.26,  -15.53,    0.00 /
      DATA B(  229), B(  230), B(  231) /    21.25,  -41.16,    0.00 /
      DATA B(  568), B(  569), B(  570) /    21.14,  -41.07,    0.00 /
      DATA B(  907), B(  908), B(  909) /    21.02,  -41.00,    0.00 /
      DATA B( 1246), B( 1247), B( 1248) /    20.90,  -40.94,    0.00 /
      DATA B( 1585), B( 1586), B( 1587) /    20.78,  -40.89,    0.00 /
      DATA B( 1924), B( 1925), B( 1926) /    20.66,  -40.85,    0.00 /
      DATA B( 2263), B( 2264), B( 2265) /    20.54,  -40.82,    0.00 /
      DATA B( 2602), B( 2603), B( 2604) /    20.41,  -40.80,    0.00 /
      DATA B( 2941), B( 2942), B( 2943) /    20.28,  -40.78,    0.00 /
      DATA B( 3280), B( 3281), B( 3282) /    21.33,  -40.77,    0.00 /
      DATA B( 3619), B( 3620), B( 3621) /    21.17,  -40.58,    0.00 /
      DATA B( 3958), B( 3959), B( 3960) /    21.00,  -40.40,    0.00 /
      DATA B( 4297), B( 4298), B( 4299) /    20.83,  -40.22,    0.00 /
      DATA B( 4636), B( 4637), B( 4638) /    20.66,  -40.04,    0.00 /
      DATA B( 4975), B( 4976), B( 4977) /    20.48,  -39.87,    0.00 /
      DATA B( 5314), B( 5315), B( 5316) /    20.30,  -39.70,    0.00 /
      DATA B( 5653), B( 5654), B( 5655) /    20.12,  -39.53,    0.00 /
      DATA B( 5992), B( 5993), B( 5994) /    19.93,  -39.36,    0.00 /
      DATA B( 6331), B( 6332), B( 6333) /    19.74,  -39.20,    0.00 /
      DATA B( 6670), B( 6671), B( 6672) /    19.54,  -39.03,    0.00 /
      DATA B( 7009), B( 7010), B( 7011) /    19.34,  -38.87,    0.00 /
      DATA B( 7348), B( 7349), B( 7350) /    19.13,  -38.70,    0.00 /
      DATA B( 7687), B( 7688), B( 7689) /    18.91,  -38.52,    0.00 /
      DATA B( 8026), B( 8027), B( 8028) /    18.69,  -38.35,    0.00 /
      DATA B( 8365), B( 8366), B( 8367) /    18.46,  -38.16,    0.00 /
      DATA B( 8704), B( 8705), B( 8706) /    18.21,  -37.96,    0.00 /
      DATA B( 9043), B( 9044), B( 9045) /    17.96,  -37.74,    0.00 /
      DATA B( 9382), B( 9383), B( 9384) /    17.69,  -37.50,    0.00 /
      DATA B( 9721), B( 9722), B( 9723) /    17.41,  -37.23,    0.00 /
      DATA B(10060), B(10061), B(10062) /    17.08,  -36.93,    0.00 /
      DATA B(10399), B(10400), B(10401) /    16.70,  -36.64,    0.00 /
      DATA B(10738), B(10739), B(10740) /    16.29,  -36.30,    0.00 /
      DATA B(11077), B(11078), B(11079) /    15.65,  -35.16,    0.00 /
      DATA B(11416), B(11417), B(11418) /    15.19,  -34.56,    0.00 /
      DATA B(11755), B(11756), B(11757) /    14.66,  -33.85,    0.00 /
      DATA B(12094), B(12095), B(12096) /    13.99,  -32.98,    0.00 /
      DATA B(12433), B(12434), B(12435) /    13.15,  -31.97,    0.00 /
      DATA B(12772), B(12773), B(12774) /    10.07,  -28.60,    0.00 /
      DATA B(13111), B(13112), B(13113) /     8.98,  -27.81,    0.00 /
      DATA B(13450), B(13451), B(13452) /     8.00,  -27.12,    0.00 /
      DATA B(13789), B(13790), B(13791) /     7.06,  -26.48,    0.00 /
      DATA B(14128), B(14129), B(14130) /     6.08,  -25.80,    0.00 /
      DATA B(14467), B(14468), B(14469) /     4.98,  -24.99,    0.00 /
      DATA B(14806), B(14807), B(14808) /     3.70,  -23.97,    0.00 /
      DATA B(15145), B(15146), B(15147) /     2.40,  -22.78,    0.00 /
      DATA B(15484), B(15485), B(15486) /     1.66,  -22.37,    0.00 /
      DATA B(15823), B(15824), B(15825) /     1.01,  -22.49,    0.00 /
      DATA B(16162), B(16163), B(16164) /     0.62,  -21.13,    0.00 /
      DATA B(16501), B(16502), B(16503) /     0.42,  -20.18,    0.00 /
      DATA B(16840), B(16841), B(16842) /     0.30,  -19.74,    0.00 /
      DATA B(17179), B(17180), B(17181) /     0.20,  -19.51,    0.00 /
      DATA B(17518), B(17519), B(17520) /    -3.42,  -18.90,    0.00 /
      DATA B(17857), B(17858), B(17859) /    -3.89,  -18.29,    0.00 /
      DATA B(18196), B(18197), B(18198) /    -4.34,  -17.71,    0.00 /
      DATA B(18535), B(18536), B(18537) /    -4.82,  -17.19,    0.00 /
      DATA B(18874), B(18875), B(18876) /    -5.30,  -16.78,    0.00 /
      DATA B(19213), B(19214), B(19215) /    -5.72,  -16.48,    0.00 /
      DATA B(19552), B(19553), B(19554) /    -6.05,  -16.29,    0.00 /
      DATA B(19891), B(19892), B(19893) /    -6.30,  -16.19,    0.00 /
      DATA B(20230), B(20231), B(20232) /    -6.50,  -16.15,    0.00 /
      DATA B(20569), B(20570), B(20571) /    -6.67,  -16.16,    0.00 /
      DATA B(20908), B(20909), B(20910) /    -6.83,  -16.19,    0.00 /
      DATA B(21247), B(21248), B(21249) /    -6.99,  -16.23,    0.00 /
      DATA B(21586), B(21587), B(21588) /    -7.14,  -16.26,    0.00 /
      DATA B(21925), B(21926), B(21927) /    -7.31,  -16.25,    0.00 /
      DATA B(22264), B(22265), B(22266) /    -7.50,  -16.24,    0.00 /
      DATA B(22603), B(22604), B(22605) /    -7.70,  -16.20,    0.00 /
      DATA B(22942), B(22943), B(22944) /    -7.89,  -16.19,    0.00 /
      DATA B(23281), B(23282), B(23283) /    -8.03,  -16.16,    0.00 /
      DATA B(23620), B(23621), B(23622) /    -8.18,  -16.15,    0.00 /
      DATA B(23959), B(23960), B(23961) /    -8.33,  -16.12,    0.00 /
      DATA B(24298), B(24299), B(24300) /    -8.49,  -16.07,    0.00 /
      DATA B(24637), B(24638), B(24639) /    -8.65,  -15.98,    0.00 /
      DATA B(24976), B(24977), B(24978) /    -8.82,  -15.83,    0.00 /
      DATA B(25315), B(25316), B(25317) /    -8.94,  -15.64,    0.00 /
      DATA B(25654), B(25655), B(25656) /    -9.01,  -15.55,    0.00 /
      DATA B(25993), B(25994), B(25995) /    -9.08,  -15.52,    0.00 /
      DATA B(26332), B(26333), B(26334) /    -9.15,  -15.51,    0.00 /
      DATA B(26671), B(26672), B(26673) /    -9.21,  -15.51,    0.00 /
      DATA B(27010), B(27011), B(27012) /    -9.26,  -15.50,    0.00 /
      DATA B(27349), B(27350), B(27351) /    -9.29,  -15.50,    0.00 /
      DATA B(  232), B(  233), B(  234) /    21.12,  -41.13,    0.00 /
      DATA B(  571), B(  572), B(  573) /    21.00,  -41.07,    0.00 /
      DATA B(  910), B(  911), B(  912) /    20.89,  -41.02,    0.00 /
      DATA B( 1249), B( 1250), B( 1251) /    20.77,  -40.97,    0.00 /
      DATA B( 1588), B( 1589), B( 1590) /    20.65,  -40.93,    0.00 /
      DATA B( 1927), B( 1928), B( 1929) /    20.52,  -40.90,    0.00 /
      DATA B( 2266), B( 2267), B( 2268) /    20.40,  -40.88,    0.00 /
      DATA B( 2605), B( 2606), B( 2607) /    20.27,  -40.86,    0.00 /
      DATA B( 2944), B( 2945), B( 2946) /    20.14,  -40.85,    0.00 /
      DATA B( 3283), B( 3284), B( 3285) /    21.29,  -40.63,    0.00 /
      DATA B( 3622), B( 3623), B( 3624) /    21.12,  -40.44,    0.00 /
      DATA B( 3961), B( 3962), B( 3963) /    20.95,  -40.26,    0.00 /
      DATA B( 4300), B( 4301), B( 4302) /    20.78,  -40.08,    0.00 /
      DATA B( 4639), B( 4640), B( 4641) /    20.61,  -39.90,    0.00 /
      DATA B( 4978), B( 4979), B( 4980) /    20.43,  -39.72,    0.00 /
      DATA B( 5317), B( 5318), B( 5319) /    20.25,  -39.55,    0.00 /
      DATA B( 5656), B( 5657), B( 5658) /    20.06,  -39.38,    0.00 /
      DATA B( 5995), B( 5996), B( 5997) /    19.87,  -39.21,    0.00 /
      DATA B( 6334), B( 6335), B( 6336) /    19.68,  -39.04,    0.00 /
      DATA B( 6673), B( 6674), B( 6675) /    19.48,  -38.86,    0.00 /
      DATA B( 7012), B( 7013), B( 7014) /    19.27,  -38.69,    0.00 /
      DATA B( 7351), B( 7352), B( 7353) /    19.05,  -38.51,    0.00 /
      DATA B( 7690), B( 7691), B( 7692) /    18.83,  -38.33,    0.00 /
      DATA B( 8029), B( 8030), B( 8031) /    18.59,  -38.14,    0.00 /
      DATA B( 8368), B( 8369), B( 8370) /    18.34,  -37.94,    0.00 /
      DATA B( 8707), B( 8708), B( 8709) /    18.08,  -37.73,    0.00 /
      DATA B( 9046), B( 9047), B( 9048) /    17.80,  -37.50,    0.00 /
      DATA B( 9385), B( 9386), B( 9387) /    17.50,  -37.24,    0.00 /
      DATA B( 9724), B( 9725), B( 9726) /    17.19,  -36.93,    0.00 /
      DATA B(10063), B(10064), B(10065) /    16.84,  -36.57,    0.00 /
      DATA B(10402), B(10403), B(10404) /    16.42,  -36.29,    0.00 /
      DATA B(10741), B(10742), B(10743) /    15.80,  -35.29,    0.00 /
      DATA B(11080), B(11081), B(11082) /    15.35,  -34.74,    0.00 /
      DATA B(11419), B(11420), B(11421) /    14.84,  -34.08,    0.00 /
      DATA B(11758), B(11759), B(11760) /    14.21,  -33.26,    0.00 /
      DATA B(12097), B(12098), B(12099) /    13.42,  -32.27,    0.00 /
      DATA B(12436), B(12437), B(12438) /    10.31,  -28.76,    0.00 /
      DATA B(12775), B(12776), B(12777) /     9.19,  -27.92,    0.00 /
      DATA B(13114), B(13115), B(13116) /     8.15,  -27.19,    0.00 /
      DATA B(13453), B(13454), B(13455) /     7.18,  -26.54,    0.00 /
      DATA B(13792), B(13793), B(13794) /     6.20,  -25.88,    0.00 /
      DATA B(14131), B(14132), B(14133) /     5.12,  -25.10,    0.00 /
      DATA B(14470), B(14471), B(14472) /     3.87,  -24.11,    0.00 /
      DATA B(14809), B(14810), B(14811) /     2.44,  -22.87,    0.00 /
      DATA B(15148), B(15149), B(15150) /     1.02,  -21.69,    0.00 /
      DATA B(15487), B(15488), B(15489) /     0.33,  -21.11,    0.00 /
      DATA B(15826), B(15827), B(15828) /    -0.48,  -20.81,    0.00 /
      DATA B(16165), B(16166), B(16167) /    -0.96,  -20.05,    0.00 /
      DATA B(16504), B(16505), B(16506) /    -1.08,  -19.36,    0.00 /
      DATA B(16843), B(16844), B(16845) /    -1.04,  -18.91,    0.00 /
      DATA B(17182), B(17183), B(17184) /    -0.98,  -18.61,    0.00 /
      DATA B(17521), B(17522), B(17523) /    -4.38,  -18.09,    0.00 /
      DATA B(17860), B(17861), B(17862) /    -4.75,  -17.48,    0.00 /
      DATA B(18199), B(18200), B(18201) /    -5.13,  -16.83,    0.00 /
      DATA B(18538), B(18539), B(18540) /    -5.57,  -16.26,    0.00 /
      DATA B(18877), B(18878), B(18879) /    -6.03,  -15.89,    0.00 /
      DATA B(19216), B(19217), B(19218) /    -6.42,  -15.72,    0.00 /
      DATA B(19555), B(19556), B(19557) /    -6.70,  -15.67,    0.00 /
      DATA B(19894), B(19895), B(19896) /    -6.91,  -15.69,    0.00 /
      DATA B(20233), B(20234), B(20235) /    -7.08,  -15.73,    0.00 /
      DATA B(20572), B(20573), B(20574) /    -7.24,  -15.81,    0.00 /
      DATA B(20911), B(20912), B(20913) /    -7.40,  -15.90,    0.00 /
      DATA B(21250), B(21251), B(21252) /    -7.56,  -15.98,    0.00 /
      DATA B(21589), B(21590), B(21591) /    -7.73,  -16.03,    0.00 /
      DATA B(21928), B(21929), B(21930) /    -7.92,  -16.05,    0.00 /
      DATA B(22267), B(22268), B(22269) /    -8.05,  -16.01,    0.00 /
      DATA B(22606), B(22607), B(22608) /    -8.18,  -16.02,    0.00 /
      DATA B(22945), B(22946), B(22947) /    -8.30,  -16.01,    0.00 /
      DATA B(23284), B(23285), B(23286) /    -8.42,  -15.99,    0.00 /
      DATA B(23623), B(23624), B(23625) /    -8.54,  -15.97,    0.00 /
      DATA B(23962), B(23963), B(23964) /    -8.66,  -15.93,    0.00 /
      DATA B(24301), B(24302), B(24303) /    -8.77,  -15.88,    0.00 /
      DATA B(24640), B(24641), B(24642) /    -8.88,  -15.81,    0.00 /
      DATA B(24979), B(24980), B(24981) /    -8.99,  -15.69,    0.00 /
      DATA B(25318), B(25319), B(25320) /    -9.07,  -15.58,    0.00 /
      DATA B(25657), B(25658), B(25659) /    -9.12,  -15.51,    0.00 /
      DATA B(25996), B(25997), B(25998) /    -9.16,  -15.48,    0.00 /
      DATA B(26335), B(26336), B(26337) /    -9.21,  -15.47,    0.00 /
      DATA B(26674), B(26675), B(26676) /    -9.26,  -15.46,    0.00 /
      DATA B(27013), B(27014), B(27015) /    -9.29,  -15.46,    0.00 /
      DATA B(27352), B(27353), B(27354) /    -9.32,  -15.46,    0.00 /
      DATA B(  235), B(  236), B(  237) /    20.98,  -41.14,    0.00 /
      DATA B(  574), B(  575), B(  576) /    20.87,  -41.10,    0.00 /
      DATA B(  913), B(  914), B(  915) /    20.75,  -41.06,    0.00 /
      DATA B( 1252), B( 1253), B( 1254) /    20.63,  -41.02,    0.00 /
      DATA B( 1591), B( 1592), B( 1593) /    20.51,  -40.99,    0.00 /
      DATA B( 1930), B( 1931), B( 1932) /    20.39,  -40.97,    0.00 /
      DATA B( 2269), B( 2270), B( 2271) /    20.26,  -40.94,    0.00 /
      DATA B( 2608), B( 2609), B( 2610) /    20.13,  -40.93,    0.00 /
      DATA B( 2947), B( 2948), B( 2949) /    21.41,  -40.68,    0.00 /
      DATA B( 3286), B( 3287), B( 3288) /    21.24,  -40.49,    0.00 /
      DATA B( 3625), B( 3626), B( 3627) /    21.07,  -40.30,    0.00 /
      DATA B( 3964), B( 3965), B( 3966) /    20.90,  -40.11,    0.00 /
      DATA B( 4303), B( 4304), B( 4305) /    20.73,  -39.93,    0.00 /
      DATA B( 4642), B( 4643), B( 4644) /    20.55,  -39.75,    0.00 /
      DATA B( 4981), B( 4982), B( 4983) /    20.37,  -39.57,    0.00 /
      DATA B( 5320), B( 5321), B( 5322) /    20.19,  -39.39,    0.00 /
      DATA B( 5659), B( 5660), B( 5661) /    20.01,  -39.22,    0.00 /
      DATA B( 5998), B( 5999), B( 6000) /    19.81,  -39.04,    0.00 /
      DATA B( 6337), B( 6338), B( 6339) /    19.62,  -38.86,    0.00 /
      DATA B( 6676), B( 6677), B( 6678) /    19.41,  -38.68,    0.00 /
      DATA B( 7015), B( 7016), B( 7017) /    19.20,  -38.49,    0.00 /
      DATA B( 7354), B( 7355), B( 7356) /    18.97,  -38.30,    0.00 /
      DATA B( 7693), B( 7694), B( 7695) /    18.73,  -38.11,    0.00 /
      DATA B( 8032), B( 8033), B( 8034) /    18.48,  -37.91,    0.00 /
      DATA B( 8371), B( 8372), B( 8373) /    18.21,  -37.69,    0.00 /
      DATA B( 8710), B( 8711), B( 8712) /    17.92,  -37.46,    0.00 /
      DATA B( 9049), B( 9050), B( 9051) /    17.60,  -37.21,    0.00 /
      DATA B( 9388), B( 9389), B( 9390) /    17.25,  -36.93,    0.00 /
      DATA B( 9727), B( 9728), B( 9729) /    16.86,  -36.61,    0.00 /
      DATA B(10066), B(10067), B(10068) /    16.49,  -36.19,    0.00 /
      DATA B(10405), B(10406), B(10407) /    15.97,  -35.35,    0.00 /
      DATA B(10744), B(10745), B(10746) /    15.58,  -34.90,    0.00 /
      DATA B(11083), B(11084), B(11085) /    15.04,  -34.27,    0.00 /
      DATA B(11422), B(11423), B(11424) /    14.41,  -33.52,    0.00 /
      DATA B(11761), B(11762), B(11763) /    13.67,  -32.57,    0.00 /
      DATA B(12100), B(12101), B(12102) /    10.62,  -28.93,    0.00 /
      DATA B(12439), B(12440), B(12441) /     9.45,  -28.04,    0.00 /
      DATA B(12778), B(12779), B(12780) /     8.34,  -27.27,    0.00 /
      DATA B(13117), B(13118), B(13119) /     7.32,  -26.61,    0.00 /
      DATA B(13456), B(13457), B(13458) /     6.30,  -25.95,    0.00 /
      DATA B(13795), B(13796), B(13797) /     5.20,  -25.20,    0.00 /
      DATA B(14134), B(14135), B(14136) /     3.94,  -24.24,    0.00 /
      DATA B(14473), B(14474), B(14475) /     2.42,  -22.98,    0.00 /
      DATA B(14812), B(14813), B(14814) /     0.79,  -21.58,    0.00 /
      DATA B(15151), B(15152), B(15153) /    -0.32,  -20.41,    0.00 /
      DATA B(15490), B(15491), B(15492) /    -1.13,  -19.76,    0.00 /
      DATA B(15829), B(15830), B(15831) /    -1.76,  -19.41,    0.00 /
      DATA B(16168), B(16169), B(16170) /    -2.11,  -18.98,    0.00 /
      DATA B(16507), B(16508), B(16509) /    -2.18,  -18.53,    0.00 /
      DATA B(16846), B(16847), B(16848) /    -2.08,  -18.13,    0.00 /
      DATA B(17185), B(17186), B(17187) /    -1.94,  -17.80,    0.00 /
      DATA B(17524), B(17525), B(17526) /    -5.18,  -17.37,    0.00 /
      DATA B(17863), B(17864), B(17865) /    -5.46,  -16.73,    0.00 /
      DATA B(18202), B(18203), B(18204) /    -5.78,  -15.91,    0.00 /
      DATA B(18541), B(18542), B(18543) /    -6.26,  -15.23,    0.00 /
      DATA B(18880), B(18881), B(18882) /    -6.77,  -14.94,    0.00 /
      DATA B(19219), B(19220), B(19221) /    -7.14,  -14.94,    0.00 /
      DATA B(19558), B(19559), B(19560) /    -7.38,  -15.05,    0.00 /
      DATA B(19897), B(19898), B(19899) /    -7.55,  -15.20,    0.00 /
      DATA B(20236), B(20237), B(20238) /    -7.69,  -15.32,    0.00 /
      DATA B(20575), B(20576), B(20577) /    -7.83,  -15.48,    0.00 /
      DATA B(20914), B(20915), B(20916) /    -7.99,  -15.68,    0.00 /
      DATA B(21253), B(21254), B(21255) /    -8.15,  -15.89,    0.00 /
      DATA B(21592), B(21593), B(21594) /    -8.24,  -15.84,    0.00 /
      DATA B(21931), B(21932), B(21933) /    -8.34,  -15.85,    0.00 /
      DATA B(22270), B(22271), B(22272) /    -8.44,  -15.85,    0.00 /
      DATA B(22609), B(22610), B(22611) /    -8.54,  -15.84,    0.00 /
      DATA B(22948), B(22949), B(22950) /    -8.63,  -15.83,    0.00 /
      DATA B(23287), B(23288), B(23289) /    -8.71,  -15.81,    0.00 /
      DATA B(23626), B(23627), B(23628) /    -8.80,  -15.79,    0.00 /
      DATA B(23965), B(23966), B(23967) /    -8.88,  -15.76,    0.00 /
      DATA B(24304), B(24305), B(24306) /    -8.96,  -15.72,    0.00 /
      DATA B(24643), B(24644), B(24645) /    -9.04,  -15.66,    0.00 /
      DATA B(24982), B(24983), B(24984) /    -9.11,  -15.59,    0.00 /
      DATA B(25321), B(25322), B(25323) /    -9.16,  -15.52,    0.00 /
      DATA B(25660), B(25661), B(25662) /    -9.20,  -15.46,    0.00 /
      DATA B(25999), B(26000), B(26001) /    -9.23,  -15.44,    0.00 /
      DATA B(26338), B(26339), B(26340) /    -9.26,  -15.43,    0.00 /
      DATA B(26677), B(26678), B(26679) /    -9.29,  -15.43,    0.00 /
      DATA B(27016), B(27017), B(27018) /    -9.32,  -15.43,    0.00 /
      DATA B(27355), B(27356), B(27357) /    -9.35,  -15.43,    0.00 /
      DATA B(  238), B(  239), B(  240) /    20.85,  -41.18,    0.00 /
      DATA B(  577), B(  578), B(  579) /    20.73,  -41.15,    0.00 /
      DATA B(  916), B(  917), B(  918) /    20.61,  -41.12,    0.00 /
      DATA B( 1255), B( 1256), B( 1257) /    20.50,  -41.09,    0.00 /
      DATA B( 1594), B( 1595), B( 1596) /    20.37,  -41.06,    0.00 /
      DATA B( 1933), B( 1934), B( 1935) /    20.25,  -41.04,    0.00 /
      DATA B( 2272), B( 2273), B( 2274) /    20.12,  -41.01,    0.00 /
      DATA B( 2611), B( 2612), B( 2613) /    19.99,  -40.99,    0.00 /
      DATA B( 2950), B( 2951), B( 2952) /    21.36,  -40.54,    0.00 /
      DATA B( 3289), B( 3290), B( 3291) /    21.20,  -40.35,    0.00 /
      DATA B( 3628), B( 3629), B( 3630) /    21.03,  -40.15,    0.00 /
      DATA B( 3967), B( 3968), B( 3969) /    20.85,  -39.96,    0.00 /
      DATA B( 4306), B( 4307), B( 4308) /    20.68,  -39.78,    0.00 /
      DATA B( 4645), B( 4646), B( 4647) /    20.50,  -39.59,    0.00 /
      DATA B( 4984), B( 4985), B( 4986) /    20.32,  -39.41,    0.00 /
      DATA B( 5323), B( 5324), B( 5325) /    20.14,  -39.22,    0.00 /
      DATA B( 5662), B( 5663), B( 5664) /    19.95,  -39.04,    0.00 /
      DATA B( 6001), B( 6002), B( 6003) /    19.76,  -38.85,    0.00 /
      DATA B( 6340), B( 6341), B( 6342) /    19.55,  -38.66,    0.00 /
      DATA B( 6679), B( 6680), B( 6681) /    19.34,  -38.47,    0.00 /
      DATA B( 7018), B( 7019), B( 7020) /    19.12,  -38.27,    0.00 /
      DATA B( 7357), B( 7358), B( 7359) /    18.89,  -38.07,    0.00 /
      DATA B( 7696), B( 7697), B( 7698) /    18.64,  -37.86,    0.00 /
      DATA B( 8035), B( 8036), B( 8037) /    18.37,  -37.64,    0.00 /
      DATA B( 8374), B( 8375), B( 8376) /    18.07,  -37.41,    0.00 /
      DATA B( 8713), B( 8714), B( 8715) /    17.74,  -37.16,    0.00 /
      DATA B( 9052), B( 9053), B( 9054) /    17.36,  -36.90,    0.00 /
      DATA B( 9391), B( 9392), B( 9393) /    16.92,  -36.61,    0.00 /
      DATA B( 9730), B( 9731), B( 9732) /    16.40,  -36.26,    0.00 /
      DATA B(10069), B(10070), B(10071) /    18.23,  -36.82,    0.00 /
      DATA B(10408), B(10409), B(10410) /    16.02,  -35.00,    0.00 /
      DATA B(10747), B(10748), B(10749) /    15.35,  -34.42,    0.00 /
      DATA B(11086), B(11087), B(11088) /    14.67,  -33.71,    0.00 /
      DATA B(11425), B(11426), B(11427) /    13.89,  -32.84,    0.00 /
      DATA B(11764), B(11765), B(11766) /    12.97,  -31.73,    0.00 /
      DATA B(12103), B(12104), B(12105) /     9.77,  -28.15,    0.00 /
      DATA B(12442), B(12443), B(12444) /     8.59,  -27.34,    0.00 /
      DATA B(12781), B(12782), B(12783) /     7.50,  -26.66,    0.00 /
      DATA B(13120), B(13121), B(13122) /     6.44,  -26.01,    0.00 /
      DATA B(13459), B(13460), B(13461) /     5.31,  -25.30,    0.00 /
      DATA B(13798), B(13799), B(13800) /     4.02,  -24.38,    0.00 /
      DATA B(14137), B(14138), B(14139) /     2.46,  -23.15,    0.00 /
      DATA B(14476), B(14477), B(14478) /     0.61,  -21.60,    0.00 /
      DATA B(14815), B(14816), B(14817) /    -0.75,  -20.16,    0.00 /
      DATA B(15154), B(15155), B(15156) /    -1.73,  -19.12,    0.00 /
      DATA B(15493), B(15494), B(15495) /    -2.42,  -18.59,    0.00 /
      DATA B(15832), B(15833), B(15834) /    -2.86,  -18.32,    0.00 /
      DATA B(16171), B(16172), B(16173) /    -3.09,  -18.07,    0.00 /
      DATA B(16510), B(16511), B(16512) /    -3.11,  -17.79,    0.00 /
      DATA B(16849), B(16850), B(16851) /    -2.96,  -17.45,    0.00 /
      DATA B(17188), B(17189), B(17190) /    -5.59,  -17.24,    0.00 /
      DATA B(17527), B(17528), B(17529) /    -5.93,  -16.76,    0.00 /
      DATA B(17866), B(17867), B(17868) /    -6.10,  -16.05,    0.00 /
      DATA B(18205), B(18206), B(18207) /    -6.40,  -14.82,    0.00 /
      DATA B(18544), B(18545), B(18546) /    -7.05,  -14.02,    0.00 /
      DATA B(18883), B(18884), B(18885) /    -7.63,  -13.94,    0.00 /
      DATA B(19222), B(19223), B(19224) /    -7.94,  -14.15,    0.00 /
      DATA B(19561), B(19562), B(19563) /    -8.11,  -14.48,    0.00 /
      DATA B(19900), B(19901), B(19902) /    -8.35,  -15.81,    0.00 /
      DATA B(20239), B(20240), B(20241) /    -8.41,  -15.86,    0.00 /
      DATA B(20578), B(20579), B(20580) /    -8.46,  -15.79,    0.00 /
      DATA B(20917), B(20918), B(20919) /    -8.53,  -15.75,    0.00 /
      DATA B(21256), B(21257), B(21258) /    -8.57,  -15.70,    0.00 /
      DATA B(21595), B(21596), B(21597) /    -8.63,  -15.68,    0.00 /
      DATA B(21934), B(21935), B(21936) /    -8.68,  -15.67,    0.00 /
      DATA B(22273), B(22274), B(22275) /    -8.74,  -15.67,    0.00 /
      DATA B(22612), B(22613), B(22614) /    -8.80,  -15.67,    0.00 /
      DATA B(22951), B(22952), B(22953) /    -8.86,  -15.66,    0.00 /
      DATA B(23290), B(23291), B(23292) /    -8.92,  -15.65,    0.00 /
      DATA B(23629), B(23630), B(23631) /    -8.97,  -15.64,    0.00 /
      DATA B(23968), B(23969), B(23970) /    -9.03,  -15.62,    0.00 /
      DATA B(24307), B(24308), B(24309) /    -9.09,  -15.59,    0.00 /
      DATA B(24646), B(24647), B(24648) /    -9.14,  -15.55,    0.00 /
      DATA B(24985), B(24986), B(24987) /    -9.19,  -15.50,    0.00 /
      DATA B(25324), B(25325), B(25326) /    -9.22,  -15.46,    0.00 /
      DATA B(25663), B(25664), B(25665) /    -9.25,  -15.42,    0.00 /
      DATA B(26002), B(26003), B(26004) /    -9.28,  -15.40,    0.00 /
      DATA B(26341), B(26342), B(26343) /    -9.30,  -15.40,    0.00 /
      DATA B(26680), B(26681), B(26682) /    -9.32,  -15.39,    0.00 /
      DATA B(27019), B(27020), B(27021) /    -9.35,  -15.40,    0.00 /
      DATA B(27358), B(27359), B(27360) /    -9.37,  -15.40,    0.00 /
      DATA B(  241), B(  242), B(  243) /    20.71,  -41.24,    0.00 /
      DATA B(  580), B(  581), B(  582) /    20.59,  -41.22,    0.00 /
      DATA B(  919), B(  920), B(  921) /    20.48,  -41.19,    0.00 /
      DATA B( 1258), B( 1259), B( 1260) /    20.36,  -41.16,    0.00 /
      DATA B( 1597), B( 1598), B( 1599) /    20.23,  -41.14,    0.00 /
      DATA B( 1936), B( 1937), B( 1938) /    20.11,  -41.11,    0.00 /
      DATA B( 2275), B( 2276), B( 2277) /    19.98,  -41.08,    0.00 /
      DATA B( 2614), B( 2615), B( 2616) /    19.84,  -41.06,    0.00 /
      DATA B( 2953), B( 2954), B( 2955) /    21.32,  -40.40,    0.00 /
      DATA B( 3292), B( 3293), B( 3294) /    21.15,  -40.20,    0.00 /
      DATA B( 3631), B( 3632), B( 3633) /    20.98,  -40.00,    0.00 /
      DATA B( 3970), B( 3971), B( 3972) /    20.80,  -39.80,    0.00 /
      DATA B( 4309), B( 4310), B( 4311) /    20.63,  -39.61,    0.00 /
      DATA B( 4648), B( 4649), B( 4650) /    20.45,  -39.42,    0.00 /
      DATA B( 4987), B( 4988), B( 4989) /    20.27,  -39.23,    0.00 /
      DATA B( 5326), B( 5327), B( 5328) /    20.08,  -39.04,    0.00 /
      DATA B( 5665), B( 5666), B( 5667) /    19.89,  -38.85,    0.00 /
      DATA B( 6004), B( 6005), B( 6006) /    19.70,  -38.65,    0.00 /
      DATA B( 6343), B( 6344), B( 6345) /    19.49,  -38.44,    0.00 /
      DATA B( 6682), B( 6683), B( 6684) /    19.28,  -38.23,    0.00 /
      DATA B( 7021), B( 7022), B( 7023) /    19.05,  -38.02,    0.00 /
      DATA B( 7360), B( 7361), B( 7362) /    18.80,  -37.80,    0.00 /
      DATA B( 7699), B( 7700), B( 7701) /    18.53,  -37.57,    0.00 /
      DATA B( 8038), B( 8039), B( 8040) /    18.23,  -37.34,    0.00 /
      DATA B( 8377), B( 8378), B( 8379) /    17.90,  -37.10,    0.00 /
      DATA B( 8716), B( 8717), B( 8718) /    17.51,  -36.84,    0.00 /
      DATA B( 9055), B( 9056), B( 9057) /    17.06,  -36.56,    0.00 /
      DATA B( 9394), B( 9395), B( 9396) /    18.67,  -37.13,    0.00 /
      DATA B( 9733), B( 9734), B( 9735) /    18.14,  -37.03,    0.00 /
      DATA B(10072), B(10073), B(10074) /    16.18,  -35.36,    0.00 /
      DATA B(10411), B(10412), B(10413) /    15.60,  -34.58,    0.00 /
      DATA B(10750), B(10751), B(10752) /    14.97,  -33.87,    0.00 /
      DATA B(11089), B(11090), B(11091) /    14.22,  -33.04,    0.00 /
      DATA B(11428), B(11429), B(11430) /    13.31,  -32.02,    0.00 /
      DATA B(11767), B(11768), B(11769) /    10.05,  -28.22,    0.00 /
      DATA B(12106), B(12107), B(12108) /     8.87,  -27.37,    0.00 /
      DATA B(12445), B(12446), B(12447) /     7.73,  -26.67,    0.00 /
      DATA B(12784), B(12785), B(12786) /     6.62,  -26.05,    0.00 /
      DATA B(13123), B(13124), B(13125) /     5.46,  -25.37,    0.00 /
      DATA B(13462), B(13463), B(13464) /     4.15,  -24.51,    0.00 /
      DATA B(13801), B(13802), B(13803) /     2.58,  -23.35,    0.00 /
      DATA B(14140), B(14141), B(14142) /     0.73,  -21.76,    0.00 /
      DATA B(14479), B(14480), B(14481) /    -1.07,  -20.05,    0.00 /
      DATA B(14818), B(14819), B(14820) /    -2.20,  -18.78,    0.00 /
      DATA B(15157), B(15158), B(15159) /    -3.03,  -18.02,    0.00 /
      DATA B(15496), B(15497), B(15498) /    -3.54,  -17.64,    0.00 /
      DATA B(15835), B(15836), B(15837) /    -3.84,  -17.46,    0.00 /
      DATA B(16174), B(16175), B(16176) /    -3.99,  -17.32,    0.00 /
      DATA B(16513), B(16514), B(16515) /    -4.02,  -17.17,    0.00 /
      DATA B(16852), B(16853), B(16854) /    -3.89,  -16.92,    0.00 /
      DATA B(17191), B(17192), B(17193) /    -6.34,  -16.60,    0.00 /
      DATA B(17530), B(17531), B(17532) /    -6.68,  -16.33,    0.00 /
      DATA B(17869), B(17870), B(17871) /    -6.76,  -15.57,    0.00 /
      DATA B(18208), B(18209), B(18210) /    -7.31,  -13.24,    0.00 /
      DATA B(18547), B(18548), B(18549) /    -8.09,  -12.85,    0.00 /
      DATA B(18886), B(18887), B(18888) /    -8.76,  -14.93,    0.00 /
      DATA B(19225), B(19226), B(19227) /    -8.91,  -15.16,    0.00 /
      DATA B(19564), B(19565), B(19566) /    -8.94,  -15.33,    0.00 /
      DATA B(19903), B(19904), B(19905) /    -8.93,  -15.48,    0.00 /
      DATA B(20242), B(20243), B(20244) /    -8.90,  -15.53,    0.00 /
      DATA B(20581), B(20582), B(20583) /    -8.90,  -15.54,    0.00 /
      DATA B(20920), B(20921), B(20922) /    -8.90,  -15.53,    0.00 /
      DATA B(21259), B(21260), B(21261) /    -8.91,  -15.51,    0.00 /
      DATA B(21598), B(21599), B(21600) /    -8.92,  -15.50,    0.00 /
      DATA B(21937), B(21938), B(21939) /    -8.94,  -15.50,    0.00 /
      DATA B(22276), B(22277), B(22278) /    -8.96,  -15.51,    0.00 /
      DATA B(22615), B(22616), B(22617) /    -8.99,  -15.51,    0.00 /
      DATA B(22954), B(22955), B(22956) /    -9.03,  -15.52,    0.00 /
      DATA B(23293), B(23294), B(23295) /    -9.06,  -15.52,    0.00 /
      DATA B(23632), B(23633), B(23634) /    -9.10,  -15.51,    0.00 /
      DATA B(23971), B(23972), B(23973) /    -9.14,  -15.50,    0.00 /
      DATA B(24310), B(24311), B(24312) /    -9.18,  -15.49,    0.00 /
      DATA B(24649), B(24650), B(24651) /    -9.21,  -15.46,    0.00 /
      DATA B(24988), B(24989), B(24990) /    -9.25,  -15.43,    0.00 /
      DATA B(25327), B(25328), B(25329) /    -9.27,  -15.40,    0.00 /
      DATA B(25666), B(25667), B(25668) /    -9.29,  -15.38,    0.00 /
      DATA B(26005), B(26006), B(26007) /    -9.31,  -15.37,    0.00 /
      DATA B(26344), B(26345), B(26346) /    -9.33,  -15.36,    0.00 /
      DATA B(26683), B(26684), B(26685) /    -9.35,  -15.36,    0.00 /
      DATA B(27022), B(27023), B(27024) /    -9.37,  -15.37,    0.00 /
      DATA B(27361), B(27362), B(27363) /    -9.38,  -15.38,    0.00 /
      DATA B(  244), B(  245), B(  246) /    20.57,  -41.31,    0.00 /
      DATA B(  583), B(  584), B(  585) /    20.45,  -41.30,    0.00 /
      DATA B(  922), B(  923), B(  924) /    20.34,  -41.27,    0.00 /
      DATA B( 1261), B( 1262), B( 1263) /    20.22,  -41.25,    0.00 /
      DATA B( 1600), B( 1601), B( 1602) /    20.09,  -41.22,    0.00 /
      DATA B( 1939), B( 1940), B( 1941) /    19.97,  -41.18,    0.00 /
      DATA B( 2278), B( 2279), B( 2280) /    19.84,  -41.15,    0.00 /
      DATA B( 2617), B( 2618), B( 2619) /    19.70,  -41.12,    0.00 /
      DATA B( 2956), B( 2957), B( 2958) /    21.27,  -40.25,    0.00 /
      DATA B( 3295), B( 3296), B( 3297) /    21.10,  -40.04,    0.00 /
      DATA B( 3634), B( 3635), B( 3636) /    20.92,  -39.83,    0.00 /
      DATA B( 3973), B( 3974), B( 3975) /    20.75,  -39.63,    0.00 /
      DATA B( 4312), B( 4313), B( 4314) /    20.57,  -39.43,    0.00 /
      DATA B( 4651), B( 4652), B( 4653) /    20.39,  -39.24,    0.00 /
      DATA B( 4990), B( 4991), B( 4992) /    20.21,  -39.04,    0.00 /
      DATA B( 5329), B( 5330), B( 5331) /    20.03,  -38.84,    0.00 /
      DATA B( 5668), B( 5669), B( 5670) /    19.84,  -38.63,    0.00 /
      DATA B( 6007), B( 6008), B( 6009) /    19.64,  -38.42,    0.00 /
      DATA B( 6346), B( 6347), B( 6348) /    19.44,  -38.20,    0.00 /
      DATA B( 6685), B( 6686), B( 6687) /    19.21,  -37.97,    0.00 /
      DATA B( 7024), B( 7025), B( 7026) /    18.97,  -37.74,    0.00 /
      DATA B( 7363), B( 7364), B( 7365) /    18.69,  -37.50,    0.00 /
      DATA B( 7702), B( 7703), B( 7704) /    18.40,  -37.27,    0.00 /
      DATA B( 8041), B( 8042), B( 8043) /    18.06,  -37.03,    0.00 /
      DATA B( 8380), B( 8381), B( 8382) /    17.70,  -36.80,    0.00 /
      DATA B( 8719), B( 8720), B( 8721) /    18.97,  -37.19,    0.00 /
      DATA B( 9058), B( 9059), B( 9060) /    18.54,  -37.21,    0.00 /
      DATA B( 9397), B( 9398), B( 9399) /    18.06,  -37.15,    0.00 /
      DATA B( 9736), B( 9737), B( 9738) /    16.30,  -35.53,    0.00 /
      DATA B(10075), B(10076), B(10077) /    15.74,  -34.86,    0.00 /
      DATA B(10414), B(10415), B(10416) /    15.17,  -34.10,    0.00 /
      DATA B(10753), B(10754), B(10755) /    14.50,  -33.27,    0.00 /
      DATA B(11092), B(11093), B(11094) /    13.66,  -32.27,    0.00 /
      DATA B(11431), B(11432), B(11433) /    12.69,  -31.07,    0.00 /
      DATA B(11770), B(11771), B(11772) /     9.17,  -27.35,    0.00 /
      DATA B(12109), B(12110), B(12111) /     7.97,  -26.62,    0.00 /
      DATA B(12448), B(12449), B(12450) /     6.82,  -26.02,    0.00 /
      DATA B(12787), B(12788), B(12789) /     5.66,  -25.40,    0.00 /
      DATA B(13126), B(13127), B(13128) /     4.36,  -24.61,    0.00 /
      DATA B(13465), B(13466), B(13467) /     2.80,  -23.53,    0.00 /
      DATA B(13804), B(13805), B(13806) /     0.93,  -22.05,    0.00 /
      DATA B(14143), B(14144), B(14145) /    -1.45,  -19.98,    0.00 /
      DATA B(14482), B(14483), B(14484) /    -2.69,  -18.61,    0.00 /
      DATA B(14821), B(14822), B(14823) /    -3.59,  -17.64,    0.00 /
      DATA B(15160), B(15161), B(15162) /    -4.17,  -17.12,    0.00 /
      DATA B(15499), B(15500), B(15501) /    -4.52,  -16.87,    0.00 /
      DATA B(15838), B(15839), B(15840) /    -4.72,  -16.75,    0.00 /
      DATA B(16177), B(16178), B(16179) /    -4.84,  -16.68,    0.00 /
      DATA B(16516), B(16517), B(16518) /    -4.95,  -16.59,    0.00 /
      DATA B(16855), B(16856), B(16857) /    -5.09,  -16.40,    0.00 /
      DATA B(17194), B(17195), B(17196) /    -6.55,  -16.01,    0.00 /
      DATA B(17533), B(17534), B(17535) /    -7.12,  -16.07,    0.00 /
      DATA B(17872), B(17873), B(17874) /    -7.60,  -16.29,    0.00 /
      DATA B(18211), B(18212), B(18213) /    -8.87,  -14.41,    0.00 /
      DATA B(18550), B(18551), B(18552) /    -9.01,  -14.32,    0.00 /
      DATA B(18889), B(18890), B(18891) /    -9.24,  -14.40,    0.00 /
      DATA B(19228), B(19229), B(19230) /    -9.40,  -14.61,    0.00 /
      DATA B(19567), B(19568), B(19569) /    -9.41,  -14.87,    0.00 /
      DATA B(19906), B(19907), B(19908) /    -9.34,  -15.07,    0.00 /
      DATA B(20245), B(20246), B(20247) /    -9.27,  -15.19,    0.00 /
      DATA B(20584), B(20585), B(20586) /    -9.21,  -15.26,    0.00 /
      DATA B(20923), B(20924), B(20925) /    -9.17,  -15.29,    0.00 /
      DATA B(21262), B(21263), B(21264) /    -9.14,  -15.31,    0.00 /
      DATA B(21601), B(21602), B(21603) /    -9.12,  -15.33,    0.00 /
      DATA B(21940), B(21941), B(21942) /    -9.12,  -15.35,    0.00 /
      DATA B(22279), B(22280), B(22281) /    -9.12,  -15.36,    0.00 /
      DATA B(22618), B(22619), B(22620) /    -9.13,  -15.38,    0.00 /
      DATA B(22957), B(22958), B(22959) /    -9.15,  -15.39,    0.00 /
      DATA B(23296), B(23297), B(23298) /    -9.17,  -15.40,    0.00 /
      DATA B(23635), B(23636), B(23637) /    -9.19,  -15.41,    0.00 /
      DATA B(23974), B(23975), B(23976) /    -9.22,  -15.41,    0.00 /
      DATA B(24313), B(24314), B(24315) /    -9.24,  -15.40,    0.00 /
      DATA B(24652), B(24653), B(24654) /    -9.27,  -15.39,    0.00 /
      DATA B(24991), B(24992), B(24993) /    -9.29,  -15.37,    0.00 /
      DATA B(25330), B(25331), B(25332) /    -9.31,  -15.35,    0.00 /
      DATA B(25669), B(25670), B(25671) /    -9.33,  -15.34,    0.00 /
      DATA B(26008), B(26009), B(26010) /    -9.34,  -15.34,    0.00 /
      DATA B(26347), B(26348), B(26349) /    -9.36,  -15.33,    0.00 /
      DATA B(26686), B(26687), B(26688) /    -9.37,  -15.34,    0.00 /
      DATA B(27025), B(27026), B(27027) /    -9.38,  -15.34,    0.00 /
      DATA B(27364), B(27365), B(27366) /    -9.40,  -15.35,    0.00 /
      DATA B(  247), B(  248), B(  249) /    20.43,  -41.40,    0.00 /
      DATA B(  586), B(  587), B(  588) /    20.31,  -41.39,    0.00 /
      DATA B(  925), B(  926), B(  927) /    20.19,  -41.37,    0.00 /
      DATA B( 1264), B( 1265), B( 1266) /    20.07,  -41.34,    0.00 /
      DATA B( 1603), B( 1604), B( 1605) /    19.95,  -41.30,    0.00 /
      DATA B( 1942), B( 1943), B( 1944) /    19.82,  -41.26,    0.00 /
      DATA B( 2281), B( 2282), B( 2283) /    19.69,  -41.21,    0.00 /
      DATA B( 2620), B( 2621), B( 2622) /    21.39,  -40.31,    0.00 /
      DATA B( 2959), B( 2960), B( 2961) /    21.22,  -40.09,    0.00 /
      DATA B( 3298), B( 3299), B( 3300) /    21.04,  -39.87,    0.00 /
      DATA B( 3637), B( 3638), B( 3639) /    20.87,  -39.66,    0.00 /
      DATA B( 3976), B( 3977), B( 3978) /    20.69,  -39.45,    0.00 /
      DATA B( 4315), B( 4316), B( 4317) /    20.51,  -39.24,    0.00 /
      DATA B( 4654), B( 4655), B( 4656) /    20.33,  -39.03,    0.00 /
      DATA B( 4993), B( 4994), B( 4995) /    20.15,  -38.82,    0.00 /
      DATA B( 5332), B( 5333), B( 5334) /    19.97,  -38.61,    0.00 /
      DATA B( 5671), B( 5672), B( 5673) /    19.78,  -38.40,    0.00 /
      DATA B( 6010), B( 6011), B( 6012) /    19.59,  -38.17,    0.00 /
      DATA B( 6349), B( 6350), B( 6351) /    19.37,  -37.93,    0.00 /
      DATA B( 6688), B( 6689), B( 6690) /    19.13,  -37.68,    0.00 /
      DATA B( 7027), B( 7028), B( 7029) /    18.87,  -37.44,    0.00 /
      DATA B( 7366), B( 7367), B( 7368) /    18.56,  -37.20,    0.00 /
      DATA B( 7705), B( 7706), B( 7707) /    19.50,  -37.13,    0.00 /
      DATA B( 8044), B( 8045), B( 8046) /    19.19,  -37.21,    0.00 /
      DATA B( 8383), B( 8384), B( 8385) /    18.84,  -37.26,    0.00 /
      DATA B( 8722), B( 8723), B( 8724) /    18.44,  -37.27,    0.00 /
      DATA B( 9061), B( 9062), B( 9063) /    17.98,  -37.22,    0.00 /
      DATA B( 9400), B( 9401), B( 9402) /    16.40,  -35.58,    0.00 /
      DATA B( 9739), B( 9740), B( 9741) /    15.87,  -34.99,    0.00 /
      DATA B(10078), B(10079), B(10080) /    15.32,  -34.32,    0.00 /
      DATA B(10417), B(10418), B(10419) /    14.70,  -33.53,    0.00 /
      DATA B(10756), B(10757), B(10758) /    13.94,  -32.58,    0.00 /
      DATA B(11095), B(11096), B(11097) /    12.98,  -31.40,    0.00 /
      DATA B(11434), B(11435), B(11436) /     9.55,  -27.39,    0.00 /
      DATA B(11773), B(11774), B(11775) /     8.25,  -26.45,    0.00 /
      DATA B(12112), B(12113), B(12114) /     7.00,  -25.86,    0.00 /
      DATA B(12451), B(12452), B(12453) /     5.83,  -25.36,    0.00 /
      DATA B(12790), B(12791), B(12792) /     4.57,  -24.68,    0.00 /
      DATA B(13129), B(13130), B(13131) /     3.08,  -23.69,    0.00 /
      DATA B(13468), B(13469), B(13470) /     1.28,  -22.31,    0.00 /
      DATA B(13807), B(13808), B(13809) /    -1.97,  -19.84,    0.00 /
      DATA B(14146), B(14147), B(14148) /    -3.21,  -18.49,    0.00 /
      DATA B(14485), B(14486), B(14487) /    -4.16,  -17.41,    0.00 /
      DATA B(14824), B(14825), B(14826) /    -4.79,  -16.74,    0.00 /
      DATA B(15163), B(15164), B(15165) /    -5.16,  -16.39,    0.00 /
      DATA B(15502), B(15503), B(15504) /    -5.39,  -16.22,    0.00 /
      DATA B(15841), B(15842), B(15843) /    -5.51,  -16.12,    0.00 /
      DATA B(16180), B(16181), B(16182) /    -5.57,  -16.19,    0.00 /
      DATA B(16519), B(16520), B(16521) /    -6.38,  -15.59,    0.00 /
      DATA B(16858), B(16859), B(16860) /    -6.63,  -15.53,    0.00 /
      DATA B(17197), B(17198), B(17199) /    -6.83,  -15.60,    0.00 /
      DATA B(17536), B(17537), B(17538) /    -7.11,  -15.87,    0.00 /
      DATA B(17875), B(17876), B(17877) /    -7.07,  -16.60,    0.00 /
      DATA B(18214), B(18215), B(18216) /    -8.47,  -12.83,    0.00 /
      DATA B(18553), B(18554), B(18555) /    -8.84,  -13.48,    0.00 /
      DATA B(18892), B(18893), B(18894) /    -9.17,  -13.75,    0.00 /
      DATA B(19231), B(19232), B(19233) /    -9.50,  -14.02,    0.00 /
      DATA B(19570), B(19571), B(19572) /    -9.63,  -14.34,    0.00 /
      DATA B(19909), B(19910), B(19911) /    -9.60,  -14.63,    0.00 /
      DATA B(20248), B(20249), B(20250) /    -9.52,  -14.84,    0.00 /
      DATA B(20587), B(20588), B(20589) /    -9.43,  -14.97,    0.00 /
      DATA B(20926), B(20927), B(20928) /    -9.37,  -15.06,    0.00 /
      DATA B(21265), B(21266), B(21267) /    -9.31,  -15.12,    0.00 /
      DATA B(21604), B(21605), B(21606) /    -9.28,  -15.17,    0.00 /
      DATA B(21943), B(21944), B(21945) /    -9.25,  -15.20,    0.00 /
      DATA B(22282), B(22283), B(22284) /    -9.24,  -15.24,    0.00 /
      DATA B(22621), B(22622), B(22623) /    -9.23,  -15.26,    0.00 /
      DATA B(22960), B(22961), B(22962) /    -9.24,  -15.29,    0.00 /
      DATA B(23299), B(23300), B(23301) /    -9.25,  -15.30,    0.00 /
      DATA B(23638), B(23639), B(23640) /    -9.26,  -15.32,    0.00 /
      DATA B(23977), B(23978), B(23979) /    -9.27,  -15.32,    0.00 /
      DATA B(24316), B(24317), B(24318) /    -9.29,  -15.32,    0.00 /
      DATA B(24655), B(24656), B(24657) /    -9.31,  -15.32,    0.00 /
      DATA B(24994), B(24995), B(24996) /    -9.32,  -15.31,    0.00 /
      DATA B(25333), B(25334), B(25335) /    -9.34,  -15.31,    0.00 /
      DATA B(25672), B(25673), B(25674) /    -9.35,  -15.30,    0.00 /
      DATA B(26011), B(26012), B(26013) /    -9.36,  -15.30,    0.00 /
      DATA B(26350), B(26351), B(26352) /    -9.37,  -15.31,    0.00 /
      DATA B(26689), B(26690), B(26691) /    -9.38,  -15.31,    0.00 /
      DATA B(27028), B(27029), B(27030) /    -9.39,  -15.32,    0.00 /
      DATA B(27367), B(27368), B(27369) /    -9.41,  -15.33,    0.00 /
      DATA B(  250), B(  251), B(  252) /    20.28,  -41.50,    0.00 /
      DATA B(  589), B(  590), B(  591) /    20.16,  -41.49,    0.00 /
      DATA B(  928), B(  929), B(  930) /    20.05,  -41.47,    0.00 /
      DATA B( 1267), B( 1268), B( 1269) /    19.93,  -41.43,    0.00 /
      DATA B( 1606), B( 1607), B( 1608) /    19.81,  -41.39,    0.00 /
      DATA B( 1945), B( 1946), B( 1947) /    19.68,  -41.33,    0.00 /
      DATA B( 2284), B( 2285), B( 2286) /    19.55,  -41.27,    0.00 /
      DATA B( 2623), B( 2624), B( 2625) /    21.34,  -40.15,    0.00 /
      DATA B( 2962), B( 2963), B( 2964) /    21.16,  -39.91,    0.00 /
      DATA B( 3301), B( 3302), B( 3303) /    20.99,  -39.68,    0.00 /
      DATA B( 3640), B( 3641), B( 3642) /    20.81,  -39.46,    0.00 /
      DATA B( 3979), B( 3980), B( 3981) /    20.63,  -39.24,    0.00 /
      DATA B( 4318), B( 4319), B( 4320) /    20.45,  -39.02,    0.00 /
      DATA B( 4657), B( 4658), B( 4659) /    20.27,  -38.81,    0.00 /
      DATA B( 4996), B( 4997), B( 4998) /    20.09,  -38.59,    0.00 /
      DATA B( 5335), B( 5336), B( 5337) /    19.91,  -38.37,    0.00 /
      DATA B( 5674), B( 5675), B( 5676) /    19.72,  -38.15,    0.00 /
      DATA B( 6013), B( 6014), B( 6015) /    19.52,  -37.91,    0.00 /
      DATA B( 6352), B( 6353), B( 6354) /    19.30,  -37.65,    0.00 /
      DATA B( 6691), B( 6692), B( 6693) /    19.04,  -37.39,    0.00 /
      DATA B( 7030), B( 7031), B( 7032) /    19.59,  -37.11,    0.00 /
      DATA B( 7369), B( 7370), B( 7371) /    19.34,  -37.18,    0.00 /
      DATA B( 7708), B( 7709), B( 7710) /    19.05,  -37.25,    0.00 /
      DATA B( 8047), B( 8048), B( 8049) /    18.73,  -37.29,    0.00 /
      DATA B( 8386), B( 8387), B( 8388) /    18.37,  -37.29,    0.00 /
      DATA B( 8725), B( 8726), B( 8727) /    17.93,  -37.25,    0.00 /
      DATA B( 9064), B( 9065), B( 9066) /    16.49,  -35.55,    0.00 /
      DATA B( 9403), B( 9404), B( 9405) /    16.00,  -35.01,    0.00 /
      DATA B( 9742), B( 9743), B( 9744) /    15.47,  -34.43,    0.00 /
      DATA B(10081), B(10082), B(10083) /    14.87,  -33.74,    0.00 /
      DATA B(10420), B(10421), B(10422) /    14.15,  -32.88,    0.00 /
      DATA B(10759), B(10760), B(10761) /    13.23,  -31.78,    0.00 /
      DATA B(11098), B(11099), B(11100) /     9.85,  -27.65,    0.00 /
      DATA B(11437), B(11438), B(11439) /     8.59,  -26.45,    0.00 /
      DATA B(11776), B(11777), B(11778) /     7.24,  -25.47,    0.00 /
      DATA B(12115), B(12116), B(12117) /     5.93,  -25.09,    0.00 /
      DATA B(12454), B(12455), B(12456) /     4.72,  -24.65,    0.00 /
      DATA B(12793), B(12794), B(12795) /     3.32,  -23.81,    0.00 /
      DATA B(13132), B(13133), B(13134) /     1.61,  -22.53,    0.00 /
      DATA B(13471), B(13472), B(13473) /    -2.54,  -19.61,    0.00 /
      DATA B(13810), B(13811), B(13812) /    -3.72,  -18.32,    0.00 /
      DATA B(14149), B(14150), B(14151) /    -4.71,  -17.22,    0.00 /
      DATA B(14488), B(14489), B(14490) /    -5.38,  -16.45,    0.00 /
      DATA B(14827), B(14828), B(14829) /    -5.78,  -16.00,    0.00 /
      DATA B(15166), B(15167), B(15168) /    -6.02,  -15.79,    0.00 /
      DATA B(15505), B(15506), B(15507) /    -6.12,  -15.62,    0.00 /
      DATA B(15844), B(15845), B(15846) /    -6.55,  -15.44,    0.00 /
      DATA B(16183), B(16184), B(16185) /    -6.70,  -15.36,    0.00 /
      DATA B(16522), B(16523), B(16524) /    -6.88,  -15.30,    0.00 /
      DATA B(16861), B(16862), B(16863) /    -7.02,  -15.27,    0.00 /
      DATA B(17200), B(17201), B(17202) /    -7.13,  -15.35,    0.00 /
      DATA B(17539), B(17540), B(17541) /    -7.21,  -15.62,    0.00 /
      DATA B(17878), B(17879), B(17880) /    -7.19,  -16.18,    0.00 /
      DATA B(18217), B(18218), B(18219) /    -7.25,  -17.00,    0.00 /
      DATA B(18556), B(18557), B(18558) /    -8.66,  -12.48,    0.00 /
      DATA B(18895), B(18896), B(18897) /    -8.95,  -12.98,    0.00 /
      DATA B(19234), B(19235), B(19236) /    -9.35,  -13.39,    0.00 /
      DATA B(19573), B(19574), B(19575) /    -9.66,  -13.79,    0.00 /
      DATA B(19912), B(19913), B(19914) /    -9.73,  -14.17,    0.00 /
      DATA B(20251), B(20252), B(20253) /    -9.68,  -14.47,    0.00 /
      DATA B(20590), B(20591), B(20592) /    -9.59,  -14.69,    0.00 /
      DATA B(20929), B(20930), B(20931) /    -9.51,  -14.83,    0.00 /
      DATA B(21268), B(21269), B(21270) /    -9.44,  -14.94,    0.00 /
      DATA B(21607), B(21608), B(21609) /    -9.39,  -15.01,    0.00 /
      DATA B(21946), B(21947), B(21948) /    -9.35,  -15.07,    0.00 /
      DATA B(22285), B(22286), B(22287) /    -9.33,  -15.12,    0.00 /
      DATA B(22624), B(22625), B(22626) /    -9.32,  -15.16,    0.00 /
      DATA B(22963), B(22964), B(22965) /    -9.31,  -15.19,    0.00 /
      DATA B(23302), B(23303), B(23304) /    -9.31,  -15.22,    0.00 /
      DATA B(23641), B(23642), B(23643) /    -9.31,  -15.24,    0.00 /
      DATA B(23980), B(23981), B(23982) /    -9.32,  -15.25,    0.00 /
      DATA B(24319), B(24320), B(24321) /    -9.33,  -15.26,    0.00 /
      DATA B(24658), B(24659), B(24660) /    -9.34,  -15.26,    0.00 /
      DATA B(24997), B(24998), B(24999) /    -9.35,  -15.26,    0.00 /
      DATA B(25336), B(25337), B(25338) /    -9.36,  -15.27,    0.00 /
      DATA B(25675), B(25676), B(25677) /    -9.37,  -15.27,    0.00 /
      DATA B(26014), B(26015), B(26016) /    -9.38,  -15.27,    0.00 /
      DATA B(26353), B(26354), B(26355) /    -9.39,  -15.28,    0.00 /
      DATA B(26692), B(26693), B(26694) /    -9.39,  -15.28,    0.00 /
      DATA B(27031), B(27032), B(27033) /    -9.40,  -15.29,    0.00 /
      DATA B(27370), B(27371), B(27372) /    -9.41,  -15.30,    0.00 /
      DATA B(  253), B(  254), B(  255) /    20.13,  -41.61,    0.00 /
      DATA B(  592), B(  593), B(  594) /    20.01,  -41.60,    0.00 /
      DATA B(  931), B(  932), B(  933) /    19.90,  -41.57,    0.00 /
      DATA B( 1270), B( 1271), B( 1272) /    19.78,  -41.53,    0.00 /
      DATA B( 1609), B( 1610), B( 1611) /    19.66,  -41.47,    0.00 /
      DATA B( 1948), B( 1949), B( 1950) /    19.54,  -41.40,    0.00 /
      DATA B( 2287), B( 2288), B( 2289) /    19.40,  -41.31,    0.00 /
      DATA B( 2626), B( 2627), B( 2628) /    21.28,  -39.97,    0.00 /
      DATA B( 2965), B( 2966), B( 2967) /    21.10,  -39.71,    0.00 /
      DATA B( 3304), B( 3305), B( 3306) /    20.92,  -39.47,    0.00 /
      DATA B( 3643), B( 3644), B( 3645) /    20.74,  -39.24,    0.00 /
      DATA B( 3982), B( 3983), B( 3984) /    20.56,  -39.01,    0.00 /
      DATA B( 4321), B( 4322), B( 4323) /    20.38,  -38.78,    0.00 /
      DATA B( 4660), B( 4661), B( 4662) /    20.20,  -38.56,    0.00 /
      DATA B( 4999), B( 5000), B( 5001) /    20.02,  -38.34,    0.00 /
      DATA B( 5338), B( 5339), B( 5340) /    19.84,  -38.13,    0.00 /
      DATA B( 5677), B( 5678), B( 5679) /    19.65,  -37.90,    0.00 /
      DATA B( 6016), B( 6017), B( 6018) /    19.44,  -37.67,    0.00 /
      DATA B( 6355), B( 6356), B( 6357) /    19.66,  -37.17,    0.00 /
      DATA B( 6694), B( 6695), B( 6696) /    19.45,  -37.20,    0.00 /
      DATA B( 7033), B( 7034), B( 7035) /    19.20,  -37.23,    0.00 /
      DATA B( 7372), B( 7373), B( 7374) /    18.93,  -37.26,    0.00 /
      DATA B( 7711), B( 7712), B( 7713) /    18.63,  -37.28,    0.00 /
      DATA B( 8050), B( 8051), B( 8052) /    18.29,  -37.28,    0.00 /
      DATA B( 8389), B( 8390), B( 8391) /    17.90,  -37.25,    0.00 /
      DATA B( 8728), B( 8729), B( 8730) /    16.60,  -35.49,    0.00 /
      DATA B( 9067), B( 9068), B( 9069) /    16.15,  -34.94,    0.00 /
      DATA B( 9406), B( 9407), B( 9408) /    15.62,  -34.40,    0.00 /
      DATA B( 9745), B( 9746), B( 9747) /    15.03,  -33.81,    0.00 /
      DATA B(10084), B(10085), B(10086) /    14.33,  -33.10,    0.00 /
      DATA B(10423), B(10424), B(10425) /    13.46,  -32.11,    0.00 /
      DATA B(10762), B(10763), B(10764) /    12.36,  -30.81,    0.00 /
      DATA B(11101), B(11102), B(11103) /     8.64,  -26.77,    0.00 /
      DATA B(11440), B(11441), B(11442) /     7.38,  -25.56,    0.00 /
      DATA B(11779), B(11780), B(11781) /     6.12,  -24.38,    0.00 /
      DATA B(12118), B(12119), B(12120) /     4.77,  -24.32,    0.00 /
      DATA B(12457), B(12458), B(12459) /     3.43,  -23.84,    0.00 /
      DATA B(12796), B(12797), B(12798) /     1.86,  -22.73,    0.00 /
      DATA B(13135), B(13136), B(13137) /    -0.05,  -21.14,    0.00 /
      DATA B(13474), B(13475), B(13476) /    -4.27,  -18.09,    0.00 /
      DATA B(13813), B(13814), B(13815) /    -5.25,  -17.00,    0.00 /
      DATA B(14152), B(14153), B(14154) /    -5.95,  -16.20,    0.00 /
      DATA B(14491), B(14492), B(14493) /    -6.36,  -15.64,    0.00 /
      DATA B(14830), B(14831), B(14832) /    -6.45,  -15.54,    0.00 /
      DATA B(15169), B(15170), B(15171) /    -6.65,  -15.24,    0.00 /
      DATA B(15508), B(15509), B(15510) /    -6.83,  -15.17,    0.00 /
      DATA B(15847), B(15848), B(15849) /    -6.97,  -15.12,    0.00 /
      DATA B(16186), B(16187), B(16188) /    -7.11,  -15.06,    0.00 /
      DATA B(16525), B(16526), B(16527) /    -7.22,  -15.02,    0.00 /
      DATA B(16864), B(16865), B(16866) /    -7.30,  -15.01,    0.00 /
      DATA B(17203), B(17204), B(17205) /    -7.35,  -15.11,    0.00 /
      DATA B(17542), B(17543), B(17544) /    -7.37,  -15.34,    0.00 /
      DATA B(17881), B(17882), B(17883) /    -7.35,  -15.76,    0.00 /
      DATA B(18220), B(18221), B(18222) /    -7.35,  -16.31,    0.00 /
      DATA B(18559), B(18560), B(18561) /    -8.62,  -11.68,    0.00 /
      DATA B(18898), B(18899), B(18900) /    -8.80,  -12.26,    0.00 /
      DATA B(19237), B(19238), B(19239) /    -9.13,  -12.77,    0.00 /
      DATA B(19576), B(19577), B(19578) /    -9.55,  -13.24,    0.00 /
      DATA B(19915), B(19916), B(19917) /    -9.76,  -13.70,    0.00 /
      DATA B(20254), B(20255), B(20256) /    -9.77,  -14.09,    0.00 /
      DATA B(20593), B(20594), B(20595) /    -9.70,  -14.39,    0.00 /
      DATA B(20932), B(20933), B(20934) /    -9.61,  -14.60,    0.00 /
      DATA B(21271), B(21272), B(21273) /    -9.54,  -14.75,    0.00 /
      DATA B(21610), B(21611), B(21612) /    -9.48,  -14.86,    0.00 /
      DATA B(21949), B(21950), B(21951) /    -9.43,  -14.94,    0.00 /
      DATA B(22288), B(22289), B(22290) /    -9.40,  -15.01,    0.00 /
      DATA B(22627), B(22628), B(22629) /    -9.38,  -15.06,    0.00 /
      DATA B(22966), B(22967), B(22968) /    -9.36,  -15.10,    0.00 /
      DATA B(23305), B(23306), B(23307) /    -9.36,  -15.14,    0.00 /
      DATA B(23644), B(23645), B(23646) /    -9.35,  -15.16,    0.00 /
      DATA B(23983), B(23984), B(23985) /    -9.36,  -15.18,    0.00 /
      DATA B(24322), B(24323), B(24324) /    -9.36,  -15.20,    0.00 /
      DATA B(24661), B(24662), B(24663) /    -9.36,  -15.21,    0.00 /
      DATA B(25000), B(25001), B(25002) /    -9.37,  -15.22,    0.00 /
      DATA B(25339), B(25340), B(25341) /    -9.38,  -15.23,    0.00 /
      DATA B(25678), B(25679), B(25680) /    -9.38,  -15.23,    0.00 /
      DATA B(26017), B(26018), B(26019) /    -9.39,  -15.24,    0.00 /
      DATA B(26356), B(26357), B(26358) /    -9.39,  -15.25,    0.00 /
      DATA B(26695), B(26696), B(26697) /    -9.40,  -15.26,    0.00 /
      DATA B(27034), B(27035), B(27036) /    -9.41,  -15.27,    0.00 /
      DATA B(27373), B(27374), B(27375) /    -9.41,  -15.28,    0.00 /
      DATA B(  256), B(  257), B(  258) /    19.98,  -41.73,    0.00 /
      DATA B(  595), B(  596), B(  597) /    19.86,  -41.72,    0.00 /
      DATA B(  934), B(  935), B(  936) /    19.74,  -41.69,    0.00 /
      DATA B( 1273), B( 1274), B( 1275) /    19.63,  -41.64,    0.00 /
      DATA B( 1612), B( 1613), B( 1614) /    19.51,  -41.56,    0.00 /
      DATA B( 1951), B( 1952), B( 1953) /    19.39,  -41.45,    0.00 /
      DATA B( 2290), B( 2291), B( 2292) /    19.24,  -41.34,    0.00 /
      DATA B( 2629), B( 2630), B( 2631) /    21.22,  -39.76,    0.00 /
      DATA B( 2968), B( 2969), B( 2970) /    21.03,  -39.49,    0.00 /
      DATA B( 3307), B( 3308), B( 3309) /    20.84,  -39.23,    0.00 /
      DATA B( 3646), B( 3647), B( 3648) /    20.65,  -38.99,    0.00 /
      DATA B( 3985), B( 3986), B( 3987) /    20.47,  -38.76,    0.00 /
      DATA B( 4324), B( 4325), B( 4326) /    20.28,  -38.53,    0.00 /
      DATA B( 4663), B( 4664), B( 4665) /    20.10,  -38.32,    0.00 /
      DATA B( 5002), B( 5003), B( 5004) /    19.92,  -38.11,    0.00 /
      DATA B( 5341), B( 5342), B( 5343) /    19.75,  -37.92,    0.00 /
      DATA B( 5680), B( 5681), B( 5682) /    19.68,  -37.30,    0.00 /
      DATA B( 6019), B( 6020), B( 6021) /    19.49,  -37.34,    0.00 /
      DATA B( 6358), B( 6359), B( 6360) /    19.30,  -37.33,    0.00 /
      DATA B( 6697), B( 6698), B( 6699) /    19.08,  -37.29,    0.00 /
      DATA B( 7036), B( 7037), B( 7038) /    18.83,  -37.24,    0.00 /
      DATA B( 7375), B( 7376), B( 7377) /    18.54,  -37.23,    0.00 /
      DATA B( 7714), B( 7715), B( 7716) /    18.22,  -37.23,    0.00 /
      DATA B( 8053), B( 8054), B( 8055) /    17.86,  -37.22,    0.00 /
      DATA B( 8392), B( 8393), B( 8394) /    17.46,  -37.14,    0.00 /
      DATA B( 8731), B( 8732), B( 8733) /    16.29,  -34.86,    0.00 /
      DATA B( 9070), B( 9071), B( 9072) /    15.79,  -34.29,    0.00 /
      DATA B( 9409), B( 9410), B( 9411) /    15.22,  -33.72,    0.00 /
      DATA B( 9748), B( 9749), B( 9750) /    14.54,  -33.11,    0.00 /
      DATA B(10087), B(10088), B(10089) /    13.71,  -32.33,    0.00 /
      DATA B(10426), B(10427), B(10428) /    12.61,  -31.22,    0.00 /
      DATA B(10765), B(10766), B(10767) /     8.73,  -26.89,    0.00 /
      DATA B(11104), B(11105), B(11106) /     7.12,  -25.79,    0.00 /
      DATA B(11443), B(11444), B(11445) /     5.57,  -24.58,    0.00 /
      DATA B(11782), B(11783), B(11784) /    -4.20,  -16.99,    0.00 /
      DATA B(12121), B(12122), B(12123) /     3.47,  -23.61,    0.00 /
      DATA B(12460), B(12461), B(12462) /     1.86,  -22.94,    0.00 /
      DATA B(12799), B(12800), B(12801) /     0.15,  -21.37,    0.00 /
      DATA B(13138), B(13139), B(13140) /    -4.95,  -17.79,    0.00 /
      DATA B(13477), B(13478), B(13479) /    -5.84,  -16.69,    0.00 /
      DATA B(13816), B(13817), B(13818) /    -6.50,  -16.02,    0.00 /
      DATA B(14155), B(14156), B(14157) /    -6.38,  -15.65,    0.00 /
      DATA B(14494), B(14495), B(14496) /    -6.71,  -15.35,    0.00 /
      DATA B(14833), B(14834), B(14835) /    -6.91,  -15.13,    0.00 /
      DATA B(15172), B(15173), B(15174) /    -7.07,  -14.99,    0.00 /
      DATA B(15511), B(15512), B(15513) /    -7.19,  -14.91,    0.00 /
      DATA B(15850), B(15851), B(15852) /    -7.30,  -14.84,    0.00 /
      DATA B(16189), B(16190), B(16191) /    -7.39,  -14.80,    0.00 /
      DATA B(16528), B(16529), B(16530) /    -7.47,  -14.77,    0.00 /
      DATA B(16867), B(16868), B(16869) /    -7.51,  -14.79,    0.00 /
      DATA B(17206), B(17207), B(17208) /    -7.53,  -14.88,    0.00 /
      DATA B(17545), B(17546), B(17547) /    -7.52,  -15.08,    0.00 /
      DATA B(17884), B(17885), B(17886) /    -7.50,  -15.39,    0.00 /
      DATA B(18223), B(18224), B(18225) /    -7.48,  -15.80,    0.00 /
      DATA B(18562), B(18563), B(18564) /    -7.50,  -16.24,    0.00 /
      DATA B(18901), B(18902), B(18903) /    -8.78,  -11.64,    0.00 /
      DATA B(19240), B(19241), B(19242) /    -8.96,  -12.20,    0.00 /
      DATA B(19579), B(19580), B(19581) /    -9.35,  -12.73,    0.00 /
      DATA B(19918), B(19919), B(19920) /    -9.70,  -13.23,    0.00 /
      DATA B(20257), B(20258), B(20259) /    -9.82,  -13.70,    0.00 /
      DATA B(20596), B(20597), B(20598) /    -9.78,  -14.08,    0.00 /
      DATA B(20935), B(20936), B(20937) /    -9.70,  -14.36,    0.00 /
      DATA B(21274), B(21275), B(21276) /    -9.62,  -14.56,    0.00 /
      DATA B(21613), B(21614), B(21615) /    -9.55,  -14.71,    0.00 /
      DATA B(21952), B(21953), B(21954) /    -9.50,  -14.82,    0.00 /
      DATA B(22291), B(22292), B(22293) /    -9.46,  -14.90,    0.00 /
      DATA B(22630), B(22631), B(22632) /    -9.43,  -14.97,    0.00 /
      DATA B(22969), B(22970), B(22971) /    -9.41,  -15.02,    0.00 /
      DATA B(23308), B(23309), B(23310) /    -9.40,  -15.06,    0.00 /
      DATA B(23647), B(23648), B(23649) /    -9.39,  -15.09,    0.00 /
      DATA B(23986), B(23987), B(23988) /    -9.38,  -15.12,    0.00 /
      DATA B(24325), B(24326), B(24327) /    -9.38,  -15.14,    0.00 /
      DATA B(24664), B(24665), B(24666) /    -9.38,  -15.16,    0.00 /
      DATA B(25003), B(25004), B(25005) /    -9.39,  -15.18,    0.00 /
      DATA B(25342), B(25343), B(25344) /    -9.39,  -15.19,    0.00 /
      DATA B(25681), B(25682), B(25683) /    -9.39,  -15.20,    0.00 /
      DATA B(26020), B(26021), B(26022) /    -9.40,  -15.21,    0.00 /
      DATA B(26359), B(26360), B(26361) /    -9.40,  -15.22,    0.00 /
      DATA B(26698), B(26699), B(26700) /    -9.41,  -15.23,    0.00 /
      DATA B(27037), B(27038), B(27039) /    -9.41,  -15.25,    0.00 /
      DATA B(27376), B(27377), B(27378) /    -9.42,  -15.26,    0.00 /
      DATA B(  259), B(  260), B(  261) /    19.82,  -41.85,    0.00 /
      DATA B(  598), B(  599), B(  600) /    19.70,  -41.84,    0.00 /
      DATA B(  937), B(  938), B(  939) /    19.58,  -41.82,    0.00 /
      DATA B( 1276), B( 1277), B( 1278) /    19.47,  -41.76,    0.00 /
      DATA B( 1615), B( 1616), B( 1617) /    19.36,  -41.66,    0.00 /
      DATA B( 1954), B( 1955), B( 1956) /    19.24,  -41.50,    0.00 /
      DATA B( 2293), B( 2294), B( 2295) /    21.34,  -39.85,    0.00 /
      DATA B( 2632), B( 2633), B( 2634) /    21.14,  -39.52,    0.00 /
      DATA B( 2971), B( 2972), B( 2973) /    20.94,  -39.24,    0.00 /
      DATA B( 3310), B( 3311), B( 3312) /    20.74,  -38.98,    0.00 /
      DATA B( 3649), B( 3650), B( 3651) /    20.54,  -38.73,    0.00 /
      DATA B( 3988), B( 3989), B( 3990) /    20.35,  -38.51,    0.00 /
      DATA B( 4327), B( 4328), B( 4329) /    20.15,  -38.31,    0.00 /
      DATA B( 4666), B( 4667), B( 4668) /    19.95,  -38.10,    0.00 /
      DATA B( 5005), B( 5006), B( 5007) /    19.74,  -37.52,    0.00 /
      DATA B( 5344), B( 5345), B( 5346) /    19.51,  -37.52,    0.00 /
      DATA B( 5683), B( 5684), B( 5685) /    19.31,  -37.53,    0.00 /
      DATA B( 6022), B( 6023), B( 6024) /    19.12,  -37.50,    0.00 /
      DATA B( 6361), B( 6362), B( 6363) /    18.94,  -37.42,    0.00 /
      DATA B( 6700), B( 6701), B( 6702) /    18.74,  -37.29,    0.00 /
      DATA B( 7039), B( 7040), B( 7041) /    18.48,  -37.15,    0.00 /
      DATA B( 7378), B( 7379), B( 7380) /    18.16,  -37.10,    0.00 /
      DATA B( 7717), B( 7718), B( 7719) /    17.80,  -37.12,    0.00 /
      DATA B( 8056), B( 8057), B( 8058) /    17.37,  -37.10,    0.00 /
      DATA B( 8395), B( 8396), B( 8397) /    16.38,  -34.77,    0.00 /
      DATA B( 8734), B( 8735), B( 8736) /    15.92,  -34.19,    0.00 /
      DATA B( 9073), B( 9074), B( 9075) /    15.41,  -33.56,    0.00 /
      DATA B( 9412), B( 9413), B( 9414) /    14.78,  -32.92,    0.00 /
      DATA B( 9751), B( 9752), B( 9753) /    13.97,  -32.27,    0.00 /
      DATA B(10090), B(10091), B(10092) /    13.00,  -31.45,    0.00 /
      DATA B(10429), B(10430), B(10431) /     8.93,  -26.80,    0.00 /
      DATA B(10768), B(10769), B(10770) /     7.30,  -25.77,    0.00 /
      DATA B(11107), B(11108), B(11109) /     5.51,  -24.64,    0.00 /
      DATA B(11446), B(11447), B(11448) /    -4.58,  -17.17,    0.00 /
      DATA B(11785), B(11786), B(11787) /    -5.82,  -16.24,    0.00 /
      DATA B(12124), B(12125), B(12126) /    -7.27,  -15.94,    0.00 /
      DATA B(12463), B(12464), B(12465) /     0.11,  -22.03,    0.00 /
      DATA B(12802), B(12803), B(12804) /    -6.04,  -17.46,    0.00 /
      DATA B(13141), B(13142), B(13143) /    -5.72,  -16.91,    0.00 /
      DATA B(13480), B(13481), B(13482) /    -6.29,  -16.19,    0.00 /
      DATA B(13819), B(13820), B(13821) /    -6.66,  -15.62,    0.00 /
      DATA B(14158), B(14159), B(14160) /    -6.94,  -15.25,    0.00 /
      DATA B(14497), B(14498), B(14499) /    -7.13,  -15.01,    0.00 /
      DATA B(14836), B(14837), B(14838) /    -7.27,  -14.85,    0.00 /
      DATA B(15175), B(15176), B(15177) /    -7.38,  -14.74,    0.00 /
      DATA B(15514), B(15515), B(15516) /    -7.47,  -14.66,    0.00 /
      DATA B(15853), B(15854), B(15855) /    -7.54,  -14.61,    0.00 /
      DATA B(16192), B(16193), B(16194) /    -7.60,  -14.57,    0.00 /
      DATA B(16531), B(16532), B(16533) /    -7.65,  -14.56,    0.00 /
      DATA B(16870), B(16871), B(16872) /    -7.67,  -14.60,    0.00 /
      DATA B(17209), B(17210), B(17211) /    -7.67,  -14.68,    0.00 /
      DATA B(17548), B(17549), B(17550) /    -7.66,  -14.85,    0.00 /
      DATA B(17887), B(17888), B(17889) /    -7.63,  -15.09,    0.00 /
      DATA B(18226), B(18227), B(18228) /    -7.60,  -15.41,    0.00 /
      DATA B(18565), B(18566), B(18567) /    -7.58,  -15.78,    0.00 /
      DATA B(18904), B(18905), B(18906) /    -8.78,  -11.14,    0.00 /
      DATA B(19243), B(19244), B(19245) /    -8.86,  -11.68,    0.00 /
      DATA B(19582), B(19583), B(19584) /    -9.14,  -12.24,    0.00 /
      DATA B(19921), B(19922), B(19923) /    -9.55,  -12.78,    0.00 /
      DATA B(20260), B(20261), B(20262) /    -9.80,  -13.30,    0.00 /
      DATA B(20599), B(20600), B(20601) /    -9.83,  -13.76,    0.00 /
      DATA B(20938), B(20939), B(20940) /    -9.77,  -14.11,    0.00 /
      DATA B(21277), B(21278), B(21279) /    -9.69,  -14.36,    0.00 /
      DATA B(21616), B(21617), B(21618) /    -9.62,  -14.55,    0.00 /
      DATA B(21955), B(21956), B(21957) /    -9.56,  -14.69,    0.00 /
      DATA B(22294), B(22295), B(22296) /    -9.51,  -14.79,    0.00 /
      DATA B(22633), B(22634), B(22635) /    -9.47,  -14.87,    0.00 /
      DATA B(22972), B(22973), B(22974) /    -9.45,  -14.94,    0.00 /
      DATA B(23311), B(23312), B(23313) /    -9.43,  -14.99,    0.00 /
      DATA B(23650), B(23651), B(23652) /    -9.42,  -15.03,    0.00 /
      DATA B(23989), B(23990), B(23991) /    -9.41,  -15.06,    0.00 /
      DATA B(24328), B(24329), B(24330) /    -9.40,  -15.09,    0.00 /
      DATA B(24667), B(24668), B(24669) /    -9.40,  -15.11,    0.00 /
      DATA B(25006), B(25007), B(25008) /    -9.40,  -15.13,    0.00 /
      DATA B(25345), B(25346), B(25347) /    -9.40,  -15.15,    0.00 /
      DATA B(25684), B(25685), B(25686) /    -9.40,  -15.17,    0.00 /
      DATA B(26023), B(26024), B(26025) /    -9.40,  -15.18,    0.00 /
      DATA B(26362), B(26363), B(26364) /    -9.40,  -15.20,    0.00 /
      DATA B(26701), B(26702), B(26703) /    -9.41,  -15.21,    0.00 /
      DATA B(27040), B(27041), B(27042) /    -9.41,  -15.22,    0.00 /
      DATA B(27379), B(27380), B(27381) /    -9.41,  -15.24,    0.00 /
      DATA B(  262), B(  263), B(  264) /    19.66,  -41.98,    0.00 /
      DATA B(  601), B(  602), B(  603) /    19.53,  -41.97,    0.00 /
      DATA B(  940), B(  941), B(  942) /    19.41,  -41.95,    0.00 /
      DATA B( 1279), B( 1280), B( 1281) /    19.29,  -41.90,    0.00 /
      DATA B( 1618), B( 1619), B( 1620) /    19.19,  -41.77,    0.00 /
      DATA B( 1957), B( 1958), B( 1959) /    19.07,  -41.54,    0.00 /
      DATA B( 2296), B( 2297), B( 2298) /    21.25,  -39.61,    0.00 /
      DATA B( 2635), B( 2636), B( 2637) /    21.02,  -39.26,    0.00 /
      DATA B( 2974), B( 2975), B( 2976) /    20.80,  -38.97,    0.00 /
      DATA B( 3313), B( 3314), B( 3315) /    20.59,  -38.72,    0.00 /
      DATA B( 3652), B( 3653), B( 3654) /    20.39,  -38.50,    0.00 /
      DATA B( 3991), B( 3992), B( 3993) /    20.13,  -37.70,    0.00 /
      DATA B( 4330), B( 4331), B( 4332) /    19.86,  -37.69,    0.00 /
      DATA B( 4669), B( 4670), B( 4671) /    19.58,  -37.72,    0.00 /
      DATA B( 5008), B( 5009), B( 5010) /    19.33,  -37.72,    0.00 /
      DATA B( 5347), B( 5348), B( 5349) /    19.10,  -37.72,    0.00 /
      DATA B( 5686), B( 5687), B( 5688) /    18.90,  -37.69,    0.00 /
      DATA B( 6025), B( 6026), B( 6027) /    18.72,  -37.62,    0.00 /
      DATA B( 6364), B( 6365), B( 6366) /    18.55,  -37.47,    0.00 /
      DATA B( 6703), B( 6704), B( 6705) /    18.37,  -37.23,    0.00 /
      DATA B( 7042), B( 7043), B( 7044) /    18.13,  -36.96,    0.00 /
      DATA B( 7381), B( 7382), B( 7383) /    17.77,  -36.87,    0.00 /
      DATA B( 7720), B( 7721), B( 7722) /    17.35,  -36.96,    0.00 /
      DATA B( 8059), B( 8060), B( 8061) /    16.46,  -34.61,    0.00 /
      DATA B( 8398), B( 8399), B( 8400) /    15.97,  -34.07,    0.00 /
      DATA B( 8737), B( 8738), B( 8739) /    15.50,  -33.44,    0.00 /
      DATA B( 9076), B( 9077), B( 9078) /    14.96,  -32.70,    0.00 /
      DATA B( 9415), B( 9416), B( 9417) /    14.23,  -31.92,    0.00 /
      DATA B( 9754), B( 9755), B( 9756) /    13.29,  -31.25,    0.00 /
      DATA B(10093), B(10094), B(10095) /    12.23,  -30.49,    0.00 /
      DATA B(10432), B(10433), B(10434) /     7.65,  -25.73,    0.00 /
      DATA B(10771), B(10772), B(10773) /     5.92,  -24.73,    0.00 /
      DATA B(11110), B(11111), B(11112) /    -5.01,  -16.70,    0.00 /
      DATA B(11449), B(11450), B(11451) /    -6.04,  -16.09,    0.00 /
      DATA B(11788), B(11789), B(11790) /    -6.85,  -15.51,    0.00 /
      DATA B(12127), B(12128), B(12129) /    -7.60,  -15.45,    0.00 /
      DATA B(12466), B(12467), B(12468) /    -7.23,  -17.92,    0.00 /
      DATA B(12805), B(12806), B(12807) /    -6.95,  -16.92,    0.00 /
      DATA B(13144), B(13145), B(13146) /    -6.98,  -16.14,    0.00 /
      DATA B(13483), B(13484), B(13485) /    -7.10,  -15.58,    0.00 /
      DATA B(13822), B(13823), B(13824) /    -7.24,  -15.19,    0.00 /
      DATA B(14161), B(14162), B(14163) /    -7.37,  -14.92,    0.00 /
      DATA B(14500), B(14501), B(14502) /    -7.47,  -14.74,    0.00 /
      DATA B(14839), B(14840), B(14841) /    -7.55,  -14.61,    0.00 /
      DATA B(15178), B(15179), B(15180) /    -7.62,  -14.51,    0.00 /
      DATA B(15517), B(15518), B(15519) /    -7.68,  -14.45,    0.00 /
      DATA B(15856), B(15857), B(15858) /    -7.73,  -14.41,    0.00 /
      DATA B(16195), B(16196), B(16197) /    -7.76,  -14.39,    0.00 /
      DATA B(16534), B(16535), B(16536) /    -7.79,  -14.39,    0.00 /
      DATA B(16873), B(16874), B(16875) /    -7.80,  -14.43,    0.00 /
      DATA B(17212), B(17213), B(17214) /    -7.79,  -14.51,    0.00 /
      DATA B(17551), B(17552), B(17553) /    -7.77,  -14.65,    0.00 /
      DATA B(17890), B(17891), B(17892) /    -7.74,  -14.84,    0.00 /
      DATA B(18229), B(18230), B(18231) /    -7.71,  -15.09,    0.00 /
      DATA B(18568), B(18569), B(18570) /    -7.68,  -15.39,    0.00 /
      DATA B(18907), B(18908), B(18909) /    -7.64,  -15.74,    0.00 /
      DATA B(19246), B(19247), B(19248) /    -8.85,  -11.25,    0.00 /
      DATA B(19585), B(19586), B(19587) /    -8.99,  -11.79,    0.00 /
      DATA B(19924), B(19925), B(19926) /    -9.34,  -12.35,    0.00 /
      DATA B(20263), B(20264), B(20265) /    -9.70,  -12.90,    0.00 /
      DATA B(20602), B(20603), B(20604) /    -9.85,  -13.41,    0.00 /
      DATA B(20941), B(20942), B(20943) /    -9.82,  -13.83,    0.00 /
      DATA B(21280), B(21281), B(21282) /    -9.75,  -14.15,    0.00 /
      DATA B(21619), B(21620), B(21621) /    -9.67,  -14.38,    0.00 /
      DATA B(21958), B(21959), B(21960) /    -9.60,  -14.55,    0.00 /
      DATA B(22297), B(22298), B(22299) /    -9.55,  -14.68,    0.00 /
      DATA B(22636), B(22637), B(22638) /    -9.51,  -14.78,    0.00 /
      DATA B(22975), B(22976), B(22977) /    -9.48,  -14.85,    0.00 /
      DATA B(23314), B(23315), B(23316) /    -9.45,  -14.92,    0.00 /
      DATA B(23653), B(23654), B(23655) /    -9.44,  -14.97,    0.00 /
      DATA B(23992), B(23993), B(23994) /    -9.42,  -15.01,    0.00 /
      DATA B(24331), B(24332), B(24333) /    -9.42,  -15.04,    0.00 /
      DATA B(24670), B(24671), B(24672) /    -9.41,  -15.07,    0.00 /
      DATA B(25009), B(25010), B(25011) /    -9.41,  -15.09,    0.00 /
      DATA B(25348), B(25349), B(25350) /    -9.40,  -15.12,    0.00 /
      DATA B(25687), B(25688), B(25689) /    -9.40,  -15.13,    0.00 /
      DATA B(26026), B(26027), B(26028) /    -9.40,  -15.15,    0.00 /
      DATA B(26365), B(26366), B(26367) /    -9.40,  -15.17,    0.00 /
      DATA B(26704), B(26705), B(26706) /    -9.41,  -15.19,    0.00 /
      DATA B(27043), B(27044), B(27045) /    -9.41,  -15.20,    0.00 /
      DATA B(27382), B(27383), B(27384) /    -9.41,  -15.22,    0.00 /
      DATA B(  265), B(  266), B(  267) /    19.50,  -42.11,    0.00 /
      DATA B(  604), B(  605), B(  606) /    19.36,  -42.10,    0.00 /
      DATA B(  943), B(  944), B(  945) /    19.22,  -42.09,    0.00 /
      DATA B( 1282), B( 1283), B( 1284) /    19.09,  -42.06,    0.00 /
      DATA B( 1621), B( 1622), B( 1623) /    18.98,  -41.93,    0.00 /
      DATA B( 1960), B( 1961), B( 1962) /    18.87,  -41.56,    0.00 /
      DATA B( 2299), B( 2300), B( 2301) /    21.08,  -39.32,    0.00 /
      DATA B( 2638), B( 2639), B( 2640) /    20.83,  -38.99,    0.00 /
      DATA B( 2977), B( 2978), B( 2979) /    20.61,  -38.75,    0.00 /
      DATA B( 3316), B( 3317), B( 3318) /    20.27,  -37.91,    0.00 /
      DATA B( 3655), B( 3656), B( 3657) /    19.98,  -37.92,    0.00 /
      DATA B( 3994), B( 3995), B( 3996) /    19.71,  -37.91,    0.00 /
      DATA B( 4333), B( 4334), B( 4335) /    19.43,  -37.89,    0.00 /
      DATA B( 4672), B( 4673), B( 4674) /    19.17,  -37.88,    0.00 /
      DATA B( 5011), B( 5012), B( 5013) /    18.91,  -37.87,    0.00 /
      DATA B( 5350), B( 5351), B( 5352) /    18.66,  -37.86,    0.00 /
      DATA B( 5689), B( 5690), B( 5691) /    18.43,  -37.82,    0.00 /
      DATA B( 6028), B( 6029), B( 6030) /    18.24,  -37.72,    0.00 /
      DATA B( 6367), B( 6368), B( 6369) /    18.07,  -37.51,    0.00 /
      DATA B( 6706), B( 6707), B( 6708) /    17.92,  -37.13,    0.00 /
      DATA B( 7045), B( 7046), B( 7047) /    17.73,  -36.66,    0.00 /
      DATA B( 7384), B( 7385), B( 7386) /    17.36,  -36.50,    0.00 /
      DATA B( 7723), B( 7724), B( 7725) /    16.72,  -34.34,    0.00 /
      DATA B( 8062), B( 8063), B( 8064) /    16.08,  -33.77,    0.00 /
      DATA B( 8401), B( 8402), B( 8403) /    15.42,  -33.25,    0.00 /
      DATA B( 8740), B( 8741), B( 8742) /    14.88,  -32.59,    0.00 /
      DATA B( 9079), B( 9080), B( 9081) /    14.29,  -31.66,    0.00 /
      DATA B( 9418), B( 9419), B( 9420) /    13.48,  -30.66,    0.00 /
      DATA B( 9757), B( 9758), B( 9759) /    12.47,  -30.02,    0.00 /
      DATA B(10096), B(10097), B(10098) /     7.92,  -25.29,    0.00 /
      DATA B(10435), B(10436), B(10437) /    -3.94,  -17.24,    0.00 /
      DATA B(10774), B(10775), B(10776) /    -5.03,  -16.57,    0.00 /
      DATA B(11113), B(11114), B(11115) /    -6.00,  -15.90,    0.00 /
      DATA B(11452), B(11453), B(11454) /    -6.69,  -15.34,    0.00 /
      DATA B(11791), B(11792), B(11793) /    -7.14,  -15.03,    0.00 /
      DATA B(12130), B(12131), B(12132) /    -7.25,  -15.27,    0.00 /
      DATA B(12469), B(12470), B(12471) /    -7.35,  -16.42,    0.00 /
      DATA B(12808), B(12809), B(12810) /    -7.71,  -16.29,    0.00 /
      DATA B(13147), B(13148), B(13149) /    -7.67,  -15.65,    0.00 /
      DATA B(13486), B(13487), B(13488) /    -7.63,  -15.19,    0.00 /
      DATA B(13825), B(13826), B(13827) /    -7.64,  -14.88,    0.00 /
      DATA B(14164), B(14165), B(14166) /    -7.68,  -14.66,    0.00 /
      DATA B(14503), B(14504), B(14505) /    -7.72,  -14.51,    0.00 /
      DATA B(14842), B(14843), B(14844) /    -7.77,  -14.40,    0.00 /
      DATA B(15181), B(15182), B(15183) /    -7.81,  -14.33,    0.00 /
      DATA B(15520), B(15521), B(15522) /    -7.84,  -14.28,    0.00 /
      DATA B(15859), B(15860), B(15861) /    -7.87,  -14.24,    0.00 /
      DATA B(16198), B(16199), B(16200) /    -7.89,  -14.23,    0.00 /
      DATA B(16537), B(16538), B(16539) /    -7.90,  -14.24,    0.00 /
      DATA B(16876), B(16877), B(16878) /    -7.90,  -14.28,    0.00 /
      DATA B(17215), B(17216), B(17217) /    -7.89,  -14.35,    0.00 /
      DATA B(17554), B(17555), B(17556) /    -7.87,  -14.47,    0.00 /
      DATA B(17893), B(17894), B(17895) /    -7.84,  -14.63,    0.00 /
      DATA B(18232), B(18233), B(18234) /    -7.81,  -14.84,    0.00 /
      DATA B(18571), B(18572), B(18573) /    -7.77,  -15.08,    0.00 /
      DATA B(18910), B(18911), B(18912) /    -7.73,  -15.38,    0.00 /
      DATA B(19249), B(19250), B(19251) /    -7.99,  -18.31,    0.00 /
      DATA B(19588), B(19589), B(19590) /    -8.93,  -11.38,    0.00 /
      DATA B(19927), B(19928), B(19929) /    -9.14,  -11.95,    0.00 /
      DATA B(20266), B(20267), B(20268) /    -9.53,  -12.51,    0.00 /
      DATA B(20605), B(20606), B(20607) /    -9.80,  -13.05,    0.00 /
      DATA B(20944), B(20945), B(20946) /    -9.85,  -13.53,    0.00 /
      DATA B(21283), B(21284), B(21285) /    -9.80,  -13.92,    0.00 /
      DATA B(21622), B(21623), B(21624) /    -9.72,  -14.20,    0.00 /
      DATA B(21961), B(21962), B(21963) /    -9.65,  -14.41,    0.00 /
      DATA B(22300), B(22301), B(22302) /    -9.59,  -14.56,    0.00 /
      DATA B(22639), B(22640), B(22641) /    -9.54,  -14.68,    0.00 /
      DATA B(22978), B(22979), B(22980) /    -9.51,  -14.77,    0.00 /
      DATA B(23317), B(23318), B(23319) /    -9.48,  -14.84,    0.00 /
      DATA B(23656), B(23657), B(23658) /    -9.46,  -14.90,    0.00 /
      DATA B(23995), B(23996), B(23997) /    -9.44,  -14.95,    0.00 /
      DATA B(24334), B(24335), B(24336) /    -9.43,  -14.99,    0.00 /
      DATA B(24673), B(24674), B(24675) /    -9.42,  -15.03,    0.00 /
      DATA B(25012), B(25013), B(25014) /    -9.41,  -15.05,    0.00 /
      DATA B(25351), B(25352), B(25353) /    -9.41,  -15.08,    0.00 /
      DATA B(25690), B(25691), B(25692) /    -9.41,  -15.10,    0.00 /
      DATA B(26029), B(26030), B(26031) /    -9.40,  -15.12,    0.00 /
      DATA B(26368), B(26369), B(26370) /    -9.40,  -15.14,    0.00 /
      DATA B(26707), B(26708), B(26709) /    -9.40,  -15.16,    0.00 /
      DATA B(27046), B(27047), B(27048) /    -9.41,  -15.18,    0.00 /
      DATA B(27385), B(27386), B(27387) /    -9.41,  -15.20,    0.00 /
      DATA B(  268), B(  269), B(  270) /    19.34,  -42.24,    0.00 /
      DATA B(  607), B(  608), B(  609) /    19.20,  -42.24,    0.00 /
      DATA B(  946), B(  947), B(  948) /    19.04,  -42.23,    0.00 /
      DATA B( 1285), B( 1286), B( 1287) /    18.87,  -42.21,    0.00 /
      DATA B( 1624), B( 1625), B( 1626) /    18.69,  -42.16,    0.00 /
      DATA B( 1963), B( 1964), B( 1965) /    21.15,  -39.61,    0.00 /
      DATA B( 2302), B( 2303), B( 2304) /    20.77,  -39.01,    0.00 /
      DATA B( 2641), B( 2642), B( 2643) /    20.34,  -38.21,    0.00 /
      DATA B( 2980), B( 2981), B( 2982) /    20.08,  -38.16,    0.00 /
      DATA B( 3319), B( 3320), B( 3321) /    19.82,  -38.13,    0.00 /
      DATA B( 3658), B( 3659), B( 3660) /    19.56,  -38.10,    0.00 /
      DATA B( 3997), B( 3998), B( 3999) /    19.29,  -38.06,    0.00 /
      DATA B( 4336), B( 4337), B( 4338) /    19.02,  -38.03,    0.00 /
      DATA B( 4675), B( 4676), B( 4677) /    18.75,  -38.00,    0.00 /
      DATA B( 5014), B( 5015), B( 5016) /    18.46,  -37.99,    0.00 /
      DATA B( 5353), B( 5354), B( 5355) /    18.17,  -37.97,    0.00 /
      DATA B( 5692), B( 5693), B( 5694) /    17.88,  -37.94,    0.00 /
      DATA B( 6031), B( 6032), B( 6033) /    17.63,  -37.83,    0.00 /
      DATA B( 6370), B( 6371), B( 6372) /    17.42,  -37.55,    0.00 /
      DATA B( 6709), B( 6710), B( 6711) /    17.25,  -36.99,    0.00 /
      DATA B( 7048), B( 7049), B( 7050) /    16.95,  -36.24,    0.00 /
      DATA B( 7387), B( 7388), B( 7389) /    17.90,  -34.25,    0.00 /
      DATA B( 7726), B( 7727), B( 7728) /    16.78,  -33.30,    0.00 /
      DATA B( 8065), B( 8066), B( 8067) /    15.52,  -32.58,    0.00 /
      DATA B( 8404), B( 8405), B( 8406) /    14.50,  -32.22,    0.00 /
      DATA B( 8743), B( 8744), B( 8745) /    13.84,  -31.62,    0.00 /
      DATA B( 9082), B( 9083), B( 9084) /    13.16,  -30.35,    0.00 /
      DATA B( 9421), B( 9422), B( 9423) /    12.09,  -29.14,    0.00 /
      DATA B( 9760), B( 9761), B( 9762) /     8.40,  -24.65,    0.00 /
      DATA B(10099), B(10100), B(10101) /     7.14,  -24.28,    0.00 /
      DATA B(10438), B(10439), B(10440) /    -4.54,  -16.29,    0.00 /
      DATA B(10777), B(10778), B(10779) /    -5.62,  -15.71,    0.00 /
      DATA B(11116), B(11117), B(11118) /    -6.46,  -15.24,    0.00 /
      DATA B(11455), B(11456), B(11457) /    -6.98,  -14.86,    0.00 /
      DATA B(11794), B(11795), B(11796) /    -7.25,  -14.73,    0.00 /
      DATA B(12133), B(12134), B(12135) /    -7.34,  -15.00,    0.00 /
      DATA B(12472), B(12473), B(12474) /    -7.53,  -15.55,    0.00 /
      DATA B(12811), B(12812), B(12813) /    -7.83,  -15.59,    0.00 /
      DATA B(13150), B(13151), B(13152) /    -7.93,  -15.23,    0.00 /
      DATA B(13489), B(13490), B(13491) /    -7.91,  -14.89,    0.00 /
      DATA B(13828), B(13829), B(13830) /    -7.90,  -14.63,    0.00 /
      DATA B(14167), B(14168), B(14169) /    -7.90,  -14.45,    0.00 /
      DATA B(14506), B(14507), B(14508) /    -7.91,  -14.33,    0.00 /
      DATA B(14845), B(14846), B(14847) /    -7.93,  -14.23,    0.00 /
      DATA B(15184), B(15185), B(15186) /    -7.95,  -14.17,    0.00 /
      DATA B(15523), B(15524), B(15525) /    -7.97,  -14.13,    0.00 /
      DATA B(15862), B(15863), B(15864) /    -7.98,  -14.10,    0.00 /
      DATA B(16201), B(16202), B(16203) /    -7.99,  -14.10,    0.00 /
      DATA B(16540), B(16541), B(16542) /    -8.00,  -14.11,    0.00 /
      DATA B(16879), B(16880), B(16881) /    -7.99,  -14.15,    0.00 /
      DATA B(17218), B(17219), B(17220) /    -7.98,  -14.22,    0.00 /
      DATA B(17557), B(17558), B(17559) /    -7.96,  -14.32,    0.00 /
      DATA B(17896), B(17897), B(17898) /    -7.93,  -14.45,    0.00 /
      DATA B(18235), B(18236), B(18237) /    -7.90,  -14.62,    0.00 /
      DATA B(18574), B(18575), B(18576) /    -7.86,  -14.83,    0.00 /
      DATA B(18913), B(18914), B(18915) /    -7.80,  -15.08,    0.00 /
      DATA B(19252), B(19253), B(19254) /    -7.74,  -15.39,    0.00 /
      DATA B(19591), B(19592), B(19593) /    -8.91,  -11.01,    0.00 /
      DATA B(19930), B(19931), B(19932) /    -9.01,  -11.56,    0.00 /
      DATA B(20269), B(20270), B(20271) /    -9.33,  -12.13,    0.00 /
      DATA B(20608), B(20609), B(20610) /    -9.69,  -12.69,    0.00 /
      DATA B(20947), B(20948), B(20949) /    -9.85,  -13.22,    0.00 /
      DATA B(21286), B(21287), B(21288) /    -9.84,  -13.66,    0.00 /
      DATA B(21625), B(21626), B(21627) /    -9.77,  -14.00,    0.00 /
      DATA B(21964), B(21965), B(21966) /    -9.69,  -14.25,    0.00 /
      DATA B(22303), B(22304), B(22305) /    -9.63,  -14.44,    0.00 /
      DATA B(22642), B(22643), B(22644) /    -9.57,  -14.58,    0.00 /
      DATA B(22981), B(22982), B(22983) /    -9.53,  -14.69,    0.00 /
      DATA B(23320), B(23321), B(23322) /    -9.50,  -14.77,    0.00 /
      DATA B(23659), B(23660), B(23661) /    -9.47,  -14.84,    0.00 /
      DATA B(23998), B(23999), B(24000) /    -9.45,  -14.90,    0.00 /
      DATA B(24337), B(24338), B(24339) /    -9.44,  -14.94,    0.00 /
      DATA B(24676), B(24677), B(24678) /    -9.43,  -14.98,    0.00 /
      DATA B(25015), B(25016), B(25017) /    -9.42,  -15.02,    0.00 /
      DATA B(25354), B(25355), B(25356) /    -9.41,  -15.05,    0.00 /
      DATA B(25693), B(25694), B(25695) /    -9.41,  -15.07,    0.00 /
      DATA B(26032), B(26033), B(26034) /    -9.40,  -15.09,    0.00 /
      DATA B(26371), B(26372), B(26373) /    -9.40,  -15.12,    0.00 /
      DATA B(26710), B(26711), B(26712) /    -9.40,  -15.14,    0.00 /
      DATA B(27049), B(27050), B(27051) /    -9.40,  -15.16,    0.00 /
      DATA B(27388), B(27389), B(27390) /    -9.40,  -15.18,    0.00 /
      DATA B(  271), B(  272), B(  273) /    19.19,  -42.37,    0.00 /
      DATA B(  610), B(  611), B(  612) /    19.04,  -42.37,    0.00 /
      DATA B(  949), B(  950), B(  951) /    18.88,  -42.36,    0.00 /
      DATA B( 1288), B( 1289), B( 1290) /    18.72,  -42.35,    0.00 /
      DATA B( 1627), B( 1628), B( 1629) /    20.31,  -37.44,    0.00 /
      DATA B( 1966), B( 1967), B( 1968) /    20.29,  -38.32,    0.00 /
      DATA B( 2305), B( 2306), B( 2307) /    20.06,  -38.44,    0.00 /
      DATA B( 2644), B( 2645), B( 2646) /    19.87,  -38.40,    0.00 /
      DATA B( 2983), B( 2984), B( 2985) /    19.65,  -38.35,    0.00 /
      DATA B( 3322), B( 3323), B( 3324) /    19.41,  -38.29,    0.00 /
      DATA B( 3661), B( 3662), B( 3663) /    19.16,  -38.23,    0.00 /
      DATA B( 4000), B( 4001), B( 4002) /    18.90,  -38.18,    0.00 /
      DATA B( 4339), B( 4340), B( 4341) /    18.62,  -38.13,    0.00 /
      DATA B( 4678), B( 4679), B( 4680) /    18.32,  -38.09,    0.00 /
      DATA B( 5017), B( 5018), B( 5019) /    17.98,  -38.06,    0.00 /
      DATA B( 5356), B( 5357), B( 5358) /    17.62,  -38.04,    0.00 /
      DATA B( 5695), B( 5696), B( 5697) /    17.23,  -38.01,    0.00 /
      DATA B( 6034), B( 6035), B( 6036) /    16.83,  -37.91,    0.00 /
      DATA B( 6373), B( 6374), B( 6375) /    16.49,  -37.60,    0.00 /
      DATA B( 6712), B( 6713), B( 6714) /    16.21,  -36.81,    0.00 /
      DATA B( 7051), B( 7052), B( 7053) /    15.88,  -35.39,    0.00 /
      DATA B( 7390), B( 7391), B( 7392) /    17.63,  -33.70,    0.00 /
      DATA B( 7729), B( 7730), B( 7731) /    16.50,  -31.85,    0.00 /
      DATA B( 8068), B( 8069), B( 8070) /    14.46,  -30.95,    0.00 /
      DATA B( 8407), B( 8408), B( 8409) /    12.94,  -30.92,    0.00 /
      DATA B( 8746), B( 8747), B( 8748) /    12.01,  -30.58,    0.00 /
      DATA B( 9085), B( 9086), B( 9087) /    11.25,  -28.70,    0.00 /
      DATA B( 9424), B( 9425), B( 9426) /     9.88,  -27.14,    0.00 /
      DATA B( 9763), B( 9764), B( 9765) /    -1.96,  -17.72,    0.00 /
      DATA B(10102), B(10103), B(10104) /    -3.72,  -16.22,    0.00 /
      DATA B(10441), B(10442), B(10443) /    -5.07,  -15.43,    0.00 /
      DATA B(10780), B(10781), B(10782) /    -6.04,  -15.00,    0.00 /
      DATA B(11119), B(11120), B(11121) /    -6.72,  -14.71,    0.00 /
      DATA B(11458), B(11459), B(11460) /    -7.13,  -14.51,    0.00 /
      DATA B(11797), B(11798), B(11799) /    -7.36,  -14.48,    0.00 /
      DATA B(12136), B(12137), B(12138) /    -7.49,  -14.67,    0.00 /
      DATA B(12475), B(12476), B(12477) /    -7.66,  -14.94,    0.00 /
      DATA B(12814), B(12815), B(12816) /    -7.88,  -15.00,    0.00 /
      DATA B(13153), B(13154), B(13155) /    -8.01,  -14.84,    0.00 /
      DATA B(13492), B(13493), B(13494) /    -8.04,  -14.61,    0.00 /
      DATA B(13831), B(13832), B(13833) /    -8.05,  -14.42,    0.00 /
      DATA B(14170), B(14171), B(14172) /    -8.04,  -14.27,    0.00 /
      DATA B(14509), B(14510), B(14511) /    -8.05,  -14.17,    0.00 /
      DATA B(14848), B(14849), B(14850) /    -8.05,  -14.09,    0.00 /
      DATA B(15187), B(15188), B(15189) /    -8.06,  -14.04,    0.00 /
      DATA B(15526), B(15527), B(15528) /    -8.07,  -14.00,    0.00 /
      DATA B(15865), B(15866), B(15867) /    -8.08,  -13.98,    0.00 /
      DATA B(16204), B(16205), B(16206) /    -8.08,  -13.98,    0.00 /
      DATA B(16543), B(16544), B(16545) /    -8.08,  -14.00,    0.00 /
      DATA B(16882), B(16883), B(16884) /    -8.07,  -14.03,    0.00 /
      DATA B(17221), B(17222), B(17223) /    -8.05,  -14.09,    0.00 /
      DATA B(17560), B(17561), B(17562) /    -8.03,  -14.18,    0.00 /
      DATA B(17899), B(17900), B(17901) /    -8.00,  -14.29,    0.00 /
      DATA B(18238), B(18239), B(18240) /    -7.97,  -14.44,    0.00 /
      DATA B(18577), B(18578), B(18579) /    -7.93,  -14.61,    0.00 /
      DATA B(18916), B(18917), B(18918) /    -7.88,  -14.83,    0.00 /
      DATA B(19255), B(19256), B(19257) /    -7.82,  -15.09,    0.00 /
      DATA B(19594), B(19595), B(19596) /    -7.76,  -15.45,    0.00 /
      DATA B(19933), B(19934), B(19935) /    -8.95,  -11.21,    0.00 /
      DATA B(20272), B(20273), B(20274) /    -9.14,  -11.77,    0.00 /
      DATA B(20611), B(20612), B(20613) /    -9.51,  -12.33,    0.00 /
      DATA B(20950), B(20951), B(20952) /    -9.79,  -12.88,    0.00 /
      DATA B(21289), B(21290), B(21291) /    -9.86,  -13.38,    0.00 /
      DATA B(21628), B(21629), B(21630) /    -9.81,  -13.78,    0.00 /
      DATA B(21967), B(21968), B(21969) /    -9.73,  -14.08,    0.00 /
      DATA B(22306), B(22307), B(22308) /    -9.66,  -14.30,    0.00 /
      DATA B(22645), B(22646), B(22647) /    -9.60,  -14.47,    0.00 /
      DATA B(22984), B(22985), B(22986) /    -9.55,  -14.60,    0.00 /
      DATA B(23323), B(23324), B(23325) /    -9.52,  -14.70,    0.00 /
      DATA B(23662), B(23663), B(23664) /    -9.49,  -14.78,    0.00 /
      DATA B(24001), B(24002), B(24003) /    -9.46,  -14.84,    0.00 /
      DATA B(24340), B(24341), B(24342) /    -9.44,  -14.89,    0.00 /
      DATA B(24679), B(24680), B(24681) /    -9.43,  -14.94,    0.00 /
      DATA B(25018), B(25019), B(25020) /    -9.42,  -14.98,    0.00 /
      DATA B(25357), B(25358), B(25359) /    -9.41,  -15.01,    0.00 /
      DATA B(25696), B(25697), B(25698) /    -9.40,  -15.04,    0.00 /
      DATA B(26035), B(26036), B(26037) /    -9.40,  -15.07,    0.00 /
      DATA B(26374), B(26375), B(26376) /    -9.40,  -15.09,    0.00 /
      DATA B(26713), B(26714), B(26715) /    -9.40,  -15.11,    0.00 /
      DATA B(27052), B(27053), B(27054) /    -9.39,  -15.13,    0.00 /
      DATA B(27391), B(27392), B(27393) /    -9.39,  -15.16,    0.00 /
      DATA B(  274), B(  275), B(  276) /    19.03,  -42.51,    0.00 /
      DATA B(  613), B(  614), B(  615) /    20.56,  -37.56,    0.00 /
      DATA B(  952), B(  953), B(  954) /    20.40,  -37.64,    0.00 /
      DATA B( 1291), B( 1292), B( 1293) /    20.25,  -37.73,    0.00 /
      DATA B( 1630), B( 1631), B( 1632) /    20.15,  -37.92,    0.00 /
      DATA B( 1969), B( 1970), B( 1971) /    20.02,  -38.36,    0.00 /
      DATA B( 2308), B( 2309), B( 2310) /    19.73,  -38.57,    0.00 /
      DATA B( 2647), B( 2648), B( 2649) /    19.49,  -38.55,    0.00 /
      DATA B( 2986), B( 2987), B( 2988) /    19.27,  -38.49,    0.00 /
      DATA B( 3325), B( 3326), B( 3327) /    19.03,  -38.42,    0.00 /
      DATA B( 3664), B( 3665), B( 3666) /    18.78,  -38.34,    0.00 /
      DATA B( 4003), B( 4004), B( 4005) /    18.51,  -38.27,    0.00 /
      DATA B( 4342), B( 4343), B( 4344) /    18.21,  -38.20,    0.00 /
      DATA B( 4681), B( 4682), B( 4683) /    17.88,  -38.14,    0.00 /
      DATA B( 5020), B( 5021), B( 5022) /    17.48,  -38.09,    0.00 /
      DATA B( 5359), B( 5360), B( 5361) /    17.02,  -38.05,    0.00 /
      DATA B( 5698), B( 5699), B( 5700) /    16.47,  -38.01,    0.00 /
      DATA B( 6037), B( 6038), B( 6039) /    15.83,  -37.92,    0.00 /
      DATA B( 6376), B( 6377), B( 6378) /    15.16,  -37.60,    0.00 /
      DATA B( 6715), B( 6716), B( 6717) /    14.46,  -36.53,    0.00 /
      DATA B( 7054), B( 7055), B( 7056) /    13.23,  -34.28,    0.00 /
      DATA B( 7393), B( 7394), B( 7395) /    17.90,  -32.89,    0.00 /
      DATA B( 7732), B( 7733), B( 7734) /     8.39,  -23.88,    0.00 /
      DATA B( 8071), B( 8072), B( 8073) /    12.86,  -29.27,    0.00 /
      DATA B( 8410), B( 8411), B( 8412) /    10.73,  -29.43,    0.00 /
      DATA B( 8749), B( 8750), B( 8751) /     9.13,  -29.45,    0.00 /
      DATA B( 9088), B( 9089), B( 9090) /     6.98,  -26.51,    0.00 /
      DATA B( 9427), B( 9428), B( 9429) /     0.00,  -18.91,    0.00 /
      DATA B( 9766), B( 9767), B( 9768) /    -2.86,  -16.51,    0.00 /
      DATA B(10105), B(10106), B(10107) /    -4.57,  -15.37,    0.00 /
      DATA B(10444), B(10445), B(10446) /    -5.66,  -14.79,    0.00 /
      DATA B(10783), B(10784), B(10785) /    -6.41,  -14.50,    0.00 /
      DATA B(11122), B(11123), B(11124) /    -6.92,  -14.32,    0.00 /
      DATA B(11461), B(11462), B(11463) /    -7.26,  -14.23,    0.00 /
      DATA B(11800), B(11801), B(11802) /    -7.46,  -14.24,    0.00 /
      DATA B(12139), B(12140), B(12141) /    -7.61,  -14.36,    0.00 /
      DATA B(12478), B(12479), B(12480) /    -7.76,  -14.52,    0.00 /
      DATA B(12817), B(12818), B(12819) /    -7.93,  -14.57,    0.00 /
      DATA B(13156), B(13157), B(13158) /    -8.05,  -14.49,    0.00 /
      DATA B(13495), B(13496), B(13497) /    -8.11,  -14.36,    0.00 /
      DATA B(13834), B(13835), B(13836) /    -8.13,  -14.22,    0.00 /
      DATA B(14173), B(14174), B(14175) /    -8.14,  -14.11,    0.00 /
      DATA B(14512), B(14513), B(14514) /    -8.14,  -14.03,    0.00 /
      DATA B(14851), B(14852), B(14853) /    -8.14,  -13.96,    0.00 /
      DATA B(15190), B(15191), B(15192) /    -8.14,  -13.92,    0.00 /
      DATA B(15529), B(15530), B(15531) /    -8.15,  -13.89,    0.00 /
      DATA B(15868), B(15869), B(15870) /    -8.15,  -13.88,    0.00 /
      DATA B(16207), B(16208), B(16209) /    -8.15,  -13.88,    0.00 /
      DATA B(16546), B(16547), B(16548) /    -8.14,  -13.90,    0.00 /
      DATA B(16885), B(16886), B(16887) /    -8.13,  -13.93,    0.00 /
      DATA B(17224), B(17225), B(17226) /    -8.11,  -13.99,    0.00 /
      DATA B(17563), B(17564), B(17565) /    -8.09,  -14.06,    0.00 /
      DATA B(17902), B(17903), B(17904) /    -8.07,  -14.16,    0.00 /
      DATA B(18241), B(18242), B(18243) /    -8.04,  -14.28,    0.00 /
      DATA B(18580), B(18581), B(18582) /    -8.00,  -14.43,    0.00 /
      DATA B(18919), B(18920), B(18921) /    -7.95,  -14.61,    0.00 /
      DATA B(19258), B(19259), B(19260) /    -7.89,  -14.84,    0.00 /
      DATA B(19597), B(19598), B(19599) /    -7.83,  -15.13,    0.00 /
      DATA B(19936), B(19937), B(19938) /    -8.97,  -10.90,    0.00 /
      DATA B(20275), B(20276), B(20277) /    -9.03,  -11.42,    0.00 /
      DATA B(20614), B(20615), B(20616) /    -9.30,  -11.99,    0.00 /
      DATA B(20953), B(20954), B(20955) /    -9.66,  -12.55,    0.00 /
      DATA B(21292), B(21293), B(21294) /    -9.84,  -13.08,    0.00 /
      DATA B(21631), B(21632), B(21633) /    -9.84,  -13.54,    0.00 /
      DATA B(21970), B(21971), B(21972) /    -9.77,  -13.89,    0.00 /
      DATA B(22309), B(22310), B(22311) /    -9.70,  -14.16,    0.00 /
      DATA B(22648), B(22649), B(22650) /    -9.63,  -14.35,    0.00 /
      DATA B(22987), B(22988), B(22989) /    -9.58,  -14.50,    0.00 /
      DATA B(23326), B(23327), B(23328) /    -9.53,  -14.62,    0.00 /
      DATA B(23665), B(23666), B(23667) /    -9.50,  -14.71,    0.00 /
      DATA B(24004), B(24005), B(24006) /    -9.47,  -14.78,    0.00 /
      DATA B(24343), B(24344), B(24345) /    -9.45,  -14.84,    0.00 /
      DATA B(24682), B(24683), B(24684) /    -9.43,  -14.89,    0.00 /
      DATA B(25021), B(25022), B(25023) /    -9.42,  -14.94,    0.00 /
      DATA B(25360), B(25361), B(25362) /    -9.41,  -14.98,    0.00 /
      DATA B(25699), B(25700), B(25701) /    -9.40,  -15.01,    0.00 /
      DATA B(26038), B(26039), B(26040) /    -9.40,  -15.04,    0.00 /
      DATA B(26377), B(26378), B(26379) /    -9.39,  -15.06,    0.00 /
      DATA B(26716), B(26717), B(26718) /    -9.39,  -15.09,    0.00 /
      DATA B(27055), B(27056), B(27057) /    -9.39,  -15.11,    0.00 /
      DATA B(27394), B(27395), B(27396) /    -9.39,  -15.13,    0.00 /
      DATA B(  277), B(  278), B(  279) /    20.42,  -37.84,    0.00 /
      DATA B(  616), B(  617), B(  618) /    20.26,  -37.93,    0.00 /
      DATA B(  955), B(  956), B(  957) /    20.10,  -38.02,    0.00 /
      DATA B( 1294), B( 1295), B( 1296) /    19.97,  -38.12,    0.00 /
      DATA B( 1633), B( 1634), B( 1635) /    19.84,  -38.29,    0.00 /
      DATA B( 1972), B( 1973), B( 1974) /    19.67,  -38.53,    0.00 /
      DATA B( 2311), B( 2312), B( 2313) /    19.41,  -38.68,    0.00 /
      DATA B( 2650), B( 2651), B( 2652) /    19.16,  -38.68,    0.00 /
      DATA B( 2989), B( 2990), B( 2991) /    18.92,  -38.62,    0.00 /
      DATA B( 3328), B( 3329), B( 3330) /    18.67,  -38.54,    0.00 /
      DATA B( 3667), B( 3668), B( 3669) /    18.41,  -38.45,    0.00 /
      DATA B( 4006), B( 4007), B( 4008) /    18.13,  -38.35,    0.00 /
      DATA B( 4345), B( 4346), B( 4347) /    17.80,  -38.25,    0.00 /
      DATA B( 4684), B( 4685), B( 4686) /    17.43,  -38.15,    0.00 /
      DATA B( 5023), B( 5024), B( 5025) /    16.98,  -38.05,    0.00 /
      DATA B( 5362), B( 5363), B( 5364) /    16.41,  -37.96,    0.00 /
      DATA B( 5701), B( 5702), B( 5703) /    15.66,  -37.86,    0.00 /
      DATA B( 6040), B( 6041), B( 6042) /    14.65,  -37.75,    0.00 /
      DATA B( 6379), B( 6380), B( 6381) /    13.38,  -37.46,    0.00 /
      DATA B( 6718), B( 6719), B( 6720) /    12.09,  -36.01,    0.00 /
      DATA B( 7057), B( 7058), B( 7059) /    17.30,  -35.44,    0.00 /
      DATA B( 7396), B( 7397), B( 7398) /    16.00,  -31.56,    0.00 /
      DATA B( 7735), B( 7736), B( 7737) /     6.55,  -22.91,    0.00 /
      DATA B( 8074), B( 8075), B( 8076) /    11.08,  -28.12,    0.00 /
      DATA B( 8413), B( 8414), B( 8415) /     8.62,  -28.21,    0.00 /
      DATA B( 8752), B( 8753), B( 8754) /     6.98,  -28.14,    0.00 /
      DATA B( 9091), B( 9092), B( 9093) /    -2.18,  -20.37,    0.00 /
      DATA B( 9430), B( 9431), B( 9432) /    -3.52,  -17.25,    0.00 /
      DATA B( 9769), B( 9770), B( 9771) /    -4.58,  -15.53,    0.00 /
      DATA B(10108), B(10109), B(10110) /    -5.52,  -14.75,    0.00 /
      DATA B(10447), B(10448), B(10449) /    -6.23,  -14.35,    0.00 /
      DATA B(10786), B(10787), B(10788) /    -6.75,  -14.15,    0.00 /
      DATA B(11125), B(11126), B(11127) /    -7.13,  -14.04,    0.00 /
      DATA B(11464), B(11465), B(11466) /    -7.39,  -14.00,    0.00 /
      DATA B(11803), B(11804), B(11805) /    -7.57,  -14.02,    0.00 /
      DATA B(12142), B(12143), B(12144) /    -7.71,  -14.11,    0.00 /
      DATA B(12481), B(12482), B(12483) /    -7.84,  -14.20,    0.00 /
      DATA B(12820), B(12821), B(12822) /    -7.97,  -14.24,    0.00 /
      DATA B(13159), B(13160), B(13161) /    -8.08,  -14.21,    0.00 /
      DATA B(13498), B(13499), B(13500) /    -8.14,  -14.14,    0.00 /
      DATA B(13837), B(13838), B(13839) /    -8.18,  -14.05,    0.00 /
      DATA B(14176), B(14177), B(14178) /    -8.19,  -13.97,    0.00 /
      DATA B(14515), B(14516), B(14517) /    -8.20,  -13.90,    0.00 /
      DATA B(14854), B(14855), B(14856) /    -8.21,  -13.85,    0.00 /
      DATA B(15193), B(15194), B(15195) /    -8.21,  -13.81,    0.00 /
      DATA B(15532), B(15533), B(15534) /    -8.21,  -13.79,    0.00 /
      DATA B(15871), B(15872), B(15873) /    -8.20,  -13.78,    0.00 /
      DATA B(16210), B(16211), B(16212) /    -8.20,  -13.79,    0.00 /
      DATA B(16549), B(16550), B(16551) /    -8.19,  -13.81,    0.00 /
      DATA B(16888), B(16889), B(16890) /    -8.18,  -13.84,    0.00 /
      DATA B(17227), B(17228), B(17229) /    -8.16,  -13.89,    0.00 /
      DATA B(17566), B(17567), B(17568) /    -8.15,  -13.95,    0.00 /
      DATA B(17905), B(17906), B(17907) /    -8.12,  -14.04,    0.00 /
      DATA B(18244), B(18245), B(18246) /    -8.09,  -14.14,    0.00 /
      DATA B(18583), B(18584), B(18585) /    -8.06,  -14.27,    0.00 /
      DATA B(18922), B(18923), B(18924) /    -8.01,  -14.43,    0.00 /
      DATA B(19261), B(19262), B(19263) /    -7.95,  -14.62,    0.00 /
      DATA B(19600), B(19601), B(19602) /    -7.88,  -14.87,    0.00 /
      DATA B(19939), B(19940), B(19941) /    -7.82,  -15.17,    0.00 /
      DATA B(20278), B(20279), B(20280) /    -8.97,  -11.10,    0.00 /
      DATA B(20617), B(20618), B(20619) /    -9.13,  -11.66,    0.00 /
      DATA B(20956), B(20957), B(20958) /    -9.47,  -12.22,    0.00 /
      DATA B(21295), B(21296), B(21297) /    -9.77,  -12.76,    0.00 /
      DATA B(21634), B(21635), B(21636) /    -9.85,  -13.27,    0.00 /
      DATA B(21973), B(21974), B(21975) /    -9.81,  -13.68,    0.00 /
      DATA B(22312), B(22313), B(22314) /    -9.73,  -13.99,    0.00 /
      DATA B(22651), B(22652), B(22653) /    -9.66,  -14.23,    0.00 /
      DATA B(22990), B(22991), B(22992) /    -9.60,  -14.40,    0.00 /
      DATA B(23329), B(23330), B(23331) /    -9.55,  -14.53,    0.00 /
      DATA B(23668), B(23669), B(23670) /    -9.51,  -14.64,    0.00 /
      DATA B(24007), B(24008), B(24009) /    -9.48,  -14.72,    0.00 /
      DATA B(24346), B(24347), B(24348) /    -9.45,  -14.79,    0.00 /
      DATA B(24685), B(24686), B(24687) /    -9.44,  -14.85,    0.00 /
      DATA B(25024), B(25025), B(25026) /    -9.42,  -14.90,    0.00 /
      DATA B(25363), B(25364), B(25365) /    -9.41,  -14.94,    0.00 /
      DATA B(25702), B(25703), B(25704) /    -9.40,  -14.98,    0.00 /
      DATA B(26041), B(26042), B(26043) /    -9.39,  -15.01,    0.00 /
      DATA B(26380), B(26381), B(26382) /    -9.39,  -15.04,    0.00 /
      DATA B(26719), B(26720), B(26721) /    -9.38,  -15.06,    0.00 /
      DATA B(27058), B(27059), B(27060) /    -9.38,  -15.09,    0.00 /
      DATA B(27397), B(27398), B(27399) /    -9.38,  -15.11,    0.00 /
      DATA B(  280), B(  281), B(  282) /    20.11,  -38.22,    0.00 /
      DATA B(  619), B(  620), B(  621) /    19.95,  -38.31,    0.00 /
      DATA B(  958), B(  959), B(  960) /    19.80,  -38.39,    0.00 /
      DATA B( 1297), B( 1298), B( 1299) /    19.65,  -38.49,    0.00 /
      DATA B( 1636), B( 1637), B( 1638) /    19.50,  -38.61,    0.00 /
      DATA B( 1975), B( 1976), B( 1977) /    19.31,  -38.74,    0.00 /
      DATA B( 2314), B( 2315), B( 2316) /    19.07,  -38.82,    0.00 /
      DATA B( 2653), B( 2654), B( 2655) /    18.82,  -38.81,    0.00 /
      DATA B( 2992), B( 2993), B( 2994) /    18.57,  -38.75,    0.00 /
      DATA B( 3331), B( 3332), B( 3333) /    18.32,  -38.65,    0.00 /
      DATA B( 3670), B( 3671), B( 3672) /    18.04,  -38.54,    0.00 /
      DATA B( 4009), B( 4010), B( 4011) /    17.73,  -38.41,    0.00 /
      DATA B( 4348), B( 4349), B( 4350) /    17.38,  -38.27,    0.00 /
      DATA B( 4687), B( 4688), B( 4689) /    16.97,  -38.11,    0.00 /
      DATA B( 5026), B( 5027), B( 5028) /    16.47,  -37.94,    0.00 /
      DATA B( 5365), B( 5366), B( 5367) /    15.82,  -37.75,    0.00 /
      DATA B( 5704), B( 5705), B( 5706) /    14.91,  -37.53,    0.00 /
      DATA B( 6043), B( 6044), B( 6045) /    13.54,  -37.27,    0.00 /
      DATA B( 6382), B( 6383), B( 6384) /    11.37,  -36.92,    0.00 /
      DATA B( 6721), B( 6722), B( 6723) /     8.64,  -35.45,    0.00 /
      DATA B( 7060), B( 7061), B( 7062) /    16.08,  -33.83,    0.00 /
      DATA B( 7399), B( 7400), B( 7401) /     5.57,  -23.11,    0.00 /
      DATA B( 7738), B( 7739), B( 7740) /     3.45,  -21.51,    0.00 /
      DATA B( 8077), B( 8078), B( 8079) /     1.33,  -21.05,    0.00 /
      DATA B( 8416), B( 8417), B( 8418) /    -3.49,  -18.22,    0.00 /
      DATA B( 8755), B( 8756), B( 8757) /    -4.44,  -17.95,    0.00 /
      DATA B( 9094), B( 9095), B( 9096) /    -5.16,  -18.51,    0.00 /
      DATA B( 9433), B( 9434), B( 9435) /    -5.77,  -16.55,    0.00 /
      DATA B( 9772), B( 9773), B( 9774) /    -6.02,  -15.12,    0.00 /
      DATA B(10111), B(10112), B(10113) /    -6.37,  -14.42,    0.00 /
      DATA B(10450), B(10451), B(10452) /    -6.74,  -14.08,    0.00 /
      DATA B(10789), B(10790), B(10791) /    -7.06,  -13.92,    0.00 /
      DATA B(11128), B(11129), B(11130) /    -7.32,  -13.84,    0.00 /
      DATA B(11467), B(11468), B(11469) /    -7.52,  -13.82,    0.00 /
      DATA B(11806), B(11807), B(11808) /    -7.67,  -13.84,    0.00 /
      DATA B(12145), B(12146), B(12147) /    -7.79,  -13.90,    0.00 /
      DATA B(12484), B(12485), B(12486) /    -7.91,  -13.96,    0.00 /
      DATA B(12823), B(12824), B(12825) /    -8.01,  -13.99,    0.00 /
      DATA B(13162), B(13163), B(13164) /    -8.10,  -13.99,    0.00 /
      DATA B(13501), B(13502), B(13503) /    -8.17,  -13.94,    0.00 /
      DATA B(13840), B(13841), B(13842) /    -8.21,  -13.89,    0.00 /
      DATA B(14179), B(14180), B(14181) /    -8.23,  -13.83,    0.00 /
      DATA B(14518), B(14519), B(14520) /    -8.25,  -13.78,    0.00 /
      DATA B(14857), B(14858), B(14859) /    -8.25,  -13.75,    0.00 /
      DATA B(15196), B(15197), B(15198) /    -8.25,  -13.72,    0.00 /
      DATA B(15535), B(15536), B(15537) /    -8.25,  -13.70,    0.00 /
      DATA B(15874), B(15875), B(15876) /    -8.25,  -13.70,    0.00 /
      DATA B(16213), B(16214), B(16215) /    -8.24,  -13.70,    0.00 /
      DATA B(16552), B(16553), B(16554) /    -8.24,  -13.72,    0.00 /
      DATA B(16891), B(16892), B(16893) /    -8.22,  -13.75,    0.00 /
      DATA B(17230), B(17231), B(17232) /    -8.21,  -13.80,    0.00 /
      DATA B(17569), B(17570), B(17571) /    -8.19,  -13.86,    0.00 /
      DATA B(17908), B(17909), B(17910) /    -8.17,  -13.93,    0.00 /
      DATA B(18247), B(18248), B(18249) /    -8.14,  -14.02,    0.00 /
      DATA B(18586), B(18587), B(18588) /    -8.11,  -14.13,    0.00 /
      DATA B(18925), B(18926), B(18927) /    -8.07,  -14.27,    0.00 /
      DATA B(19264), B(19265), B(19266) /    -8.01,  -14.44,    0.00 /
      DATA B(19603), B(19604), B(19605) /    -7.95,  -14.65,    0.00 /
      DATA B(19942), B(19943), B(19944) /    -7.87,  -14.92,    0.00 /
      DATA B(20281), B(20282), B(20283) /    -9.01,  -10.83,    0.00 /
      DATA B(20620), B(20621), B(20622) /    -9.02,  -11.34,    0.00 /
      DATA B(20959), B(20960), B(20961) /    -9.27,  -11.90,    0.00 /
      DATA B(21298), B(21299), B(21300) /    -9.62,  -12.45,    0.00 /
      DATA B(21637), B(21638), B(21639) /    -9.82,  -12.98,    0.00 /
      DATA B(21976), B(21977), B(21978) /    -9.83,  -13.45,    0.00 /
      DATA B(22315), B(22316), B(22317) /    -9.77,  -13.81,    0.00 /
      DATA B(22654), B(22655), B(22656) /    -9.69,  -14.09,    0.00 /
      DATA B(22993), B(22994), B(22995) /    -9.62,  -14.29,    0.00 /
      DATA B(23332), B(23333), B(23334) /    -9.57,  -14.45,    0.00 /
      DATA B(23671), B(23672), B(23673) /    -9.52,  -14.57,    0.00 /
      DATA B(24010), B(24011), B(24012) /    -9.49,  -14.66,    0.00 /
      DATA B(24349), B(24350), B(24351) /    -9.46,  -14.74,    0.00 /
      DATA B(24688), B(24689), B(24690) /    -9.44,  -14.80,    0.00 /
      DATA B(25027), B(25028), B(25029) /    -9.42,  -14.86,    0.00 /
      DATA B(25366), B(25367), B(25368) /    -9.40,  -14.90,    0.00 /
      DATA B(25705), B(25706), B(25707) /    -9.39,  -14.94,    0.00 /
      DATA B(26044), B(26045), B(26046) /    -9.38,  -14.98,    0.00 /
      DATA B(26383), B(26384), B(26385) /    -9.38,  -15.01,    0.00 /
      DATA B(26722), B(26723), B(26724) /    -9.37,  -15.04,    0.00 /
      DATA B(27061), B(27062), B(27063) /    -9.37,  -15.07,    0.00 /
      DATA B(27400), B(27401), B(27402) /    -9.37,  -15.09,    0.00 /
      DATA B(  283), B(  284), B(  285) /    19.79,  -38.60,    0.00 /
      DATA B(  622), B(  623), B(  624) /    19.63,  -38.69,    0.00 /
      DATA B(  961), B(  962), B(  963) /    19.47,  -38.76,    0.00 /
      DATA B( 1300), B( 1301), B( 1302) /    19.32,  -38.84,    0.00 /
      DATA B( 1639), B( 1640), B( 1641) /    19.15,  -38.91,    0.00 /
      DATA B( 1978), B( 1979), B( 1980) /    18.95,  -38.98,    0.00 /
      DATA B( 2317), B( 2318), B( 2319) /    18.72,  -39.00,    0.00 /
      DATA B( 2656), B( 2657), B( 2658) /    18.48,  -38.96,    0.00 /
      DATA B( 2995), B( 2996), B( 2997) /    18.22,  -38.88,    0.00 /
      DATA B( 3334), B( 3335), B( 3336) /    17.94,  -38.76,    0.00 /
      DATA B( 3673), B( 3674), B( 3675) /    17.65,  -38.61,    0.00 /
      DATA B( 4012), B( 4013), B( 4014) /    17.32,  -38.44,    0.00 /
      DATA B( 4351), B( 4352), B( 4353) /    16.95,  -38.24,    0.00 /
      DATA B( 4690), B( 4691), B( 4692) /    16.51,  -38.01,    0.00 /
      DATA B( 5029), B( 5030), B( 5031) /    15.97,  -37.75,    0.00 /
      DATA B( 5368), B( 5369), B( 5370) /    15.27,  -37.43,    0.00 /
      DATA B( 5707), B( 5708), B( 5709) /    14.31,  -37.02,    0.00 /
      DATA B( 6046), B( 6047), B( 6048) /    12.86,  -36.47,    0.00 /
      DATA B( 6385), B( 6386), B( 6387) /    10.47,  -35.71,    0.00 /
      DATA B( 6724), B( 6725), B( 6726) /     5.83,  -34.89,    0.00 /
      DATA B( 7063), B( 7064), B( 7065) /     3.07,  -23.89,    0.00 /
      DATA B( 7402), B( 7403), B( 7404) /     1.20,  -20.92,    0.00 /
      DATA B( 7741), B( 7742), B( 7743) /    -0.14,  -19.83,    0.00 /
      DATA B( 8080), B( 8081), B( 8082) /    -2.02,  -19.28,    0.00 /
      DATA B( 8419), B( 8420), B( 8421) /    -3.97,  -17.70,    0.00 /
      DATA B( 8758), B( 8759), B( 8760) /    -5.06,  -17.25,    0.00 /
      DATA B( 9097), B( 9098), B( 9099) /    -5.93,  -16.97,    0.00 /
      DATA B( 9436), B( 9437), B( 9438) /    -6.56,  -15.91,    0.00 /
      DATA B( 9775), B( 9776), B( 9777) /    -6.79,  -14.86,    0.00 /
      DATA B(10114), B(10115), B(10116) /    -6.95,  -14.25,    0.00 /
      DATA B(10453), B(10454), B(10455) /    -7.13,  -13.92,    0.00 /
      DATA B(10792), B(10793), B(10794) /    -7.32,  -13.76,    0.00 /
      DATA B(11131), B(11132), B(11133) /    -7.49,  -13.69,    0.00 /
      DATA B(11470), B(11471), B(11472) /    -7.64,  -13.67,    0.00 /
      DATA B(11809), B(11810), B(11811) /    -7.76,  -13.69,    0.00 /
      DATA B(12148), B(12149), B(12150) /    -7.87,  -13.73,    0.00 /
      DATA B(12487), B(12488), B(12489) /    -7.97,  -13.77,    0.00 /
      DATA B(12826), B(12827), B(12828) /    -8.06,  -13.80,    0.00 /
      DATA B(13165), B(13166), B(13167) /    -8.13,  -13.80,    0.00 /
      DATA B(13504), B(13505), B(13506) /    -8.19,  -13.78,    0.00 /
      DATA B(13843), B(13844), B(13845) /    -8.23,  -13.75,    0.00 /
      DATA B(14182), B(14183), B(14184) /    -8.26,  -13.71,    0.00 /
      DATA B(14521), B(14522), B(14523) /    -8.28,  -13.68,    0.00 /
      DATA B(14860), B(14861), B(14862) /    -8.28,  -13.65,    0.00 /
      DATA B(15199), B(15200), B(15201) /    -8.29,  -13.63,    0.00 /
      DATA B(15538), B(15539), B(15540) /    -8.29,  -13.62,    0.00 /
      DATA B(15877), B(15878), B(15879) /    -8.28,  -13.62,    0.00 /
      DATA B(16216), B(16217), B(16218) /    -8.28,  -13.63,    0.00 /
      DATA B(16555), B(16556), B(16557) /    -8.27,  -13.65,    0.00 /
      DATA B(16894), B(16895), B(16896) /    -8.26,  -13.68,    0.00 /
      DATA B(17233), B(17234), B(17235) /    -8.25,  -13.72,    0.00 /
      DATA B(17572), B(17573), B(17574) /    -8.23,  -13.77,    0.00 /
      DATA B(17911), B(17912), B(17913) /    -8.21,  -13.84,    0.00 /
      DATA B(18250), B(18251), B(18252) /    -8.18,  -13.92,    0.00 /
      DATA B(18589), B(18590), B(18591) /    -8.15,  -14.01,    0.00 /
      DATA B(18928), B(18929), B(18930) /    -8.11,  -14.13,    0.00 /
      DATA B(19267), B(19268), B(19269) /    -8.06,  -14.28,    0.00 /
      DATA B(19606), B(19607), B(19608) /    -8.00,  -14.46,    0.00 /
      DATA B(19945), B(19946), B(19947) /    -7.93,  -14.70,    0.00 /
      DATA B(20284), B(20285), B(20286) /    -7.86,  -14.98,    0.00 /
      DATA B(20623), B(20624), B(20625) /    -9.00,  -11.05,    0.00 /
      DATA B(20962), B(20963), B(20964) /    -9.11,  -11.59,    0.00 /
      DATA B(21301), B(21302), B(21303) /    -9.43,  -12.14,    0.00 /
      DATA B(21640), B(21641), B(21642) /    -9.73,  -12.68,    0.00 /
      DATA B(21979), B(21980), B(21981) /    -9.83,  -13.19,    0.00 /
      DATA B(22318), B(22319), B(22320) /    -9.80,  -13.61,    0.00 /
      DATA B(22657), B(22658), B(22659) /    -9.72,  -13.93,    0.00 /
      DATA B(22996), B(22997), B(22998) /    -9.65,  -14.17,    0.00 /
      DATA B(23335), B(23336), B(23337) /    -9.59,  -14.35,    0.00 /
      DATA B(23674), B(23675), B(23676) /    -9.54,  -14.49,    0.00 /
      DATA B(24013), B(24014), B(24015) /    -9.50,  -14.60,    0.00 /
      DATA B(24352), B(24353), B(24354) /    -9.46,  -14.68,    0.00 /
      DATA B(24691), B(24692), B(24693) /    -9.44,  -14.76,    0.00 /
      DATA B(25030), B(25031), B(25032) /    -9.42,  -14.82,    0.00 /
      DATA B(25369), B(25370), B(25371) /    -9.40,  -14.87,    0.00 /
      DATA B(25708), B(25709), B(25710) /    -9.39,  -14.91,    0.00 /
      DATA B(26047), B(26048), B(26049) /    -9.38,  -14.95,    0.00 /
      DATA B(26386), B(26387), B(26388) /    -9.37,  -14.98,    0.00 /
      DATA B(26725), B(26726), B(26727) /    -9.36,  -15.01,    0.00 /
      DATA B(27064), B(27065), B(27066) /    -9.36,  -15.04,    0.00 /
      DATA B(27403), B(27404), B(27405) /    -9.36,  -15.07,    0.00 /
      DATA B(  286), B(  287), B(  288) /    19.46,  -38.99,    0.00 /
      DATA B(  625), B(  626), B(  627) /    19.30,  -39.06,    0.00 /
      DATA B(  964), B(  965), B(  966) /    19.14,  -39.13,    0.00 /
      DATA B( 1303), B( 1304), B( 1305) /    18.97,  -39.18,    0.00 /
      DATA B( 1642), B( 1643), B( 1644) /    18.79,  -39.22,    0.00 /
      DATA B( 1981), B( 1982), B( 1983) /    18.59,  -39.23,    0.00 /
      DATA B( 2320), B( 2321), B( 2322) /    18.36,  -39.20,    0.00 /
      DATA B( 2659), B( 2660), B( 2661) /    18.11,  -39.13,    0.00 /
      DATA B( 2998), B( 2999), B( 3000) /    17.84,  -39.01,    0.00 /
      DATA B( 3337), B( 3338), B( 3339) /    17.55,  -38.85,    0.00 /
      DATA B( 3676), B( 3677), B( 3678) /    17.24,  -38.66,    0.00 /
      DATA B( 4015), B( 4016), B( 4017) /    16.88,  -38.43,    0.00 /
      DATA B( 4354), B( 4355), B( 4356) /    16.48,  -38.16,    0.00 /
      DATA B( 4693), B( 4694), B( 4695) /    16.00,  -37.84,    0.00 /
      DATA B( 5032), B( 5033), B( 5034) /    15.43,  -37.46,    0.00 /
      DATA B( 5371), B( 5372), B( 5373) /    14.70,  -36.99,    0.00 /
      DATA B( 5710), B( 5711), B( 5712) /    13.76,  -36.39,    0.00 /
      DATA B( 6049), B( 6050), B( 6051) /    12.54,  -35.61,    0.00 /
      DATA B( 6388), B( 6389), B( 6390) /    11.20,  -34.78,    0.00 /
      DATA B( 6727), B( 6728), B( 6729) /    -1.54,  -21.15,    0.00 /
      DATA B( 7066), B( 7067), B( 7068) /    -1.83,  -21.84,    0.00 /
      DATA B( 7405), B( 7406), B( 7407) /    -2.07,  -19.48,    0.00 /
      DATA B( 7744), B( 7745), B( 7746) /    -2.76,  -18.36,    0.00 /
      DATA B( 8083), B( 8084), B( 8085) /    -3.87,  -17.66,    0.00 /
      DATA B( 8422), B( 8423), B( 8424) /    -4.96,  -16.84,    0.00 /
      DATA B( 8761), B( 8762), B( 8763) /    -5.73,  -16.33,    0.00 /
      DATA B( 9100), B( 9101), B( 9102) /    -6.39,  -15.93,    0.00 /
      DATA B( 9439), B( 9440), B( 9441) /    -6.89,  -15.28,    0.00 /
      DATA B( 9778), B( 9779), B( 9780) /    -7.14,  -14.59,    0.00 /
      DATA B(10117), B(10118), B(10119) /    -7.28,  -14.10,    0.00 /
      DATA B(10456), B(10457), B(10458) /    -7.40,  -13.81,    0.00 /
      DATA B(10795), B(10796), B(10797) /    -7.52,  -13.65,    0.00 /
      DATA B(11134), B(11135), B(11136) /    -7.64,  -13.58,    0.00 /
      DATA B(11473), B(11474), B(11475) /    -7.75,  -13.56,    0.00 /
      DATA B(11812), B(11813), B(11814) /    -7.85,  -13.57,    0.00 /
      DATA B(12151), B(12152), B(12153) /    -7.94,  -13.59,    0.00 /
      DATA B(12490), B(12491), B(12492) /    -8.02,  -13.62,    0.00 /
      DATA B(12829), B(12830), B(12831) /    -8.09,  -13.65,    0.00 /
      DATA B(13168), B(13169), B(13170) /    -8.16,  -13.65,    0.00 /
      DATA B(13507), B(13508), B(13509) /    -8.21,  -13.65,    0.00 /
      DATA B(13846), B(13847), B(13848) /    -8.25,  -13.63,    0.00 /
      DATA B(14185), B(14186), B(14187) /    -8.28,  -13.60,    0.00 /
      DATA B(14524), B(14525), B(14526) /    -8.30,  -13.58,    0.00 /
      DATA B(14863), B(14864), B(14865) /    -8.31,  -13.56,    0.00 /
      DATA B(15202), B(15203), B(15204) /    -8.31,  -13.55,    0.00 /
      DATA B(15541), B(15542), B(15543) /    -8.31,  -13.55,    0.00 /
      DATA B(15880), B(15881), B(15882) /    -8.31,  -13.55,    0.00 /
      DATA B(16219), B(16220), B(16221) /    -8.31,  -13.56,    0.00 /
      DATA B(16558), B(16559), B(16560) /    -8.30,  -13.58,    0.00 /
      DATA B(16897), B(16898), B(16899) /    -8.29,  -13.61,    0.00 /
      DATA B(17236), B(17237), B(17238) /    -8.28,  -13.64,    0.00 /
      DATA B(17575), B(17576), B(17577) /    -8.26,  -13.69,    0.00 /
      DATA B(17914), B(17915), B(17916) /    -8.24,  -13.75,    0.00 /
      DATA B(18253), B(18254), B(18255) /    -8.22,  -13.82,    0.00 /
      DATA B(18592), B(18593), B(18594) /    -8.19,  -13.91,    0.00 /
      DATA B(18931), B(18932), B(18933) /    -8.15,  -14.01,    0.00 /
      DATA B(19270), B(19271), B(19272) /    -8.11,  -14.14,    0.00 /
      DATA B(19609), B(19610), B(19611) /    -8.05,  -14.29,    0.00 /
      DATA B(19948), B(19949), B(19950) /    -7.98,  -14.50,    0.00 /
      DATA B(20287), B(20288), B(20289) /    -7.90,  -14.76,    0.00 /
      DATA B(20626), B(20627), B(20628) /    -8.98,  -10.75,    0.00 /
      DATA B(20965), B(20966), B(20967) /    -9.02,  -11.29,    0.00 /
      DATA B(21304), B(21305), B(21306) /    -9.23,  -11.84,    0.00 /
      DATA B(21643), B(21644), B(21645) /    -9.58,  -12.38,    0.00 /
      DATA B(21982), B(21983), B(21984) /    -9.79,  -12.91,    0.00 /
      DATA B(22321), B(22322), B(22323) /    -9.81,  -13.38,    0.00 /
      DATA B(22660), B(22661), B(22662) /    -9.75,  -13.75,    0.00 /
      DATA B(22999), B(23000), B(23001) /    -9.68,  -14.03,    0.00 /
      DATA B(23338), B(23339), B(23340) /    -9.61,  -14.24,    0.00 /
      DATA B(23677), B(23678), B(23679) /    -9.55,  -14.40,    0.00 /
      DATA B(24016), B(24017), B(24018) /    -9.50,  -14.53,    0.00 /
      DATA B(24355), B(24356), B(24357) /    -9.47,  -14.63,    0.00 /
      DATA B(24694), B(24695), B(24696) /    -9.44,  -14.71,    0.00 /
      DATA B(25033), B(25034), B(25035) /    -9.42,  -14.77,    0.00 /
      DATA B(25372), B(25373), B(25374) /    -9.40,  -14.83,    0.00 /
      DATA B(25711), B(25712), B(25713) /    -9.38,  -14.88,    0.00 /
      DATA B(26050), B(26051), B(26052) /    -9.37,  -14.92,    0.00 /
      DATA B(26389), B(26390), B(26391) /    -9.36,  -14.96,    0.00 /
      DATA B(26728), B(26729), B(26730) /    -9.35,  -14.99,    0.00 /
      DATA B(27067), B(27068), B(27069) /    -9.35,  -15.02,    0.00 /
      DATA B(27406), B(27407), B(27408) /    -9.34,  -15.05,    0.00 /
      DATA B(  289), B(  290), B(  291) /    19.13,  -39.37,    0.00 /
      DATA B(  628), B(  629), B(  630) /    18.96,  -39.44,    0.00 /
      DATA B(  967), B(  968), B(  969) /    18.80,  -39.49,    0.00 /
      DATA B( 1306), B( 1307), B( 1308) /    18.62,  -39.52,    0.00 /
      DATA B( 1645), B( 1646), B( 1647) /    18.43,  -39.52,    0.00 /
      DATA B( 1984), B( 1985), B( 1986) /    18.22,  -39.48,    0.00 /
      DATA B( 2323), B( 2324), B( 2325) /    17.99,  -39.41,    0.00 /
      DATA B( 2662), B( 2663), B( 2664) /    17.73,  -39.29,    0.00 /
      DATA B( 3001), B( 3002), B( 3003) /    17.45,  -39.12,    0.00 /
      DATA B( 3340), B( 3341), B( 3342) /    17.13,  -38.91,    0.00 /
      DATA B( 3679), B( 3680), B( 3681) /    16.79,  -38.66,    0.00 /
      DATA B( 4018), B( 4019), B( 4020) /    16.40,  -38.36,    0.00 /
      DATA B( 4357), B( 4358), B( 4359) /    15.95,  -38.00,    0.00 /
      DATA B( 4696), B( 4697), B( 4698) /    15.43,  -37.57,    0.00 /
      DATA B( 5035), B( 5036), B( 5037) /    14.79,  -37.04,    0.00 /
      DATA B( 5374), B( 5375), B( 5376) /    13.99,  -36.39,    0.00 /
      DATA B( 5713), B( 5714), B( 5715) /    13.00,  -35.58,    0.00 /
      DATA B( 6052), B( 6053), B( 6054) /    11.77,  -34.66,    0.00 /
      DATA B( 6391), B( 6392), B( 6393) /    10.49,  -33.92,    0.00 /
      DATA B( 6730), B( 6731), B( 6732) /    -1.16,  -20.32,    0.00 /
      DATA B( 7069), B( 7070), B( 7071) /    -2.57,  -19.68,    0.00 /
      DATA B( 7408), B( 7409), B( 7410) /    -3.54,  -18.28,    0.00 /
      DATA B( 7747), B( 7748), B( 7749) /    -4.22,  -17.26,    0.00 /
      DATA B( 8086), B( 8087), B( 8088) /    -4.96,  -16.58,    0.00 /
      DATA B( 8425), B( 8426), B( 8427) /    -5.65,  -16.00,    0.00 /
      DATA B( 8764), B( 8765), B( 8766) /    -6.21,  -15.58,    0.00 /
      DATA B( 9103), B( 9104), B( 9105) /    -6.70,  -15.21,    0.00 /
      DATA B( 9442), B( 9443), B( 9444) /    -7.08,  -14.78,    0.00 /
      DATA B( 9781), B( 9782), B( 9783) /    -7.33,  -14.32,    0.00 /
      DATA B(10120), B(10121), B(10122) /    -7.47,  -13.95,    0.00 /
      DATA B(10459), B(10460), B(10461) /    -7.58,  -13.71,    0.00 /
      DATA B(10798), B(10799), B(10800) /    -7.67,  -13.56,    0.00 /
      DATA B(11137), B(11138), B(11139) /    -7.76,  -13.49,    0.00 /
      DATA B(11476), B(11477), B(11478) /    -7.84,  -13.46,    0.00 /
      DATA B(11815), B(11816), B(11817) /    -7.92,  -13.46,    0.00 /
      DATA B(12154), B(12155), B(12156) /    -8.00,  -13.48,    0.00 /
      DATA B(12493), B(12494), B(12495) /    -8.06,  -13.50,    0.00 /
      DATA B(12832), B(12833), B(12834) /    -8.13,  -13.52,    0.00 /
      DATA B(13171), B(13172), B(13173) /    -8.18,  -13.53,    0.00 /
      DATA B(13510), B(13511), B(13512) /    -8.23,  -13.53,    0.00 /
      DATA B(13849), B(13850), B(13851) /    -8.27,  -13.52,    0.00 /
      DATA B(14188), B(14189), B(14190) /    -8.29,  -13.51,    0.00 /
      DATA B(14527), B(14528), B(14529) /    -8.31,  -13.50,    0.00 /
      DATA B(14866), B(14867), B(14868) /    -8.33,  -13.49,    0.00 /
      DATA B(15205), B(15206), B(15207) /    -8.33,  -13.48,    0.00 /
      DATA B(15544), B(15545), B(15546) /    -8.33,  -13.48,    0.00 /
      DATA B(15883), B(15884), B(15885) /    -8.33,  -13.48,    0.00 /
      DATA B(16222), B(16223), B(16224) /    -8.33,  -13.50,    0.00 /
      DATA B(16561), B(16562), B(16563) /    -8.32,  -13.51,    0.00 /
      DATA B(16900), B(16901), B(16902) /    -8.31,  -13.54,    0.00 /
      DATA B(17239), B(17240), B(17241) /    -8.30,  -13.58,    0.00 /
      DATA B(17578), B(17579), B(17580) /    -8.29,  -13.62,    0.00 /
      DATA B(17917), B(17918), B(17919) /    -8.27,  -13.67,    0.00 /
      DATA B(18256), B(18257), B(18258) /    -8.25,  -13.73,    0.00 /
      DATA B(18595), B(18596), B(18597) /    -8.22,  -13.81,    0.00 /
      DATA B(18934), B(18935), B(18936) /    -8.19,  -13.90,    0.00 /
      DATA B(19273), B(19274), B(19275) /    -8.15,  -14.01,    0.00 /
      DATA B(19612), B(19613), B(19614) /    -8.10,  -14.15,    0.00 /
      DATA B(19951), B(19952), B(19953) /    -8.04,  -14.32,    0.00 /
      DATA B(20290), B(20291), B(20292) /    -7.96,  -14.55,    0.00 /
      DATA B(20629), B(20630), B(20631) /    -7.88,  -14.83,    0.00 /
      DATA B(20968), B(20969), B(20970) /    -9.02,  -11.02,    0.00 /
      DATA B(21307), B(21308), B(21309) /    -9.08,  -11.55,    0.00 /
      DATA B(21646), B(21647), B(21648) /    -9.38,  -12.09,    0.00 /
      DATA B(21985), B(21986), B(21987) /    -9.69,  -12.62,    0.00 /
      DATA B(22324), B(22325), B(22326) /    -9.80,  -13.13,    0.00 /
      DATA B(22663), B(22664), B(22665) /    -9.78,  -13.55,    0.00 /
      DATA B(23002), B(23003), B(23004) /    -9.70,  -13.88,    0.00 /
      DATA B(23341), B(23342), B(23343) /    -9.63,  -14.12,    0.00 /
      DATA B(23680), B(23681), B(23682) /    -9.57,  -14.31,    0.00 /
      DATA B(24019), B(24020), B(24021) /    -9.51,  -14.45,    0.00 /
      DATA B(24358), B(24359), B(24360) /    -9.47,  -14.56,    0.00 /
      DATA B(24697), B(24698), B(24699) /    -9.44,  -14.65,    0.00 /
      DATA B(25036), B(25037), B(25038) /    -9.41,  -14.73,    0.00 /
      DATA B(25375), B(25376), B(25377) /    -9.39,  -14.79,    0.00 /
      DATA B(25714), B(25715), B(25716) /    -9.38,  -14.84,    0.00 /
      DATA B(26053), B(26054), B(26055) /    -9.36,  -14.89,    0.00 /
      DATA B(26392), B(26393), B(26394) /    -9.35,  -14.93,    0.00 /
      DATA B(26731), B(26732), B(26733) /    -9.34,  -14.96,    0.00 /
      DATA B(27070), B(27071), B(27072) /    -9.34,  -14.99,    0.00 /
      DATA B(27409), B(27410), B(27411) /    -9.33,  -15.02,    0.00 /
      DATA B(  292), B(  293), B(  294) /    18.79,  -39.76,    0.00 /
      DATA B(  631), B(  632), B(  633) /    18.62,  -39.82,    0.00 /
      DATA B(  970), B(  971), B(  972) /    18.44,  -39.86,    0.00 /
      DATA B( 1309), B( 1310), B( 1311) /    18.26,  -39.86,    0.00 /
      DATA B( 1648), B( 1649), B( 1650) /    18.06,  -39.82,    0.00 /
      DATA B( 1987), B( 1988), B( 1989) /    17.84,  -39.74,    0.00 /
      DATA B( 2326), B( 2327), B( 2328) /    17.60,  -39.62,    0.00 /
      DATA B( 2665), B( 2666), B( 2667) /    17.33,  -39.44,    0.00 /
      DATA B( 3004), B( 3005), B( 3006) /    17.02,  -39.22,    0.00 /
      DATA B( 3343), B( 3344), B( 3345) /    16.68,  -38.94,    0.00 /
      DATA B( 3682), B( 3683), B( 3684) /    16.30,  -38.61,    0.00 /
      DATA B( 4021), B( 4022), B( 4023) /    15.86,  -38.21,    0.00 /
      DATA B( 4360), B( 4361), B( 4362) /    15.35,  -37.74,    0.00 /
      DATA B( 4699), B( 4700), B( 4701) /    14.73,  -37.15,    0.00 /
      DATA B( 5038), B( 5039), B( 5040) /    13.98,  -36.44,    0.00 /
      DATA B( 5377), B( 5378), B( 5379) /    13.02,  -35.54,    0.00 /
      DATA B( 5716), B( 5717), B( 5718) /    11.78,  -34.47,    0.00 /
      DATA B( 6055), B( 6056), B( 6057) /    10.44,  -33.20,    0.00 /
      DATA B( 6394), B( 6395), B( 6396) /    -0.35,  -20.99,    0.00 /
      DATA B( 6733), B( 6734), B( 6735) /    -1.76,  -19.08,    0.00 /
      DATA B( 7072), B( 7073), B( 7074) /    -3.17,  -18.09,    0.00 /
      DATA B( 7411), B( 7412), B( 7413) /    -4.26,  -17.18,    0.00 /
      DATA B( 7750), B( 7751), B( 7752) /    -5.01,  -16.40,    0.00 /
      DATA B( 8089), B( 8090), B( 8091) /    -5.61,  -15.82,    0.00 /
      DATA B( 8428), B( 8429), B( 8430) /    -6.12,  -15.37,    0.00 /
      DATA B( 8767), B( 8768), B( 8769) /    -6.56,  -15.02,    0.00 /
      DATA B( 9106), B( 9107), B( 9108) /    -6.93,  -14.71,    0.00 /
      DATA B( 9445), B( 9446), B( 9447) /    -7.24,  -14.39,    0.00 /
      DATA B( 9784), B( 9785), B( 9786) /    -7.45,  -14.07,    0.00 /
      DATA B(10123), B(10124), B(10125) /    -7.60,  -13.80,    0.00 /
      DATA B(10462), B(10463), B(10464) /    -7.70,  -13.61,    0.00 /
      DATA B(10801), B(10802), B(10803) /    -7.78,  -13.48,    0.00 /
      DATA B(11140), B(11141), B(11142) /    -7.85,  -13.41,    0.00 /
      DATA B(11479), B(11480), B(11481) /    -7.92,  -13.38,    0.00 /
      DATA B(11818), B(11819), B(11820) /    -7.99,  -13.37,    0.00 /
      DATA B(12157), B(12158), B(12159) /    -8.05,  -13.38,    0.00 /
      DATA B(12496), B(12497), B(12498) /    -8.11,  -13.40,    0.00 /
      DATA B(12835), B(12836), B(12837) /    -8.16,  -13.41,    0.00 /
      DATA B(13174), B(13175), B(13176) /    -8.21,  -13.42,    0.00 /
      DATA B(13513), B(13514), B(13515) /    -8.25,  -13.43,    0.00 /
      DATA B(13852), B(13853), B(13854) /    -8.28,  -13.43,    0.00 /
      DATA B(14191), B(14192), B(14193) /    -8.31,  -13.42,    0.00 /
      DATA B(14530), B(14531), B(14532) /    -8.33,  -13.42,    0.00 /
      DATA B(14869), B(14870), B(14871) /    -8.34,  -13.41,    0.00 /
      DATA B(15208), B(15209), B(15210) /    -8.35,  -13.41,    0.00 /
      DATA B(15547), B(15548), B(15549) /    -8.35,  -13.42,    0.00 /
      DATA B(15886), B(15887), B(15888) /    -8.35,  -13.42,    0.00 /
      DATA B(16225), B(16226), B(16227) /    -8.35,  -13.44,    0.00 /
      DATA B(16564), B(16565), B(16566) /    -8.34,  -13.45,    0.00 /
      DATA B(16903), B(16904), B(16905) /    -8.33,  -13.48,    0.00 /
      DATA B(17242), B(17243), B(17244) /    -8.32,  -13.51,    0.00 /
      DATA B(17581), B(17582), B(17583) /    -8.31,  -13.55,    0.00 /
      DATA B(17920), B(17921), B(17922) /    -8.29,  -13.60,    0.00 /
      DATA B(18259), B(18260), B(18261) /    -8.27,  -13.66,    0.00 /
      DATA B(18598), B(18599), B(18600) /    -8.25,  -13.73,    0.00 /
      DATA B(18937), B(18938), B(18939) /    -8.22,  -13.81,    0.00 /
      DATA B(19276), B(19277), B(19278) /    -8.18,  -13.90,    0.00 /
      DATA B(19615), B(19616), B(19617) /    -8.14,  -14.02,    0.00 /
      DATA B(19954), B(19955), B(19956) /    -8.08,  -14.17,    0.00 /
      DATA B(20293), B(20294), B(20295) /    -8.01,  -14.37,    0.00 /
      DATA B(20632), B(20633), B(20634) /    -7.93,  -14.62,    0.00 /
      DATA B(20971), B(20972), B(20973) /    -8.12,  -17.41,    0.00 /
      DATA B(21310), B(21311), B(21312) /    -9.02,  -11.26,    0.00 /
      DATA B(21649), B(21650), B(21651) /    -9.19,  -11.81,    0.00 /
      DATA B(21988), B(21989), B(21990) /    -9.52,  -12.34,    0.00 /
      DATA B(22327), B(22328), B(22329) /    -9.75,  -12.86,    0.00 /
      DATA B(22666), B(22667), B(22668) /    -9.79,  -13.33,    0.00 /
      DATA B(23005), B(23006), B(23007) /    -9.73,  -13.71,    0.00 /
      DATA B(23344), B(23345), B(23346) /    -9.65,  -13.99,    0.00 /
      DATA B(23683), B(23684), B(23685) /    -9.58,  -14.21,    0.00 /
      DATA B(24022), B(24023), B(24024) /    -9.53,  -14.37,    0.00 /
      DATA B(24361), B(24362), B(24363) /    -9.48,  -14.50,    0.00 /
      DATA B(24700), B(24701), B(24702) /    -9.44,  -14.60,    0.00 /
      DATA B(25039), B(25040), B(25041) /    -9.41,  -14.68,    0.00 /
      DATA B(25378), B(25379), B(25380) /    -9.39,  -14.75,    0.00 /
      DATA B(25717), B(25718), B(25719) /    -9.37,  -14.80,    0.00 /
      DATA B(26056), B(26057), B(26058) /    -9.35,  -14.85,    0.00 /
      DATA B(26395), B(26396), B(26397) /    -9.34,  -14.90,    0.00 /
      DATA B(26734), B(26735), B(26736) /    -9.33,  -14.93,    0.00 /
      DATA B(27073), B(27074), B(27075) /    -9.32,  -14.97,    0.00 /
      DATA B(27412), B(27413), B(27414) /    -9.32,  -15.00,    0.00 /
      DATA B(  295), B(  296), B(  297) /    18.44,  -40.16,    0.00 /
      DATA B(  634), B(  635), B(  636) /    18.26,  -40.21,    0.00 /
      DATA B(  973), B(  974), B(  975) /    18.08,  -40.23,    0.00 /
      DATA B( 1312), B( 1313), B( 1314) /    17.88,  -40.20,    0.00 /
      DATA B( 1651), B( 1652), B( 1653) /    17.68,  -40.13,    0.00 /
      DATA B( 1990), B( 1991), B( 1992) /    17.45,  -40.00,    0.00 /
      DATA B( 2329), B( 2330), B( 2331) /    17.19,  -39.82,    0.00 /
      DATA B( 2668), B( 2669), B( 2670) /    16.90,  -39.57,    0.00 /
      DATA B( 3007), B( 3008), B( 3009) /    16.57,  -39.27,    0.00 /
      DATA B( 3346), B( 3347), B( 3348) /    16.19,  -38.91,    0.00 /
      DATA B( 3685), B( 3686), B( 3687) /    15.75,  -38.48,    0.00 /
      DATA B( 4024), B( 4025), B( 4026) /    15.23,  -37.96,    0.00 /
      DATA B( 4363), B( 4364), B( 4365) /    14.62,  -37.33,    0.00 /
      DATA B( 4702), B( 4703), B( 4704) /    13.86,  -36.55,    0.00 /
      DATA B( 5041), B( 5042), B( 5043) /    12.90,  -35.56,    0.00 /
      DATA B( 5380), B( 5381), B( 5382) /    11.64,  -34.33,    0.00 /
      DATA B( 5719), B( 5720), B( 5721) /    10.02,  -32.80,    0.00 /
      DATA B( 6058), B( 6059), B( 6060) /     1.00,  -22.99,    0.00 /
      DATA B( 6397), B( 6398), B( 6399) /    -0.80,  -19.81,    0.00 /
      DATA B( 6736), B( 6737), B( 6738) /    -2.47,  -18.01,    0.00 /
      DATA B( 7075), B( 7076), B( 7077) /    -3.79,  -17.01,    0.00 /
      DATA B( 7414), B( 7415), B( 7416) /    -4.78,  -16.30,    0.00 /
      DATA B( 7753), B( 7754), B( 7755) /    -5.50,  -15.72,    0.00 /
      DATA B( 8092), B( 8093), B( 8094) /    -6.03,  -15.26,    0.00 /
      DATA B( 8431), B( 8432), B( 8433) /    -6.46,  -14.89,    0.00 /
      DATA B( 8770), B( 8771), B( 8772) /    -6.82,  -14.60,    0.00 /
      DATA B( 9109), B( 9110), B( 9111) /    -7.12,  -14.34,    0.00 /
      DATA B( 9448), B( 9449), B( 9450) /    -7.36,  -14.10,    0.00 /
      DATA B( 9787), B( 9788), B( 9789) /    -7.55,  -13.87,    0.00 /
      DATA B(10126), B(10127), B(10128) /    -7.69,  -13.67,    0.00 /
      DATA B(10465), B(10466), B(10467) /    -7.79,  -13.51,    0.00 /
      DATA B(10804), B(10805), B(10806) /    -7.86,  -13.40,    0.00 /
      DATA B(11143), B(11144), B(11145) /    -7.93,  -13.34,    0.00 /
      DATA B(11482), B(11483), B(11484) /    -7.99,  -13.31,    0.00 /
      DATA B(11821), B(11822), B(11823) /    -8.04,  -13.30,    0.00 /
      DATA B(12160), B(12161), B(12162) /    -8.09,  -13.30,    0.00 /
      DATA B(12499), B(12500), B(12501) /    -8.14,  -13.31,    0.00 /
      DATA B(12838), B(12839), B(12840) /    -8.19,  -13.33,    0.00 /
      DATA B(13177), B(13178), B(13179) /    -8.23,  -13.34,    0.00 /
      DATA B(13516), B(13517), B(13518) /    -8.27,  -13.34,    0.00 /
      DATA B(13855), B(13856), B(13857) /    -8.30,  -13.35,    0.00 /
      DATA B(14194), B(14195), B(14196) /    -8.32,  -13.35,    0.00 /
      DATA B(14533), B(14534), B(14535) /    -8.34,  -13.35,    0.00 /
      DATA B(14872), B(14873), B(14874) /    -8.35,  -13.35,    0.00 /
      DATA B(15211), B(15212), B(15213) /    -8.36,  -13.35,    0.00 /
      DATA B(15550), B(15551), B(15552) /    -8.36,  -13.36,    0.00 /
      DATA B(15889), B(15890), B(15891) /    -8.36,  -13.37,    0.00 /
      DATA B(16228), B(16229), B(16230) /    -8.36,  -13.38,    0.00 /
      DATA B(16567), B(16568), B(16569) /    -8.36,  -13.40,    0.00 /
      DATA B(16906), B(16907), B(16908) /    -8.35,  -13.42,    0.00 /
      DATA B(17245), B(17246), B(17247) /    -8.34,  -13.45,    0.00 /
      DATA B(17584), B(17585), B(17586) /    -8.33,  -13.49,    0.00 /
      DATA B(17923), B(17924), B(17925) /    -8.31,  -13.54,    0.00 /
      DATA B(18262), B(18263), B(18264) /    -8.30,  -13.59,    0.00 /
      DATA B(18601), B(18602), B(18603) /    -8.27,  -13.65,    0.00 /
      DATA B(18940), B(18941), B(18942) /    -8.25,  -13.72,    0.00 /
      DATA B(19279), B(19280), B(19281) /    -8.21,  -13.81,    0.00 /
      DATA B(19618), B(19619), B(19620) /    -8.17,  -13.91,    0.00 /
      DATA B(19957), B(19958), B(19959) /    -8.12,  -14.04,    0.00 /
      DATA B(20296), B(20297), B(20298) /    -8.06,  -14.21,    0.00 /
      DATA B(20635), B(20636), B(20637) /    -7.98,  -14.42,    0.00 /
      DATA B(20974), B(20975), B(20976) /    -7.89,  -14.71,    0.00 /
      DATA B(21313), B(21314), B(21315) /    -8.98,  -11.00,    0.00 /
      DATA B(21652), B(21653), B(21654) /    -9.06,  -11.52,    0.00 /
      DATA B(21991), B(21992), B(21993) /    -9.33,  -12.06,    0.00 /
      DATA B(22330), B(22331), B(22332) /    -9.64,  -12.58,    0.00 /
      DATA B(22669), B(22670), B(22671) /    -9.77,  -13.08,    0.00 /
      DATA B(23008), B(23009), B(23010) /    -9.75,  -13.51,    0.00 /
      DATA B(23347), B(23348), B(23349) /    -9.68,  -13.85,    0.00 /
      DATA B(23686), B(23687), B(23688) /    -9.60,  -14.09,    0.00 /
      DATA B(24025), B(24026), B(24027) /    -9.54,  -14.28,    0.00 /
      DATA B(24364), B(24365), B(24366) /    -9.49,  -14.43,    0.00 /
      DATA B(24703), B(24704), B(24705) /    -9.44,  -14.54,    0.00 /
      DATA B(25042), B(25043), B(25044) /    -9.41,  -14.63,    0.00 /
      DATA B(25381), B(25382), B(25383) /    -9.38,  -14.70,    0.00 /
      DATA B(25720), B(25721), B(25722) /    -9.36,  -14.77,    0.00 /
      DATA B(26059), B(26060), B(26061) /    -9.34,  -14.82,    0.00 /
      DATA B(26398), B(26399), B(26400) /    -9.33,  -14.87,    0.00 /
      DATA B(26737), B(26738), B(26739) /    -9.32,  -14.91,    0.00 /
      DATA B(27076), B(27077), B(27078) /    -9.31,  -14.94,    0.00 /
      DATA B(27415), B(27416), B(27417) /    -9.31,  -14.98,    0.00 /
      DATA B(  298), B(  299), B(  300) /    18.07,  -40.56,    0.00 /
      DATA B(  637), B(  638), B(  639) /    17.89,  -40.61,    0.00 /
      DATA B(  976), B(  977), B(  978) /    17.70,  -40.61,    0.00 /
      DATA B( 1315), B( 1316), B( 1317) /    17.50,  -40.55,    0.00 /
      DATA B( 1654), B( 1655), B( 1656) /    17.28,  -40.43,    0.00 /
      DATA B( 1993), B( 1994), B( 1995) /    17.04,  -40.25,    0.00 /
      DATA B( 2332), B( 2333), B( 2334) /    16.77,  -40.00,    0.00 /
      DATA B( 2671), B( 2672), B( 2673) /    16.45,  -39.67,    0.00 /
      DATA B( 3010), B( 3011), B( 3012) /    16.07,  -39.27,    0.00 /
      DATA B( 3349), B( 3350), B( 3351) /    15.63,  -38.80,    0.00 /
      DATA B( 3688), B( 3689), B( 3690) /    15.12,  -38.24,    0.00 /
      DATA B( 4027), B( 4028), B( 4029) /    14.50,  -37.57,    0.00 /
      DATA B( 4366), B( 4367), B( 4368) /    13.73,  -36.73,    0.00 /
      DATA B( 4705), B( 4706), B( 4707) /    12.75,  -35.68,    0.00 /
      DATA B( 5044), B( 5045), B( 5046) /    11.46,  -34.31,    0.00 /
      DATA B( 5383), B( 5384), B( 5385) /     9.72,  -32.59,    0.00 /
      DATA B( 5722), B( 5723), B( 5724) /     7.37,  -30.77,    0.00 /
      DATA B( 6061), B( 6062), B( 6063) /     0.46,  -21.47,    0.00 /
      DATA B( 6400), B( 6401), B( 6402) /    -1.71,  -18.76,    0.00 /
      DATA B( 6739), B( 6740), B( 6741) /    -3.25,  -17.12,    0.00 /
      DATA B( 7078), B( 7079), B( 7080) /    -4.39,  -16.22,    0.00 /
      DATA B( 7417), B( 7418), B( 7419) /    -5.24,  -15.64,    0.00 /
      DATA B( 7756), B( 7757), B( 7758) /    -5.87,  -15.19,    0.00 /
      DATA B( 8095), B( 8096), B( 8097) /    -6.35,  -14.82,    0.00 /
      DATA B( 8434), B( 8435), B( 8436) /    -6.72,  -14.52,    0.00 /
      DATA B( 8773), B( 8774), B( 8775) /    -7.02,  -14.28,    0.00 /
      DATA B( 9112), B( 9113), B( 9114) /    -7.27,  -14.07,    0.00 /
      DATA B( 9451), B( 9452), B( 9453) /    -7.48,  -13.87,    0.00 /
      DATA B( 9790), B( 9791), B( 9792) /    -7.64,  -13.69,    0.00 /
      DATA B(10129), B(10130), B(10131) /    -7.76,  -13.54,    0.00 /
      DATA B(10468), B(10469), B(10470) /    -7.85,  -13.42,    0.00 /
      DATA B(10807), B(10808), B(10809) /    -7.93,  -13.33,    0.00 /
      DATA B(11146), B(11147), B(11148) /    -7.99,  -13.27,    0.00 /
      DATA B(11485), B(11486), B(11487) /    -8.04,  -13.24,    0.00 /
      DATA B(11824), B(11825), B(11826) /    -8.09,  -13.23,    0.00 /
      DATA B(12163), B(12164), B(12165) /    -8.13,  -13.23,    0.00 /
      DATA B(12502), B(12503), B(12504) /    -8.18,  -13.24,    0.00 /
      DATA B(12841), B(12842), B(12843) /    -8.21,  -13.25,    0.00 /
      DATA B(13180), B(13181), B(13182) /    -8.25,  -13.26,    0.00 /
      DATA B(13519), B(13520), B(13521) /    -8.28,  -13.27,    0.00 /
      DATA B(13858), B(13859), B(13860) /    -8.31,  -13.27,    0.00 /
      DATA B(14197), B(14198), B(14199) /    -8.33,  -13.28,    0.00 /
      DATA B(14536), B(14537), B(14538) /    -8.35,  -13.28,    0.00 /
      DATA B(14875), B(14876), B(14877) /    -8.36,  -13.29,    0.00 /
      DATA B(15214), B(15215), B(15216) /    -8.37,  -13.29,    0.00 /
      DATA B(15553), B(15554), B(15555) /    -8.37,  -13.30,    0.00 /
      DATA B(15892), B(15893), B(15894) /    -8.37,  -13.31,    0.00 /
      DATA B(16231), B(16232), B(16233) /    -8.37,  -13.33,    0.00 /
      DATA B(16570), B(16571), B(16572) /    -8.37,  -13.35,    0.00 /
      DATA B(16909), B(16910), B(16911) /    -8.36,  -13.37,    0.00 /
      DATA B(17248), B(17249), B(17250) /    -8.35,  -13.40,    0.00 /
      DATA B(17587), B(17588), B(17589) /    -8.34,  -13.44,    0.00 /
      DATA B(17926), B(17927), B(17928) /    -8.33,  -13.48,    0.00 /
      DATA B(18265), B(18266), B(18267) /    -8.31,  -13.52,    0.00 /
      DATA B(18604), B(18605), B(18606) /    -8.29,  -13.58,    0.00 /
      DATA B(18943), B(18944), B(18945) /    -8.27,  -13.65,    0.00 /
      DATA B(19282), B(19283), B(19284) /    -8.24,  -13.72,    0.00 /
      DATA B(19621), B(19622), B(19623) /    -8.20,  -13.82,    0.00 /
      DATA B(19960), B(19961), B(19962) /    -8.16,  -13.93,    0.00 /
      DATA B(20299), B(20300), B(20301) /    -8.10,  -14.07,    0.00 /
      DATA B(20638), B(20639), B(20640) /    -8.03,  -14.26,    0.00 /
      DATA B(20977), B(20978), B(20979) /    -7.95,  -14.49,    0.00 /
      DATA B(21316), B(21317), B(21318) /    -7.89,  -14.81,    0.00 /
      DATA B(21655), B(21656), B(21657) /    -9.01,  -11.26,    0.00 /
      DATA B(21994), B(21995), B(21996) /    -9.15,  -11.78,    0.00 /
      DATA B(22333), B(22334), B(22335) /    -9.47,  -12.31,    0.00 /
      DATA B(22672), B(22673), B(22674) /    -9.71,  -12.82,    0.00 /
      DATA B(23011), B(23012), B(23013) /    -9.76,  -13.30,    0.00 /
      DATA B(23350), B(23351), B(23352) /    -9.70,  -13.68,    0.00 /
      DATA B(23689), B(23690), B(23691) /    -9.62,  -13.97,    0.00 /
      DATA B(24028), B(24029), B(24030) /    -9.55,  -14.18,    0.00 /
      DATA B(24367), B(24368), B(24369) /    -9.49,  -14.35,    0.00 /
      DATA B(24706), B(24707), B(24708) /    -9.45,  -14.48,    0.00 /
      DATA B(25045), B(25046), B(25047) /    -9.41,  -14.58,    0.00 /
      DATA B(25384), B(25385), B(25386) /    -9.38,  -14.66,    0.00 /
      DATA B(25723), B(25724), B(25725) /    -9.35,  -14.73,    0.00 /
      DATA B(26062), B(26063), B(26064) /    -9.34,  -14.78,    0.00 /
      DATA B(26401), B(26402), B(26403) /    -9.32,  -14.83,    0.00 /
      DATA B(26740), B(26741), B(26742) /    -9.31,  -14.88,    0.00 /
      DATA B(27079), B(27080), B(27081) /    -9.30,  -14.92,    0.00 /
      DATA B(27418), B(27419), B(27420) /    -9.29,  -14.95,    0.00 /
      DATA B(  301), B(  302), B(  303) /    17.70,  -40.97,    0.00 /
      DATA B(  640), B(  641), B(  642) /    17.51,  -41.01,    0.00 /
      DATA B(  979), B(  980), B(  981) /    17.31,  -40.99,    0.00 /
      DATA B( 1318), B( 1319), B( 1320) /    17.10,  -40.91,    0.00 /
      DATA B( 1657), B( 1658), B( 1659) /    16.87,  -40.74,    0.00 /
      DATA B( 1996), B( 1997), B( 1998) /    16.62,  -40.49,    0.00 /
      DATA B( 2335), B( 2336), B( 2337) /    16.32,  -40.15,    0.00 /
      DATA B( 2674), B( 2675), B( 2676) /    15.96,  -39.72,    0.00 /
      DATA B( 3013), B( 3014), B( 3015) /    15.53,  -39.20,    0.00 /
      DATA B( 3352), B( 3353), B( 3354) /    15.01,  -38.59,    0.00 /
      DATA B( 3691), B( 3692), B( 3693) /    14.39,  -37.86,    0.00 /
      DATA B( 4030), B( 4031), B( 4032) /    13.61,  -36.98,    0.00 /
      DATA B( 4369), B( 4370), B( 4371) /    12.62,  -35.87,    0.00 /
      DATA B( 4708), B( 4709), B( 4710) /    11.30,  -34.46,    0.00 /
      DATA B( 5047), B( 5048), B( 5049) /     9.50,  -32.61,    0.00 /
      DATA B( 5386), B( 5387), B( 5388) /     7.22,  -30.32,    0.00 /
      DATA B( 5725), B( 5726), B( 5727) /     1.61,  -23.69,    0.00 /
      DATA B( 6064), B( 6065), B( 6066) /    -0.90,  -20.13,    0.00 /
      DATA B( 6403), B( 6404), B( 6405) /    -2.71,  -17.77,    0.00 /
      DATA B( 6742), B( 6743), B( 6744) /    -4.02,  -16.41,    0.00 /
      DATA B( 7081), B( 7082), B( 7083) /    -4.96,  -15.64,    0.00 /
      DATA B( 7420), B( 7421), B( 7422) /    -5.66,  -15.14,    0.00 /
      DATA B( 7759), B( 7760), B( 7761) /    -6.20,  -14.77,    0.00 /
      DATA B( 8098), B( 8099), B( 8100) /    -6.61,  -14.48,    0.00 /
      DATA B( 8437), B( 8438), B( 8439) /    -6.93,  -14.23,    0.00 /
      DATA B( 8776), B( 8777), B( 8778) /    -7.19,  -14.03,    0.00 /
      DATA B( 9115), B( 9116), B( 9117) /    -7.40,  -13.85,    0.00 /
      DATA B( 9454), B( 9455), B( 9456) /    -7.58,  -13.69,    0.00 /
      DATA B( 9793), B( 9794), B( 9795) /    -7.72,  -13.55,    0.00 /
      DATA B(10132), B(10133), B(10134) /    -7.83,  -13.43,    0.00 /
      DATA B(10471), B(10472), B(10473) /    -7.91,  -13.33,    0.00 /
      DATA B(10810), B(10811), B(10812) /    -7.98,  -13.26,    0.00 /
      DATA B(11149), B(11150), B(11151) /    -8.04,  -13.21,    0.00 /
      DATA B(11488), B(11489), B(11490) /    -8.08,  -13.18,    0.00 /
      DATA B(11827), B(11828), B(11829) /    -8.13,  -13.17,    0.00 /
      DATA B(12166), B(12167), B(12168) /    -8.17,  -13.17,    0.00 /
      DATA B(12505), B(12506), B(12507) /    -8.20,  -13.18,    0.00 /
      DATA B(12844), B(12845), B(12846) /    -8.24,  -13.18,    0.00 /
      DATA B(13183), B(13184), B(13185) /    -8.27,  -13.19,    0.00 /
      DATA B(13522), B(13523), B(13524) /    -8.30,  -13.20,    0.00 /
      DATA B(13861), B(13862), B(13863) /    -8.32,  -13.21,    0.00 /
      DATA B(14200), B(14201), B(14202) /    -8.34,  -13.22,    0.00 /
      DATA B(14539), B(14540), B(14541) /    -8.36,  -13.23,    0.00 /
      DATA B(14878), B(14879), B(14880) /    -8.37,  -13.23,    0.00 /
      DATA B(15217), B(15218), B(15219) /    -8.38,  -13.24,    0.00 /
      DATA B(15556), B(15557), B(15558) /    -8.38,  -13.25,    0.00 /
      DATA B(15895), B(15896), B(15897) /    -8.38,  -13.26,    0.00 /
      DATA B(16234), B(16235), B(16236) /    -8.38,  -13.28,    0.00 /
      DATA B(16573), B(16574), B(16575) /    -8.38,  -13.30,    0.00 /
      DATA B(16912), B(16913), B(16914) /    -8.37,  -13.32,    0.00 /
      DATA B(17251), B(17252), B(17253) /    -8.37,  -13.35,    0.00 /
      DATA B(17590), B(17591), B(17592) /    -8.36,  -13.38,    0.00 /
      DATA B(17929), B(17930), B(17931) /    -8.34,  -13.42,    0.00 /
      DATA B(18268), B(18269), B(18270) /    -8.33,  -13.47,    0.00 /
      DATA B(18607), B(18608), B(18609) /    -8.31,  -13.52,    0.00 /
      DATA B(18946), B(18947), B(18948) /    -8.29,  -13.58,    0.00 /
      DATA B(19285), B(19286), B(19287) /    -8.26,  -13.65,    0.00 /
      DATA B(19624), B(19625), B(19626) /    -8.23,  -13.73,    0.00 /
      DATA B(19963), B(19964), B(19965) /    -8.19,  -13.83,    0.00 /
      DATA B(20302), B(20303), B(20304) /    -8.13,  -13.95,    0.00 /
      DATA B(20641), B(20642), B(20643) /    -8.07,  -14.11,    0.00 /
      DATA B(20980), B(20981), B(20982) /    -8.00,  -14.32,    0.00 /
      DATA B(21319), B(21320), B(21321) /    -7.92,  -14.58,    0.00 /
      DATA B(21658), B(21659), B(21660) /    -9.00,  -11.02,    0.00 /
      DATA B(21997), B(21998), B(21999) /    -9.04,  -11.51,    0.00 /
      DATA B(22336), B(22337), B(22338) /    -9.27,  -12.04,    0.00 /
      DATA B(22675), B(22676), B(22677) /    -9.59,  -12.56,    0.00 /
      DATA B(23014), B(23015), B(23016) /    -9.73,  -13.06,    0.00 /
      DATA B(23353), B(23354), B(23355) /    -9.72,  -13.49,    0.00 /
      DATA B(23692), B(23693), B(23694) /    -9.65,  -13.82,    0.00 /
      DATA B(24031), B(24032), B(24033) /    -9.57,  -14.07,    0.00 /
      DATA B(24370), B(24371), B(24372) /    -9.50,  -14.26,    0.00 /
      DATA B(24709), B(24710), B(24711) /    -9.45,  -14.41,    0.00 /
      DATA B(25048), B(25049), B(25050) /    -9.41,  -14.52,    0.00 /
      DATA B(25387), B(25388), B(25389) /    -9.37,  -14.61,    0.00 /
      DATA B(25726), B(25727), B(25728) /    -9.35,  -14.69,    0.00 /
      DATA B(26065), B(26066), B(26067) /    -9.33,  -14.75,    0.00 /
      DATA B(26404), B(26405), B(26406) /    -9.31,  -14.80,    0.00 /
      DATA B(26743), B(26744), B(26745) /    -9.30,  -14.85,    0.00 /
      DATA B(27082), B(27083), B(27084) /    -9.29,  -14.89,    0.00 /
      DATA B(27421), B(27422), B(27423) /    -9.28,  -14.93,    0.00 /
      DATA B(  304), B(  305), B(  306) /    17.32,  -41.39,    0.00 /
      DATA B(  643), B(  644), B(  645) /    17.11,  -41.42,    0.00 /
      DATA B(  982), B(  983), B(  984) /    16.90,  -41.39,    0.00 /
      DATA B( 1321), B( 1322), B( 1323) /    16.68,  -41.28,    0.00 /
      DATA B( 1660), B( 1661), B( 1662) /    16.44,  -41.06,    0.00 /
      DATA B( 1999), B( 2000), B( 2001) /    16.17,  -40.72,    0.00 /
      DATA B( 2338), B( 2339), B( 2340) /    15.84,  -40.27,    0.00 /
      DATA B( 2677), B( 2678), B( 2679) /    15.43,  -39.70,    0.00 /
      DATA B( 3016), B( 3017), B( 3018) /    14.92,  -39.03,    0.00 /
      DATA B( 3355), B( 3356), B( 3357) /    14.30,  -38.23,    0.00 /
      DATA B( 3694), B( 3695), B( 3696) /    13.52,  -37.29,    0.00 /
      DATA B( 4033), B( 4034), B( 4035) /    12.52,  -36.13,    0.00 /
      DATA B( 4372), B( 4373), B( 4374) /    11.20,  -34.68,    0.00 /
      DATA B( 4711), B( 4712), B( 4713) /     9.38,  -32.83,    0.00 /
      DATA B( 5050), B( 5051), B( 5052) /     6.93,  -30.41,    0.00 /
      DATA B( 5389), B( 5390), B( 5391) /     3.87,  -27.82,    0.00 /
      DATA B( 5728), B( 5729), B( 5730) /    -0.18,  -21.85,    0.00 /
      DATA B( 6067), B( 6068), B( 6069) /    -2.26,  -18.84,    0.00 /
      DATA B( 6406), B( 6407), B( 6408) /    -3.73,  -16.96,    0.00 /
      DATA B( 6745), B( 6746), B( 6747) /    -4.75,  -15.85,    0.00 /
      DATA B( 7084), B( 7085), B( 7086) /    -5.50,  -15.19,    0.00 /
      DATA B( 7423), B( 7424), B( 7425) /    -6.06,  -14.76,    0.00 /
      DATA B( 7762), B( 7763), B( 7764) /    -6.50,  -14.45,    0.00 /
      DATA B( 8101), B( 8102), B( 8103) /    -6.84,  -14.20,    0.00 /
      DATA B( 8440), B( 8441), B( 8442) /    -7.12,  -13.99,    0.00 /
      DATA B( 8779), B( 8780), B( 8781) /    -7.34,  -13.82,    0.00 /
      DATA B( 9118), B( 9119), B( 9120) /    -7.52,  -13.67,    0.00 /
      DATA B( 9457), B( 9458), B( 9459) /    -7.67,  -13.54,    0.00 /
      DATA B( 9796), B( 9797), B( 9798) /    -7.79,  -13.43,    0.00 /
      DATA B(10135), B(10136), B(10137) /    -7.89,  -13.33,    0.00 /
      DATA B(10474), B(10475), B(10476) /    -7.97,  -13.25,    0.00 /
      DATA B(10813), B(10814), B(10815) /    -8.03,  -13.20,    0.00 /
      DATA B(11152), B(11153), B(11154) /    -8.08,  -13.15,    0.00 /
      DATA B(11491), B(11492), B(11493) /    -8.12,  -13.13,    0.00 /
      DATA B(11830), B(11831), B(11832) /    -8.16,  -13.12,    0.00 /
      DATA B(12169), B(12170), B(12171) /    -8.20,  -13.12,    0.00 /
      DATA B(12508), B(12509), B(12510) /    -8.23,  -13.12,    0.00 /
      DATA B(12847), B(12848), B(12849) /    -8.26,  -13.13,    0.00 /
      DATA B(13186), B(13187), B(13188) /    -8.29,  -13.14,    0.00 /
      DATA B(13525), B(13526), B(13527) /    -8.31,  -13.15,    0.00 /
      DATA B(13864), B(13865), B(13866) /    -8.33,  -13.15,    0.00 /
      DATA B(14203), B(14204), B(14205) /    -8.35,  -13.16,    0.00 /
      DATA B(14542), B(14543), B(14544) /    -8.36,  -13.17,    0.00 /
      DATA B(14881), B(14882), B(14883) /    -8.38,  -13.18,    0.00 /
      DATA B(15220), B(15221), B(15222) /    -8.38,  -13.19,    0.00 /
      DATA B(15559), B(15560), B(15561) /    -8.39,  -13.20,    0.00 /
      DATA B(15898), B(15899), B(15900) /    -8.39,  -13.22,    0.00 /
      DATA B(16237), B(16238), B(16239) /    -8.39,  -13.24,    0.00 /
      DATA B(16576), B(16577), B(16578) /    -8.39,  -13.26,    0.00 /
      DATA B(16915), B(16916), B(16917) /    -8.38,  -13.28,    0.00 /
      DATA B(17254), B(17255), B(17256) /    -8.37,  -13.31,    0.00 /
      DATA B(17593), B(17594), B(17595) /    -8.37,  -13.34,    0.00 /
      DATA B(17932), B(17933), B(17934) /    -8.35,  -13.37,    0.00 /
      DATA B(18271), B(18272), B(18273) /    -8.34,  -13.41,    0.00 /
      DATA B(18610), B(18611), B(18612) /    -8.32,  -13.46,    0.00 /
      DATA B(18949), B(18950), B(18951) /    -8.30,  -13.51,    0.00 /
      DATA B(19288), B(19289), B(19290) /    -8.28,  -13.58,    0.00 /
      DATA B(19627), B(19628), B(19629) /    -8.25,  -13.65,    0.00 /
      DATA B(19966), B(19967), B(19968) /    -8.21,  -13.74,    0.00 /
      DATA B(20305), B(20306), B(20307) /    -8.17,  -13.85,    0.00 /
      DATA B(20644), B(20645), B(20646) /    -8.11,  -13.99,    0.00 /
      DATA B(20983), B(20984), B(20985) /    -8.04,  -14.16,    0.00 /
      DATA B(21322), B(21323), B(21324) /    -7.96,  -14.39,    0.00 /
      DATA B(21661), B(21662), B(21663) /    -7.86,  -14.69,    0.00 /
      DATA B(22000), B(22001), B(22002) /    -8.98,  -11.26,    0.00 /
      DATA B(22339), B(22340), B(22341) /    -9.11,  -11.77,    0.00 /
      DATA B(22678), B(22679), B(22680) /    -9.41,  -12.30,    0.00 /
      DATA B(23017), B(23018), B(23019) /    -9.66,  -12.81,    0.00 /
      DATA B(23356), B(23357), B(23358) /    -9.71,  -13.28,    0.00 /
      DATA B(23695), B(23696), B(23697) /    -9.66,  -13.66,    0.00 /
      DATA B(24034), B(24035), B(24036) /    -9.59,  -13.95,    0.00 /
      DATA B(24373), B(24374), B(24375) /    -9.52,  -14.17,    0.00 /
      DATA B(24712), B(24713), B(24714) /    -9.46,  -14.33,    0.00 /
      DATA B(25051), B(25052), B(25053) /    -9.41,  -14.46,    0.00 /
      DATA B(25390), B(25391), B(25392) /    -9.37,  -14.56,    0.00 /
      DATA B(25729), B(25730), B(25731) /    -9.34,  -14.64,    0.00 /
      DATA B(26068), B(26069), B(26070) /    -9.32,  -14.71,    0.00 /
      DATA B(26407), B(26408), B(26409) /    -9.30,  -14.77,    0.00 /
      DATA B(26746), B(26747), B(26748) /    -9.28,  -14.82,    0.00 /
      DATA B(27085), B(27086), B(27087) /    -9.27,  -14.86,    0.00 /
      DATA B(27424), B(27425), B(27426) /    -9.26,  -14.90,    0.00 /
      DATA B(  307), B(  308), B(  309) /    16.92,  -41.82,    0.00 /
      DATA B(  646), B(  647), B(  648) /    16.69,  -41.85,    0.00 /
      DATA B(  985), B(  986), B(  987) /    16.47,  -41.81,    0.00 /
      DATA B( 1324), B( 1325), B( 1326) /    16.23,  -41.66,    0.00 /
      DATA B( 1663), B( 1664), B( 1665) /    15.98,  -41.38,    0.00 /
      DATA B( 2002), B( 2003), B( 2004) /    15.69,  -40.94,    0.00 /
      DATA B( 2341), B( 2342), B( 2343) /    15.32,  -40.34,    0.00 /
      DATA B( 2680), B( 2681), B( 2682) /    14.84,  -39.60,    0.00 /
      DATA B( 3019), B( 3020), B( 3021) /    14.22,  -38.71,    0.00 /
      DATA B( 3358), B( 3359), B( 3360) /    13.45,  -37.68,    0.00 /
      DATA B( 3697), B( 3698), B( 3699) /    12.45,  -36.45,    0.00 /
      DATA B( 4036), B( 4037), B( 4038) /    11.14,  -34.95,    0.00 /
      DATA B( 4375), B( 4376), B( 4377) /     9.35,  -33.11,    0.00 /
      DATA B( 4714), B( 4715), B( 4716) /     6.87,  -30.81,    0.00 /
      DATA B( 5053), B( 5054), B( 5055) /     3.63,  -28.00,    0.00 /
      DATA B( 5392), B( 5393), B( 5394) /     0.23,  -23.83,    0.00 /
      DATA B( 5731), B( 5732), B( 5733) /    -2.11,  -20.27,    0.00 /
      DATA B( 6070), B( 6071), B( 6072) /    -3.64,  -17.84,    0.00 /
      DATA B( 6409), B( 6410), B( 6411) /    -4.69,  -16.33,    0.00 /
      DATA B( 6748), B( 6749), B( 6750) /    -5.43,  -15.42,    0.00 /
      DATA B( 7087), B( 7088), B( 7089) /    -5.99,  -14.85,    0.00 /
      DATA B( 7426), B( 7427), B( 7428) /    -6.43,  -14.47,    0.00 /
      DATA B( 7765), B( 7766), B( 7767) /    -6.78,  -14.19,    0.00 /
      DATA B( 8104), B( 8105), B( 8106) /    -7.06,  -13.98,    0.00 /
      DATA B( 8443), B( 8444), B( 8445) /    -7.29,  -13.80,    0.00 /
      DATA B( 8782), B( 8783), B( 8784) /    -7.47,  -13.66,    0.00 /
      DATA B( 9121), B( 9122), B( 9123) /    -7.63,  -13.53,    0.00 /
      DATA B( 9460), B( 9461), B( 9462) /    -7.76,  -13.42,    0.00 /
      DATA B( 9799), B( 9800), B( 9801) /    -7.86,  -13.33,    0.00 /
      DATA B(10138), B(10139), B(10140) /    -7.95,  -13.25,    0.00 /
      DATA B(10477), B(10478), B(10479) /    -8.02,  -13.18,    0.00 /
      DATA B(10816), B(10817), B(10818) /    -8.07,  -13.14,    0.00 /
      DATA B(11155), B(11156), B(11157) /    -8.12,  -13.10,    0.00 /
      DATA B(11494), B(11495), B(11496) /    -8.16,  -13.08,    0.00 /
      DATA B(11833), B(11834), B(11835) /    -8.19,  -13.07,    0.00 /
      DATA B(12172), B(12173), B(12174) /    -8.23,  -13.07,    0.00 /
      DATA B(12511), B(12512), B(12513) /    -8.25,  -13.07,    0.00 /
      DATA B(12850), B(12851), B(12852) /    -8.28,  -13.08,    0.00 /
      DATA B(13189), B(13190), B(13191) /    -8.30,  -13.08,    0.00 /
      DATA B(13528), B(13529), B(13530) /    -8.33,  -13.09,    0.00 /
      DATA B(13867), B(13868), B(13869) /    -8.34,  -13.10,    0.00 /
      DATA B(14206), B(14207), B(14208) /    -8.36,  -13.11,    0.00 /
      DATA B(14545), B(14546), B(14547) /    -8.37,  -13.13,    0.00 /
      DATA B(14884), B(14885), B(14886) /    -8.38,  -13.14,    0.00 /
      DATA B(15223), B(15224), B(15225) /    -8.39,  -13.15,    0.00 /
      DATA B(15562), B(15563), B(15564) /    -8.39,  -13.16,    0.00 /
      DATA B(15901), B(15902), B(15903) /    -8.39,  -13.18,    0.00 /
      DATA B(16240), B(16241), B(16242) /    -8.39,  -13.19,    0.00 /
      DATA B(16579), B(16580), B(16581) /    -8.39,  -13.21,    0.00 /
      DATA B(16918), B(16919), B(16920) /    -8.39,  -13.24,    0.00 /
      DATA B(17257), B(17258), B(17259) /    -8.38,  -13.26,    0.00 /
      DATA B(17596), B(17597), B(17598) /    -8.37,  -13.29,    0.00 /
      DATA B(17935), B(17936), B(17937) /    -8.36,  -13.32,    0.00 /
      DATA B(18274), B(18275), B(18276) /    -8.35,  -13.36,    0.00 /
      DATA B(18613), B(18614), B(18615) /    -8.33,  -13.41,    0.00 /
      DATA B(18952), B(18953), B(18954) /    -8.32,  -13.46,    0.00 /
      DATA B(19291), B(19292), B(19293) /    -8.29,  -13.51,    0.00 /
      DATA B(19630), B(19631), B(19632) /    -8.27,  -13.58,    0.00 /
      DATA B(19969), B(19970), B(19971) /    -8.23,  -13.66,    0.00 /
      DATA B(20308), B(20309), B(20310) /    -8.19,  -13.76,    0.00 /
      DATA B(20647), B(20648), B(20649) /    -8.14,  -13.88,    0.00 /
      DATA B(20986), B(20987), B(20988) /    -8.08,  -14.03,    0.00 /
      DATA B(21325), B(21326), B(21327) /    -8.01,  -14.22,    0.00 /
      DATA B(21664), B(21665), B(21666) /    -7.93,  -14.47,    0.00 /
      DATA B(22003), B(22004), B(22005) /    -9.00,  -11.05,    0.00 /
      DATA B(22342), B(22343), B(22344) /    -9.01,  -11.52,    0.00 /
      DATA B(22681), B(22682), B(22683) /    -9.22,  -12.04,    0.00 /
      DATA B(23020), B(23021), B(23022) /    -9.53,  -12.56,    0.00 /
      DATA B(23359), B(23360), B(23361) /    -9.68,  -13.05,    0.00 /
      DATA B(23698), B(23699), B(23700) /    -9.67,  -13.48,    0.00 /
      DATA B(24037), B(24038), B(24039) /    -9.61,  -13.81,    0.00 /
      DATA B(24376), B(24377), B(24378) /    -9.53,  -14.06,    0.00 /
      DATA B(24715), B(24716), B(24717) /    -9.47,  -14.25,    0.00 /
      DATA B(25054), B(25055), B(25056) /    -9.41,  -14.39,    0.00 /
      DATA B(25393), B(25394), B(25395) /    -9.37,  -14.50,    0.00 /
      DATA B(25732), B(25733), B(25734) /    -9.34,  -14.59,    0.00 /
      DATA B(26071), B(26072), B(26073) /    -9.31,  -14.67,    0.00 /
      DATA B(26410), B(26411), B(26412) /    -9.29,  -14.73,    0.00 /
      DATA B(26749), B(26750), B(26751) /    -9.27,  -14.78,    0.00 /
      DATA B(27088), B(27089), B(27090) /    -9.26,  -14.83,    0.00 /
      DATA B(27427), B(27428), B(27429) /    -9.25,  -14.87,    0.00 /
      DATA B(  310), B(  311), B(  312) /    16.51,  -42.26,    0.00 /
      DATA B(  649), B(  650), B(  651) /    16.25,  -42.30,    0.00 /
      DATA B(  988), B(  989), B(  990) /    16.01,  -42.25,    0.00 /
      DATA B( 1327), B( 1328), B( 1329) /    15.76,  -42.07,    0.00 /
      DATA B( 1666), B( 1667), B( 1668) /    15.49,  -41.72,    0.00 /
      DATA B( 2005), B( 2006), B( 2007) /    15.17,  -41.15,    0.00 /
      DATA B( 2344), B( 2345), B( 2346) /    14.74,  -40.36,    0.00 /
      DATA B( 2683), B( 2684), B( 2685) /    14.16,  -39.37,    0.00 /
      DATA B( 3022), B( 3023), B( 3024) /    13.40,  -38.20,    0.00 /
      DATA B( 3361), B( 3362), B( 3363) /    12.40,  -36.86,    0.00 /
      DATA B( 3700), B( 3701), B( 3702) /    11.08,  -35.28,    0.00 /
      DATA B( 4039), B( 4040), B( 4041) /     9.31,  -33.39,    0.00 /
      DATA B( 4378), B( 4379), B( 4380) /     6.88,  -31.16,    0.00 /
      DATA B( 4717), B( 4718), B( 4719) /     3.79,  -28.58,    0.00 /
      DATA B( 5056), B( 5057), B( 5058) /     0.51,  -25.31,    0.00 /
      DATA B( 5395), B( 5396), B( 5397) /    -2.14,  -21.89,    0.00 /
      DATA B( 5734), B( 5735), B( 5736) /    -3.79,  -19.04,    0.00 /
      DATA B( 6073), B( 6074), B( 6075) /    -4.81,  -17.10,    0.00 /
      DATA B( 6412), B( 6413), B( 6414) /    -5.51,  -15.86,    0.00 /
      DATA B( 6751), B( 6752), B( 6753) /    -6.03,  -15.08,    0.00 /
      DATA B( 7090), B( 7091), B( 7092) /    -6.43,  -14.58,    0.00 /
      DATA B( 7429), B( 7430), B( 7431) /    -6.76,  -14.24,    0.00 /
      DATA B( 7768), B( 7769), B( 7770) /    -7.03,  -13.99,    0.00 /
      DATA B( 8107), B( 8108), B( 8109) /    -7.26,  -13.80,    0.00 /
      DATA B( 8446), B( 8447), B( 8448) /    -7.44,  -13.65,    0.00 /
      DATA B( 8785), B( 8786), B( 8787) /    -7.60,  -13.52,    0.00 /
      DATA B( 9124), B( 9125), B( 9126) /    -7.73,  -13.41,    0.00 /
      DATA B( 9463), B( 9464), B( 9465) /    -7.84,  -13.32,    0.00 /
      DATA B( 9802), B( 9803), B( 9804) /    -7.93,  -13.24,    0.00 /
      DATA B(10141), B(10142), B(10143) /    -8.00,  -13.18,    0.00 /
      DATA B(10480), B(10481), B(10482) /    -8.06,  -13.12,    0.00 /
      DATA B(10819), B(10820), B(10821) /    -8.11,  -13.08,    0.00 /
      DATA B(11158), B(11159), B(11160) /    -8.16,  -13.05,    0.00 /
      DATA B(11497), B(11498), B(11499) /    -8.19,  -13.03,    0.00 /
      DATA B(11836), B(11837), B(11838) /    -8.22,  -13.02,    0.00 /
      DATA B(12175), B(12176), B(12177) /    -8.25,  -13.02,    0.00 /
      DATA B(12514), B(12515), B(12516) /    -8.27,  -13.02,    0.00 /
      DATA B(12853), B(12854), B(12855) /    -8.30,  -13.03,    0.00 /
      DATA B(13192), B(13193), B(13194) /    -8.32,  -13.04,    0.00 /
      DATA B(13531), B(13532), B(13533) /    -8.34,  -13.05,    0.00 /
      DATA B(13870), B(13871), B(13872) /    -8.35,  -13.06,    0.00 /
      DATA B(14209), B(14210), B(14211) /    -8.37,  -13.07,    0.00 /
      DATA B(14548), B(14549), B(14550) /    -8.38,  -13.08,    0.00 /
      DATA B(14887), B(14888), B(14889) /    -8.39,  -13.09,    0.00 /
      DATA B(15226), B(15227), B(15228) /    -8.39,  -13.11,    0.00 /
      DATA B(15565), B(15566), B(15567) /    -8.40,  -13.12,    0.00 /
      DATA B(15904), B(15905), B(15906) /    -8.40,  -13.14,    0.00 /
      DATA B(16243), B(16244), B(16245) /    -8.40,  -13.16,    0.00 /
      DATA B(16582), B(16583), B(16584) /    -8.40,  -13.17,    0.00 /
      DATA B(16921), B(16922), B(16923) /    -8.39,  -13.20,    0.00 /
      DATA B(17260), B(17261), B(17262) /    -8.39,  -13.22,    0.00 /
      DATA B(17599), B(17600), B(17601) /    -8.38,  -13.25,    0.00 /
      DATA B(17938), B(17939), B(17940) /    -8.37,  -13.28,    0.00 /
      DATA B(18277), B(18278), B(18279) /    -8.36,  -13.32,    0.00 /
      DATA B(18616), B(18617), B(18618) /    -8.34,  -13.36,    0.00 /
      DATA B(18955), B(18956), B(18957) /    -8.33,  -13.40,    0.00 /
      DATA B(19294), B(19295), B(19296) /    -8.31,  -13.46,    0.00 /
      DATA B(19633), B(19634), B(19635) /    -8.28,  -13.52,    0.00 /
      DATA B(19972), B(19973), B(19974) /    -8.25,  -13.59,    0.00 /
      DATA B(20311), B(20312), B(20313) /    -8.21,  -13.68,    0.00 /
      DATA B(20650), B(20651), B(20652) /    -8.17,  -13.78,    0.00 /
      DATA B(20989), B(20990), B(20991) /    -8.11,  -13.91,    0.00 /
      DATA B(21328), B(21329), B(21330) /    -8.05,  -14.08,    0.00 /
      DATA B(21667), B(21668), B(21669) /    -7.97,  -14.29,    0.00 /
      DATA B(22006), B(22007), B(22008) /    -7.89,  -14.57,    0.00 /
      DATA B(22345), B(22346), B(22347) /    -8.98,  -11.28,    0.00 /
      DATA B(22684), B(22685), B(22686) /    -9.08,  -11.79,    0.00 /
      DATA B(23023), B(23024), B(23025) /    -9.35,  -12.31,    0.00 /
      DATA B(23362), B(23363), B(23364) /    -9.60,  -12.81,    0.00 /
      DATA B(23701), B(23702), B(23703) /    -9.67,  -13.27,    0.00 /
      DATA B(24040), B(24041), B(24042) /    -9.62,  -13.65,    0.00 /
      DATA B(24379), B(24380), B(24381) /    -9.55,  -13.94,    0.00 /
      DATA B(24718), B(24719), B(24720) /    -9.48,  -14.15,    0.00 /
      DATA B(25057), B(25058), B(25059) /    -9.42,  -14.32,    0.00 /
      DATA B(25396), B(25397), B(25398) /    -9.37,  -14.44,    0.00 /
      DATA B(25735), B(25736), B(25737) /    -9.33,  -14.54,    0.00 /
      DATA B(26074), B(26075), B(26076) /    -9.30,  -14.62,    0.00 /
      DATA B(26413), B(26414), B(26415) /    -9.28,  -14.69,    0.00 /
      DATA B(26752), B(26753), B(26754) /    -9.26,  -14.75,    0.00 /
      DATA B(27091), B(27092), B(27093) /    -9.25,  -14.80,    0.00 /
      DATA B(27430), B(27431), B(27432) /    -9.23,  -14.84,    0.00 /
      DATA B(  313), B(  314), B(  315) /    16.08,  -42.70,    0.00 /
      DATA B(  652), B(  653), B(  654) /    15.79,  -42.76,    0.00 /
      DATA B(  991), B(  992), B(  993) /    15.51,  -42.72,    0.00 /
      DATA B( 1330), B( 1331), B( 1332) /    15.23,  -42.52,    0.00 /
      DATA B( 1669), B( 1670), B( 1671) /    14.94,  -42.09,    0.00 /
      DATA B( 2008), B( 2009), B( 2010) /    14.59,  -41.35,    0.00 /
      DATA B( 2347), B( 2348), B( 2349) /    14.09,  -40.29,    0.00 /
      DATA B( 2686), B( 2687), B( 2688) /    13.37,  -38.96,    0.00 /
      DATA B( 3025), B( 3026), B( 3027) /    12.37,  -37.43,    0.00 /
      DATA B( 3364), B( 3365), B( 3366) /    11.03,  -35.69,    0.00 /
      DATA B( 3703), B( 3704), B( 3705) /     9.24,  -33.71,    0.00 /
      DATA B( 4042), B( 4043), B( 4044) /     6.82,  -31.47,    0.00 /
      DATA B( 4381), B( 4382), B( 4383) /     3.80,  -28.95,    0.00 /
      DATA B( 4720), B( 4721), B( 4722) /     0.63,  -26.00,    0.00 /
      DATA B( 5059), B( 5060), B( 5061) /    -2.04,  -23.04,    0.00 /
      DATA B( 5398), B( 5399), B( 5400) /    -3.91,  -20.29,    0.00 /
      DATA B( 5737), B( 5738), B( 5739) /    -5.04,  -18.08,    0.00 /
      DATA B( 6076), B( 6077), B( 6078) /    -5.72,  -16.52,    0.00 /
      DATA B( 6415), B( 6416), B( 6417) /    -6.18,  -15.49,    0.00 /
      DATA B( 6754), B( 6755), B( 6756) /    -6.54,  -14.82,    0.00 /
      DATA B( 7093), B( 7094), B( 7095) /    -6.82,  -14.37,    0.00 /
      DATA B( 7432), B( 7433), B( 7434) /    -7.07,  -14.06,    0.00 /
      DATA B( 7771), B( 7772), B( 7773) /    -7.27,  -13.83,    0.00 /
      DATA B( 8110), B( 8111), B( 8112) /    -7.44,  -13.66,    0.00 /
      DATA B( 8449), B( 8450), B( 8451) /    -7.59,  -13.52,    0.00 /
      DATA B( 8788), B( 8789), B( 8790) /    -7.72,  -13.41,    0.00 /
      DATA B( 9127), B( 9128), B( 9129) /    -7.83,  -13.31,    0.00 /
      DATA B( 9466), B( 9467), B( 9468) /    -7.92,  -13.23,    0.00 /
      DATA B( 9805), B( 9806), B( 9807) /    -7.99,  -13.17,    0.00 /
      DATA B(10144), B(10145), B(10146) /    -8.06,  -13.11,    0.00 /
      DATA B(10483), B(10484), B(10485) /    -8.11,  -13.07,    0.00 /
      DATA B(10822), B(10823), B(10824) /    -8.15,  -13.03,    0.00 /
      DATA B(11161), B(11162), B(11163) /    -8.19,  -13.01,    0.00 /
      DATA B(11500), B(11501), B(11502) /    -8.22,  -12.99,    0.00 /
      DATA B(11839), B(11840), B(11841) /    -8.25,  -12.98,    0.00 /
      DATA B(12178), B(12179), B(12180) /    -8.27,  -12.98,    0.00 /
      DATA B(12517), B(12518), B(12519) /    -8.29,  -12.98,    0.00 /
      DATA B(12856), B(12857), B(12858) /    -8.31,  -12.99,    0.00 /
      DATA B(13195), B(13196), B(13197) /    -8.33,  -13.00,    0.00 /
      DATA B(13534), B(13535), B(13536) /    -8.35,  -13.01,    0.00 /
      DATA B(13873), B(13874), B(13875) /    -8.36,  -13.02,    0.00 /
      DATA B(14212), B(14213), B(14214) /    -8.37,  -13.03,    0.00 /
      DATA B(14551), B(14552), B(14553) /    -8.38,  -13.04,    0.00 /
      DATA B(14890), B(14891), B(14892) /    -8.39,  -13.06,    0.00 /
      DATA B(15229), B(15230), B(15231) /    -8.40,  -13.07,    0.00 /
      DATA B(15568), B(15569), B(15570) /    -8.40,  -13.08,    0.00 /
      DATA B(15907), B(15908), B(15909) /    -8.40,  -13.10,    0.00 /
      DATA B(16246), B(16247), B(16248) /    -8.40,  -13.12,    0.00 /
      DATA B(16585), B(16586), B(16587) /    -8.40,  -13.14,    0.00 /
      DATA B(16924), B(16925), B(16926) /    -8.40,  -13.16,    0.00 /
      DATA B(17263), B(17264), B(17265) /    -8.39,  -13.18,    0.00 /
      DATA B(17602), B(17603), B(17604) /    -8.38,  -13.21,    0.00 /
      DATA B(17941), B(17942), B(17943) /    -8.37,  -13.24,    0.00 /
      DATA B(18280), B(18281), B(18282) /    -8.36,  -13.28,    0.00 /
      DATA B(18619), B(18620), B(18621) /    -8.35,  -13.31,    0.00 /
      DATA B(18958), B(18959), B(18960) /    -8.33,  -13.36,    0.00 /
      DATA B(19297), B(19298), B(19299) /    -8.32,  -13.40,    0.00 /
      DATA B(19636), B(19637), B(19638) /    -8.29,  -13.46,    0.00 /
      DATA B(19975), B(19976), B(19977) /    -8.27,  -13.52,    0.00 /
      DATA B(20314), B(20315), B(20316) /    -8.23,  -13.60,    0.00 /
      DATA B(20653), B(20654), B(20655) /    -8.19,  -13.69,    0.00 /
      DATA B(20992), B(20993), B(20994) /    -8.14,  -13.81,    0.00 /
      DATA B(21331), B(21332), B(21333) /    -8.08,  -13.95,    0.00 /
      DATA B(21670), B(21671), B(21672) /    -8.01,  -14.14,    0.00 /
      DATA B(22009), B(22010), B(22011) /    -7.92,  -14.38,    0.00 /
      DATA B(22348), B(22349), B(22350) /    -8.94,  -11.04,    0.00 /
      DATA B(22687), B(22688), B(22689) /    -8.98,  -11.55,    0.00 /
      DATA B(23026), B(23027), B(23028) /    -9.17,  -12.06,    0.00 /
      DATA B(23365), B(23366), B(23367) /    -9.47,  -12.56,    0.00 /
      DATA B(23704), B(23705), B(23706) /    -9.63,  -13.05,    0.00 /
      DATA B(24043), B(24044), B(24045) /    -9.63,  -13.47,    0.00 /
      DATA B(24382), B(24383), B(24384) /    -9.56,  -13.80,    0.00 /
      DATA B(24721), B(24722), B(24723) /    -9.49,  -14.05,    0.00 /
      DATA B(25060), B(25061), B(25062) /    -9.42,  -14.23,    0.00 /
      DATA B(25399), B(25400), B(25401) /    -9.37,  -14.38,    0.00 /
      DATA B(25738), B(25739), B(25740) /    -9.33,  -14.49,    0.00 /
      DATA B(26077), B(26078), B(26079) /    -9.29,  -14.58,    0.00 /
      DATA B(26416), B(26417), B(26418) /    -9.27,  -14.65,    0.00 /
      DATA B(26755), B(26756), B(26757) /    -9.25,  -14.71,    0.00 /
      DATA B(27094), B(27095), B(27096) /    -9.23,  -14.76,    0.00 /
      DATA B(27433), B(27434), B(27435) /    -9.22,  -14.81,    0.00 /
      DATA B(  316), B(  317), B(  318) /    15.65,  -43.14,    0.00 /
      DATA B(  655), B(  656), B(  657) /    15.31,  -43.23,    0.00 /
      DATA B(  994), B(  995), B(  996) /    14.97,  -43.21,    0.00 /
      DATA B( 1333), B( 1334), B( 1335) /    14.65,  -43.02,    0.00 /
      DATA B( 1672), B( 1673), B( 1674) /    14.32,  -42.51,    0.00 /
      DATA B( 2011), B( 2012), B( 2013) /    13.93,  -41.56,    0.00 /
      DATA B( 2350), B( 2351), B( 2352) /    13.32,  -40.11,    0.00 /
      DATA B( 2689), B( 2690), B( 2691) /    12.37,  -38.31,    0.00 /
      DATA B( 3028), B( 3029), B( 3030) /    11.01,  -36.29,    0.00 /
      DATA B( 3367), B( 3368), B( 3369) /     9.16,  -34.10,    0.00 /
      DATA B( 3706), B( 3707), B( 3708) /     6.70,  -31.76,    0.00 /
      DATA B( 4045), B( 4046), B( 4047) /     3.69,  -29.23,    0.00 /
      DATA B( 4384), B( 4385), B( 4386) /     0.57,  -26.39,    0.00 /
      DATA B( 4723), B( 4724), B( 4725) /    -2.04,  -23.65,    0.00 /
      DATA B( 5062), B( 5063), B( 5064) /    -3.94,  -21.13,    0.00 /
      DATA B( 5401), B( 5402), B( 5403) /    -5.18,  -18.98,    0.00 /
      DATA B( 5740), B( 5741), B( 5742) /    -5.93,  -17.28,    0.00 /
      DATA B( 6079), B( 6080), B( 6081) /    -6.40,  -16.05,    0.00 /
      DATA B( 6418), B( 6419), B( 6420) /    -6.72,  -15.19,    0.00 /
      DATA B( 6757), B( 6758), B( 6759) /    -6.96,  -14.60,    0.00 /
      DATA B( 7096), B( 7097), B( 7098) /    -7.16,  -14.20,    0.00 /
      DATA B( 7435), B( 7436), B( 7437) /    -7.33,  -13.91,    0.00 /
      DATA B( 7774), B( 7775), B( 7776) /    -7.48,  -13.70,    0.00 /
      DATA B( 8113), B( 8114), B( 8115) /    -7.62,  -13.54,    0.00 /
      DATA B( 8452), B( 8453), B( 8454) /    -7.73,  -13.42,    0.00 /
      DATA B( 8791), B( 8792), B( 8793) /    -7.83,  -13.32,    0.00 /
      DATA B( 9130), B( 9131), B( 9132) /    -7.92,  -13.23,    0.00 /
      DATA B( 9469), B( 9470), B( 9471) /    -7.99,  -13.16,    0.00 /
      DATA B( 9808), B( 9809), B( 9810) /    -8.05,  -13.10,    0.00 /
      DATA B(10147), B(10148), B(10149) /    -8.11,  -13.05,    0.00 /
      DATA B(10486), B(10487), B(10488) /    -8.15,  -13.02,    0.00 /
      DATA B(10825), B(10826), B(10827) /    -8.19,  -12.99,    0.00 /
      DATA B(11164), B(11165), B(11166) /    -8.22,  -12.97,    0.00 /
      DATA B(11503), B(11504), B(11505) /    -8.25,  -12.95,    0.00 /
      DATA B(11842), B(11843), B(11844) /    -8.27,  -12.95,    0.00 /
      DATA B(12181), B(12182), B(12183) /    -8.29,  -12.94,    0.00 /
      DATA B(12520), B(12521), B(12522) /    -8.31,  -12.95,    0.00 /
      DATA B(12859), B(12860), B(12861) /    -8.33,  -12.95,    0.00 /
      DATA B(13198), B(13199), B(13200) /    -8.34,  -12.96,    0.00 /
      DATA B(13537), B(13538), B(13539) /    -8.36,  -12.97,    0.00 /
      DATA B(13876), B(13877), B(13878) /    -8.37,  -12.98,    0.00 /
      DATA B(14215), B(14216), B(14217) /    -8.38,  -12.99,    0.00 /
      DATA B(14554), B(14555), B(14556) /    -8.39,  -13.01,    0.00 /
      DATA B(14893), B(14894), B(14895) /    -8.40,  -13.02,    0.00 /
      DATA B(15232), B(15233), B(15234) /    -8.40,  -13.04,    0.00 /
      DATA B(15571), B(15572), B(15573) /    -8.40,  -13.05,    0.00 /
      DATA B(15910), B(15911), B(15912) /    -8.40,  -13.07,    0.00 /
      DATA B(16249), B(16250), B(16251) /    -8.40,  -13.09,    0.00 /
      DATA B(16588), B(16589), B(16590) /    -8.40,  -13.10,    0.00 /
      DATA B(16927), B(16928), B(16929) /    -8.40,  -13.13,    0.00 /
      DATA B(17266), B(17267), B(17268) /    -8.39,  -13.15,    0.00 /
      DATA B(17605), B(17606), B(17607) /    -8.39,  -13.18,    0.00 /
      DATA B(17944), B(17945), B(17946) /    -8.38,  -13.20,    0.00 /
      DATA B(18283), B(18284), B(18285) /    -8.37,  -13.24,    0.00 /
      DATA B(18622), B(18623), B(18624) /    -8.36,  -13.27,    0.00 /
      DATA B(18961), B(18962), B(18963) /    -8.34,  -13.31,    0.00 /
      DATA B(19300), B(19301), B(19302) /    -8.32,  -13.36,    0.00 /
      DATA B(19639), B(19640), B(19641) /    -8.30,  -13.41,    0.00 /
      DATA B(19978), B(19979), B(19980) /    -8.28,  -13.47,    0.00 /
      DATA B(20317), B(20318), B(20319) /    -8.25,  -13.54,    0.00 /
      DATA B(20656), B(20657), B(20658) /    -8.21,  -13.62,    0.00 /
      DATA B(20995), B(20996), B(20997) /    -8.17,  -13.72,    0.00 /
      DATA B(21334), B(21335), B(21336) /    -8.11,  -13.85,    0.00 /
      DATA B(21673), B(21674), B(21675) /    -8.04,  -14.01,    0.00 /
      DATA B(22012), B(22013), B(22014) /    -7.96,  -14.22,    0.00 /
      DATA B(22351), B(22352), B(22353) /    -7.89,  -14.48,    0.00 /
      DATA B(22690), B(22691), B(22692) /    -8.98,  -11.33,    0.00 /
      DATA B(23029), B(23030), B(23031) /    -9.03,  -11.82,    0.00 /
      DATA B(23368), B(23369), B(23370) /    -9.30,  -12.32,    0.00 /
      DATA B(23707), B(23708), B(23709) /    -9.55,  -12.82,    0.00 /
      DATA B(24046), B(24047), B(24048) /    -9.62,  -13.27,    0.00 /
      DATA B(24385), B(24386), B(24387) /    -9.57,  -13.65,    0.00 /
      DATA B(24724), B(24725), B(24726) /    -9.50,  -13.93,    0.00 /
      DATA B(25063), B(25064), B(25065) /    -9.43,  -14.14,    0.00 /
      DATA B(25402), B(25403), B(25404) /    -9.37,  -14.30,    0.00 /
      DATA B(25741), B(25742), B(25743) /    -9.33,  -14.43,    0.00 /
      DATA B(26080), B(26081), B(26082) /    -9.29,  -14.53,    0.00 /
      DATA B(26419), B(26420), B(26421) /    -9.26,  -14.61,    0.00 /
      DATA B(26758), B(26759), B(26760) /    -9.24,  -14.67,    0.00 /
      DATA B(27097), B(27098), B(27099) /    -9.22,  -14.73,    0.00 /
      DATA B(27436), B(27437), B(27438) /    -9.20,  -14.78,    0.00 /
      DATA B(  319), B(  320), B(  321) /    15.22,  -43.59,    0.00 /
      DATA B(  658), B(  659), B(  660) /    14.82,  -43.70,    0.00 /
      DATA B(  997), B(  998), B(  999) /    14.39,  -43.74,    0.00 /
      DATA B( 1336), B( 1337), B( 1338) /    13.98,  -43.58,    0.00 /
      DATA B( 1675), B( 1676), B( 1677) /    13.59,  -43.03,    0.00 /
      DATA B( 2014), B( 2015), B( 2016) /    13.14,  -41.81,    0.00 /
      DATA B( 2353), B( 2354), B( 2355) /    12.38,  -39.80,    0.00 /
      DATA B( 2692), B( 2693), B( 2694) /    11.05,  -37.30,    0.00 /
      DATA B( 3031), B( 3032), B( 3033) /     9.11,  -34.69,    0.00 /
      DATA B( 3370), B( 3371), B( 3372) /     6.55,  -32.09,    0.00 /
      DATA B( 3709), B( 3710), B( 3711) /     3.44,  -29.57,    0.00 /
      DATA B( 4048), B( 4049), B( 4050) /     0.38,  -26.65,    0.00 /
      DATA B( 4387), B( 4388), B( 4389) /    -2.18,  -23.99,    0.00 /
      DATA B( 4726), B( 4727), B( 4728) /    -4.03,  -21.62,    0.00 /
      DATA B( 5065), B( 5066), B( 5067) /    -5.28,  -19.60,    0.00 /
      DATA B( 5404), B( 5405), B( 5406) /    -6.09,  -17.93,    0.00 /
      DATA B( 5743), B( 5744), B( 5745) /    -6.60,  -16.63,    0.00 /
      DATA B( 6082), B( 6083), B( 6084) /    -6.92,  -15.64,    0.00 /
      DATA B( 6421), B( 6422), B( 6423) /    -7.14,  -14.93,    0.00 /
      DATA B( 6760), B( 6761), B( 6762) /    -7.30,  -14.42,    0.00 /
      DATA B( 7099), B( 7100), B( 7101) /    -7.44,  -14.06,    0.00 /
      DATA B( 7438), B( 7439), B( 7440) /    -7.56,  -13.79,    0.00 /
      DATA B( 7777), B( 7778), B( 7779) /    -7.67,  -13.60,    0.00 /
      DATA B( 8116), B( 8117), B( 8118) /    -7.77,  -13.45,    0.00 /
      DATA B( 8455), B( 8456), B( 8457) /    -7.86,  -13.33,    0.00 /
      DATA B( 8794), B( 8795), B( 8796) /    -7.93,  -13.24,    0.00 /
      DATA B( 9133), B( 9134), B( 9135) /    -8.00,  -13.16,    0.00 /
      DATA B( 9472), B( 9473), B( 9474) /    -8.06,  -13.10,    0.00 /
      DATA B( 9811), B( 9812), B( 9813) /    -8.11,  -13.05,    0.00 /
      DATA B(10150), B(10151), B(10152) /    -8.15,  -13.01,    0.00 /
      DATA B(10489), B(10490), B(10491) /    -8.19,  -12.97,    0.00 /
      DATA B(10828), B(10829), B(10830) /    -8.22,  -12.95,    0.00 /
      DATA B(11167), B(11168), B(11169) /    -8.25,  -12.93,    0.00 /
      DATA B(11506), B(11507), B(11508) /    -8.27,  -12.92,    0.00 /
      DATA B(11845), B(11846), B(11847) /    -8.29,  -12.91,    0.00 /
      DATA B(12184), B(12185), B(12186) /    -8.31,  -12.91,    0.00 /
      DATA B(12523), B(12524), B(12525) /    -8.33,  -12.91,    0.00 /
      DATA B(12862), B(12863), B(12864) /    -8.34,  -12.92,    0.00 /
      DATA B(13201), B(13202), B(13203) /    -8.36,  -12.93,    0.00 /
      DATA B(13540), B(13541), B(13542) /    -8.37,  -12.94,    0.00 /
      DATA B(13879), B(13880), B(13881) /    -8.38,  -12.95,    0.00 /
      DATA B(14218), B(14219), B(14220) /    -8.39,  -12.96,    0.00 /
      DATA B(14557), B(14558), B(14559) /    -8.39,  -12.97,    0.00 /
      DATA B(14896), B(14897), B(14898) /    -8.40,  -12.99,    0.00 /
      DATA B(15235), B(15236), B(15237) /    -8.40,  -13.00,    0.00 /
      DATA B(15574), B(15575), B(15576) /    -8.40,  -13.02,    0.00 /
      DATA B(15913), B(15914), B(15915) /    -8.41,  -13.04,    0.00 /
      DATA B(16252), B(16253), B(16254) /    -8.41,  -13.05,    0.00 /
      DATA B(16591), B(16592), B(16593) /    -8.40,  -13.07,    0.00 /
      DATA B(16930), B(16931), B(16932) /    -8.40,  -13.09,    0.00 /
      DATA B(17269), B(17270), B(17271) /    -8.39,  -13.12,    0.00 /
      DATA B(17608), B(17609), B(17610) /    -8.39,  -13.14,    0.00 /
      DATA B(17947), B(17948), B(17949) /    -8.38,  -13.17,    0.00 /
      DATA B(18286), B(18287), B(18288) /    -8.37,  -13.20,    0.00 /
      DATA B(18625), B(18626), B(18627) /    -8.36,  -13.23,    0.00 /
      DATA B(18964), B(18965), B(18966) /    -8.35,  -13.27,    0.00 /
      DATA B(19303), B(19304), B(19305) /    -8.33,  -13.31,    0.00 /
      DATA B(19642), B(19643), B(19644) /    -8.31,  -13.36,    0.00 /
      DATA B(19981), B(19982), B(19983) /    -8.29,  -13.41,    0.00 /
      DATA B(20320), B(20321), B(20322) /    -8.26,  -13.48,    0.00 /
      DATA B(20659), B(20660), B(20661) /    -8.23,  -13.55,    0.00 /
      DATA B(20998), B(20999), B(21000) /    -8.18,  -13.64,    0.00 /
      DATA B(21337), B(21338), B(21339) /    -8.13,  -13.75,    0.00 /
      DATA B(21676), B(21677), B(21678) /    -8.07,  -13.89,    0.00 /
      DATA B(22015), B(22016), B(22017) /    -8.00,  -14.07,    0.00 /
      DATA B(22354), B(22355), B(22356) /    -7.92,  -14.31,    0.00 /
      DATA B(22693), B(22694), B(22695) /    -8.96,  -11.14,    0.00 /
      DATA B(23032), B(23033), B(23034) /    -8.96,  -11.59,    0.00 /
      DATA B(23371), B(23372), B(23373) /    -9.13,  -12.09,    0.00 /
      DATA B(23710), B(23711), B(23712) /    -9.41,  -12.58,    0.00 /
      DATA B(24049), B(24050), B(24051) /    -9.58,  -13.05,    0.00 /
      DATA B(24388), B(24389), B(24390) /    -9.58,  -13.47,    0.00 /
      DATA B(24727), B(24728), B(24729) /    -9.51,  -13.80,    0.00 /
      DATA B(25066), B(25067), B(25068) /    -9.44,  -14.04,    0.00 /
      DATA B(25405), B(25406), B(25407) /    -9.38,  -14.22,    0.00 /
      DATA B(25744), B(25745), B(25746) /    -9.32,  -14.36,    0.00 /
      DATA B(26083), B(26084), B(26085) /    -9.28,  -14.47,    0.00 /
      DATA B(26422), B(26423), B(26424) /    -9.25,  -14.56,    0.00 /
      DATA B(26761), B(26762), B(26763) /    -9.22,  -14.63,    0.00 /
      DATA B(27100), B(27101), B(27102) /    -9.20,  -14.69,    0.00 /
      DATA B(27439), B(27440), B(27441) /    -9.19,  -14.74,    0.00 /
      DATA B(  322), B(  323), B(  324) /    14.82,  -44.02,    0.00 /
      DATA B(  661), B(  662), B(  663) /    14.33,  -44.17,    0.00 /
      DATA B( 1000), B( 1001), B( 1002) /    13.79,  -44.26,    0.00 /
      DATA B( 1339), B( 1340), B( 1341) /    13.21,  -44.21,    0.00 /
      DATA B( 1678), B( 1679), B( 1680) /    12.67,  -43.71,    0.00 /
      DATA B( 2017), B( 2018), B( 2019) /    12.14,  -42.18,    0.00 /
      DATA B( 2356), B( 2357), B( 2358) /    11.14,  -39.29,    0.00 /
      DATA B( 2695), B( 2696), B( 2697) /     9.15,  -35.80,    0.00 /
      DATA B( 3034), B( 3035), B( 3036) /     6.39,  -32.59,    0.00 /
      DATA B( 3373), B( 3374), B( 3375) /     3.17,  -29.78,    0.00 /
      DATA B( 3712), B( 3713), B( 3714) /     0.05,  -26.83,    0.00 /
      DATA B( 4051), B( 4052), B( 4053) /    -2.45,  -24.19,    0.00 /
      DATA B( 4390), B( 4391), B( 4392) /    -4.24,  -21.89,    0.00 /
      DATA B( 4729), B( 4730), B( 4731) /    -5.44,  -19.97,    0.00 /
      DATA B( 5068), B( 5069), B( 5070) /    -6.24,  -18.39,    0.00 /
      DATA B( 5407), B( 5408), B( 5409) /    -6.77,  -17.10,    0.00 /
      DATA B( 5746), B( 5747), B( 5748) /    -7.11,  -16.08,    0.00 /
      DATA B( 6085), B( 6086), B( 6087) /    -7.33,  -15.29,    0.00 /
      DATA B( 6424), B( 6425), B( 6426) /    -7.48,  -14.70,    0.00 /
      DATA B( 6763), B( 6764), B( 6765) /    -7.59,  -14.26,    0.00 /
      DATA B( 7102), B( 7103), B( 7104) /    -7.68,  -13.93,    0.00 /
      DATA B( 7441), B( 7442), B( 7443) /    -7.76,  -13.69,    0.00 /
      DATA B( 7780), B( 7781), B( 7782) /    -7.84,  -13.51,    0.00 /
      DATA B( 8119), B( 8120), B( 8121) /    -7.91,  -13.37,    0.00 /
      DATA B( 8458), B( 8459), B( 8460) /    -7.97,  -13.26,    0.00 /
      DATA B( 8797), B( 8798), B( 8799) /    -8.03,  -13.17,    0.00 /
      DATA B( 9136), B( 9137), B( 9138) /    -8.08,  -13.10,    0.00 /
      DATA B( 9475), B( 9476), B( 9477) /    -8.13,  -13.05,    0.00 /
      DATA B( 9814), B( 9815), B( 9816) /    -8.17,  -13.00,    0.00 /
      DATA B(10153), B(10154), B(10155) /    -8.20,  -12.96,    0.00 /
      DATA B(10492), B(10493), B(10494) /    -8.23,  -12.93,    0.00 /
      DATA B(10831), B(10832), B(10833) /    -8.26,  -12.91,    0.00 /
      DATA B(11170), B(11171), B(11172) /    -8.28,  -12.89,    0.00 /
      DATA B(11509), B(11510), B(11511) /    -8.30,  -12.88,    0.00 /
      DATA B(11848), B(11849), B(11850) /    -8.31,  -12.88,    0.00 /
      DATA B(12187), B(12188), B(12189) /    -8.33,  -12.88,    0.00 /
      DATA B(12526), B(12527), B(12528) /    -8.34,  -12.88,    0.00 /
      DATA B(12865), B(12866), B(12867) /    -8.35,  -12.89,    0.00 /
      DATA B(13204), B(13205), B(13206) /    -8.37,  -12.90,    0.00 /
      DATA B(13543), B(13544), B(13545) /    -8.38,  -12.91,    0.00 /
      DATA B(13882), B(13883), B(13884) /    -8.38,  -12.92,    0.00 /
      DATA B(14221), B(14222), B(14223) /    -8.39,  -12.93,    0.00 /
      DATA B(14560), B(14561), B(14562) /    -8.40,  -12.94,    0.00 /
      DATA B(14899), B(14900), B(14901) /    -8.40,  -12.96,    0.00 /
      DATA B(15238), B(15239), B(15240) /    -8.40,  -12.97,    0.00 /
      DATA B(15577), B(15578), B(15579) /    -8.41,  -12.99,    0.00 /
      DATA B(15916), B(15917), B(15918) /    -8.41,  -13.01,    0.00 /
      DATA B(16255), B(16256), B(16257) /    -8.41,  -13.02,    0.00 /
      DATA B(16594), B(16595), B(16596) /    -8.40,  -13.04,    0.00 /
      DATA B(16933), B(16934), B(16935) /    -8.40,  -13.06,    0.00 /
      DATA B(17272), B(17273), B(17274) /    -8.40,  -13.09,    0.00 /
      DATA B(17611), B(17612), B(17613) /    -8.39,  -13.11,    0.00 /
      DATA B(17950), B(17951), B(17952) /    -8.38,  -13.14,    0.00 /
      DATA B(18289), B(18290), B(18291) /    -8.37,  -13.17,    0.00 /
      DATA B(18628), B(18629), B(18630) /    -8.36,  -13.20,    0.00 /
      DATA B(18967), B(18968), B(18969) /    -8.35,  -13.23,    0.00 /
      DATA B(19306), B(19307), B(19308) /    -8.33,  -13.27,    0.00 /
      DATA B(19645), B(19646), B(19647) /    -8.32,  -13.32,    0.00 /
      DATA B(19984), B(19985), B(19986) /    -8.29,  -13.37,    0.00 /
      DATA B(20323), B(20324), B(20325) /    -8.27,  -13.42,    0.00 /
      DATA B(20662), B(20663), B(20664) /    -8.24,  -13.49,    0.00 /
      DATA B(21001), B(21002), B(21003) /    -8.20,  -13.57,    0.00 /
      DATA B(21340), B(21341), B(21342) /    -8.16,  -13.67,    0.00 /
      DATA B(21679), B(21680), B(21681) /    -8.10,  -13.79,    0.00 /
      DATA B(22018), B(22019), B(22020) /    -8.03,  -13.95,    0.00 /
      DATA B(22357), B(22358), B(22359) /    -7.96,  -14.15,    0.00 /
      DATA B(22696), B(22697), B(22698) /    -7.87,  -14.41,    0.00 /
      DATA B(23035), B(23036), B(23037) /    -8.92,  -11.38,    0.00 /
      DATA B(23374), B(23375), B(23376) /    -9.00,  -11.86,    0.00 /
      DATA B(23713), B(23714), B(23715) /    -9.24,  -12.35,    0.00 /
      DATA B(24052), B(24053), B(24054) /    -9.49,  -12.83,    0.00 /
      DATA B(24391), B(24392), B(24393) /    -9.56,  -13.27,    0.00 /
      DATA B(24730), B(24731), B(24732) /    -9.52,  -13.64,    0.00 /
      DATA B(25069), B(25070), B(25071) /    -9.45,  -13.92,    0.00 /
      DATA B(25408), B(25409), B(25410) /    -9.38,  -14.13,    0.00 /
      DATA B(25747), B(25748), B(25749) /    -9.32,  -14.29,    0.00 /
      DATA B(26086), B(26087), B(26088) /    -9.28,  -14.41,    0.00 /
      DATA B(26425), B(26426), B(26427) /    -9.24,  -14.51,    0.00 /
      DATA B(26764), B(26765), B(26766) /    -9.21,  -14.59,    0.00 /
      DATA B(27103), B(27104), B(27105) /    -9.19,  -14.65,    0.00 /
      DATA B(27442), B(27443), B(27444) /    -9.17,  -14.70,    0.00 /
      DATA B(  325), B(  326), B(  327) /    14.46,  -44.43,    0.00 /
      DATA B(  664), B(  665), B(  666) /    13.91,  -44.60,    0.00 /
      DATA B( 1003), B( 1004), B( 1005) /    13.22,  -44.76,    0.00 /
      DATA B( 1342), B( 1343), B( 1344) /    12.38,  -44.84,    0.00 /
      DATA B( 1681), B( 1682), B( 1683) /    11.50,  -44.58,    0.00 /
      DATA B( 2020), B( 2021), B( 2022) /    10.78,  -42.89,    0.00 /
      DATA B( 2359), B( 2360), B( 2361) /     9.38,  -38.48,    0.00 /
      DATA B( 2698), B( 2699), B( 2700) /     6.30,  -33.58,    0.00 /
      DATA B( 3037), B( 3038), B( 3039) /     2.52,  -29.93,    0.00 /
      DATA B( 3376), B( 3377), B( 3378) /    -0.49,  -26.95,    0.00 /
      DATA B( 3715), B( 3716), B( 3717) /    -2.93,  -24.30,    0.00 /
      DATA B( 4054), B( 4055), B( 4056) /    -4.61,  -22.04,    0.00 /
      DATA B( 4393), B( 4394), B( 4395) /    -5.73,  -20.19,    0.00 /
      DATA B( 4732), B( 4733), B( 4734) /    -6.47,  -18.67,    0.00 /
      DATA B( 5071), B( 5072), B( 5073) /    -6.96,  -17.44,    0.00 /
      DATA B( 5410), B( 5411), B( 5412) /    -7.30,  -16.44,    0.00 /
      DATA B( 5749), B( 5750), B( 5751) /    -7.51,  -15.63,    0.00 /
      DATA B( 6088), B( 6089), B( 6090) /    -7.66,  -14.99,    0.00 /
      DATA B( 6427), B( 6428), B( 6429) /    -7.75,  -14.49,    0.00 /
      DATA B( 6766), B( 6767), B( 6768) /    -7.83,  -14.11,    0.00 /
      DATA B( 7105), B( 7106), B( 7107) /    -7.88,  -13.82,    0.00 /
      DATA B( 7444), B( 7445), B( 7446) /    -7.94,  -13.60,    0.00 /
      DATA B( 7783), B( 7784), B( 7785) /    -7.98,  -13.43,    0.00 /
      DATA B( 8122), B( 8123), B( 8124) /    -8.03,  -13.30,    0.00 /
      DATA B( 8461), B( 8462), B( 8463) /    -8.07,  -13.20,    0.00 /
      DATA B( 8800), B( 8801), B( 8802) /    -8.11,  -13.12,    0.00 /
      DATA B( 9139), B( 9140), B( 9141) /    -8.15,  -13.05,    0.00 /
      DATA B( 9478), B( 9479), B( 9480) /    -8.19,  -13.00,    0.00 /
      DATA B( 9817), B( 9818), B( 9819) /    -8.22,  -12.96,    0.00 /
      DATA B(10156), B(10157), B(10158) /    -8.24,  -12.92,    0.00 /
      DATA B(10495), B(10496), B(10497) /    -8.27,  -12.90,    0.00 /
      DATA B(10834), B(10835), B(10836) /    -8.29,  -12.88,    0.00 /
      DATA B(11173), B(11174), B(11175) /    -8.30,  -12.86,    0.00 /
      DATA B(11512), B(11513), B(11514) /    -8.32,  -12.86,    0.00 /
      DATA B(11851), B(11852), B(11853) /    -8.33,  -12.85,    0.00 /
      DATA B(12190), B(12191), B(12192) /    -8.34,  -12.85,    0.00 /
      DATA B(12529), B(12530), B(12531) /    -8.36,  -12.86,    0.00 /
      DATA B(12868), B(12869), B(12870) /    -8.37,  -12.86,    0.00 /
      DATA B(13207), B(13208), B(13209) /    -8.37,  -12.87,    0.00 /
      DATA B(13546), B(13547), B(13548) /    -8.38,  -12.88,    0.00 /
      DATA B(13885), B(13886), B(13887) /    -8.39,  -12.89,    0.00 /
      DATA B(14224), B(14225), B(14226) /    -8.39,  -12.90,    0.00 /
      DATA B(14563), B(14564), B(14565) /    -8.40,  -12.92,    0.00 /
      DATA B(14902), B(14903), B(14904) /    -8.40,  -12.93,    0.00 /
      DATA B(15241), B(15242), B(15243) /    -8.41,  -12.95,    0.00 /
      DATA B(15580), B(15581), B(15582) /    -8.41,  -12.96,    0.00 /
      DATA B(15919), B(15920), B(15921) /    -8.41,  -12.98,    0.00 /
      DATA B(16258), B(16259), B(16260) /    -8.41,  -13.00,    0.00 /
      DATA B(16597), B(16598), B(16599) /    -8.40,  -13.02,    0.00 /
      DATA B(16936), B(16937), B(16938) /    -8.40,  -13.04,    0.00 /
      DATA B(17275), B(17276), B(17277) /    -8.40,  -13.06,    0.00 /
      DATA B(17614), B(17615), B(17616) /    -8.39,  -13.08,    0.00 /
      DATA B(17953), B(17954), B(17955) /    -8.38,  -13.11,    0.00 /
      DATA B(18292), B(18293), B(18294) /    -8.37,  -13.14,    0.00 /
      DATA B(18631), B(18632), B(18633) /    -8.36,  -13.17,    0.00 /
      DATA B(18970), B(18971), B(18972) /    -8.35,  -13.20,    0.00 /
      DATA B(19309), B(19310), B(19311) /    -8.34,  -13.24,    0.00 /
      DATA B(19648), B(19649), B(19650) /    -8.32,  -13.28,    0.00 /
      DATA B(19987), B(19988), B(19989) /    -8.30,  -13.32,    0.00 /
      DATA B(20326), B(20327), B(20328) /    -8.28,  -13.37,    0.00 /
      DATA B(20665), B(20666), B(20667) /    -8.25,  -13.44,    0.00 /
      DATA B(21004), B(21005), B(21006) /    -8.22,  -13.51,    0.00 /
      DATA B(21343), B(21344), B(21345) /    -8.17,  -13.60,    0.00 /
      DATA B(21682), B(21683), B(21684) /    -8.12,  -13.70,    0.00 /
      DATA B(22021), B(22022), B(22023) /    -8.06,  -13.84,    0.00 /
      DATA B(22360), B(22361), B(22362) /    -7.99,  -14.01,    0.00 /
      DATA B(22699), B(22700), B(22701) /    -7.91,  -14.23,    0.00 /
      DATA B(23038), B(23039), B(23040) /    -7.85,  -14.54,    0.00 /
      DATA B(23377), B(23378), B(23379) /    -8.93,  -11.64,    0.00 /
      DATA B(23716), B(23717), B(23718) /    -9.08,  -12.12,    0.00 /
      DATA B(24055), B(24056), B(24057) /    -9.35,  -12.60,    0.00 /
      DATA B(24394), B(24395), B(24396) /    -9.52,  -13.06,    0.00 /
      DATA B(24733), B(24734), B(24735) /    -9.53,  -13.47,    0.00 /
      DATA B(25072), B(25073), B(25074) /    -9.46,  -13.79,    0.00 /
      DATA B(25411), B(25412), B(25413) /    -9.39,  -14.03,    0.00 /
      DATA B(25750), B(25751), B(25752) /    -9.33,  -14.21,    0.00 /
      DATA B(26089), B(26090), B(26091) /    -9.27,  -14.35,    0.00 /
      DATA B(26428), B(26429), B(26430) /    -9.23,  -14.45,    0.00 /
      DATA B(26767), B(26768), B(26769) /    -9.20,  -14.54,    0.00 /
      DATA B(27106), B(27107), B(27108) /    -9.18,  -14.61,    0.00 /
      DATA B(27445), B(27446), B(27447) /    -9.16,  -14.66,    0.00 /
      DATA B(  328), B(  329), B(  330) /    14.20,  -44.82,    0.00 /
      DATA B(  667), B(  668), B(  669) /    13.61,  -45.01,    0.00 /
      DATA B( 1006), B( 1007), B( 1008) /    12.82,  -45.19,    0.00 /
      DATA B( 1345), B( 1346), B( 1347) /    11.72,  -45.38,    0.00 /
      DATA B( 1684), B( 1685), B( 1686) /    10.20,  -45.48,    0.00 /
      DATA B( 2023), B( 2024), B( 2025) /     8.72,  -44.37,    0.00 /
      DATA B( 2362), B( 2363), B( 2364) /     6.64,  -36.84,    0.00 /
      DATA B( 2701), B( 2702), B( 2703) /     1.74,  -30.35,    0.00 /
      DATA B( 3040), B( 3041), B( 3042) /    -1.57,  -26.94,    0.00 /
      DATA B( 3379), B( 3380), B( 3381) /    -3.80,  -24.30,    0.00 /
      DATA B( 3718), B( 3719), B( 3720) /    -5.26,  -22.10,    0.00 /
      DATA B( 4057), B( 4058), B( 4059) /    -6.20,  -20.30,    0.00 /
      DATA B( 4396), B( 4397), B( 4398) /    -6.81,  -18.85,    0.00 /
      DATA B( 4735), B( 4736), B( 4737) /    -7.23,  -17.67,    0.00 /
      DATA B( 5074), B( 5075), B( 5076) /    -7.52,  -16.70,    0.00 /
      DATA B( 5413), B( 5414), B( 5415) /    -7.71,  -15.91,    0.00 /
      DATA B( 5752), B( 5753), B( 5754) /    -7.84,  -15.26,    0.00 /
      DATA B( 6091), B( 6092), B( 6093) /    -7.93,  -14.73,    0.00 /
      DATA B( 6430), B( 6431), B( 6432) /    -7.98,  -14.31,    0.00 /
      DATA B( 6769), B( 6770), B( 6771) /    -8.02,  -13.98,    0.00 /
      DATA B( 7108), B( 7109), B( 7110) /    -8.05,  -13.72,    0.00 /
      DATA B( 7447), B( 7448), B( 7449) /    -8.08,  -13.52,    0.00 /
      DATA B( 7786), B( 7787), B( 7788) /    -8.11,  -13.37,    0.00 /
      DATA B( 8125), B( 8126), B( 8127) /    -8.14,  -13.24,    0.00 /
      DATA B( 8464), B( 8465), B( 8466) /    -8.17,  -13.15,    0.00 /
      DATA B( 8803), B( 8804), B( 8805) /    -8.19,  -13.07,    0.00 /
      DATA B( 9142), B( 9143), B( 9144) /    -8.22,  -13.01,    0.00 /
      DATA B( 9481), B( 9482), B( 9483) /    -8.24,  -12.96,    0.00 /
      DATA B( 9820), B( 9821), B( 9822) /    -8.26,  -12.92,    0.00 /
      DATA B(10159), B(10160), B(10161) /    -8.28,  -12.89,    0.00 /
      DATA B(10498), B(10499), B(10500) /    -8.30,  -12.87,    0.00 /
      DATA B(10837), B(10838), B(10839) /    -8.31,  -12.85,    0.00 /
      DATA B(11176), B(11177), B(11178) /    -8.33,  -12.84,    0.00 /
      DATA B(11515), B(11516), B(11517) /    -8.34,  -12.83,    0.00 /
      DATA B(11854), B(11855), B(11856) /    -8.35,  -12.83,    0.00 /
      DATA B(12193), B(12194), B(12195) /    -8.36,  -12.83,    0.00 /
      DATA B(12532), B(12533), B(12534) /    -8.37,  -12.83,    0.00 /
      DATA B(12871), B(12872), B(12873) /    -8.38,  -12.84,    0.00 /
      DATA B(13210), B(13211), B(13212) /    -8.38,  -12.84,    0.00 /
      DATA B(13549), B(13550), B(13551) /    -8.39,  -12.85,    0.00 /
      DATA B(13888), B(13889), B(13890) /    -8.39,  -12.87,    0.00 /
      DATA B(14227), B(14228), B(14229) /    -8.40,  -12.88,    0.00 /
      DATA B(14566), B(14567), B(14568) /    -8.40,  -12.89,    0.00 /
      DATA B(14905), B(14906), B(14907) /    -8.40,  -12.91,    0.00 /
      DATA B(15244), B(15245), B(15246) /    -8.41,  -12.92,    0.00 /
      DATA B(15583), B(15584), B(15585) /    -8.41,  -12.94,    0.00 /
      DATA B(15922), B(15923), B(15924) /    -8.41,  -12.95,    0.00 /
      DATA B(16261), B(16262), B(16263) /    -8.40,  -12.97,    0.00 /
      DATA B(16600), B(16601), B(16602) /    -8.40,  -12.99,    0.00 /
      DATA B(16939), B(16940), B(16941) /    -8.40,  -13.01,    0.00 /
      DATA B(17278), B(17279), B(17280) /    -8.39,  -13.03,    0.00 /
      DATA B(17617), B(17618), B(17619) /    -8.39,  -13.06,    0.00 /
      DATA B(17956), B(17957), B(17958) /    -8.38,  -13.08,    0.00 /
      DATA B(18295), B(18296), B(18297) /    -8.37,  -13.11,    0.00 /
      DATA B(18634), B(18635), B(18636) /    -8.36,  -13.14,    0.00 /
      DATA B(18973), B(18974), B(18975) /    -8.35,  -13.17,    0.00 /
      DATA B(19312), B(19313), B(19314) /    -8.34,  -13.20,    0.00 /
      DATA B(19651), B(19652), B(19653) /    -8.32,  -13.24,    0.00 /
      DATA B(19990), B(19991), B(19992) /    -8.30,  -13.28,    0.00 /
      DATA B(20329), B(20330), B(20331) /    -8.28,  -13.33,    0.00 /
      DATA B(20668), B(20669), B(20670) /    -8.26,  -13.39,    0.00 /
      DATA B(21007), B(21008), B(21009) /    -8.23,  -13.45,    0.00 /
      DATA B(21346), B(21347), B(21348) /    -8.19,  -13.53,    0.00 /
      DATA B(21685), B(21686), B(21687) /    -8.14,  -13.62,    0.00 /
      DATA B(22024), B(22025), B(22026) /    -8.09,  -13.74,    0.00 /
      DATA B(22363), B(22364), B(22365) /    -8.02,  -13.89,    0.00 /
      DATA B(22702), B(22703), B(22704) /    -7.94,  -14.08,    0.00 /
      DATA B(23041), B(23042), B(23043) /    -7.87,  -14.33,    0.00 /
      DATA B(23380), B(23381), B(23382) /    -8.91,  -11.45,    0.00 /
      DATA B(23719), B(23720), B(23721) /    -8.96,  -11.91,    0.00 /
      DATA B(24058), B(24059), B(24060) /    -9.18,  -12.38,    0.00 /
      DATA B(24397), B(24398), B(24399) /    -9.43,  -12.84,    0.00 /
      DATA B(24736), B(24737), B(24738) /    -9.51,  -13.28,    0.00 /
      DATA B(25075), B(25076), B(25077) /    -9.47,  -13.64,    0.00 /
      DATA B(25414), B(25415), B(25416) /    -9.40,  -13.91,    0.00 /
      DATA B(25753), B(25754), B(25755) /    -9.33,  -14.12,    0.00 /
      DATA B(26092), B(26093), B(26094) /    -9.27,  -14.27,    0.00 /
      DATA B(26431), B(26432), B(26433) /    -9.23,  -14.39,    0.00 /
      DATA B(26770), B(26771), B(26772) /    -9.19,  -14.48,    0.00 /
      DATA B(27109), B(27110), B(27111) /    -9.17,  -14.56,    0.00 /
      DATA B(27448), B(27449), B(27450) /    -9.14,  -14.62,    0.00 /
      DATA B(  331), B(  332), B(  333) /    14.04,  -45.22,    0.00 /
      DATA B(  670), B(  671), B(  672) /    13.49,  -45.40,    0.00 /
      DATA B( 1009), B( 1010), B( 1011) /    12.74,  -45.59,    0.00 /
      DATA B( 1348), B( 1349), B( 1350) /    11.67,  -45.77,    0.00 /
      DATA B( 1687), B( 1688), B( 1689) /     9.94,  -45.98,    0.00 /
      DATA B( 2026), B( 2027), B( 2028) /     6.60,  -46.34,    0.00 /
      DATA B( 2365), B( 2366), B( 2367) /    -1.58,  -30.60,    0.00 /
      DATA B( 2704), B( 2705), B( 2706) /    -4.46,  -26.61,    0.00 /
      DATA B( 3043), B( 3044), B( 3045) /    -5.60,  -24.18,    0.00 /
      DATA B( 3382), B( 3383), B( 3384) /    -6.41,  -22.10,    0.00 /
      DATA B( 3721), B( 3722), B( 3723) /    -6.96,  -20.36,    0.00 /
      DATA B( 4060), B( 4061), B( 4062) /    -7.34,  -18.96,    0.00 /
      DATA B( 4399), B( 4400), B( 4401) /    -7.61,  -17.82,    0.00 /
      DATA B( 4738), B( 4739), B( 4740) /    -7.81,  -16.89,    0.00 /
      DATA B( 5077), B( 5078), B( 5079) /    -7.95,  -16.12,    0.00 /
      DATA B( 5416), B( 5417), B( 5418) /    -8.04,  -15.48,    0.00 /
      DATA B( 5755), B( 5756), B( 5757) /    -8.11,  -14.94,    0.00 /
      DATA B( 6094), B( 6095), B( 6096) /    -8.14,  -14.50,    0.00 /
      DATA B( 6433), B( 6434), B( 6435) /    -8.17,  -14.15,    0.00 /
      DATA B( 6772), B( 6773), B( 6774) /    -8.18,  -13.86,    0.00 /
      DATA B( 7111), B( 7112), B( 7113) /    -8.20,  -13.63,    0.00 /
      DATA B( 7450), B( 7451), B( 7452) /    -8.21,  -13.45,    0.00 /
      DATA B( 7789), B( 7790), B( 7791) /    -8.22,  -13.31,    0.00 /
      DATA B( 8128), B( 8129), B( 8130) /    -8.23,  -13.19,    0.00 /
      DATA B( 8467), B( 8468), B( 8469) /    -8.25,  -13.10,    0.00 /
      DATA B( 8806), B( 8807), B( 8808) /    -8.26,  -13.03,    0.00 /
      DATA B( 9145), B( 9146), B( 9147) /    -8.28,  -12.97,    0.00 /
      DATA B( 9484), B( 9485), B( 9486) /    -8.29,  -12.93,    0.00 /
      DATA B( 9823), B( 9824), B( 9825) /    -8.30,  -12.89,    0.00 /
      DATA B(10162), B(10163), B(10164) /    -8.32,  -12.86,    0.00 /
      DATA B(10501), B(10502), B(10503) /    -8.33,  -12.84,    0.00 /
      DATA B(10840), B(10841), B(10842) /    -8.34,  -12.82,    0.00 /
      DATA B(11179), B(11180), B(11181) /    -8.35,  -12.81,    0.00 /
      DATA B(11518), B(11519), B(11520) /    -8.36,  -12.81,    0.00 /
      DATA B(11857), B(11858), B(11859) /    -8.37,  -12.80,    0.00 /
      DATA B(12196), B(12197), B(12198) /    -8.37,  -12.80,    0.00 /
      DATA B(12535), B(12536), B(12537) /    -8.38,  -12.81,    0.00 /
      DATA B(12874), B(12875), B(12876) /    -8.38,  -12.81,    0.00 /
      DATA B(13213), B(13214), B(13215) /    -8.39,  -12.82,    0.00 /
      DATA B(13552), B(13553), B(13554) /    -8.39,  -12.83,    0.00 /
      DATA B(13891), B(13892), B(13893) /    -8.40,  -12.84,    0.00 /
      DATA B(14230), B(14231), B(14232) /    -8.40,  -12.86,    0.00 /
      DATA B(14569), B(14570), B(14571) /    -8.40,  -12.87,    0.00 /
      DATA B(14908), B(14909), B(14910) /    -8.40,  -12.88,    0.00 /
      DATA B(15247), B(15248), B(15249) /    -8.41,  -12.90,    0.00 /
      DATA B(15586), B(15587), B(15588) /    -8.41,  -12.91,    0.00 /
      DATA B(15925), B(15926), B(15927) /    -8.40,  -12.93,    0.00 /
      DATA B(16264), B(16265), B(16266) /    -8.40,  -12.95,    0.00 /
      DATA B(16603), B(16604), B(16605) /    -8.40,  -12.97,    0.00 /
      DATA B(16942), B(16943), B(16944) /    -8.40,  -12.99,    0.00 /
      DATA B(17281), B(17282), B(17283) /    -8.39,  -13.01,    0.00 /
      DATA B(17620), B(17621), B(17622) /    -8.39,  -13.03,    0.00 /
      DATA B(17959), B(17960), B(17961) /    -8.38,  -13.05,    0.00 /
      DATA B(18298), B(18299), B(18300) /    -8.37,  -13.08,    0.00 /
      DATA B(18637), B(18638), B(18639) /    -8.36,  -13.11,    0.00 /
      DATA B(18976), B(18977), B(18978) /    -8.35,  -13.14,    0.00 /
      DATA B(19315), B(19316), B(19317) /    -8.34,  -13.17,    0.00 /
      DATA B(19654), B(19655), B(19656) /    -8.32,  -13.21,    0.00 /
      DATA B(19993), B(19994), B(19995) /    -8.31,  -13.25,    0.00 /
      DATA B(20332), B(20333), B(20334) /    -8.29,  -13.29,    0.00 /
      DATA B(20671), B(20672), B(20673) /    -8.26,  -13.34,    0.00 /
      DATA B(21010), B(21011), B(21012) /    -8.23,  -13.40,    0.00 /
      DATA B(21349), B(21350), B(21351) /    -8.20,  -13.47,    0.00 /
      DATA B(21688), B(21689), B(21690) /    -8.16,  -13.56,    0.00 /
      DATA B(22027), B(22028), B(22029) /    -8.11,  -13.66,    0.00 /
      DATA B(22366), B(22367), B(22368) /    -8.05,  -13.79,    0.00 /
      DATA B(22705), B(22706), B(22707) /    -7.98,  -13.95,    0.00 /
      DATA B(23044), B(23045), B(23046) /    -7.90,  -14.16,    0.00 /
      DATA B(23383), B(23384), B(23385) /    -7.82,  -14.38,    0.00 /
      DATA B(23722), B(23723), B(23724) /    -8.89,  -11.70,    0.00 /
      DATA B(24061), B(24062), B(24063) /    -9.03,  -12.16,    0.00 /
      DATA B(24400), B(24401), B(24402) /    -9.29,  -12.63,    0.00 /
      DATA B(24739), B(24740), B(24741) /    -9.46,  -13.07,    0.00 /
      DATA B(25078), B(25079), B(25080) /    -9.47,  -13.47,    0.00 /
      DATA B(25417), B(25418), B(25419) /    -9.41,  -13.78,    0.00 /
      DATA B(25756), B(25757), B(25758) /    -9.34,  -14.02,    0.00 /
      DATA B(26095), B(26096), B(26097) /    -9.27,  -14.19,    0.00 /
      DATA B(26434), B(26435), B(26436) /    -9.22,  -14.32,    0.00 /
      DATA B(26773), B(26774), B(26775) /    -9.18,  -14.42,    0.00 /
      DATA B(27112), B(27113), B(27114) /    -9.15,  -14.50,    0.00 /
      DATA B(27451), B(27452), B(27453) /    -9.13,  -14.57,    0.00 /
      DATA B(  334), B(  335), B(  336) /   -10.56,  -11.39,    0.00 /
      DATA B(  673), B(  674), B(  675) /   -10.86,  -11.42,    0.00 /
      DATA B( 1012), B( 1013), B( 1014) /   -11.25,  -11.47,    0.00 /
      DATA B( 1351), B( 1352), B( 1353) /   -11.72,  -11.57,    0.00 /
      DATA B( 1690), B( 1691), B( 1692) /   -12.05,  -11.91,    0.00 /
      DATA B( 2029), B( 2030), B( 2031) /   -10.47,  -14.41,    0.00 /
      DATA B( 2368), B( 2369), B( 2370) /    -8.74,  -25.23,    0.00 /
      DATA B( 2707), B( 2708), B( 2709) /    -8.67,  -24.21,    0.00 /
      DATA B( 3046), B( 3047), B( 3048) /    -8.23,  -22.14,    0.00 /
      DATA B( 3385), B( 3386), B( 3387) /    -8.10,  -20.43,    0.00 /
      DATA B( 3724), B( 3725), B( 3726) /    -8.10,  -19.05,    0.00 /
      DATA B( 4063), B( 4064), B( 4065) /    -8.14,  -17.94,    0.00 /
      DATA B( 4402), B( 4403), B( 4404) /    -8.19,  -17.03,    0.00 /
      DATA B( 4741), B( 4742), B( 4743) /    -8.24,  -16.28,    0.00 /
      DATA B( 5080), B( 5081), B( 5082) /    -8.28,  -15.65,    0.00 /
      DATA B( 5419), B( 5420), B( 5421) /    -8.30,  -15.12,    0.00 /
      DATA B( 5758), B( 5759), B( 5760) /    -8.32,  -14.68,    0.00 /
      DATA B( 6097), B( 6098), B( 6099) /    -8.32,  -14.31,    0.00 /
      DATA B( 6436), B( 6437), B( 6438) /    -8.32,  -14.00,    0.00 /
      DATA B( 6775), B( 6776), B( 6777) /    -8.32,  -13.75,    0.00 /
      DATA B( 7114), B( 7115), B( 7116) /    -8.31,  -13.55,    0.00 /
      DATA B( 7453), B( 7454), B( 7455) /    -8.31,  -13.38,    0.00 /
      DATA B( 7792), B( 7793), B( 7794) /    -8.31,  -13.25,    0.00 /
      DATA B( 8131), B( 8132), B( 8133) /    -8.31,  -13.15,    0.00 /
      DATA B( 8470), B( 8471), B( 8472) /    -8.31,  -13.06,    0.00 /
      DATA B( 8809), B( 8810), B( 8811) /    -8.32,  -12.99,    0.00 /
      DATA B( 9148), B( 9149), B( 9150) /    -8.33,  -12.94,    0.00 /
      DATA B( 9487), B( 9488), B( 9489) /    -8.33,  -12.90,    0.00 /
      DATA B( 9826), B( 9827), B( 9828) /    -8.34,  -12.86,    0.00 /
      DATA B(10165), B(10166), B(10167) /    -8.35,  -12.83,    0.00 /
      DATA B(10504), B(10505), B(10506) /    -8.36,  -12.81,    0.00 /
      DATA B(10843), B(10844), B(10845) /    -8.36,  -12.80,    0.00 /
      DATA B(11182), B(11183), B(11184) /    -8.37,  -12.79,    0.00 /
      DATA B(11521), B(11522), B(11523) /    -8.37,  -12.78,    0.00 /
      DATA B(11860), B(11861), B(11862) /    -8.38,  -12.78,    0.00 /
      DATA B(12199), B(12200), B(12201) /    -8.38,  -12.78,    0.00 /
      DATA B(12538), B(12539), B(12540) /    -8.39,  -12.79,    0.00 /
      DATA B(12877), B(12878), B(12879) /    -8.39,  -12.79,    0.00 /
      DATA B(13216), B(13217), B(13218) /    -8.40,  -12.80,    0.00 /
      DATA B(13555), B(13556), B(13557) /    -8.40,  -12.81,    0.00 /
      DATA B(13894), B(13895), B(13896) /    -8.40,  -12.82,    0.00 /
      DATA B(14233), B(14234), B(14235) /    -8.40,  -12.83,    0.00 /
      DATA B(14572), B(14573), B(14574) /    -8.40,  -12.85,    0.00 /
      DATA B(14911), B(14912), B(14913) /    -8.40,  -12.86,    0.00 /
      DATA B(15250), B(15251), B(15252) /    -8.40,  -12.88,    0.00 /
      DATA B(15589), B(15590), B(15591) /    -8.40,  -12.89,    0.00 /
      DATA B(15928), B(15929), B(15930) /    -8.40,  -12.91,    0.00 /
      DATA B(16267), B(16268), B(16269) /    -8.40,  -12.93,    0.00 /
      DATA B(16606), B(16607), B(16608) /    -8.40,  -12.94,    0.00 /
      DATA B(16945), B(16946), B(16947) /    -8.39,  -12.96,    0.00 /
      DATA B(17284), B(17285), B(17286) /    -8.39,  -12.98,    0.00 /
      DATA B(17623), B(17624), B(17625) /    -8.38,  -13.01,    0.00 /
      DATA B(17962), B(17963), B(17964) /    -8.38,  -13.03,    0.00 /
      DATA B(18301), B(18302), B(18303) /    -8.37,  -13.05,    0.00 /
      DATA B(18640), B(18641), B(18642) /    -8.36,  -13.08,    0.00 /
      DATA B(18979), B(18980), B(18981) /    -8.35,  -13.11,    0.00 /
      DATA B(19318), B(19319), B(19320) /    -8.34,  -13.14,    0.00 /
      DATA B(19657), B(19658), B(19659) /    -8.32,  -13.17,    0.00 /
      DATA B(19996), B(19997), B(19998) /    -8.31,  -13.21,    0.00 /
      DATA B(20335), B(20336), B(20337) /    -8.29,  -13.25,    0.00 /
      DATA B(20674), B(20675), B(20676) /    -8.27,  -13.30,    0.00 /
      DATA B(21013), B(21014), B(21015) /    -8.24,  -13.36,    0.00 /
      DATA B(21352), B(21353), B(21354) /    -8.21,  -13.42,    0.00 /
      DATA B(21691), B(21692), B(21693) /    -8.17,  -13.49,    0.00 /
      DATA B(22030), B(22031), B(22032) /    -8.13,  -13.58,    0.00 /
      DATA B(22369), B(22370), B(22371) /    -8.07,  -13.70,    0.00 /
      DATA B(22708), B(22709), B(22710) /    -8.01,  -13.84,    0.00 /
      DATA B(23047), B(23048), B(23049) /    -7.93,  -14.02,    0.00 /
      DATA B(23386), B(23387), B(23388) /    -7.85,  -14.26,    0.00 /
      DATA B(23725), B(23726), B(23727) /    -8.91,  -11.50,    0.00 /
      DATA B(24064), B(24065), B(24066) /    -8.91,  -11.95,    0.00 /
      DATA B(24403), B(24404), B(24405) /    -9.12,  -12.41,    0.00 /
      DATA B(24742), B(24743), B(24744) /    -9.36,  -12.86,    0.00 /
      DATA B(25081), B(25082), B(25083) /    -9.45,  -13.28,    0.00 /
      DATA B(25420), B(25421), B(25422) /    -9.41,  -13.63,    0.00 /
      DATA B(25759), B(25760), B(25761) /    -9.34,  -13.90,    0.00 /
      DATA B(26098), B(26099), B(26100) /    -9.27,  -14.10,    0.00 /
      DATA B(26437), B(26438), B(26439) /    -9.22,  -14.25,    0.00 /
      DATA B(26776), B(26777), B(26778) /    -9.17,  -14.36,    0.00 /
      DATA B(27115), B(27116), B(27117) /    -9.14,  -14.45,    0.00 /
      DATA B(27454), B(27455), B(27456) /    -9.12,  -14.52,    0.00 /
      DATA B(  337), B(  338), B(  339) /   -10.25,  -11.45,    0.00 /
      DATA B(  676), B(  677), B(  678) /   -10.40,  -11.53,    0.00 /
      DATA B( 1015), B( 1016), B( 1017) /   -10.53,  -11.67,    0.00 /
      DATA B( 1354), B( 1355), B( 1356) /   -10.51,  -11.99,    0.00 /
      DATA B( 1693), B( 1694), B( 1695) /    -9.96,  -12.98,    0.00 /
      DATA B( 2032), B( 2033), B( 2034) /    -8.55,  -16.13,    0.00 /
      DATA B( 2371), B( 2372), B( 2373) /    -8.42,  -20.97,    0.00 /
      DATA B( 2710), B( 2711), B( 2712) /    -9.23,  -21.72,    0.00 /
      DATA B( 3049), B( 3050), B( 3051) /    -9.17,  -20.44,    0.00 /
      DATA B( 3388), B( 3389), B( 3390) /    -8.93,  -19.12,    0.00 /
      DATA B( 3727), B( 3728), B( 3729) /    -8.75,  -18.03,    0.00 /
      DATA B( 4066), B( 4067), B( 4068) /    -8.64,  -17.14,    0.00 /
      DATA B( 4405), B( 4406), B( 4407) /    -8.58,  -16.40,    0.00 /
      DATA B( 4744), B( 4745), B( 4746) /    -8.54,  -15.79,    0.00 /
      DATA B( 5083), B( 5084), B( 5085) /    -8.52,  -15.27,    0.00 /
      DATA B( 5422), B( 5423), B( 5424) /    -8.50,  -14.83,    0.00 /
      DATA B( 5761), B( 5762), B( 5763) /    -8.48,  -14.46,    0.00 /
      DATA B( 6100), B( 6101), B( 6102) /    -8.46,  -14.14,    0.00 /
      DATA B( 6439), B( 6440), B( 6441) /    -8.44,  -13.87,    0.00 /
      DATA B( 6778), B( 6779), B( 6780) /    -8.42,  -13.65,    0.00 /
      DATA B( 7117), B( 7118), B( 7119) /    -8.41,  -13.47,    0.00 /
      DATA B( 7456), B( 7457), B( 7458) /    -8.40,  -13.32,    0.00 /
      DATA B( 7795), B( 7796), B( 7797) /    -8.39,  -13.20,    0.00 /
      DATA B( 8134), B( 8135), B( 8136) /    -8.38,  -13.10,    0.00 /
      DATA B( 8473), B( 8474), B( 8475) /    -8.37,  -13.02,    0.00 /
      DATA B( 8812), B( 8813), B( 8814) /    -8.37,  -12.96,    0.00 /
      DATA B( 9151), B( 9152), B( 9153) /    -8.37,  -12.91,    0.00 /
      DATA B( 9490), B( 9491), B( 9492) /    -8.37,  -12.87,    0.00 /
      DATA B( 9829), B( 9830), B( 9831) /    -8.37,  -12.84,    0.00 /
      DATA B(10168), B(10169), B(10170) /    -8.38,  -12.81,    0.00 /
      DATA B(10507), B(10508), B(10509) /    -8.38,  -12.79,    0.00 /
      DATA B(10846), B(10847), B(10848) /    -8.38,  -12.78,    0.00 /
      DATA B(11185), B(11186), B(11187) /    -8.39,  -12.77,    0.00 /
      DATA B(11524), B(11525), B(11526) /    -8.39,  -12.76,    0.00 /
      DATA B(11863), B(11864), B(11865) /    -8.39,  -12.76,    0.00 /
      DATA B(12202), B(12203), B(12204) /    -8.39,  -12.76,    0.00 /
      DATA B(12541), B(12542), B(12543) /    -8.40,  -12.77,    0.00 /
      DATA B(12880), B(12881), B(12882) /    -8.40,  -12.77,    0.00 /
      DATA B(13219), B(13220), B(13221) /    -8.40,  -12.78,    0.00 /
      DATA B(13558), B(13559), B(13560) /    -8.40,  -12.79,    0.00 /
      DATA B(13897), B(13898), B(13899) /    -8.40,  -12.80,    0.00 /
      DATA B(14236), B(14237), B(14238) /    -8.40,  -12.81,    0.00 /
      DATA B(14575), B(14576), B(14577) /    -8.40,  -12.83,    0.00 /
      DATA B(14914), B(14915), B(14916) /    -8.40,  -12.84,    0.00 /
      DATA B(15253), B(15254), B(15255) /    -8.40,  -12.86,    0.00 /
      DATA B(15592), B(15593), B(15594) /    -8.40,  -12.87,    0.00 /
      DATA B(15931), B(15932), B(15933) /    -8.40,  -12.89,    0.00 /
      DATA B(16270), B(16271), B(16272) /    -8.40,  -12.91,    0.00 /
      DATA B(16609), B(16610), B(16611) /    -8.39,  -12.92,    0.00 /
      DATA B(16948), B(16949), B(16950) /    -8.39,  -12.94,    0.00 /
      DATA B(17287), B(17288), B(17289) /    -8.39,  -12.96,    0.00 /
      DATA B(17626), B(17627), B(17628) /    -8.38,  -12.98,    0.00 /
      DATA B(17965), B(17966), B(17967) /    -8.37,  -13.01,    0.00 /
      DATA B(18304), B(18305), B(18306) /    -8.37,  -13.03,    0.00 /
      DATA B(18643), B(18644), B(18645) /    -8.36,  -13.06,    0.00 /
      DATA B(18982), B(18983), B(18984) /    -8.35,  -13.08,    0.00 /
      DATA B(19321), B(19322), B(19323) /    -8.34,  -13.11,    0.00 /
      DATA B(19660), B(19661), B(19662) /    -8.32,  -13.15,    0.00 /
      DATA B(19999), B(20000), B(20001) /    -8.31,  -13.18,    0.00 /
      DATA B(20338), B(20339), B(20340) /    -8.29,  -13.22,    0.00 /
      DATA B(20677), B(20678), B(20679) /    -8.27,  -13.26,    0.00 /
      DATA B(21016), B(21017), B(21018) /    -8.25,  -13.31,    0.00 /
      DATA B(21355), B(21356), B(21357) /    -8.22,  -13.37,    0.00 /
      DATA B(21694), B(21695), B(21696) /    -8.18,  -13.44,    0.00 /
      DATA B(22033), B(22034), B(22035) /    -8.14,  -13.52,    0.00 /
      DATA B(22372), B(22373), B(22374) /    -8.09,  -13.62,    0.00 /
      DATA B(22711), B(22712), B(22713) /    -8.03,  -13.74,    0.00 /
      DATA B(23050), B(23051), B(23052) /    -7.96,  -13.90,    0.00 /
      DATA B(23389), B(23390), B(23391) /    -7.88,  -14.10,    0.00 /
      DATA B(23728), B(23729), B(23730) /    -7.81,  -14.35,    0.00 /
      DATA B(24067), B(24068), B(24069) /    -8.86,  -11.76,    0.00 /
      DATA B(24406), B(24407), B(24408) /    -8.97,  -12.21,    0.00 /
      DATA B(24745), B(24746), B(24747) /    -9.22,  -12.65,    0.00 /
      DATA B(25084), B(25085), B(25086) /    -9.39,  -13.08,    0.00 /
      DATA B(25423), B(25424), B(25425) /    -9.41,  -13.47,    0.00 /
      DATA B(25762), B(25763), B(25764) /    -9.35,  -13.77,    0.00 /
      DATA B(26101), B(26102), B(26103) /    -9.28,  -13.99,    0.00 /
      DATA B(26440), B(26441), B(26442) /    -9.21,  -14.16,    0.00 /
      DATA B(26779), B(26780), B(26781) /    -9.17,  -14.28,    0.00 /
      DATA B(27118), B(27119), B(27120) /    -9.13,  -14.38,    0.00 /
      DATA B(27457), B(27458), B(27459) /    -9.10,  -14.46,    0.00 /
      DATA GRDLX( 2) / 235.00000000000 /,
     *     GRDUX( 2) / 241.00000000000 /,
     *     GRDLY( 2) /  36.00000000000 /,
     *     GRDUY( 2) /  40.00000000000 /,
     *     ICNTX( 2) / 96 /,
     *     ICNTY( 2) / 64 /,
     *     NBASE( 2) /27459 /
      DATA B(27460), B(27461), B(27462) /    27.01,  -42.17,    0.00 /
      DATA B(27751), B(27752), B(27753) /    27.01,  -42.10,    0.00 /
      DATA B(28042), B(28043), B(28044) /    27.01,  -42.04,    0.00 /
      DATA B(28333), B(28334), B(28335) /    27.01,  -41.98,    0.00 /
      DATA B(28624), B(28625), B(28626) /    27.00,  -41.91,    0.00 /
      DATA B(28915), B(28916), B(28917) /    27.00,  -41.85,    0.00 /
      DATA B(29206), B(29207), B(29208) /    27.00,  -41.78,    0.00 /
      DATA B(29497), B(29498), B(29499) /    27.00,  -41.72,    0.00 /
      DATA B(29788), B(29789), B(29790) /    26.99,  -41.65,    0.00 /
      DATA B(30079), B(30080), B(30081) /    26.99,  -41.59,    0.00 /
      DATA B(30370), B(30371), B(30372) /    26.99,  -41.52,    0.00 /
      DATA B(30661), B(30662), B(30663) /    26.98,  -41.46,    0.00 /
      DATA B(30952), B(30953), B(30954) /    26.98,  -41.39,    0.00 /
      DATA B(31243), B(31244), B(31245) /    26.98,  -41.33,    0.00 /
      DATA B(31534), B(31535), B(31536) /    26.97,  -41.26,    0.00 /
      DATA B(31825), B(31826), B(31827) /    26.97,  -41.19,    0.00 /
      DATA B(32116), B(32117), B(32118) /    26.97,  -41.13,    0.00 /
      DATA B(32407), B(32408), B(32409) /    26.96,  -41.06,    0.00 /
      DATA B(32698), B(32699), B(32700) /    26.96,  -40.99,    0.00 /
      DATA B(32989), B(32990), B(32991) /    26.95,  -40.93,    0.00 /
      DATA B(33280), B(33281), B(33282) /    26.95,  -40.86,    0.00 /
      DATA B(33571), B(33572), B(33573) /    26.94,  -40.79,    0.00 /
      DATA B(33862), B(33863), B(33864) /    26.94,  -40.72,    0.00 /
      DATA B(34153), B(34154), B(34155) /    26.93,  -40.65,    0.00 /
      DATA B(34444), B(34445), B(34446) /    26.93,  -40.59,    0.00 /
      DATA B(34735), B(34736), B(34737) /    26.92,  -40.52,    0.00 /
      DATA B(35026), B(35027), B(35028) /    26.92,  -40.45,    0.00 /
      DATA B(35317), B(35318), B(35319) /    26.91,  -40.38,    0.00 /
      DATA B(35608), B(35609), B(35610) /    26.90,  -40.31,    0.00 /
      DATA B(35899), B(35900), B(35901) /    26.90,  -40.25,    0.00 /
      DATA B(36190), B(36191), B(36192) /    26.89,  -40.18,    0.00 /
      DATA B(36481), B(36482), B(36483) /    26.89,  -40.11,    0.00 /
      DATA B(36772), B(36773), B(36774) /    26.88,  -40.04,    0.00 /
      DATA B(37063), B(37064), B(37065) /    26.87,  -39.97,    0.00 /
      DATA B(37354), B(37355), B(37356) /    26.86,  -39.90,    0.00 /
      DATA B(37645), B(37646), B(37647) /    26.86,  -39.83,    0.00 /
      DATA B(37936), B(37937), B(37938) /    26.85,  -39.75,    0.00 /
      DATA B(38227), B(38228), B(38229) /    26.84,  -39.68,    0.00 /
      DATA B(38518), B(38519), B(38520) /    26.84,  -39.61,    0.00 /
      DATA B(38809), B(38810), B(38811) /    26.83,  -39.53,    0.00 /
      DATA B(39100), B(39101), B(39102) /    26.83,  -39.46,    0.00 /
      DATA B(39391), B(39392), B(39393) /    26.82,  -39.38,    0.00 /
      DATA B(39682), B(39683), B(39684) /    26.81,  -39.30,    0.00 /
      DATA B(39973), B(39974), B(39975) /    26.81,  -39.22,    0.00 /
      DATA B(40264), B(40265), B(40266) /    26.80,  -39.14,    0.00 /
      DATA B(40555), B(40556), B(40557) /    26.80,  -39.06,    0.00 /
      DATA B(40846), B(40847), B(40848) /    26.79,  -38.97,    0.00 /
      DATA B(41137), B(41138), B(41139) /    26.78,  -38.88,    0.00 /
      DATA B(41428), B(41429), B(41430) /    26.78,  -38.80,    0.00 /
      DATA B(41719), B(41720), B(41721) /    26.78,  -38.71,    0.00 /
      DATA B(42010), B(42011), B(42012) /    26.77,  -38.62,    0.00 /
      DATA B(42301), B(42302), B(42303) /    26.77,  -38.52,    0.00 /
      DATA B(42592), B(42593), B(42594) /    26.77,  -38.43,    0.00 /
      DATA B(42883), B(42884), B(42885) /    26.77,  -38.34,    0.00 /
      DATA B(43174), B(43175), B(43176) /    26.77,  -38.24,    0.00 /
      DATA B(43465), B(43466), B(43467) /    26.78,  -38.14,    0.00 /
      DATA B(43756), B(43757), B(43758) /    26.79,  -38.04,    0.00 /
      DATA B(44047), B(44048), B(44049) /    26.81,  -37.94,    0.00 /
      DATA B(44338), B(44339), B(44340) /    26.83,  -37.83,    0.00 /
      DATA B(44629), B(44630), B(44631) /    26.86,  -37.72,    0.00 /
      DATA B(44920), B(44921), B(44922) /    26.91,  -37.60,    0.00 /
      DATA B(45211), B(45212), B(45213) /    26.97,  -37.47,    0.00 /
      DATA B(45502), B(45503), B(45504) /    27.05,  -37.33,    0.00 /
      DATA B(45793), B(45794), B(45795) /    27.15,  -37.17,    0.00 /
      DATA B(46084), B(46085), B(46086) /    27.29,  -36.98,    0.00 /
      DATA B(27463), B(27464), B(27465) /    26.99,  -42.15,    0.00 /
      DATA B(27754), B(27755), B(27756) /    26.98,  -42.08,    0.00 /
      DATA B(28045), B(28046), B(28047) /    26.98,  -42.02,    0.00 /
      DATA B(28336), B(28337), B(28338) /    26.98,  -41.96,    0.00 /
      DATA B(28627), B(28628), B(28629) /    26.98,  -41.89,    0.00 /
      DATA B(28918), B(28919), B(28920) /    26.97,  -41.83,    0.00 /
      DATA B(29209), B(29210), B(29211) /    26.97,  -41.76,    0.00 /
      DATA B(29500), B(29501), B(29502) /    26.97,  -41.70,    0.00 /
      DATA B(29791), B(29792), B(29793) /    26.97,  -41.63,    0.00 /
      DATA B(30082), B(30083), B(30084) /    26.96,  -41.57,    0.00 /
      DATA B(30373), B(30374), B(30375) /    26.96,  -41.50,    0.00 /
      DATA B(30664), B(30665), B(30666) /    26.96,  -41.44,    0.00 /
      DATA B(30955), B(30956), B(30957) /    26.95,  -41.37,    0.00 /
      DATA B(31246), B(31247), B(31248) /    26.95,  -41.31,    0.00 /
      DATA B(31537), B(31538), B(31539) /    26.95,  -41.24,    0.00 /
      DATA B(31828), B(31829), B(31830) /    26.94,  -41.17,    0.00 /
      DATA B(32119), B(32120), B(32121) /    26.94,  -41.11,    0.00 /
      DATA B(32410), B(32411), B(32412) /    26.93,  -41.04,    0.00 /
      DATA B(32701), B(32702), B(32703) /    26.93,  -40.97,    0.00 /
      DATA B(32992), B(32993), B(32994) /    26.92,  -40.90,    0.00 /
      DATA B(33283), B(33284), B(33285) /    26.92,  -40.84,    0.00 /
      DATA B(33574), B(33575), B(33576) /    26.91,  -40.77,    0.00 /
      DATA B(33865), B(33866), B(33867) /    26.91,  -40.70,    0.00 /
      DATA B(34156), B(34157), B(34158) /    26.90,  -40.63,    0.00 /
      DATA B(34447), B(34448), B(34449) /    26.90,  -40.56,    0.00 /
      DATA B(34738), B(34739), B(34740) /    26.89,  -40.49,    0.00 /
      DATA B(35029), B(35030), B(35031) /    26.89,  -40.43,    0.00 /
      DATA B(35320), B(35321), B(35322) /    26.88,  -40.36,    0.00 /
      DATA B(35611), B(35612), B(35613) /    26.87,  -40.29,    0.00 /
      DATA B(35902), B(35903), B(35904) /    26.86,  -40.22,    0.00 /
      DATA B(36193), B(36194), B(36195) /    26.86,  -40.15,    0.00 /
      DATA B(36484), B(36485), B(36486) /    26.85,  -40.08,    0.00 /
      DATA B(36775), B(36776), B(36777) /    26.84,  -40.01,    0.00 /
      DATA B(37066), B(37067), B(37068) /    26.84,  -39.94,    0.00 /
      DATA B(37357), B(37358), B(37359) /    26.83,  -39.87,    0.00 /
      DATA B(37648), B(37649), B(37650) /    26.82,  -39.80,    0.00 /
      DATA B(37939), B(37940), B(37941) /    26.81,  -39.73,    0.00 /
      DATA B(38230), B(38231), B(38232) /    26.80,  -39.66,    0.00 /
      DATA B(38521), B(38522), B(38523) /    26.80,  -39.58,    0.00 /
      DATA B(38812), B(38813), B(38814) /    26.79,  -39.51,    0.00 /
      DATA B(39103), B(39104), B(39105) /    26.78,  -39.43,    0.00 /
      DATA B(39394), B(39395), B(39396) /    26.78,  -39.35,    0.00 /
      DATA B(39685), B(39686), B(39687) /    26.77,  -39.27,    0.00 /
      DATA B(39976), B(39977), B(39978) /    26.76,  -39.19,    0.00 /
      DATA B(40267), B(40268), B(40269) /    26.75,  -39.11,    0.00 /
      DATA B(40558), B(40559), B(40560) /    26.75,  -39.02,    0.00 /
      DATA B(40849), B(40850), B(40851) /    26.74,  -38.93,    0.00 /
      DATA B(41140), B(41141), B(41142) /    26.73,  -38.85,    0.00 /
      DATA B(41431), B(41432), B(41433) /    26.73,  -38.76,    0.00 /
      DATA B(41722), B(41723), B(41724) /    26.72,  -38.66,    0.00 /
      DATA B(42013), B(42014), B(42015) /    26.71,  -38.57,    0.00 /
      DATA B(42304), B(42305), B(42306) /    26.71,  -38.48,    0.00 /
      DATA B(42595), B(42596), B(42597) /    26.70,  -38.38,    0.00 /
      DATA B(42886), B(42887), B(42888) /    26.70,  -38.28,    0.00 /
      DATA B(43177), B(43178), B(43179) /    26.70,  -38.19,    0.00 /
      DATA B(43468), B(43469), B(43470) /    26.71,  -38.09,    0.00 /
      DATA B(43759), B(43760), B(43761) /    26.72,  -37.98,    0.00 /
      DATA B(44050), B(44051), B(44052) /    26.73,  -37.88,    0.00 /
      DATA B(44341), B(44342), B(44343) /    26.75,  -37.77,    0.00 /
      DATA B(44632), B(44633), B(44634) /    26.78,  -37.65,    0.00 /
      DATA B(44923), B(44924), B(44925) /    26.82,  -37.53,    0.00 /
      DATA B(45214), B(45215), B(45216) /    26.88,  -37.39,    0.00 /
      DATA B(45505), B(45506), B(45507) /    26.96,  -37.24,    0.00 /
      DATA B(45796), B(45797), B(45798) /    27.06,  -37.07,    0.00 /
      DATA B(46087), B(46088), B(46089) /    27.20,  -36.87,    0.00 /
      DATA B(27466), B(27467), B(27468) /    26.96,  -42.13,    0.00 /
      DATA B(27757), B(27758), B(27759) /    26.96,  -42.06,    0.00 /
      DATA B(28048), B(28049), B(28050) /    26.95,  -42.00,    0.00 /
      DATA B(28339), B(28340), B(28341) /    26.95,  -41.94,    0.00 /
      DATA B(28630), B(28631), B(28632) /    26.95,  -41.87,    0.00 /
      DATA B(28921), B(28922), B(28923) /    26.95,  -41.81,    0.00 /
      DATA B(29212), B(29213), B(29214) /    26.94,  -41.74,    0.00 /
      DATA B(29503), B(29504), B(29505) /    26.94,  -41.68,    0.00 /
      DATA B(29794), B(29795), B(29796) /    26.94,  -41.61,    0.00 /
      DATA B(30085), B(30086), B(30087) /    26.93,  -41.55,    0.00 /
      DATA B(30376), B(30377), B(30378) /    26.93,  -41.48,    0.00 /
      DATA B(30667), B(30668), B(30669) /    26.93,  -41.42,    0.00 /
      DATA B(30958), B(30959), B(30960) /    26.92,  -41.35,    0.00 /
      DATA B(31249), B(31250), B(31251) /    26.92,  -41.28,    0.00 /
      DATA B(31540), B(31541), B(31542) /    26.92,  -41.22,    0.00 /
      DATA B(31831), B(31832), B(31833) /    26.91,  -41.15,    0.00 /
      DATA B(32122), B(32123), B(32124) /    26.91,  -41.08,    0.00 /
      DATA B(32413), B(32414), B(32415) /    26.90,  -41.02,    0.00 /
      DATA B(32704), B(32705), B(32706) /    26.90,  -40.95,    0.00 /
      DATA B(32995), B(32996), B(32997) /    26.90,  -40.88,    0.00 /
      DATA B(33286), B(33287), B(33288) /    26.89,  -40.81,    0.00 /
      DATA B(33577), B(33578), B(33579) /    26.88,  -40.74,    0.00 /
      DATA B(33868), B(33869), B(33870) /    26.88,  -40.68,    0.00 /
      DATA B(34159), B(34160), B(34161) /    26.87,  -40.61,    0.00 /
      DATA B(34450), B(34451), B(34452) /    26.87,  -40.54,    0.00 /
      DATA B(34741), B(34742), B(34743) /    26.86,  -40.47,    0.00 /
      DATA B(35032), B(35033), B(35034) /    26.85,  -40.40,    0.00 /
      DATA B(35323), B(35324), B(35325) /    26.85,  -40.33,    0.00 /
      DATA B(35614), B(35615), B(35616) /    26.84,  -40.26,    0.00 /
      DATA B(35905), B(35906), B(35907) /    26.83,  -40.19,    0.00 /
      DATA B(36196), B(36197), B(36198) /    26.82,  -40.13,    0.00 /
      DATA B(36487), B(36488), B(36489) /    26.81,  -40.06,    0.00 /
      DATA B(36778), B(36779), B(36780) /    26.81,  -39.99,    0.00 /
      DATA B(37069), B(37070), B(37071) /    26.80,  -39.92,    0.00 /
      DATA B(37360), B(37361), B(37362) /    26.79,  -39.85,    0.00 /
      DATA B(37651), B(37652), B(37653) /    26.78,  -39.77,    0.00 /
      DATA B(37942), B(37943), B(37944) /    26.77,  -39.70,    0.00 /
      DATA B(38233), B(38234), B(38235) /    26.76,  -39.63,    0.00 /
      DATA B(38524), B(38525), B(38526) /    26.75,  -39.55,    0.00 /
      DATA B(38815), B(38816), B(38817) /    26.75,  -39.48,    0.00 /
      DATA B(39106), B(39107), B(39108) /    26.74,  -39.40,    0.00 /
      DATA B(39397), B(39398), B(39399) /    26.73,  -39.32,    0.00 /
      DATA B(39688), B(39689), B(39690) /    26.72,  -39.24,    0.00 /
      DATA B(39979), B(39980), B(39981) /    26.71,  -39.16,    0.00 /
      DATA B(40270), B(40271), B(40272) /    26.70,  -39.07,    0.00 /
      DATA B(40561), B(40562), B(40563) /    26.69,  -38.99,    0.00 /
      DATA B(40852), B(40853), B(40854) /    26.69,  -38.90,    0.00 /
      DATA B(41143), B(41144), B(41145) /    26.68,  -38.81,    0.00 /
      DATA B(41434), B(41435), B(41436) /    26.67,  -38.72,    0.00 /
      DATA B(41725), B(41726), B(41727) /    26.66,  -38.62,    0.00 /
      DATA B(42016), B(42017), B(42018) /    26.65,  -38.53,    0.00 /
      DATA B(42307), B(42308), B(42309) /    26.64,  -38.43,    0.00 /
      DATA B(42598), B(42599), B(42600) /    26.63,  -38.33,    0.00 /
      DATA B(42889), B(42890), B(42891) /    26.63,  -38.23,    0.00 /
      DATA B(43180), B(43181), B(43182) /    26.63,  -38.13,    0.00 /
      DATA B(43471), B(43472), B(43473) /    26.63,  -38.03,    0.00 /
      DATA B(43762), B(43763), B(43764) /    26.63,  -37.92,    0.00 /
      DATA B(44053), B(44054), B(44055) /    26.64,  -37.81,    0.00 /
      DATA B(44344), B(44345), B(44346) /    26.66,  -37.70,    0.00 /
      DATA B(44635), B(44636), B(44637) /    26.69,  -37.58,    0.00 /
      DATA B(44926), B(44927), B(44928) /    26.72,  -37.45,    0.00 /
      DATA B(45217), B(45218), B(45219) /    26.78,  -37.31,    0.00 /
      DATA B(45508), B(45509), B(45510) /    26.85,  -37.15,    0.00 /
      DATA B(45799), B(45800), B(45801) /    26.96,  -36.97,    0.00 /
      DATA B(46090), B(46091), B(46092) /    27.10,  -36.75,    0.00 /
      DATA B(27469), B(27470), B(27471) /    26.93,  -42.11,    0.00 /
      DATA B(27760), B(27761), B(27762) /    26.93,  -42.05,    0.00 /
      DATA B(28051), B(28052), B(28053) /    26.93,  -41.98,    0.00 /
      DATA B(28342), B(28343), B(28344) /    26.92,  -41.92,    0.00 /
      DATA B(28633), B(28634), B(28635) /    26.92,  -41.85,    0.00 /
      DATA B(28924), B(28925), B(28926) /    26.92,  -41.79,    0.00 /
      DATA B(29215), B(29216), B(29217) /    26.92,  -41.72,    0.00 /
      DATA B(29506), B(29507), B(29508) /    26.91,  -41.66,    0.00 /
      DATA B(29797), B(29798), B(29799) /    26.91,  -41.59,    0.00 /
      DATA B(30088), B(30089), B(30090) /    26.91,  -41.53,    0.00 /
      DATA B(30379), B(30380), B(30381) /    26.90,  -41.46,    0.00 /
      DATA B(30670), B(30671), B(30672) /    26.90,  -41.40,    0.00 /
      DATA B(30961), B(30962), B(30963) /    26.90,  -41.33,    0.00 /
      DATA B(31252), B(31253), B(31254) /    26.89,  -41.26,    0.00 /
      DATA B(31543), B(31544), B(31545) /    26.89,  -41.20,    0.00 /
      DATA B(31834), B(31835), B(31836) /    26.88,  -41.13,    0.00 /
      DATA B(32125), B(32126), B(32127) /    26.88,  -41.06,    0.00 /
      DATA B(32416), B(32417), B(32418) /    26.88,  -40.99,    0.00 /
      DATA B(32707), B(32708), B(32709) /    26.87,  -40.93,    0.00 /
      DATA B(32998), B(32999), B(33000) /    26.87,  -40.86,    0.00 /
      DATA B(33289), B(33290), B(33291) /    26.86,  -40.79,    0.00 /
      DATA B(33580), B(33581), B(33582) /    26.85,  -40.72,    0.00 /
      DATA B(33871), B(33872), B(33873) /    26.85,  -40.65,    0.00 /
      DATA B(34162), B(34163), B(34164) /    26.84,  -40.58,    0.00 /
      DATA B(34453), B(34454), B(34455) /    26.83,  -40.51,    0.00 /
      DATA B(34744), B(34745), B(34746) /    26.83,  -40.45,    0.00 /
      DATA B(35035), B(35036), B(35037) /    26.82,  -40.38,    0.00 /
      DATA B(35326), B(35327), B(35328) /    26.81,  -40.31,    0.00 /
      DATA B(35617), B(35618), B(35619) /    26.80,  -40.24,    0.00 /
      DATA B(35908), B(35909), B(35910) /    26.80,  -40.17,    0.00 /
      DATA B(36199), B(36200), B(36201) /    26.79,  -40.10,    0.00 /
      DATA B(36490), B(36491), B(36492) /    26.78,  -40.03,    0.00 /
      DATA B(36781), B(36782), B(36783) /    26.77,  -39.96,    0.00 /
      DATA B(37072), B(37073), B(37074) /    26.76,  -39.89,    0.00 /
      DATA B(37363), B(37364), B(37365) /    26.75,  -39.82,    0.00 /
      DATA B(37654), B(37655), B(37656) /    26.74,  -39.75,    0.00 /
      DATA B(37945), B(37946), B(37947) /    26.73,  -39.68,    0.00 /
      DATA B(38236), B(38237), B(38238) /    26.72,  -39.60,    0.00 /
      DATA B(38527), B(38528), B(38529) /    26.71,  -39.53,    0.00 /
      DATA B(38818), B(38819), B(38820) /    26.70,  -39.45,    0.00 /
      DATA B(39109), B(39110), B(39111) /    26.69,  -39.37,    0.00 /
      DATA B(39400), B(39401), B(39402) /    26.68,  -39.29,    0.00 /
      DATA B(39691), B(39692), B(39693) /    26.67,  -39.21,    0.00 /
      DATA B(39982), B(39983), B(39984) /    26.66,  -39.13,    0.00 /
      DATA B(40273), B(40274), B(40275) /    26.65,  -39.04,    0.00 /
      DATA B(40564), B(40565), B(40566) /    26.64,  -38.95,    0.00 /
      DATA B(40855), B(40856), B(40857) /    26.63,  -38.86,    0.00 /
      DATA B(41146), B(41147), B(41148) /    26.62,  -38.77,    0.00 /
      DATA B(41437), B(41438), B(41439) /    26.60,  -38.67,    0.00 /
      DATA B(41728), B(41729), B(41730) /    26.59,  -38.58,    0.00 /
      DATA B(42019), B(42020), B(42021) /    26.58,  -38.48,    0.00 /
      DATA B(42310), B(42311), B(42312) /    26.57,  -38.38,    0.00 /
      DATA B(42601), B(42602), B(42603) /    26.56,  -38.28,    0.00 /
      DATA B(42892), B(42893), B(42894) /    26.55,  -38.17,    0.00 /
      DATA B(43183), B(43184), B(43185) /    26.54,  -38.07,    0.00 /
      DATA B(43474), B(43475), B(43476) /    26.54,  -37.96,    0.00 /
      DATA B(43765), B(43766), B(43767) /    26.54,  -37.85,    0.00 /
      DATA B(44056), B(44057), B(44058) /    26.54,  -37.74,    0.00 /
      DATA B(44347), B(44348), B(44349) /    26.55,  -37.62,    0.00 /
      DATA B(44638), B(44639), B(44640) /    26.57,  -37.50,    0.00 /
      DATA B(44929), B(44930), B(44931) /    26.61,  -37.37,    0.00 /
      DATA B(45220), B(45221), B(45222) /    26.65,  -37.22,    0.00 /
      DATA B(45511), B(45512), B(45513) /    26.72,  -37.05,    0.00 /
      DATA B(45802), B(45803), B(45804) /    26.82,  -36.86,    0.00 /
      DATA B(46093), B(46094), B(46095) /    26.96,  -36.61,    0.00 /
      DATA B(27472), B(27473), B(27474) /    26.91,  -42.09,    0.00 /
      DATA B(27763), B(27764), B(27765) /    26.90,  -42.03,    0.00 /
      DATA B(28054), B(28055), B(28056) /    26.90,  -41.96,    0.00 /
      DATA B(28345), B(28346), B(28347) /    26.90,  -41.90,    0.00 /
      DATA B(28636), B(28637), B(28638) /    26.89,  -41.83,    0.00 /
      DATA B(28927), B(28928), B(28929) /    26.89,  -41.77,    0.00 /
      DATA B(29218), B(29219), B(29220) /    26.89,  -41.70,    0.00 /
      DATA B(29509), B(29510), B(29511) /    26.89,  -41.64,    0.00 /
      DATA B(29800), B(29801), B(29802) /    26.88,  -41.57,    0.00 /
      DATA B(30091), B(30092), B(30093) /    26.88,  -41.51,    0.00 /
      DATA B(30382), B(30383), B(30384) /    26.88,  -41.44,    0.00 /
      DATA B(30673), B(30674), B(30675) /    26.87,  -41.38,    0.00 /
      DATA B(30964), B(30965), B(30966) /    26.87,  -41.31,    0.00 /
      DATA B(31255), B(31256), B(31257) /    26.86,  -41.24,    0.00 /
      DATA B(31546), B(31547), B(31548) /    26.86,  -41.17,    0.00 /
      DATA B(31837), B(31838), B(31839) /    26.86,  -41.11,    0.00 /
      DATA B(32128), B(32129), B(32130) /    26.85,  -41.04,    0.00 /
      DATA B(32419), B(32420), B(32421) /    26.85,  -40.97,    0.00 /
      DATA B(32710), B(32711), B(32712) /    26.84,  -40.90,    0.00 /
      DATA B(33001), B(33002), B(33003) /    26.84,  -40.83,    0.00 /
      DATA B(33292), B(33293), B(33294) /    26.83,  -40.77,    0.00 /
      DATA B(33583), B(33584), B(33585) /    26.82,  -40.70,    0.00 /
      DATA B(33874), B(33875), B(33876) /    26.82,  -40.63,    0.00 /
      DATA B(34165), B(34166), B(34167) /    26.81,  -40.56,    0.00 /
      DATA B(34456), B(34457), B(34458) /    26.80,  -40.49,    0.00 /
      DATA B(34747), B(34748), B(34749) /    26.80,  -40.42,    0.00 /
      DATA B(35038), B(35039), B(35040) /    26.79,  -40.35,    0.00 /
      DATA B(35329), B(35330), B(35331) /    26.78,  -40.28,    0.00 /
      DATA B(35620), B(35621), B(35622) /    26.77,  -40.21,    0.00 /
      DATA B(35911), B(35912), B(35913) /    26.76,  -40.14,    0.00 /
      DATA B(36202), B(36203), B(36204) /    26.75,  -40.07,    0.00 /
      DATA B(36493), B(36494), B(36495) /    26.74,  -40.00,    0.00 /
      DATA B(36784), B(36785), B(36786) /    26.73,  -39.93,    0.00 /
      DATA B(37075), B(37076), B(37077) /    26.72,  -39.86,    0.00 /
      DATA B(37366), B(37367), B(37368) /    26.71,  -39.79,    0.00 /
      DATA B(37657), B(37658), B(37659) /    26.70,  -39.72,    0.00 /
      DATA B(37948), B(37949), B(37950) /    26.69,  -39.65,    0.00 /
      DATA B(38239), B(38240), B(38241) /    26.68,  -39.57,    0.00 /
      DATA B(38530), B(38531), B(38532) /    26.66,  -39.50,    0.00 /
      DATA B(38821), B(38822), B(38823) /    26.65,  -39.42,    0.00 /
      DATA B(39112), B(39113), B(39114) /    26.64,  -39.34,    0.00 /
      DATA B(39403), B(39404), B(39405) /    26.63,  -39.26,    0.00 /
      DATA B(39694), B(39695), B(39696) /    26.62,  -39.18,    0.00 /
      DATA B(39985), B(39986), B(39987) /    26.61,  -39.10,    0.00 /
      DATA B(40276), B(40277), B(40278) /    26.59,  -39.01,    0.00 /
      DATA B(40567), B(40568), B(40569) /    26.58,  -38.92,    0.00 /
      DATA B(40858), B(40859), B(40860) /    26.57,  -38.82,    0.00 /
      DATA B(41149), B(41150), B(41151) /    26.55,  -38.73,    0.00 /
      DATA B(41440), B(41441), B(41442) /    26.54,  -38.63,    0.00 /
      DATA B(41731), B(41732), B(41733) /    26.52,  -38.53,    0.00 /
      DATA B(42022), B(42023), B(42024) /    26.51,  -38.43,    0.00 /
      DATA B(42313), B(42314), B(42315) /    26.49,  -38.32,    0.00 /
      DATA B(42604), B(42605), B(42606) /    26.48,  -38.22,    0.00 /
      DATA B(42895), B(42896), B(42897) /    26.46,  -38.11,    0.00 /
      DATA B(43186), B(43187), B(43188) /    26.45,  -38.00,    0.00 /
      DATA B(43477), B(43478), B(43479) /    26.44,  -37.89,    0.00 /
      DATA B(43768), B(43769), B(43770) /    26.43,  -37.78,    0.00 /
      DATA B(44059), B(44060), B(44061) /    26.43,  -37.66,    0.00 /
      DATA B(44350), B(44351), B(44352) /    26.43,  -37.54,    0.00 /
      DATA B(44641), B(44642), B(44643) /    26.44,  -37.41,    0.00 /
      DATA B(44932), B(44933), B(44934) /    26.47,  -37.27,    0.00 /
      DATA B(45223), B(45224), B(45225) /    26.51,  -37.12,    0.00 /
      DATA B(45514), B(45515), B(45516) /    26.57,  -36.95,    0.00 /
      DATA B(45805), B(45806), B(45807) /    26.66,  -36.74,    0.00 /
      DATA B(46096), B(46097), B(46098) /    26.78,  -36.47,    0.00 /
      DATA B(27475), B(27476), B(27477) /    26.88,  -42.07,    0.00 /
      DATA B(27766), B(27767), B(27768) /    26.88,  -42.01,    0.00 /
      DATA B(28057), B(28058), B(28059) /    26.87,  -41.94,    0.00 /
      DATA B(28348), B(28349), B(28350) /    26.87,  -41.88,    0.00 /
      DATA B(28639), B(28640), B(28641) /    26.87,  -41.81,    0.00 /
      DATA B(28930), B(28931), B(28932) /    26.86,  -41.75,    0.00 /
      DATA B(29221), B(29222), B(29223) /    26.86,  -41.68,    0.00 /
      DATA B(29512), B(29513), B(29514) /    26.86,  -41.62,    0.00 /
      DATA B(29803), B(29804), B(29805) /    26.85,  -41.55,    0.00 /
      DATA B(30094), B(30095), B(30096) /    26.85,  -41.49,    0.00 /
      DATA B(30385), B(30386), B(30387) /    26.85,  -41.42,    0.00 /
      DATA B(30676), B(30677), B(30678) /    26.84,  -41.35,    0.00 /
      DATA B(30967), B(30968), B(30969) /    26.84,  -41.29,    0.00 /
      DATA B(31258), B(31259), B(31260) /    26.84,  -41.22,    0.00 /
      DATA B(31549), B(31550), B(31551) /    26.83,  -41.15,    0.00 /
      DATA B(31840), B(31841), B(31842) /    26.83,  -41.09,    0.00 /
      DATA B(32131), B(32132), B(32133) /    26.82,  -41.02,    0.00 /
      DATA B(32422), B(32423), B(32424) /    26.82,  -40.95,    0.00 /
      DATA B(32713), B(32714), B(32715) /    26.81,  -40.88,    0.00 /
      DATA B(33004), B(33005), B(33006) /    26.81,  -40.81,    0.00 /
      DATA B(33295), B(33296), B(33297) /    26.80,  -40.74,    0.00 /
      DATA B(33586), B(33587), B(33588) /    26.79,  -40.67,    0.00 /
      DATA B(33877), B(33878), B(33879) /    26.79,  -40.60,    0.00 /
      DATA B(34168), B(34169), B(34170) /    26.78,  -40.53,    0.00 /
      DATA B(34459), B(34460), B(34461) /    26.77,  -40.46,    0.00 /
      DATA B(34750), B(34751), B(34752) /    26.76,  -40.39,    0.00 /
      DATA B(35041), B(35042), B(35043) /    26.75,  -40.33,    0.00 /
      DATA B(35332), B(35333), B(35334) /    26.74,  -40.26,    0.00 /
      DATA B(35623), B(35624), B(35625) /    26.73,  -40.19,    0.00 /
      DATA B(35914), B(35915), B(35916) /    26.72,  -40.12,    0.00 /
      DATA B(36205), B(36206), B(36207) /    26.71,  -40.05,    0.00 /
      DATA B(36496), B(36497), B(36498) /    26.70,  -39.98,    0.00 /
      DATA B(36787), B(36788), B(36789) /    26.69,  -39.91,    0.00 /
      DATA B(37078), B(37079), B(37080) /    26.68,  -39.84,    0.00 /
      DATA B(37369), B(37370), B(37371) /    26.67,  -39.77,    0.00 /
      DATA B(37660), B(37661), B(37662) /    26.66,  -39.69,    0.00 /
      DATA B(37951), B(37952), B(37953) /    26.64,  -39.62,    0.00 /
      DATA B(38242), B(38243), B(38244) /    26.63,  -39.55,    0.00 /
      DATA B(38533), B(38534), B(38535) /    26.62,  -39.47,    0.00 /
      DATA B(38824), B(38825), B(38826) /    26.60,  -39.39,    0.00 /
      DATA B(39115), B(39116), B(39117) /    26.59,  -39.32,    0.00 /
      DATA B(39406), B(39407), B(39408) /    26.58,  -39.23,    0.00 /
      DATA B(39697), B(39698), B(39699) /    26.56,  -39.15,    0.00 /
      DATA B(39988), B(39989), B(39990) /    26.55,  -39.06,    0.00 /
      DATA B(40279), B(40280), B(40281) /    26.53,  -38.97,    0.00 /
      DATA B(40570), B(40571), B(40572) /    26.52,  -38.88,    0.00 /
      DATA B(40861), B(40862), B(40863) /    26.50,  -38.78,    0.00 /
      DATA B(41152), B(41153), B(41154) /    26.48,  -38.68,    0.00 /
      DATA B(41443), B(41444), B(41445) /    26.47,  -38.58,    0.00 /
      DATA B(41734), B(41735), B(41736) /    26.45,  -38.48,    0.00 /
      DATA B(42025), B(42026), B(42027) /    26.43,  -38.37,    0.00 /
      DATA B(42316), B(42317), B(42318) /    26.41,  -38.26,    0.00 /
      DATA B(42607), B(42608), B(42609) /    26.38,  -38.15,    0.00 /
      DATA B(42898), B(42899), B(42900) /    26.36,  -38.04,    0.00 /
      DATA B(43189), B(43190), B(43191) /    26.34,  -37.93,    0.00 /
      DATA B(43480), B(43481), B(43482) /    26.32,  -37.82,    0.00 /
      DATA B(43771), B(43772), B(43773) /    26.31,  -37.70,    0.00 /
      DATA B(44062), B(44063), B(44064) /    26.30,  -37.58,    0.00 /
      DATA B(44353), B(44354), B(44355) /    26.29,  -37.45,    0.00 /
      DATA B(44644), B(44645), B(44646) /    26.29,  -37.32,    0.00 /
      DATA B(44935), B(44936), B(44937) /    26.30,  -37.17,    0.00 /
      DATA B(45226), B(45227), B(45228) /    26.33,  -37.02,    0.00 /
      DATA B(45517), B(45518), B(45519) /    26.37,  -36.83,    0.00 /
      DATA B(45808), B(45809), B(45810) /    26.45,  -36.61,    0.00 /
      DATA B(46099), B(46100), B(46101) /    26.56,  -36.32,    0.00 /
      DATA B(27478), B(27479), B(27480) /    26.85,  -42.05,    0.00 /
      DATA B(27769), B(27770), B(27771) /    26.85,  -41.99,    0.00 /
      DATA B(28060), B(28061), B(28062) /    26.85,  -41.92,    0.00 /
      DATA B(28351), B(28352), B(28353) /    26.84,  -41.86,    0.00 /
      DATA B(28642), B(28643), B(28644) /    26.84,  -41.79,    0.00 /
      DATA B(28933), B(28934), B(28935) /    26.84,  -41.73,    0.00 /
      DATA B(29224), B(29225), B(29226) /    26.83,  -41.66,    0.00 /
      DATA B(29515), B(29516), B(29517) /    26.83,  -41.60,    0.00 /
      DATA B(29806), B(29807), B(29808) /    26.83,  -41.53,    0.00 /
      DATA B(30097), B(30098), B(30099) /    26.82,  -41.47,    0.00 /
      DATA B(30388), B(30389), B(30390) /    26.82,  -41.40,    0.00 /
      DATA B(30679), B(30680), B(30681) /    26.81,  -41.33,    0.00 /
      DATA B(30970), B(30971), B(30972) /    26.81,  -41.27,    0.00 /
      DATA B(31261), B(31262), B(31263) /    26.81,  -41.20,    0.00 /
      DATA B(31552), B(31553), B(31554) /    26.80,  -41.13,    0.00 /
      DATA B(31843), B(31844), B(31845) /    26.80,  -41.06,    0.00 /
      DATA B(32134), B(32135), B(32136) /    26.79,  -40.99,    0.00 /
      DATA B(32425), B(32426), B(32427) /    26.79,  -40.93,    0.00 /
      DATA B(32716), B(32717), B(32718) /    26.78,  -40.86,    0.00 /
      DATA B(33007), B(33008), B(33009) /    26.77,  -40.79,    0.00 /
      DATA B(33298), B(33299), B(33300) /    26.77,  -40.72,    0.00 /
      DATA B(33589), B(33590), B(33591) /    26.76,  -40.65,    0.00 /
      DATA B(33880), B(33881), B(33882) /    26.75,  -40.58,    0.00 /
      DATA B(34171), B(34172), B(34173) /    26.75,  -40.51,    0.00 /
      DATA B(34462), B(34463), B(34464) /    26.74,  -40.44,    0.00 /
      DATA B(34753), B(34754), B(34755) /    26.73,  -40.37,    0.00 /
      DATA B(35044), B(35045), B(35046) /    26.72,  -40.30,    0.00 /
      DATA B(35335), B(35336), B(35337) /    26.71,  -40.23,    0.00 /
      DATA B(35626), B(35627), B(35628) /    26.70,  -40.16,    0.00 /
      DATA B(35917), B(35918), B(35919) /    26.69,  -40.09,    0.00 /
      DATA B(36208), B(36209), B(36210) /    26.68,  -40.02,    0.00 /
      DATA B(36499), B(36500), B(36501) /    26.66,  -39.95,    0.00 /
      DATA B(36790), B(36791), B(36792) /    26.65,  -39.88,    0.00 /
      DATA B(37081), B(37082), B(37083) /    26.64,  -39.81,    0.00 /
      DATA B(37372), B(37373), B(37374) /    26.62,  -39.74,    0.00 /
      DATA B(37663), B(37664), B(37665) /    26.61,  -39.67,    0.00 /
      DATA B(37954), B(37955), B(37956) /    26.60,  -39.59,    0.00 /
      DATA B(38245), B(38246), B(38247) /    26.58,  -39.52,    0.00 /
      DATA B(38536), B(38537), B(38538) /    26.57,  -39.44,    0.00 /
      DATA B(38827), B(38828), B(38829) /    26.55,  -39.37,    0.00 /
      DATA B(39118), B(39119), B(39120) /    26.54,  -39.29,    0.00 /
      DATA B(39409), B(39410), B(39411) /    26.52,  -39.20,    0.00 /
      DATA B(39700), B(39701), B(39702) /    26.51,  -39.12,    0.00 /
      DATA B(39991), B(39992), B(39993) /    26.49,  -39.03,    0.00 /
      DATA B(40282), B(40283), B(40284) /    26.47,  -38.94,    0.00 /
      DATA B(40573), B(40574), B(40575) /    26.45,  -38.84,    0.00 /
      DATA B(40864), B(40865), B(40866) /    26.43,  -38.74,    0.00 /
      DATA B(41155), B(41156), B(41157) /    26.41,  -38.64,    0.00 /
      DATA B(41446), B(41447), B(41448) /    26.39,  -38.53,    0.00 /
      DATA B(41737), B(41738), B(41739) /    26.36,  -38.42,    0.00 /
      DATA B(42028), B(42029), B(42030) /    26.34,  -38.31,    0.00 /
      DATA B(42319), B(42320), B(42321) /    26.31,  -38.20,    0.00 /
      DATA B(42610), B(42611), B(42612) /    26.28,  -38.09,    0.00 /
      DATA B(42901), B(42902), B(42903) /    26.25,  -37.97,    0.00 /
      DATA B(43192), B(43193), B(43194) /    26.23,  -37.85,    0.00 /
      DATA B(43483), B(43484), B(43485) /    26.20,  -37.73,    0.00 /
      DATA B(43774), B(43775), B(43776) /    26.17,  -37.61,    0.00 /
      DATA B(44065), B(44066), B(44067) /    26.15,  -37.48,    0.00 /
      DATA B(44356), B(44357), B(44358) /    26.13,  -37.35,    0.00 /
      DATA B(44647), B(44648), B(44649) /    26.11,  -37.21,    0.00 /
      DATA B(44938), B(44939), B(44940) /    26.10,  -37.06,    0.00 /
      DATA B(45229), B(45230), B(45231) /    26.11,  -36.90,    0.00 /
      DATA B(45520), B(45521), B(45522) /    26.13,  -36.70,    0.00 /
      DATA B(45811), B(45812), B(45813) /    26.19,  -36.47,    0.00 /
      DATA B(46102), B(46103), B(46104) /    26.28,  -36.16,    0.00 /
      DATA B(27481), B(27482), B(27483) /    26.82,  -42.03,    0.00 /
      DATA B(27772), B(27773), B(27774) /    26.82,  -41.97,    0.00 /
      DATA B(28063), B(28064), B(28065) /    26.82,  -41.90,    0.00 /
      DATA B(28354), B(28355), B(28356) /    26.81,  -41.84,    0.00 /
      DATA B(28645), B(28646), B(28647) /    26.81,  -41.77,    0.00 /
      DATA B(28936), B(28937), B(28938) /    26.81,  -41.71,    0.00 /
      DATA B(29227), B(29228), B(29229) /    26.80,  -41.64,    0.00 /
      DATA B(29518), B(29519), B(29520) /    26.80,  -41.58,    0.00 /
      DATA B(29809), B(29810), B(29811) /    26.80,  -41.51,    0.00 /
      DATA B(30100), B(30101), B(30102) /    26.79,  -41.45,    0.00 /
      DATA B(30391), B(30392), B(30393) /    26.79,  -41.38,    0.00 /
      DATA B(30682), B(30683), B(30684) /    26.79,  -41.31,    0.00 /
      DATA B(30973), B(30974), B(30975) /    26.78,  -41.25,    0.00 /
      DATA B(31264), B(31265), B(31266) /    26.78,  -41.18,    0.00 /
      DATA B(31555), B(31556), B(31557) /    26.77,  -41.11,    0.00 /
      DATA B(31846), B(31847), B(31848) /    26.77,  -41.04,    0.00 /
      DATA B(32137), B(32138), B(32139) /    26.76,  -40.97,    0.00 /
      DATA B(32428), B(32429), B(32430) /    26.76,  -40.90,    0.00 /
      DATA B(32719), B(32720), B(32721) /    26.75,  -40.83,    0.00 /
      DATA B(33010), B(33011), B(33012) /    26.74,  -40.76,    0.00 /
      DATA B(33301), B(33302), B(33303) /    26.74,  -40.69,    0.00 /
      DATA B(33592), B(33593), B(33594) /    26.73,  -40.62,    0.00 /
      DATA B(33883), B(33884), B(33885) /    26.72,  -40.55,    0.00 /
      DATA B(34174), B(34175), B(34176) /    26.71,  -40.48,    0.00 /
      DATA B(34465), B(34466), B(34467) /    26.70,  -40.41,    0.00 /
      DATA B(34756), B(34757), B(34758) /    26.70,  -40.34,    0.00 /
      DATA B(35047), B(35048), B(35049) /    26.68,  -40.27,    0.00 /
      DATA B(35338), B(35339), B(35340) /    26.67,  -40.20,    0.00 /
      DATA B(35629), B(35630), B(35631) /    26.66,  -40.13,    0.00 /
      DATA B(35920), B(35921), B(35922) /    26.65,  -40.06,    0.00 /
      DATA B(36211), B(36212), B(36213) /    26.64,  -39.99,    0.00 /
      DATA B(36502), B(36503), B(36504) /    26.62,  -39.92,    0.00 /
      DATA B(36793), B(36794), B(36795) /    26.61,  -39.85,    0.00 /
      DATA B(37084), B(37085), B(37086) /    26.60,  -39.78,    0.00 /
      DATA B(37375), B(37376), B(37377) /    26.58,  -39.71,    0.00 /
      DATA B(37666), B(37667), B(37668) /    26.57,  -39.64,    0.00 /
      DATA B(37957), B(37958), B(37959) /    26.55,  -39.56,    0.00 /
      DATA B(38248), B(38249), B(38250) /    26.53,  -39.49,    0.00 /
      DATA B(38539), B(38540), B(38541) /    26.52,  -39.41,    0.00 /
      DATA B(38830), B(38831), B(38832) /    26.50,  -39.34,    0.00 /
      DATA B(39121), B(39122), B(39123) /    26.48,  -39.26,    0.00 /
      DATA B(39412), B(39413), B(39414) /    26.46,  -39.17,    0.00 /
      DATA B(39703), B(39704), B(39705) /    26.45,  -39.09,    0.00 /
      DATA B(39994), B(39995), B(39996) /    26.43,  -38.99,    0.00 /
      DATA B(40285), B(40286), B(40287) /    26.40,  -38.90,    0.00 /
      DATA B(40576), B(40577), B(40578) /    26.38,  -38.80,    0.00 /
      DATA B(40867), B(40868), B(40869) /    26.36,  -38.70,    0.00 /
      DATA B(41158), B(41159), B(41160) /    26.33,  -38.59,    0.00 /
      DATA B(41449), B(41450), B(41451) /    26.30,  -38.48,    0.00 /
      DATA B(41740), B(41741), B(41742) /    26.27,  -38.37,    0.00 /
      DATA B(42031), B(42032), B(42033) /    26.24,  -38.25,    0.00 /
      DATA B(42322), B(42323), B(42324) /    26.21,  -38.13,    0.00 /
      DATA B(42613), B(42614), B(42615) /    26.17,  -38.01,    0.00 /
      DATA B(42904), B(42905), B(42906) /    26.13,  -37.89,    0.00 /
      DATA B(43195), B(43196), B(43197) /    26.09,  -37.77,    0.00 /
      DATA B(43486), B(43487), B(43488) /    26.05,  -37.64,    0.00 /
      DATA B(43777), B(43778), B(43779) /    26.01,  -37.51,    0.00 /
      DATA B(44068), B(44069), B(44070) /    25.98,  -37.38,    0.00 /
      DATA B(44359), B(44360), B(44361) /    25.94,  -37.24,    0.00 /
      DATA B(44650), B(44651), B(44652) /    25.90,  -37.09,    0.00 /
      DATA B(44941), B(44942), B(44943) /    25.87,  -36.94,    0.00 /
      DATA B(45232), B(45233), B(45234) /    25.85,  -36.76,    0.00 /
      DATA B(45523), B(45524), B(45525) /    25.84,  -36.56,    0.00 /
      DATA B(45814), B(45815), B(45816) /    25.86,  -36.31,    0.00 /
      DATA B(46105), B(46106), B(46107) /    25.91,  -35.99,    0.00 /
      DATA B(27484), B(27485), B(27486) /    26.80,  -42.01,    0.00 /
      DATA B(27775), B(27776), B(27777) /    26.79,  -41.95,    0.00 /
      DATA B(28066), B(28067), B(28068) /    26.79,  -41.88,    0.00 /
      DATA B(28357), B(28358), B(28359) /    26.79,  -41.82,    0.00 /
      DATA B(28648), B(28649), B(28650) /    26.78,  -41.75,    0.00 /
      DATA B(28939), B(28940), B(28941) /    26.78,  -41.69,    0.00 /
      DATA B(29230), B(29231), B(29232) /    26.78,  -41.62,    0.00 /
      DATA B(29521), B(29522), B(29523) /    26.77,  -41.56,    0.00 /
      DATA B(29812), B(29813), B(29814) /    26.77,  -41.49,    0.00 /
      DATA B(30103), B(30104), B(30105) /    26.76,  -41.43,    0.00 /
      DATA B(30394), B(30395), B(30396) /    26.76,  -41.36,    0.00 /
      DATA B(30685), B(30686), B(30687) /    26.76,  -41.29,    0.00 /
      DATA B(30976), B(30977), B(30978) /    26.75,  -41.22,    0.00 /
      DATA B(31267), B(31268), B(31269) /    26.75,  -41.16,    0.00 /
      DATA B(31558), B(31559), B(31560) /    26.74,  -41.09,    0.00 /
      DATA B(31849), B(31850), B(31851) /    26.74,  -41.02,    0.00 /
      DATA B(32140), B(32141), B(32142) /    26.73,  -40.95,    0.00 /
      DATA B(32431), B(32432), B(32433) /    26.73,  -40.88,    0.00 /
      DATA B(32722), B(32723), B(32724) /    26.72,  -40.81,    0.00 /
      DATA B(33013), B(33014), B(33015) /    26.71,  -40.74,    0.00 /
      DATA B(33304), B(33305), B(33306) /    26.71,  -40.67,    0.00 /
      DATA B(33595), B(33596), B(33597) /    26.70,  -40.60,    0.00 /
      DATA B(33886), B(33887), B(33888) /    26.69,  -40.53,    0.00 /
      DATA B(34177), B(34178), B(34179) /    26.68,  -40.46,    0.00 /
      DATA B(34468), B(34469), B(34470) /    26.67,  -40.39,    0.00 /
      DATA B(34759), B(34760), B(34761) /    26.66,  -40.31,    0.00 /
      DATA B(35050), B(35051), B(35052) /    26.65,  -40.24,    0.00 /
      DATA B(35341), B(35342), B(35343) /    26.64,  -40.17,    0.00 /
      DATA B(35632), B(35633), B(35634) /    26.63,  -40.10,    0.00 /
      DATA B(35923), B(35924), B(35925) /    26.61,  -40.03,    0.00 /
      DATA B(36214), B(36215), B(36216) /    26.60,  -39.96,    0.00 /
      DATA B(36505), B(36506), B(36507) /    26.58,  -39.89,    0.00 /
      DATA B(36796), B(36797), B(36798) /    26.57,  -39.82,    0.00 /
      DATA B(37087), B(37088), B(37089) /    26.55,  -39.75,    0.00 /
      DATA B(37378), B(37379), B(37380) /    26.54,  -39.68,    0.00 /
      DATA B(37669), B(37670), B(37671) /    26.52,  -39.61,    0.00 /
      DATA B(37960), B(37961), B(37962) /    26.50,  -39.54,    0.00 /
      DATA B(38251), B(38252), B(38253) /    26.48,  -39.46,    0.00 /
      DATA B(38542), B(38543), B(38544) /    26.46,  -39.38,    0.00 /
      DATA B(38833), B(38834), B(38835) /    26.44,  -39.31,    0.00 /
      DATA B(39124), B(39125), B(39126) /    26.42,  -39.23,    0.00 /
      DATA B(39415), B(39416), B(39417) /    26.40,  -39.14,    0.00 /
      DATA B(39706), B(39707), B(39708) /    26.38,  -39.05,    0.00 /
      DATA B(39997), B(39998), B(39999) /    26.36,  -38.96,    0.00 /
      DATA B(40288), B(40289), B(40290) /    26.33,  -38.86,    0.00 /
      DATA B(40579), B(40580), B(40581) /    26.31,  -38.76,    0.00 /
      DATA B(40870), B(40871), B(40872) /    26.28,  -38.65,    0.00 /
      DATA B(41161), B(41162), B(41163) /    26.25,  -38.54,    0.00 /
      DATA B(41452), B(41453), B(41454) /    26.21,  -38.42,    0.00 /
      DATA B(41743), B(41744), B(41745) /    26.17,  -38.30,    0.00 /
      DATA B(42034), B(42035), B(42036) /    26.13,  -38.18,    0.00 /
      DATA B(42325), B(42326), B(42327) /    26.09,  -38.05,    0.00 /
      DATA B(42616), B(42617), B(42618) /    26.04,  -37.93,    0.00 /
      DATA B(42907), B(42908), B(42909) /    25.99,  -37.80,    0.00 /
      DATA B(43198), B(43199), B(43200) /    25.94,  -37.67,    0.00 /
      DATA B(43489), B(43490), B(43491) /    25.89,  -37.54,    0.00 /
      DATA B(43780), B(43781), B(43782) /    25.83,  -37.40,    0.00 /
      DATA B(44071), B(44072), B(44073) /    25.78,  -37.26,    0.00 /
      DATA B(44362), B(44363), B(44364) /    25.72,  -37.11,    0.00 /
      DATA B(44653), B(44654), B(44655) /    25.66,  -36.96,    0.00 /
      DATA B(44944), B(44945), B(44946) /    25.60,  -36.79,    0.00 /
      DATA B(45235), B(45236), B(45237) /    25.54,  -36.60,    0.00 /
      DATA B(45526), B(45527), B(45528) /    25.48,  -36.39,    0.00 /
      DATA B(45817), B(45818), B(45819) /    25.44,  -36.13,    0.00 /
      DATA B(46108), B(46109), B(46110) /    25.43,  -35.79,    0.00 /
      DATA B(27487), B(27488), B(27489) /    26.77,  -41.99,    0.00 /
      DATA B(27778), B(27779), B(27780) /    26.76,  -41.93,    0.00 /
      DATA B(28069), B(28070), B(28071) /    26.76,  -41.86,    0.00 /
      DATA B(28360), B(28361), B(28362) /    26.76,  -41.80,    0.00 /
      DATA B(28651), B(28652), B(28653) /    26.75,  -41.73,    0.00 /
      DATA B(28942), B(28943), B(28944) /    26.75,  -41.67,    0.00 /
      DATA B(29233), B(29234), B(29235) /    26.75,  -41.60,    0.00 /
      DATA B(29524), B(29525), B(29526) /    26.74,  -41.54,    0.00 /
      DATA B(29815), B(29816), B(29817) /    26.74,  -41.47,    0.00 /
      DATA B(30106), B(30107), B(30108) /    26.73,  -41.41,    0.00 /
      DATA B(30397), B(30398), B(30399) /    26.73,  -41.34,    0.00 /
      DATA B(30688), B(30689), B(30690) /    26.73,  -41.27,    0.00 /
      DATA B(30979), B(30980), B(30981) /    26.72,  -41.20,    0.00 /
      DATA B(31270), B(31271), B(31272) /    26.72,  -41.13,    0.00 /
      DATA B(31561), B(31562), B(31563) /    26.71,  -41.07,    0.00 /
      DATA B(31852), B(31853), B(31854) /    26.71,  -41.00,    0.00 /
      DATA B(32143), B(32144), B(32145) /    26.70,  -40.93,    0.00 /
      DATA B(32434), B(32435), B(32436) /    26.70,  -40.86,    0.00 /
      DATA B(32725), B(32726), B(32727) /    26.69,  -40.79,    0.00 /
      DATA B(33016), B(33017), B(33018) /    26.68,  -40.72,    0.00 /
      DATA B(33307), B(33308), B(33309) /    26.67,  -40.64,    0.00 /
      DATA B(33598), B(33599), B(33600) /    26.67,  -40.57,    0.00 /
      DATA B(33889), B(33890), B(33891) /    26.66,  -40.50,    0.00 /
      DATA B(34180), B(34181), B(34182) /    26.65,  -40.43,    0.00 /
      DATA B(34471), B(34472), B(34473) /    26.64,  -40.36,    0.00 /
      DATA B(34762), B(34763), B(34764) /    26.63,  -40.29,    0.00 /
      DATA B(35053), B(35054), B(35055) /    26.61,  -40.22,    0.00 /
      DATA B(35344), B(35345), B(35346) /    26.60,  -40.14,    0.00 /
      DATA B(35635), B(35636), B(35637) /    26.59,  -40.07,    0.00 /
      DATA B(35926), B(35927), B(35928) /    26.57,  -40.00,    0.00 /
      DATA B(36217), B(36218), B(36219) /    26.56,  -39.93,    0.00 /
      DATA B(36508), B(36509), B(36510) /    26.54,  -39.86,    0.00 /
      DATA B(36799), B(36800), B(36801) /    26.53,  -39.79,    0.00 /
      DATA B(37090), B(37091), B(37092) /    26.51,  -39.72,    0.00 /
      DATA B(37381), B(37382), B(37383) /    26.49,  -39.65,    0.00 /
      DATA B(37672), B(37673), B(37674) /    26.47,  -39.58,    0.00 /
      DATA B(37963), B(37964), B(37965) /    26.45,  -39.51,    0.00 /
      DATA B(38254), B(38255), B(38256) /    26.43,  -39.43,    0.00 /
      DATA B(38545), B(38546), B(38547) /    26.41,  -39.36,    0.00 /
      DATA B(38836), B(38837), B(38838) /    26.38,  -39.28,    0.00 /
      DATA B(39127), B(39128), B(39129) /    26.36,  -39.19,    0.00 /
      DATA B(39418), B(39419), B(39420) /    26.34,  -39.11,    0.00 /
      DATA B(39709), B(39710), B(39711) /    26.31,  -39.02,    0.00 /
      DATA B(40000), B(40001), B(40002) /    26.28,  -38.92,    0.00 /
      DATA B(40291), B(40292), B(40293) /    26.26,  -38.82,    0.00 /
      DATA B(40582), B(40583), B(40584) /    26.22,  -38.72,    0.00 /
      DATA B(40873), B(40874), B(40875) /    26.19,  -38.60,    0.00 /
      DATA B(41164), B(41165), B(41166) /    26.15,  -38.48,    0.00 /
      DATA B(41455), B(41456), B(41457) /    26.11,  -38.36,    0.00 /
      DATA B(41746), B(41747), B(41748) /    26.06,  -38.23,    0.00 /
      DATA B(42037), B(42038), B(42039) /    26.01,  -38.10,    0.00 /
      DATA B(42328), B(42329), B(42330) /    25.96,  -37.97,    0.00 /
      DATA B(42619), B(42620), B(42621) /    25.90,  -37.83,    0.00 /
      DATA B(42910), B(42911), B(42912) /    25.84,  -37.70,    0.00 /
      DATA B(43201), B(43202), B(43203) /    25.77,  -37.56,    0.00 /
      DATA B(43492), B(43493), B(43494) /    25.70,  -37.42,    0.00 /
      DATA B(43783), B(43784), B(43785) /    25.62,  -37.27,    0.00 /
      DATA B(44074), B(44075), B(44076) /    25.54,  -37.12,    0.00 /
      DATA B(44365), B(44366), B(44367) /    25.46,  -36.96,    0.00 /
      DATA B(44656), B(44657), B(44658) /    25.37,  -36.79,    0.00 /
      DATA B(44947), B(44948), B(44949) /    25.27,  -36.61,    0.00 /
      DATA B(45238), B(45239), B(45240) /    25.16,  -36.41,    0.00 /
      DATA B(45529), B(45530), B(45531) /    25.04,  -36.19,    0.00 /
      DATA B(45820), B(45821), B(45822) /    24.93,  -35.91,    0.00 /
      DATA B(46111), B(46112), B(46113) /    24.81,  -35.55,    0.00 /
      DATA B(27490), B(27491), B(27492) /    26.74,  -41.97,    0.00 /
      DATA B(27781), B(27782), B(27783) /    26.74,  -41.91,    0.00 /
      DATA B(28072), B(28073), B(28074) /    26.73,  -41.84,    0.00 /
      DATA B(28363), B(28364), B(28365) /    26.73,  -41.78,    0.00 /
      DATA B(28654), B(28655), B(28656) /    26.72,  -41.71,    0.00 /
      DATA B(28945), B(28946), B(28947) /    26.72,  -41.65,    0.00 /
      DATA B(29236), B(29237), B(29238) /    26.72,  -41.58,    0.00 /
      DATA B(29527), B(29528), B(29529) /    26.71,  -41.52,    0.00 /
      DATA B(29818), B(29819), B(29820) /    26.71,  -41.45,    0.00 /
      DATA B(30109), B(30110), B(30111) /    26.70,  -41.38,    0.00 /
      DATA B(30400), B(30401), B(30402) /    26.70,  -41.32,    0.00 /
      DATA B(30691), B(30692), B(30693) /    26.70,  -41.25,    0.00 /
      DATA B(30982), B(30983), B(30984) /    26.69,  -41.18,    0.00 /
      DATA B(31273), B(31274), B(31275) /    26.69,  -41.11,    0.00 /
      DATA B(31564), B(31565), B(31566) /    26.68,  -41.04,    0.00 /
      DATA B(31855), B(31856), B(31857) /    26.68,  -40.97,    0.00 /
      DATA B(32146), B(32147), B(32148) /    26.67,  -40.90,    0.00 /
      DATA B(32437), B(32438), B(32439) /    26.66,  -40.83,    0.00 /
      DATA B(32728), B(32729), B(32730) /    26.66,  -40.76,    0.00 /
      DATA B(33019), B(33020), B(33021) /    26.65,  -40.69,    0.00 /
      DATA B(33310), B(33311), B(33312) /    26.64,  -40.62,    0.00 /
      DATA B(33601), B(33602), B(33603) /    26.63,  -40.55,    0.00 /
      DATA B(33892), B(33893), B(33894) /    26.62,  -40.48,    0.00 /
      DATA B(34183), B(34184), B(34185) /    26.61,  -40.40,    0.00 /
      DATA B(34474), B(34475), B(34476) /    26.60,  -40.33,    0.00 /
      DATA B(34765), B(34766), B(34767) /    26.59,  -40.26,    0.00 /
      DATA B(35056), B(35057), B(35058) /    26.58,  -40.19,    0.00 /
      DATA B(35347), B(35348), B(35349) /    26.57,  -40.11,    0.00 /
      DATA B(35638), B(35639), B(35640) /    26.55,  -40.04,    0.00 /
      DATA B(35929), B(35930), B(35931) /    26.53,  -39.97,    0.00 /
      DATA B(36220), B(36221), B(36222) /    26.52,  -39.90,    0.00 /
      DATA B(36511), B(36512), B(36513) /    26.50,  -39.83,    0.00 /
      DATA B(36802), B(36803), B(36804) /    26.48,  -39.76,    0.00 /
      DATA B(37093), B(37094), B(37095) /    26.46,  -39.69,    0.00 /
      DATA B(37384), B(37385), B(37386) /    26.44,  -39.62,    0.00 /
      DATA B(37675), B(37676), B(37677) /    26.42,  -39.55,    0.00 /
      DATA B(37966), B(37967), B(37968) /    26.40,  -39.47,    0.00 /
      DATA B(38257), B(38258), B(38259) /    26.37,  -39.40,    0.00 /
      DATA B(38548), B(38549), B(38550) /    26.35,  -39.32,    0.00 /
      DATA B(38839), B(38840), B(38841) /    26.32,  -39.25,    0.00 /
      DATA B(39130), B(39131), B(39132) /    26.30,  -39.16,    0.00 /
      DATA B(39421), B(39422), B(39423) /    26.27,  -39.08,    0.00 /
      DATA B(39712), B(39713), B(39714) /    26.24,  -38.99,    0.00 /
      DATA B(40003), B(40004), B(40005) /    26.21,  -38.89,    0.00 /
      DATA B(40294), B(40295), B(40296) /    26.17,  -38.78,    0.00 /
      DATA B(40585), B(40586), B(40587) /    26.13,  -38.67,    0.00 /
      DATA B(40876), B(40877), B(40878) /    26.09,  -38.55,    0.00 /
      DATA B(41167), B(41168), B(41169) /    26.05,  -38.43,    0.00 /
      DATA B(41458), B(41459), B(41460) /    26.00,  -38.29,    0.00 /
      DATA B(41749), B(41750), B(41751) /    25.94,  -38.16,    0.00 /
      DATA B(42040), B(42041), B(42042) /    25.88,  -38.01,    0.00 /
      DATA B(42331), B(42332), B(42333) /    25.81,  -37.87,    0.00 /
      DATA B(42622), B(42623), B(42624) /    25.74,  -37.73,    0.00 /
      DATA B(42913), B(42914), B(42915) /    25.66,  -37.58,    0.00 /
      DATA B(43204), B(43205), B(43206) /    25.57,  -37.43,    0.00 /
      DATA B(43495), B(43496), B(43497) /    25.48,  -37.28,    0.00 /
      DATA B(43786), B(43787), B(43788) /    25.38,  -37.12,    0.00 /
      DATA B(44077), B(44078), B(44079) /    25.27,  -36.96,    0.00 /
      DATA B(44368), B(44369), B(44370) /    25.15,  -36.79,    0.00 /
      DATA B(44659), B(44660), B(44661) /    25.02,  -36.60,    0.00 /
      DATA B(44950), B(44951), B(44952) /    24.87,  -36.40,    0.00 /
      DATA B(45241), B(45242), B(45243) /    24.70,  -36.18,    0.00 /
      DATA B(45532), B(45533), B(45534) /    24.50,  -35.93,    0.00 /
      DATA B(45823), B(45824), B(45825) /    24.28,  -35.63,    0.00 /
      DATA B(46114), B(46115), B(46116) /    24.03,  -35.23,    0.00 /
      DATA B(27493), B(27494), B(27495) /    26.71,  -41.95,    0.00 /
      DATA B(27784), B(27785), B(27786) /    26.71,  -41.89,    0.00 /
      DATA B(28075), B(28076), B(28077) /    26.70,  -41.82,    0.00 /
      DATA B(28366), B(28367), B(28368) /    26.70,  -41.76,    0.00 /
      DATA B(28657), B(28658), B(28659) /    26.70,  -41.69,    0.00 /
      DATA B(28948), B(28949), B(28950) /    26.69,  -41.63,    0.00 /
      DATA B(29239), B(29240), B(29241) /    26.69,  -41.56,    0.00 /
      DATA B(29530), B(29531), B(29532) /    26.68,  -41.50,    0.00 /
      DATA B(29821), B(29822), B(29823) /    26.68,  -41.43,    0.00 /
      DATA B(30112), B(30113), B(30114) /    26.68,  -41.36,    0.00 /
      DATA B(30403), B(30404), B(30405) /    26.67,  -41.30,    0.00 /
      DATA B(30694), B(30695), B(30696) /    26.67,  -41.23,    0.00 /
      DATA B(30985), B(30986), B(30987) /    26.66,  -41.16,    0.00 /
      DATA B(31276), B(31277), B(31278) /    26.66,  -41.09,    0.00 /
      DATA B(31567), B(31568), B(31569) /    26.65,  -41.02,    0.00 /
      DATA B(31858), B(31859), B(31860) /    26.65,  -40.95,    0.00 /
      DATA B(32149), B(32150), B(32151) /    26.64,  -40.88,    0.00 /
      DATA B(32440), B(32441), B(32442) /    26.63,  -40.81,    0.00 /
      DATA B(32731), B(32732), B(32733) /    26.63,  -40.74,    0.00 /
      DATA B(33022), B(33023), B(33024) /    26.62,  -40.67,    0.00 /
      DATA B(33313), B(33314), B(33315) /    26.61,  -40.59,    0.00 /
      DATA B(33604), B(33605), B(33606) /    26.60,  -40.52,    0.00 /
      DATA B(33895), B(33896), B(33897) /    26.59,  -40.45,    0.00 /
      DATA B(34186), B(34187), B(34188) /    26.58,  -40.38,    0.00 /
      DATA B(34477), B(34478), B(34479) /    26.57,  -40.30,    0.00 /
      DATA B(34768), B(34769), B(34770) /    26.56,  -40.23,    0.00 /
      DATA B(35059), B(35060), B(35061) /    26.54,  -40.16,    0.00 /
      DATA B(35350), B(35351), B(35352) /    26.53,  -40.08,    0.00 /
      DATA B(35641), B(35642), B(35643) /    26.51,  -40.01,    0.00 /
      DATA B(35932), B(35933), B(35934) /    26.50,  -39.94,    0.00 /
      DATA B(36223), B(36224), B(36225) /    26.48,  -39.87,    0.00 /
      DATA B(36514), B(36515), B(36516) /    26.46,  -39.80,    0.00 /
      DATA B(36805), B(36806), B(36807) /    26.44,  -39.73,    0.00 /
      DATA B(37096), B(37097), B(37098) /    26.42,  -39.66,    0.00 /
      DATA B(37387), B(37388), B(37389) /    26.39,  -39.59,    0.00 /
      DATA B(37678), B(37679), B(37680) /    26.37,  -39.52,    0.00 /
      DATA B(37969), B(37970), B(37971) /    26.34,  -39.44,    0.00 /
      DATA B(38260), B(38261), B(38262) /    26.31,  -39.37,    0.00 /
      DATA B(38551), B(38552), B(38553) /    26.29,  -39.29,    0.00 /
      DATA B(38842), B(38843), B(38844) /    26.26,  -39.21,    0.00 /
      DATA B(39133), B(39134), B(39135) /    26.23,  -39.13,    0.00 /
      DATA B(39424), B(39425), B(39426) /    26.19,  -39.04,    0.00 /
      DATA B(39715), B(39716), B(39717) /    26.16,  -38.95,    0.00 /
      DATA B(40006), B(40007), B(40008) /    26.12,  -38.85,    0.00 /
      DATA B(40297), B(40298), B(40299) /    26.08,  -38.74,    0.00 /
      DATA B(40588), B(40589), B(40590) /    26.04,  -38.62,    0.00 /
      DATA B(40879), B(40880), B(40881) /    25.99,  -38.50,    0.00 /
      DATA B(41170), B(41171), B(41172) /    25.93,  -38.36,    0.00 /
      DATA B(41461), B(41462), B(41463) /    25.87,  -38.22,    0.00 /
      DATA B(41752), B(41753), B(41754) /    25.80,  -38.07,    0.00 /
      DATA B(42043), B(42044), B(42045) /    25.72,  -37.92,    0.00 /
      DATA B(42334), B(42335), B(42336) /    25.64,  -37.76,    0.00 /
      DATA B(42625), B(42626), B(42627) /    25.54,  -37.60,    0.00 /
      DATA B(42916), B(42917), B(42918) /    25.44,  -37.44,    0.00 /
      DATA B(43207), B(43208), B(43209) /    25.33,  -37.28,    0.00 /
      DATA B(43498), B(43499), B(43500) /    25.21,  -37.12,    0.00 /
      DATA B(43789), B(43790), B(43791) /    25.08,  -36.94,    0.00 /
      DATA B(44080), B(44081), B(44082) /    24.93,  -36.76,    0.00 /
      DATA B(44371), B(44372), B(44373) /    24.77,  -36.57,    0.00 /
      DATA B(44662), B(44663), B(44664) /    24.59,  -36.37,    0.00 /
      DATA B(44953), B(44954), B(44955) /    24.38,  -36.15,    0.00 /
      DATA B(45244), B(45245), B(45246) /    24.13,  -35.90,    0.00 /
      DATA B(45535), B(45536), B(45537) /    23.83,  -35.61,    0.00 /
      DATA B(45826), B(45827), B(45828) /    23.48,  -35.26,    0.00 /
      DATA B(46117), B(46118), B(46119) /    23.06,  -34.80,    0.00 /
      DATA B(27496), B(27497), B(27498) /    26.68,  -41.93,    0.00 /
      DATA B(27787), B(27788), B(27789) /    26.68,  -41.87,    0.00 /
      DATA B(28078), B(28079), B(28080) /    26.67,  -41.80,    0.00 /
      DATA B(28369), B(28370), B(28371) /    26.67,  -41.74,    0.00 /
      DATA B(28660), B(28661), B(28662) /    26.67,  -41.67,    0.00 /
      DATA B(28951), B(28952), B(28953) /    26.66,  -41.61,    0.00 /
      DATA B(29242), B(29243), B(29244) /    26.66,  -41.54,    0.00 /
      DATA B(29533), B(29534), B(29535) /    26.65,  -41.48,    0.00 /
      DATA B(29824), B(29825), B(29826) /    26.65,  -41.41,    0.00 /
      DATA B(30115), B(30116), B(30117) /    26.64,  -41.34,    0.00 /
      DATA B(30406), B(30407), B(30408) /    26.64,  -41.28,    0.00 /
      DATA B(30697), B(30698), B(30699) /    26.64,  -41.21,    0.00 /
      DATA B(30988), B(30989), B(30990) /    26.63,  -41.14,    0.00 /
      DATA B(31279), B(31280), B(31281) /    26.63,  -41.07,    0.00 /
      DATA B(31570), B(31571), B(31572) /    26.62,  -41.00,    0.00 /
      DATA B(31861), B(31862), B(31863) /    26.61,  -40.93,    0.00 /
      DATA B(32152), B(32153), B(32154) /    26.61,  -40.86,    0.00 /
      DATA B(32443), B(32444), B(32445) /    26.60,  -40.79,    0.00 /
      DATA B(32734), B(32735), B(32736) /    26.59,  -40.71,    0.00 /
      DATA B(33025), B(33026), B(33027) /    26.59,  -40.64,    0.00 /
      DATA B(33316), B(33317), B(33318) /    26.58,  -40.57,    0.00 /
      DATA B(33607), B(33608), B(33609) /    26.57,  -40.49,    0.00 /
      DATA B(33898), B(33899), B(33900) /    26.56,  -40.42,    0.00 /
      DATA B(34189), B(34190), B(34191) /    26.55,  -40.35,    0.00 /
      DATA B(34480), B(34481), B(34482) /    26.53,  -40.27,    0.00 /
      DATA B(34771), B(34772), B(34773) /    26.52,  -40.20,    0.00 /
      DATA B(35062), B(35063), B(35064) /    26.51,  -40.13,    0.00 /
      DATA B(35353), B(35354), B(35355) /    26.49,  -40.05,    0.00 /
      DATA B(35644), B(35645), B(35646) /    26.47,  -39.98,    0.00 /
      DATA B(35935), B(35936), B(35937) /    26.46,  -39.91,    0.00 /
      DATA B(36226), B(36227), B(36228) /    26.44,  -39.84,    0.00 /
      DATA B(36517), B(36518), B(36519) /    26.41,  -39.77,    0.00 /
      DATA B(36808), B(36809), B(36810) /    26.39,  -39.69,    0.00 /
      DATA B(37099), B(37100), B(37101) /    26.37,  -39.62,    0.00 /
      DATA B(37390), B(37391), B(37392) /    26.34,  -39.55,    0.00 /
      DATA B(37681), B(37682), B(37683) /    26.31,  -39.48,    0.00 /
      DATA B(37972), B(37973), B(37974) /    26.28,  -39.41,    0.00 /
      DATA B(38263), B(38264), B(38265) /    26.25,  -39.34,    0.00 /
      DATA B(38554), B(38555), B(38556) /    26.22,  -39.26,    0.00 /
      DATA B(38845), B(38846), B(38847) /    26.19,  -39.18,    0.00 /
      DATA B(39136), B(39137), B(39138) /    26.15,  -39.10,    0.00 /
      DATA B(39427), B(39428), B(39429) /    26.11,  -39.01,    0.00 /
      DATA B(39718), B(39719), B(39720) /    26.07,  -38.92,    0.00 /
      DATA B(40009), B(40010), B(40011) /    26.03,  -38.81,    0.00 /
      DATA B(40300), B(40301), B(40302) /    25.98,  -38.70,    0.00 /
      DATA B(40591), B(40592), B(40593) /    25.93,  -38.57,    0.00 /
      DATA B(40882), B(40883), B(40884) /    25.87,  -38.44,    0.00 /
      DATA B(41173), B(41174), B(41175) /    25.80,  -38.29,    0.00 /
      DATA B(41464), B(41465), B(41466) /    25.73,  -38.14,    0.00 /
      DATA B(41755), B(41756), B(41757) /    25.64,  -37.97,    0.00 /
      DATA B(42046), B(42047), B(42048) /    25.54,  -37.80,    0.00 /
      DATA B(42337), B(42338), B(42339) /    25.43,  -37.63,    0.00 /
      DATA B(42628), B(42629), B(42630) /    25.31,  -37.46,    0.00 /
      DATA B(42919), B(42920), B(42921) /    25.18,  -37.28,    0.00 /
      DATA B(43210), B(43211), B(43212) /    25.04,  -37.11,    0.00 /
      DATA B(43501), B(43502), B(43503) /    24.89,  -36.92,    0.00 /
      DATA B(43792), B(43793), B(43794) /    24.71,  -36.73,    0.00 /
      DATA B(44083), B(44084), B(44085) /    24.52,  -36.53,    0.00 /
      DATA B(44374), B(44375), B(44376) /    24.30,  -36.31,    0.00 /
      DATA B(44665), B(44666), B(44667) /    24.04,  -36.08,    0.00 /
      DATA B(44956), B(44957), B(44958) /    23.75,  -35.83,    0.00 /
      DATA B(45247), B(45248), B(45249) /    23.40,  -35.54,    0.00 /
      DATA B(45538), B(45539), B(45540) /    22.98,  -35.20,    0.00 /
      DATA B(45829), B(45830), B(45831) /    22.47,  -34.79,    0.00 /
      DATA B(46120), B(46121), B(46122) /    21.87,  -34.22,    0.00 /
      DATA B(27499), B(27500), B(27501) /    26.65,  -41.91,    0.00 /
      DATA B(27790), B(27791), B(27792) /    26.65,  -41.85,    0.00 /
      DATA B(28081), B(28082), B(28083) /    26.64,  -41.78,    0.00 /
      DATA B(28372), B(28373), B(28374) /    26.64,  -41.72,    0.00 /
      DATA B(28663), B(28664), B(28665) /    26.64,  -41.65,    0.00 /
      DATA B(28954), B(28955), B(28956) /    26.63,  -41.59,    0.00 /
      DATA B(29245), B(29246), B(29247) /    26.63,  -41.52,    0.00 /
      DATA B(29536), B(29537), B(29538) /    26.62,  -41.46,    0.00 /
      DATA B(29827), B(29828), B(29829) /    26.62,  -41.39,    0.00 /
      DATA B(30118), B(30119), B(30120) /    26.61,  -41.32,    0.00 /
      DATA B(30409), B(30410), B(30411) /    26.61,  -41.26,    0.00 /
      DATA B(30700), B(30701), B(30702) /    26.60,  -41.19,    0.00 /
      DATA B(30991), B(30992), B(30993) /    26.60,  -41.12,    0.00 /
      DATA B(31282), B(31283), B(31284) /    26.59,  -41.05,    0.00 /
      DATA B(31573), B(31574), B(31575) /    26.59,  -40.98,    0.00 /
      DATA B(31864), B(31865), B(31866) /    26.58,  -40.91,    0.00 /
      DATA B(32155), B(32156), B(32157) /    26.58,  -40.84,    0.00 /
      DATA B(32446), B(32447), B(32448) /    26.57,  -40.76,    0.00 /
      DATA B(32737), B(32738), B(32739) /    26.56,  -40.69,    0.00 /
      DATA B(33028), B(33029), B(33030) /    26.55,  -40.62,    0.00 /
      DATA B(33319), B(33320), B(33321) /    26.54,  -40.54,    0.00 /
      DATA B(33610), B(33611), B(33612) /    26.53,  -40.47,    0.00 /
      DATA B(33901), B(33902), B(33903) /    26.52,  -40.39,    0.00 /
      DATA B(34192), B(34193), B(34194) /    26.51,  -40.32,    0.00 /
      DATA B(34483), B(34484), B(34485) /    26.50,  -40.24,    0.00 /
      DATA B(34774), B(34775), B(34776) /    26.49,  -40.17,    0.00 /
      DATA B(35065), B(35066), B(35067) /    26.47,  -40.09,    0.00 /
      DATA B(35356), B(35357), B(35358) /    26.45,  -40.02,    0.00 /
      DATA B(35647), B(35648), B(35649) /    26.43,  -39.95,    0.00 /
      DATA B(35938), B(35939), B(35940) /    26.41,  -39.87,    0.00 /
      DATA B(36229), B(36230), B(36231) /    26.39,  -39.80,    0.00 /
      DATA B(36520), B(36521), B(36522) /    26.37,  -39.73,    0.00 /
      DATA B(36811), B(36812), B(36813) /    26.34,  -39.66,    0.00 /
      DATA B(37102), B(37103), B(37104) /    26.32,  -39.59,    0.00 /
      DATA B(37393), B(37394), B(37395) /    26.29,  -39.52,    0.00 /
      DATA B(37684), B(37685), B(37686) /    26.26,  -39.45,    0.00 /
      DATA B(37975), B(37976), B(37977) /    26.23,  -39.38,    0.00 /
      DATA B(38266), B(38267), B(38268) /    26.19,  -39.30,    0.00 /
      DATA B(38557), B(38558), B(38559) /    26.15,  -39.23,    0.00 /
      DATA B(38848), B(38849), B(38850) /    26.11,  -39.15,    0.00 /
      DATA B(39139), B(39140), B(39141) /    26.07,  -39.07,    0.00 /
      DATA B(39430), B(39431), B(39432) /    26.03,  -38.98,    0.00 /
      DATA B(39721), B(39722), B(39723) /    25.98,  -38.88,    0.00 /
      DATA B(40012), B(40013), B(40014) /    25.93,  -38.77,    0.00 /
      DATA B(40303), B(40304), B(40305) /    25.87,  -38.65,    0.00 /
      DATA B(40594), B(40595), B(40596) /    25.80,  -38.52,    0.00 /
      DATA B(40885), B(40886), B(40887) /    25.73,  -38.38,    0.00 /
      DATA B(41176), B(41177), B(41178) /    25.65,  -38.21,    0.00 /
      DATA B(41467), B(41468), B(41469) /    25.56,  -38.04,    0.00 /
      DATA B(41758), B(41759), B(41760) /    25.45,  -37.86,    0.00 /
      DATA B(42049), B(42050), B(42051) /    25.33,  -37.67,    0.00 /
      DATA B(42340), B(42341), B(42342) /    25.19,  -37.48,    0.00 /
      DATA B(42631), B(42632), B(42633) /    25.03,  -37.28,    0.00 /
      DATA B(42922), B(42923), B(42924) /    24.87,  -37.09,    0.00 /
      DATA B(43213), B(43214), B(43215) /    24.68,  -36.89,    0.00 /
      DATA B(43504), B(43505), B(43506) /    24.47,  -36.69,    0.00 /
      DATA B(43795), B(43796), B(43797) /    24.24,  -36.47,    0.00 /
      DATA B(44086), B(44087), B(44088) /    23.98,  -36.24,    0.00 /
      DATA B(44377), B(44378), B(44379) /    23.68,  -35.99,    0.00 /
      DATA B(44668), B(44669), B(44670) /    23.33,  -35.72,    0.00 /
      DATA B(44959), B(44960), B(44961) /    22.93,  -35.43,    0.00 /
      DATA B(45250), B(45251), B(45252) /    22.46,  -35.09,    0.00 /
      DATA B(45541), B(45542), B(45543) /    21.89,  -34.69,    0.00 /
      DATA B(45832), B(45833), B(45834) /    21.22,  -34.19,    0.00 /
      DATA B(46123), B(46124), B(46125) /    20.47,  -33.47,    0.00 /
      DATA B(27502), B(27503), B(27504) /    26.62,  -41.89,    0.00 /
      DATA B(27793), B(27794), B(27795) /    26.62,  -41.83,    0.00 /
      DATA B(28084), B(28085), B(28086) /    26.62,  -41.76,    0.00 /
      DATA B(28375), B(28376), B(28377) /    26.61,  -41.70,    0.00 /
      DATA B(28666), B(28667), B(28668) /    26.61,  -41.63,    0.00 /
      DATA B(28957), B(28958), B(28959) /    26.60,  -41.57,    0.00 /
      DATA B(29248), B(29249), B(29250) /    26.60,  -41.50,    0.00 /
      DATA B(29539), B(29540), B(29541) /    26.59,  -41.44,    0.00 /
      DATA B(29830), B(29831), B(29832) /    26.59,  -41.37,    0.00 /
      DATA B(30121), B(30122), B(30123) /    26.58,  -41.30,    0.00 /
      DATA B(30412), B(30413), B(30414) /    26.58,  -41.23,    0.00 /
      DATA B(30703), B(30704), B(30705) /    26.57,  -41.17,    0.00 /
      DATA B(30994), B(30995), B(30996) /    26.57,  -41.10,    0.00 /
      DATA B(31285), B(31286), B(31287) /    26.56,  -41.03,    0.00 /
      DATA B(31576), B(31577), B(31578) /    26.56,  -40.96,    0.00 /
      DATA B(31867), B(31868), B(31869) /    26.55,  -40.88,    0.00 /
      DATA B(32158), B(32159), B(32160) /    26.54,  -40.81,    0.00 /
      DATA B(32449), B(32450), B(32451) /    26.54,  -40.74,    0.00 /
      DATA B(32740), B(32741), B(32742) /    26.53,  -40.67,    0.00 /
      DATA B(33031), B(33032), B(33033) /    26.52,  -40.59,    0.00 /
      DATA B(33322), B(33323), B(33324) /    26.51,  -40.52,    0.00 /
      DATA B(33613), B(33614), B(33615) /    26.50,  -40.44,    0.00 /
      DATA B(33904), B(33905), B(33906) /    26.49,  -40.36,    0.00 /
      DATA B(34195), B(34196), B(34197) /    26.48,  -40.29,    0.00 /
      DATA B(34486), B(34487), B(34488) /    26.46,  -40.21,    0.00 /
      DATA B(34777), B(34778), B(34779) /    26.45,  -40.14,    0.00 /
      DATA B(35068), B(35069), B(35070) /    26.43,  -40.06,    0.00 /
      DATA B(35359), B(35360), B(35361) /    26.41,  -39.99,    0.00 /
      DATA B(35650), B(35651), B(35652) /    26.39,  -39.91,    0.00 /
      DATA B(35941), B(35942), B(35943) /    26.37,  -39.84,    0.00 /
      DATA B(36232), B(36233), B(36234) /    26.35,  -39.77,    0.00 /
      DATA B(36523), B(36524), B(36525) /    26.32,  -39.69,    0.00 /
      DATA B(36814), B(36815), B(36816) /    26.30,  -39.62,    0.00 /
      DATA B(37105), B(37106), B(37107) /    26.27,  -39.55,    0.00 /
      DATA B(37396), B(37397), B(37398) /    26.24,  -39.48,    0.00 /
      DATA B(37687), B(37688), B(37689) /    26.20,  -39.41,    0.00 /
      DATA B(37978), B(37979), B(37980) /    26.16,  -39.34,    0.00 /
      DATA B(38269), B(38270), B(38271) /    26.13,  -39.27,    0.00 /
      DATA B(38560), B(38561), B(38562) /    26.08,  -39.19,    0.00 /
      DATA B(38851), B(38852), B(38853) /    26.04,  -39.11,    0.00 /
      DATA B(39142), B(39143), B(39144) /    25.99,  -39.03,    0.00 /
      DATA B(39433), B(39434), B(39435) /    25.93,  -38.94,    0.00 /
      DATA B(39724), B(39725), B(39726) /    25.87,  -38.84,    0.00 /
      DATA B(40015), B(40016), B(40017) /    25.81,  -38.73,    0.00 /
      DATA B(40306), B(40307), B(40308) /    25.74,  -38.61,    0.00 /
      DATA B(40597), B(40598), B(40599) /    25.67,  -38.47,    0.00 /
      DATA B(40888), B(40889), B(40890) /    25.58,  -38.31,    0.00 /
      DATA B(41179), B(41180), B(41181) /    25.48,  -38.13,    0.00 /
      DATA B(41470), B(41471), B(41472) /    25.36,  -37.93,    0.00 /
      DATA B(41761), B(41762), B(41763) /    25.22,  -37.72,    0.00 /
      DATA B(42052), B(42053), B(42054) /    25.06,  -37.50,    0.00 /
      DATA B(42343), B(42344), B(42345) /    24.88,  -37.29,    0.00 /
      DATA B(42634), B(42635), B(42636) /    24.68,  -37.07,    0.00 /
      DATA B(42925), B(42926), B(42927) /    24.46,  -36.85,    0.00 /
      DATA B(43216), B(43217), B(43218) /    24.21,  -36.63,    0.00 /
      DATA B(43507), B(43508), B(43509) /    23.94,  -36.39,    0.00 /
      DATA B(43798), B(43799), B(43800) /    23.62,  -36.14,    0.00 /
      DATA B(44089), B(44090), B(44091) /    23.26,  -35.87,    0.00 /
      DATA B(44380), B(44381), B(44382) /    22.85,  -35.58,    0.00 /
      DATA B(44671), B(44672), B(44673) /    22.37,  -35.28,    0.00 /
      DATA B(44962), B(44963), B(44964) /    21.84,  -34.93,    0.00 /
      DATA B(45253), B(45254), B(45255) /    21.23,  -34.56,    0.00 /
      DATA B(45544), B(45545), B(45546) /    20.56,  -34.06,    0.00 /
      DATA B(45835), B(45836), B(45837) /    19.73,  -33.46,    0.00 /
      DATA B(46126), B(46127), B(46128) /    18.88,  -32.77,    0.00 /
      DATA B(27505), B(27506), B(27507) /    26.59,  -41.87,    0.00 /
      DATA B(27796), B(27797), B(27798) /    26.59,  -41.81,    0.00 /
      DATA B(28087), B(28088), B(28089) /    26.59,  -41.74,    0.00 /
      DATA B(28378), B(28379), B(28380) /    26.58,  -41.68,    0.00 /
      DATA B(28669), B(28670), B(28671) /    26.58,  -41.61,    0.00 /
      DATA B(28960), B(28961), B(28962) /    26.57,  -41.55,    0.00 /
      DATA B(29251), B(29252), B(29253) /    26.57,  -41.48,    0.00 /
      DATA B(29542), B(29543), B(29544) /    26.56,  -41.42,    0.00 /
      DATA B(29833), B(29834), B(29835) /    26.56,  -41.35,    0.00 /
      DATA B(30124), B(30125), B(30126) /    26.55,  -41.28,    0.00 /
      DATA B(30415), B(30416), B(30417) /    26.55,  -41.21,    0.00 /
      DATA B(30706), B(30707), B(30708) /    26.54,  -41.15,    0.00 /
      DATA B(30997), B(30998), B(30999) /    26.54,  -41.08,    0.00 /
      DATA B(31288), B(31289), B(31290) /    26.53,  -41.01,    0.00 /
      DATA B(31579), B(31580), B(31581) /    26.52,  -40.93,    0.00 /
      DATA B(31870), B(31871), B(31872) /    26.52,  -40.86,    0.00 /
      DATA B(32161), B(32162), B(32163) /    26.51,  -40.79,    0.00 /
      DATA B(32452), B(32453), B(32454) /    26.50,  -40.72,    0.00 /
      DATA B(32743), B(32744), B(32745) /    26.50,  -40.64,    0.00 /
      DATA B(33034), B(33035), B(33036) /    26.49,  -40.56,    0.00 /
      DATA B(33325), B(33326), B(33327) /    26.48,  -40.49,    0.00 /
      DATA B(33616), B(33617), B(33618) /    26.47,  -40.41,    0.00 /
      DATA B(33907), B(33908), B(33909) /    26.46,  -40.34,    0.00 /
      DATA B(34198), B(34199), B(34200) /    26.44,  -40.26,    0.00 /
      DATA B(34489), B(34490), B(34491) /    26.43,  -40.18,    0.00 /
      DATA B(34780), B(34781), B(34782) /    26.41,  -40.10,    0.00 /
      DATA B(35071), B(35072), B(35073) /    26.39,  -40.03,    0.00 /
      DATA B(35362), B(35363), B(35364) /    26.38,  -39.95,    0.00 /
      DATA B(35653), B(35654), B(35655) /    26.35,  -39.88,    0.00 /
      DATA B(35944), B(35945), B(35946) /    26.33,  -39.80,    0.00 /
      DATA B(36235), B(36236), B(36237) /    26.31,  -39.73,    0.00 /
      DATA B(36526), B(36527), B(36528) /    26.28,  -39.66,    0.00 /
      DATA B(36817), B(36818), B(36819) /    26.25,  -39.58,    0.00 /
      DATA B(37108), B(37109), B(37110) /    26.22,  -39.51,    0.00 /
      DATA B(37399), B(37400), B(37401) /    26.18,  -39.44,    0.00 /
      DATA B(37690), B(37691), B(37692) /    26.14,  -39.37,    0.00 /
      DATA B(37981), B(37982), B(37983) /    26.10,  -39.30,    0.00 /
      DATA B(38272), B(38273), B(38274) /    26.06,  -39.23,    0.00 /
      DATA B(38563), B(38564), B(38565) /    26.01,  -39.16,    0.00 /
      DATA B(38854), B(38855), B(38856) /    25.95,  -39.08,    0.00 /
      DATA B(39145), B(39146), B(39147) /    25.90,  -38.99,    0.00 /
      DATA B(39436), B(39437), B(39438) /    25.83,  -38.90,    0.00 /
      DATA B(39727), B(39728), B(39729) /    25.76,  -38.80,    0.00 /
      DATA B(40018), B(40019), B(40020) /    25.68,  -38.69,    0.00 /
      DATA B(40309), B(40310), B(40311) /    25.60,  -38.56,    0.00 /
      DATA B(40600), B(40601), B(40602) /    25.50,  -38.41,    0.00 /
      DATA B(40891), B(40892), B(40893) /    25.40,  -38.23,    0.00 /
      DATA B(41182), B(41183), B(41184) /    25.27,  -38.03,    0.00 /
      DATA B(41473), B(41474), B(41475) /    25.12,  -37.80,    0.00 /
      DATA B(41764), B(41765), B(41766) /    24.94,  -37.55,    0.00 /
      DATA B(42055), B(42056), B(42057) /    24.73,  -37.30,    0.00 /
      DATA B(42346), B(42347), B(42348) /    24.49,  -37.05,    0.00 /
      DATA B(42637), B(42638), B(42639) /    24.22,  -36.80,    0.00 /
      DATA B(42928), B(42929), B(42930) /    23.92,  -36.55,    0.00 /
      DATA B(43219), B(43220), B(43221) /    23.59,  -36.29,    0.00 /
      DATA B(43510), B(43511), B(43512) /    23.21,  -36.02,    0.00 /
      DATA B(43801), B(43802), B(43803) /    22.78,  -35.73,    0.00 /
      DATA B(44092), B(44093), B(44094) /    22.29,  -35.41,    0.00 /
      DATA B(44383), B(44384), B(44385) /    21.73,  -35.10,    0.00 /
      DATA B(44674), B(44675), B(44676) /    21.11,  -34.74,    0.00 /
      DATA B(44965), B(44966), B(44967) /    20.46,  -34.37,    0.00 /
      DATA B(45256), B(45257), B(45258) /    19.68,  -33.91,    0.00 /
      DATA B(45547), B(45548), B(45549) /    18.87,  -33.46,    0.00 /
      DATA B(45838), B(45839), B(45840) /    18.05,  -32.83,    0.00 /
      DATA B(46129), B(46130), B(46131) /    17.27,  -32.07,    0.00 /
      DATA B(27508), B(27509), B(27510) /    26.56,  -41.85,    0.00 /
      DATA B(27799), B(27800), B(27801) /    26.56,  -41.79,    0.00 /
      DATA B(28090), B(28091), B(28092) /    26.56,  -41.72,    0.00 /
      DATA B(28381), B(28382), B(28383) /    26.55,  -41.66,    0.00 /
      DATA B(28672), B(28673), B(28674) /    26.55,  -41.59,    0.00 /
      DATA B(28963), B(28964), B(28965) /    26.54,  -41.53,    0.00 /
      DATA B(29254), B(29255), B(29256) /    26.54,  -41.46,    0.00 /
      DATA B(29545), B(29546), B(29547) /    26.53,  -41.40,    0.00 /
      DATA B(29836), B(29837), B(29838) /    26.52,  -41.33,    0.00 /
      DATA B(30127), B(30128), B(30129) /    26.52,  -41.26,    0.00 /
      DATA B(30418), B(30419), B(30420) /    26.51,  -41.19,    0.00 /
      DATA B(30709), B(30710), B(30711) /    26.51,  -41.12,    0.00 /
      DATA B(31000), B(31001), B(31002) /    26.50,  -41.05,    0.00 /
      DATA B(31291), B(31292), B(31293) /    26.50,  -40.98,    0.00 /
      DATA B(31582), B(31583), B(31584) /    26.49,  -40.91,    0.00 /
      DATA B(31873), B(31874), B(31875) /    26.48,  -40.84,    0.00 /
      DATA B(32164), B(32165), B(32166) /    26.48,  -40.77,    0.00 /
      DATA B(32455), B(32456), B(32457) /    26.47,  -40.69,    0.00 /
      DATA B(32746), B(32747), B(32748) /    26.46,  -40.62,    0.00 /
      DATA B(33037), B(33038), B(33039) /    26.45,  -40.54,    0.00 /
      DATA B(33328), B(33329), B(33330) /    26.44,  -40.46,    0.00 /
      DATA B(33619), B(33620), B(33621) /    26.43,  -40.38,    0.00 /
      DATA B(33910), B(33911), B(33912) /    26.42,  -40.31,    0.00 /
      DATA B(34201), B(34202), B(34203) /    26.41,  -40.23,    0.00 /
      DATA B(34492), B(34493), B(34494) /    26.39,  -40.15,    0.00 /
      DATA B(34783), B(34784), B(34785) /    26.38,  -40.07,    0.00 /
      DATA B(35074), B(35075), B(35076) /    26.36,  -39.99,    0.00 /
      DATA B(35365), B(35366), B(35367) /    26.34,  -39.91,    0.00 /
      DATA B(35656), B(35657), B(35658) /    26.31,  -39.84,    0.00 /
      DATA B(35947), B(35948), B(35949) /    26.29,  -39.76,    0.00 /
      DATA B(36238), B(36239), B(36240) /    26.26,  -39.69,    0.00 /
      DATA B(36529), B(36530), B(36531) /    26.23,  -39.62,    0.00 /
      DATA B(36820), B(36821), B(36822) /    26.20,  -39.54,    0.00 /
      DATA B(37111), B(37112), B(37113) /    26.16,  -39.47,    0.00 /
      DATA B(37402), B(37403), B(37404) /    26.13,  -39.40,    0.00 /
      DATA B(37693), B(37694), B(37695) /    26.08,  -39.33,    0.00 /
      DATA B(37984), B(37985), B(37986) /    26.04,  -39.26,    0.00 /
      DATA B(38275), B(38276), B(38277) /    25.98,  -39.19,    0.00 /
      DATA B(38566), B(38567), B(38568) /    25.93,  -39.12,    0.00 /
      DATA B(38857), B(38858), B(38859) /    25.87,  -39.04,    0.00 /
      DATA B(39148), B(39149), B(39150) /    25.80,  -38.96,    0.00 /
      DATA B(39439), B(39440), B(39441) /    25.72,  -38.87,    0.00 /
      DATA B(39730), B(39731), B(39732) /    25.64,  -38.76,    0.00 /
      DATA B(40021), B(40022), B(40023) /    25.54,  -38.64,    0.00 /
      DATA B(40312), B(40313), B(40314) /    25.43,  -38.51,    0.00 /
      DATA B(40603), B(40604), B(40605) /    25.31,  -38.34,    0.00 /
      DATA B(40894), B(40895), B(40896) /    25.18,  -38.14,    0.00 /
      DATA B(41185), B(41186), B(41187) /    25.01,  -37.91,    0.00 /
      DATA B(41476), B(41477), B(41478) /    24.82,  -37.64,    0.00 /
      DATA B(41767), B(41768), B(41769) /    24.58,  -37.34,    0.00 /
      DATA B(42058), B(42059), B(42060) /    24.30,  -37.04,    0.00 /
      DATA B(42349), B(42350), B(42351) /    23.97,  -36.75,    0.00 /
      DATA B(42640), B(42641), B(42642) /    23.61,  -36.46,    0.00 /
      DATA B(42931), B(42932), B(42933) /    23.20,  -36.16,    0.00 /
      DATA B(43222), B(43223), B(43224) /    22.73,  -35.86,    0.00 /
      DATA B(43513), B(43514), B(43515) /    22.22,  -35.55,    0.00 /
      DATA B(43804), B(43805), B(43806) /    21.64,  -35.24,    0.00 /
      DATA B(44095), B(44096), B(44097) /    21.02,  -34.86,    0.00 /
      DATA B(44386), B(44387), B(44388) /    20.30,  -34.55,    0.00 /
      DATA B(44677), B(44678), B(44679) /    19.53,  -34.19,    0.00 /
      DATA B(44968), B(44969), B(44970) /    18.75,  -33.79,    0.00 /
      DATA B(45259), B(45260), B(45261) /    17.98,  -33.37,    0.00 /
      DATA B(45550), B(45551), B(45552) /    17.24,  -32.87,    0.00 /
      DATA B(45841), B(45842), B(45843) /    16.53,  -32.28,    0.00 /
      DATA B(46132), B(46133), B(46134) /    15.88,  -31.55,    0.00 /
      DATA B(27511), B(27512), B(27513) /    26.53,  -41.83,    0.00 /
      DATA B(27802), B(27803), B(27804) /    26.53,  -41.77,    0.00 /
      DATA B(28093), B(28094), B(28095) /    26.52,  -41.70,    0.00 /
      DATA B(28384), B(28385), B(28386) /    26.52,  -41.64,    0.00 /
      DATA B(28675), B(28676), B(28677) /    26.51,  -41.57,    0.00 /
      DATA B(28966), B(28967), B(28968) /    26.51,  -41.51,    0.00 /
      DATA B(29257), B(29258), B(29259) /    26.50,  -41.44,    0.00 /
      DATA B(29548), B(29549), B(29550) /    26.50,  -41.38,    0.00 /
      DATA B(29839), B(29840), B(29841) /    26.49,  -41.31,    0.00 /
      DATA B(30130), B(30131), B(30132) /    26.49,  -41.24,    0.00 /
      DATA B(30421), B(30422), B(30423) /    26.48,  -41.17,    0.00 /
      DATA B(30712), B(30713), B(30714) /    26.48,  -41.10,    0.00 /
      DATA B(31003), B(31004), B(31005) /    26.47,  -41.03,    0.00 /
      DATA B(31294), B(31295), B(31296) /    26.46,  -40.96,    0.00 /
      DATA B(31585), B(31586), B(31587) /    26.46,  -40.89,    0.00 /
      DATA B(31876), B(31877), B(31878) /    26.45,  -40.82,    0.00 /
      DATA B(32167), B(32168), B(32169) /    26.44,  -40.74,    0.00 /
      DATA B(32458), B(32459), B(32460) /    26.44,  -40.67,    0.00 /
      DATA B(32749), B(32750), B(32751) /    26.43,  -40.59,    0.00 /
      DATA B(33040), B(33041), B(33042) /    26.42,  -40.51,    0.00 /
      DATA B(33331), B(33332), B(33333) /    26.41,  -40.43,    0.00 /
      DATA B(33622), B(33623), B(33624) /    26.40,  -40.35,    0.00 /
      DATA B(33913), B(33914), B(33915) /    26.38,  -40.27,    0.00 /
      DATA B(34204), B(34205), B(34206) /    26.37,  -40.19,    0.00 /
      DATA B(34495), B(34496), B(34497) /    26.36,  -40.11,    0.00 /
      DATA B(34786), B(34787), B(34788) /    26.34,  -40.03,    0.00 /
      DATA B(35077), B(35078), B(35079) /    26.32,  -39.95,    0.00 /
      DATA B(35368), B(35369), B(35370) /    26.30,  -39.88,    0.00 /
      DATA B(35659), B(35660), B(35661) /    26.27,  -39.80,    0.00 /
      DATA B(35950), B(35951), B(35952) /    26.25,  -39.72,    0.00 /
      DATA B(36241), B(36242), B(36243) /    26.22,  -39.65,    0.00 /
      DATA B(36532), B(36533), B(36534) /    26.18,  -39.57,    0.00 /
      DATA B(36823), B(36824), B(36825) /    26.15,  -39.50,    0.00 /
      DATA B(37114), B(37115), B(37116) /    26.11,  -39.43,    0.00 /
      DATA B(37405), B(37406), B(37407) /    26.07,  -39.36,    0.00 /
      DATA B(37696), B(37697), B(37698) /    26.02,  -39.29,    0.00 /
      DATA B(37987), B(37988), B(37989) /    25.97,  -39.22,    0.00 /
      DATA B(38278), B(38279), B(38280) /    25.91,  -39.15,    0.00 /
      DATA B(38569), B(38570), B(38571) /    25.85,  -39.08,    0.00 /
      DATA B(38860), B(38861), B(38862) /    25.77,  -39.00,    0.00 /
      DATA B(39151), B(39152), B(39153) /    25.69,  -38.92,    0.00 /
      DATA B(39442), B(39443), B(39444) /    25.60,  -38.82,    0.00 /
      DATA B(39733), B(39734), B(39735) /    25.49,  -38.72,    0.00 /
      DATA B(40024), B(40025), B(40026) /    25.38,  -38.59,    0.00 /
      DATA B(40315), B(40316), B(40317) /    25.24,  -38.45,    0.00 /
      DATA B(40606), B(40607), B(40608) /    25.09,  -38.27,    0.00 /
      DATA B(40897), B(40898), B(40899) /    24.91,  -38.04,    0.00 /
      DATA B(41188), B(41189), B(41190) /    24.69,  -37.77,    0.00 /
      DATA B(41479), B(41480), B(41481) /    24.43,  -37.43,    0.00 /
      DATA B(41770), B(41771), B(41772) /    24.11,  -37.07,    0.00 /
      DATA B(42061), B(42062), B(42063) /    23.71,  -36.70,    0.00 /
      DATA B(42352), B(42353), B(42354) /    23.26,  -36.35,    0.00 /
      DATA B(42643), B(42644), B(42645) /    22.76,  -36.01,    0.00 /
      DATA B(42934), B(42935), B(42936) /    22.20,  -35.68,    0.00 /
      DATA B(43225), B(43226), B(43227) /    21.59,  -35.32,    0.00 /
      DATA B(43516), B(43517), B(43518) /    20.94,  -35.00,    0.00 /
      DATA B(43807), B(43808), B(43809) /    20.16,  -34.61,    0.00 /
      DATA B(44098), B(44099), B(44100) /    19.40,  -34.31,    0.00 /
      DATA B(44389), B(44390), B(44391) /    18.61,  -33.96,    0.00 /
      DATA B(44680), B(44681), B(44682) /    17.86,  -33.62,    0.00 /
      DATA B(44971), B(44972), B(44973) /    17.16,  -33.25,    0.00 /
      DATA B(45262), B(45263), B(45264) /    16.49,  -32.83,    0.00 /
      DATA B(45553), B(45554), B(45555) /    15.86,  -32.36,    0.00 /
      DATA B(45844), B(45845), B(45846) /    15.25,  -31.79,    0.00 /
      DATA B(46135), B(46136), B(46137) /    14.65,  -31.10,    0.00 /
      DATA B(27514), B(27515), B(27516) /    26.50,  -41.81,    0.00 /
      DATA B(27805), B(27806), B(27807) /    26.50,  -41.75,    0.00 /
      DATA B(28096), B(28097), B(28098) /    26.49,  -41.68,    0.00 /
      DATA B(28387), B(28388), B(28389) /    26.49,  -41.62,    0.00 /
      DATA B(28678), B(28679), B(28680) /    26.48,  -41.55,    0.00 /
      DATA B(28969), B(28970), B(28971) /    26.48,  -41.49,    0.00 /
      DATA B(29260), B(29261), B(29262) /    26.47,  -41.42,    0.00 /
      DATA B(29551), B(29552), B(29553) /    26.47,  -41.36,    0.00 /
      DATA B(29842), B(29843), B(29844) /    26.46,  -41.29,    0.00 /
      DATA B(30133), B(30134), B(30135) /    26.45,  -41.22,    0.00 /
      DATA B(30424), B(30425), B(30426) /    26.45,  -41.15,    0.00 /
      DATA B(30715), B(30716), B(30717) /    26.44,  -41.08,    0.00 /
      DATA B(31006), B(31007), B(31008) /    26.44,  -41.01,    0.00 /
      DATA B(31297), B(31298), B(31299) /    26.43,  -40.94,    0.00 /
      DATA B(31588), B(31589), B(31590) /    26.42,  -40.87,    0.00 /
      DATA B(31879), B(31880), B(31881) /    26.42,  -40.79,    0.00 /
      DATA B(32170), B(32171), B(32172) /    26.41,  -40.72,    0.00 /
      DATA B(32461), B(32462), B(32463) /    26.40,  -40.64,    0.00 /
      DATA B(32752), B(32753), B(32754) /    26.39,  -40.56,    0.00 /
      DATA B(33043), B(33044), B(33045) /    26.38,  -40.49,    0.00 /
      DATA B(33334), B(33335), B(33336) /    26.37,  -40.41,    0.00 /
      DATA B(33625), B(33626), B(33627) /    26.36,  -40.32,    0.00 /
      DATA B(33916), B(33917), B(33918) /    26.35,  -40.24,    0.00 /
      DATA B(34207), B(34208), B(34209) /    26.33,  -40.16,    0.00 /
      DATA B(34498), B(34499), B(34500) /    26.32,  -40.08,    0.00 /
      DATA B(34789), B(34790), B(34791) /    26.30,  -40.00,    0.00 /
      DATA B(35080), B(35081), B(35082) /    26.28,  -39.92,    0.00 /
      DATA B(35371), B(35372), B(35373) /    26.26,  -39.83,    0.00 /
      DATA B(35662), B(35663), B(35664) /    26.23,  -39.76,    0.00 /
      DATA B(35953), B(35954), B(35955) /    26.20,  -39.68,    0.00 /
      DATA B(36244), B(36245), B(36246) /    26.17,  -39.60,    0.00 /
      DATA B(36535), B(36536), B(36537) /    26.14,  -39.53,    0.00 /
      DATA B(36826), B(36827), B(36828) /    26.10,  -39.45,    0.00 /
      DATA B(37117), B(37118), B(37119) /    26.06,  -39.38,    0.00 /
      DATA B(37408), B(37409), B(37410) /    26.01,  -39.31,    0.00 /
      DATA B(37699), B(37700), B(37701) /    25.96,  -39.24,    0.00 /
      DATA B(37990), B(37991), B(37992) /    25.90,  -39.17,    0.00 /
      DATA B(38281), B(38282), B(38283) /    25.83,  -39.10,    0.00 /
      DATA B(38572), B(38573), B(38574) /    25.76,  -39.03,    0.00 /
      DATA B(38863), B(38864), B(38865) /    25.67,  -38.96,    0.00 /
      DATA B(39154), B(39155), B(39156) /    25.58,  -38.87,    0.00 /
      DATA B(39445), B(39446), B(39447) /    25.47,  -38.78,    0.00 /
      DATA B(39736), B(39737), B(39738) /    25.34,  -38.67,    0.00 /
      DATA B(40027), B(40028), B(40029) /    25.19,  -38.54,    0.00 /
      DATA B(40318), B(40319), B(40320) /    25.01,  -38.38,    0.00 /
      DATA B(40609), B(40610), B(40611) /    24.81,  -38.18,    0.00 /
      DATA B(40900), B(40901), B(40902) /    24.56,  -37.92,    0.00 /
      DATA B(41191), B(41192), B(41193) /    24.27,  -37.59,    0.00 /
      DATA B(41482), B(41483), B(41484) /    23.91,  -37.17,    0.00 /
      DATA B(41773), B(41774), B(41775) /    23.46,  -36.70,    0.00 /
      DATA B(42064), B(42065), B(42066) /    22.90,  -36.25,    0.00 /
      DATA B(42355), B(42356), B(42357) /    22.28,  -35.84,    0.00 /
      DATA B(42646), B(42647), B(42648) /    21.63,  -35.45,    0.00 /
      DATA B(42937), B(42938), B(42939) /    20.90,  -35.11,    0.00 /
      DATA B(43228), B(43229), B(43230) /    20.11,  -34.73,    0.00 /
      DATA B(43519), B(43520), B(43521) /    19.31,  -34.36,    0.00 /
      DATA B(43810), B(43811), B(43812) /    18.52,  -34.06,    0.00 /
      DATA B(44101), B(44102), B(44103) /    17.78,  -33.75,    0.00 /
      DATA B(44392), B(44393), B(44394) /    17.09,  -33.43,    0.00 /
      DATA B(44683), B(44684), B(44685) /    16.45,  -33.10,    0.00 /
      DATA B(44974), B(44975), B(44976) /    15.84,  -32.75,    0.00 /
      DATA B(45265), B(45266), B(45267) /    15.26,  -32.35,    0.00 /
      DATA B(45556), B(45557), B(45558) /    14.69,  -31.89,    0.00 /
      DATA B(45847), B(45848), B(45849) /    14.11,  -31.34,    0.00 /
      DATA B(46138), B(46139), B(46140) /    13.51,  -30.66,    0.00 /
      DATA B(27517), B(27518), B(27519) /    26.47,  -41.79,    0.00 /
      DATA B(27808), B(27809), B(27810) /    26.47,  -41.73,    0.00 /
      DATA B(28099), B(28100), B(28101) /    26.46,  -41.66,    0.00 /
      DATA B(28390), B(28391), B(28392) /    26.46,  -41.60,    0.00 /
      DATA B(28681), B(28682), B(28683) /    26.45,  -41.53,    0.00 /
      DATA B(28972), B(28973), B(28974) /    26.44,  -41.47,    0.00 /
      DATA B(29263), B(29264), B(29265) /    26.44,  -41.40,    0.00 /
      DATA B(29554), B(29555), B(29556) /    26.43,  -41.34,    0.00 /
      DATA B(29845), B(29846), B(29847) /    26.43,  -41.27,    0.00 /
      DATA B(30136), B(30137), B(30138) /    26.42,  -41.20,    0.00 /
      DATA B(30427), B(30428), B(30429) /    26.41,  -41.13,    0.00 /
      DATA B(30718), B(30719), B(30720) /    26.41,  -41.06,    0.00 /
      DATA B(31009), B(31010), B(31011) /    26.40,  -40.99,    0.00 /
      DATA B(31300), B(31301), B(31302) /    26.39,  -40.92,    0.00 /
      DATA B(31591), B(31592), B(31593) /    26.39,  -40.85,    0.00 /
      DATA B(31882), B(31883), B(31884) /    26.38,  -40.77,    0.00 /
      DATA B(32173), B(32174), B(32175) /    26.37,  -40.70,    0.00 /
      DATA B(32464), B(32465), B(32466) /    26.37,  -40.62,    0.00 /
      DATA B(32755), B(32756), B(32757) /    26.36,  -40.54,    0.00 /
      DATA B(33046), B(33047), B(33048) /    26.35,  -40.46,    0.00 /
      DATA B(33337), B(33338), B(33339) /    26.34,  -40.38,    0.00 /
      DATA B(33628), B(33629), B(33630) /    26.32,  -40.29,    0.00 /
      DATA B(33919), B(33920), B(33921) /    26.31,  -40.21,    0.00 /
      DATA B(34210), B(34211), B(34212) /    26.30,  -40.13,    0.00 /
      DATA B(34501), B(34502), B(34503) /    26.28,  -40.04,    0.00 /
      DATA B(34792), B(34793), B(34794) /    26.26,  -39.96,    0.00 /
      DATA B(35083), B(35084), B(35085) /    26.24,  -39.87,    0.00 /
      DATA B(35374), B(35375), B(35376) /    26.21,  -39.79,    0.00 /
      DATA B(35665), B(35666), B(35667) /    26.19,  -39.71,    0.00 /
      DATA B(35956), B(35957), B(35958) /    26.16,  -39.63,    0.00 /
      DATA B(36247), B(36248), B(36249) /    26.12,  -39.55,    0.00 /
      DATA B(36538), B(36539), B(36540) /    26.09,  -39.48,    0.00 /
      DATA B(36829), B(36830), B(36831) /    26.05,  -39.41,    0.00 /
      DATA B(37120), B(37121), B(37122) /    26.00,  -39.33,    0.00 /
      DATA B(37411), B(37412), B(37413) /    25.95,  -39.26,    0.00 /
      DATA B(37702), B(37703), B(37704) /    25.89,  -39.19,    0.00 /
      DATA B(37993), B(37994), B(37995) /    25.83,  -39.13,    0.00 /
      DATA B(38284), B(38285), B(38286) /    25.75,  -39.06,    0.00 /
      DATA B(38575), B(38576), B(38577) /    25.67,  -38.98,    0.00 /
      DATA B(38866), B(38867), B(38868) /    25.57,  -38.91,    0.00 /
      DATA B(39157), B(39158), B(39159) /    25.45,  -38.82,    0.00 /
      DATA B(39448), B(39449), B(39450) /    25.32,  -38.73,    0.00 /
      DATA B(39739), B(39740), B(39741) /    25.16,  -38.61,    0.00 /
      DATA B(40030), B(40031), B(40032) /    24.97,  -38.47,    0.00 /
      DATA B(40321), B(40322), B(40323) /    24.74,  -38.29,    0.00 /
      DATA B(40612), B(40613), B(40614) /    24.46,  -38.07,    0.00 /
      DATA B(40903), B(40904), B(40905) /    24.12,  -37.76,    0.00 /
      DATA B(41194), B(41195), B(41196) /    23.71,  -37.35,    0.00 /
      DATA B(41485), B(41486), B(41487) /    23.20,  -36.82,    0.00 /
      DATA B(41776), B(41777), B(41778) /    22.55,  -36.21,    0.00 /
      DATA B(42067), B(42068), B(42069) /    21.79,  -35.69,    0.00 /
      DATA B(42358), B(42359), B(42360) /    21.02,  -35.21,    0.00 /
      DATA B(42649), B(42650), B(42651) /    20.17,  -34.82,    0.00 /
      DATA B(42940), B(42941), B(42942) /    19.29,  -34.45,    0.00 /
      DATA B(43231), B(43232), B(43233) /    18.49,  -34.11,    0.00 /
      DATA B(43522), B(43523), B(43524) /    17.74,  -33.79,    0.00 /
      DATA B(43813), B(43814), B(43815) /    17.06,  -33.51,    0.00 /
      DATA B(44104), B(44105), B(44106) /    16.43,  -33.23,    0.00 /
      DATA B(44395), B(44396), B(44397) /    15.85,  -32.94,    0.00 /
      DATA B(44686), B(44687), B(44688) /    15.29,  -32.63,    0.00 /
      DATA B(44977), B(44978), B(44979) /    14.75,  -32.29,    0.00 /
      DATA B(45268), B(45269), B(45270) /    14.20,  -31.90,    0.00 /
      DATA B(45559), B(45560), B(45561) /    13.62,  -31.43,    0.00 /
      DATA B(45850), B(45851), B(45852) /    13.02,  -30.88,    0.00 /
      DATA B(46141), B(46142), B(46143) /    12.37,  -30.18,    0.00 /
      DATA B(27520), B(27521), B(27522) /    26.44,  -41.77,    0.00 /
      DATA B(27811), B(27812), B(27813) /    26.44,  -41.71,    0.00 /
      DATA B(28102), B(28103), B(28104) /    26.43,  -41.64,    0.00 /
      DATA B(28393), B(28394), B(28395) /    26.42,  -41.58,    0.00 /
      DATA B(28684), B(28685), B(28686) /    26.42,  -41.51,    0.00 /
      DATA B(28975), B(28976), B(28977) /    26.41,  -41.45,    0.00 /
      DATA B(29266), B(29267), B(29268) /    26.41,  -41.38,    0.00 /
      DATA B(29557), B(29558), B(29559) /    26.40,  -41.32,    0.00 /
      DATA B(29848), B(29849), B(29850) /    26.39,  -41.25,    0.00 /
      DATA B(30139), B(30140), B(30141) /    26.39,  -41.18,    0.00 /
      DATA B(30430), B(30431), B(30432) /    26.38,  -41.11,    0.00 /
      DATA B(30721), B(30722), B(30723) /    26.37,  -41.04,    0.00 /
      DATA B(31012), B(31013), B(31014) /    26.37,  -40.97,    0.00 /
      DATA B(31303), B(31304), B(31305) /    26.36,  -40.90,    0.00 /
      DATA B(31594), B(31595), B(31596) /    26.35,  -40.82,    0.00 /
      DATA B(31885), B(31886), B(31887) /    26.34,  -40.75,    0.00 /
      DATA B(32176), B(32177), B(32178) /    26.34,  -40.67,    0.00 /
      DATA B(32467), B(32468), B(32469) /    26.33,  -40.59,    0.00 /
      DATA B(32758), B(32759), B(32760) /    26.32,  -40.51,    0.00 /
      DATA B(33049), B(33050), B(33051) /    26.31,  -40.43,    0.00 /
      DATA B(33340), B(33341), B(33342) /    26.30,  -40.35,    0.00 /
      DATA B(33631), B(33632), B(33633) /    26.29,  -40.26,    0.00 /
      DATA B(33922), B(33923), B(33924) /    26.27,  -40.18,    0.00 /
      DATA B(34213), B(34214), B(34215) /    26.26,  -40.09,    0.00 /
      DATA B(34504), B(34505), B(34506) /    26.24,  -40.00,    0.00 /
      DATA B(34795), B(34796), B(34797) /    26.22,  -39.92,    0.00 /
      DATA B(35086), B(35087), B(35088) /    26.20,  -39.83,    0.00 /
      DATA B(35377), B(35378), B(35379) /    26.17,  -39.75,    0.00 /
      DATA B(35668), B(35669), B(35670) /    26.14,  -39.66,    0.00 /
      DATA B(35959), B(35960), B(35961) /    26.11,  -39.58,    0.00 /
      DATA B(36250), B(36251), B(36252) /    26.08,  -39.50,    0.00 /
      DATA B(36541), B(36542), B(36543) /    26.04,  -39.43,    0.00 /
      DATA B(36832), B(36833), B(36834) /    25.99,  -39.35,    0.00 /
      DATA B(37123), B(37124), B(37125) /    25.95,  -39.28,    0.00 /
      DATA B(37414), B(37415), B(37416) /    25.89,  -39.21,    0.00 /
      DATA B(37705), B(37706), B(37707) /    25.83,  -39.14,    0.00 /
      DATA B(37996), B(37997), B(37998) /    25.75,  -39.07,    0.00 /
      DATA B(38287), B(38288), B(38289) /    25.67,  -39.00,    0.00 /
      DATA B(38578), B(38579), B(38580) /    25.57,  -38.93,    0.00 /
      DATA B(38869), B(38870), B(38871) /    25.46,  -38.85,    0.00 /
      DATA B(39160), B(39161), B(39162) /    25.32,  -38.77,    0.00 /
      DATA B(39451), B(39452), B(39453) /    25.16,  -38.67,    0.00 /
      DATA B(39742), B(39743), B(39744) /    24.96,  -38.54,    0.00 /
      DATA B(40033), B(40034), B(40035) /    24.71,  -38.39,    0.00 /
      DATA B(40324), B(40325), B(40326) /    24.41,  -38.18,    0.00 /
      DATA B(40615), B(40616), B(40617) /    24.02,  -37.91,    0.00 /
      DATA B(40906), B(40907), B(40908) /    23.55,  -37.53,    0.00 /
      DATA B(41197), B(41198), B(41199) /    22.97,  -36.99,    0.00 /
      DATA B(41488), B(41489), B(41490) /    22.21,  -36.37,    0.00 /
      DATA B(41779), B(41780), B(41781) /    21.31,  -35.56,    0.00 /
      DATA B(42070), B(42071), B(42072) /    20.35,  -35.00,    0.00 /
      DATA B(42361), B(42362), B(42363) /    19.40,  -34.61,    0.00 /
      DATA B(42652), B(42653), B(42654) /    18.54,  -34.21,    0.00 /
      DATA B(42943), B(42944), B(42945) /    17.75,  -33.87,    0.00 /
      DATA B(43234), B(43235), B(43236) /    17.06,  -33.56,    0.00 /
      DATA B(43525), B(43526), B(43527) /    16.44,  -33.29,    0.00 /
      DATA B(43816), B(43817), B(43818) /    15.87,  -33.03,    0.00 /
      DATA B(44107), B(44108), B(44109) /    15.34,  -32.77,    0.00 /
      DATA B(44398), B(44399), B(44400) /    14.82,  -32.50,    0.00 /
      DATA B(44689), B(44690), B(44691) /    14.30,  -32.19,    0.00 /
      DATA B(44980), B(44981), B(44982) /    13.77,  -31.84,    0.00 /
      DATA B(45271), B(45272), B(45273) /    13.20,  -31.44,    0.00 /
      DATA B(45562), B(45563), B(45564) /    12.58,  -30.97,    0.00 /
      DATA B(45853), B(45854), B(45855) /     8.07,  -27.22,    0.00 /
      DATA B(46144), B(46145), B(46146) /     7.23,  -26.94,    0.00 /
      DATA B(27523), B(27524), B(27525) /    26.41,  -41.75,    0.00 /
      DATA B(27814), B(27815), B(27816) /    26.41,  -41.69,    0.00 /
      DATA B(28105), B(28106), B(28107) /    26.40,  -41.62,    0.00 /
      DATA B(28396), B(28397), B(28398) /    26.39,  -41.56,    0.00 /
      DATA B(28687), B(28688), B(28689) /    26.39,  -41.49,    0.00 /
      DATA B(28978), B(28979), B(28980) /    26.38,  -41.43,    0.00 /
      DATA B(29269), B(29270), B(29271) /    26.37,  -41.36,    0.00 /
      DATA B(29560), B(29561), B(29562) /    26.37,  -41.30,    0.00 /
      DATA B(29851), B(29852), B(29853) /    26.36,  -41.23,    0.00 /
      DATA B(30142), B(30143), B(30144) /    26.35,  -41.16,    0.00 /
      DATA B(30433), B(30434), B(30435) /    26.34,  -41.09,    0.00 /
      DATA B(30724), B(30725), B(30726) /    26.34,  -41.02,    0.00 /
      DATA B(31015), B(31016), B(31017) /    26.33,  -40.95,    0.00 /
      DATA B(31306), B(31307), B(31308) /    26.32,  -40.88,    0.00 /
      DATA B(31597), B(31598), B(31599) /    26.31,  -40.80,    0.00 /
      DATA B(31888), B(31889), B(31890) /    26.31,  -40.73,    0.00 /
      DATA B(32179), B(32180), B(32181) /    26.30,  -40.65,    0.00 /
      DATA B(32470), B(32471), B(32472) /    26.29,  -40.57,    0.00 /
      DATA B(32761), B(32762), B(32763) /    26.28,  -40.49,    0.00 /
      DATA B(33052), B(33053), B(33054) /    26.27,  -40.40,    0.00 /
      DATA B(33343), B(33344), B(33345) /    26.26,  -40.32,    0.00 /
      DATA B(33634), B(33635), B(33636) /    26.25,  -40.23,    0.00 /
      DATA B(33925), B(33926), B(33927) /    26.23,  -40.14,    0.00 /
      DATA B(34216), B(34217), B(34218) /    26.22,  -40.05,    0.00 /
      DATA B(34507), B(34508), B(34509) /    26.20,  -39.96,    0.00 /
      DATA B(34798), B(34799), B(34800) /    26.18,  -39.88,    0.00 /
      DATA B(35089), B(35090), B(35091) /    26.16,  -39.79,    0.00 /
      DATA B(35380), B(35381), B(35382) /    26.13,  -39.70,    0.00 /
      DATA B(35671), B(35672), B(35673) /    26.10,  -39.61,    0.00 /
      DATA B(35962), B(35963), B(35964) /    26.07,  -39.53,    0.00 /
      DATA B(36253), B(36254), B(36255) /    26.03,  -39.45,    0.00 /
      DATA B(36544), B(36545), B(36546) /    25.99,  -39.37,    0.00 /
      DATA B(36835), B(36836), B(36837) /    25.94,  -39.30,    0.00 /
      DATA B(37126), B(37127), B(37128) /    25.89,  -39.22,    0.00 /
      DATA B(37417), B(37418), B(37419) /    25.83,  -39.15,    0.00 /
      DATA B(37708), B(37709), B(37710) /    25.76,  -39.08,    0.00 /
      DATA B(37999), B(38000), B(38001) /    25.68,  -39.01,    0.00 /
      DATA B(38290), B(38291), B(38292) /    25.59,  -38.94,    0.00 /
      DATA B(38581), B(38582), B(38583) /    25.48,  -38.87,    0.00 /
      DATA B(38872), B(38873), B(38874) /    25.34,  -38.79,    0.00 /
      DATA B(39163), B(39164), B(39165) /    25.18,  -38.71,    0.00 /
      DATA B(39454), B(39455), B(39456) /    24.98,  -38.60,    0.00 /
      DATA B(39745), B(39746), B(39747) /    24.74,  -38.46,    0.00 /
      DATA B(40036), B(40037), B(40038) /    24.42,  -38.27,    0.00 /
      DATA B(40327), B(40328), B(40329) /    24.02,  -38.02,    0.00 /
      DATA B(40618), B(40619), B(40620) /    23.50,  -37.67,    0.00 /
      DATA B(40909), B(40910), B(40911) /    22.83,  -37.18,    0.00 /
      DATA B(41200), B(41201), B(41202) /    22.06,  -36.44,    0.00 /
      DATA B(41491), B(41492), B(41493) /    20.45,  -35.28,    0.00 /
      DATA B(41782), B(41783), B(41784) /    19.62,  -34.86,    0.00 /
      DATA B(42073), B(42074), B(42075) /    18.68,  -34.37,    0.00 /
      DATA B(42364), B(42365), B(42366) /    17.85,  -33.99,    0.00 /
      DATA B(42655), B(42656), B(42657) /    17.12,  -33.65,    0.00 /
      DATA B(42946), B(42947), B(42948) /    16.48,  -33.36,    0.00 /
      DATA B(43237), B(43238), B(43239) /    15.91,  -33.09,    0.00 /
      DATA B(43528), B(43529), B(43530) /    15.39,  -32.84,    0.00 /
      DATA B(43819), B(43820), B(43821) /    14.90,  -32.60,    0.00 /
      DATA B(44110), B(44111), B(44112) /    14.41,  -32.35,    0.00 /
      DATA B(44401), B(44402), B(44403) /    13.91,  -32.07,    0.00 /
      DATA B(44692), B(44693), B(44694) /    13.38,  -31.75,    0.00 /
      DATA B(44983), B(44984), B(44985) /    12.81,  -31.39,    0.00 /
      DATA B(45274), B(45275), B(45276) /    12.19,  -30.97,    0.00 /
      DATA B(45565), B(45566), B(45567) /     7.65,  -27.46,    0.00 /
      DATA B(45856), B(45857), B(45858) /     6.79,  -27.27,    0.00 /
      DATA B(46147), B(46148), B(46149) /     5.94,  -26.99,    0.00 /
      DATA B(27526), B(27527), B(27528) /    26.38,  -41.73,    0.00 /
      DATA B(27817), B(27818), B(27819) /    26.37,  -41.67,    0.00 /
      DATA B(28108), B(28109), B(28110) /    26.37,  -41.60,    0.00 /
      DATA B(28399), B(28400), B(28401) /    26.36,  -41.54,    0.00 /
      DATA B(28690), B(28691), B(28692) /    26.35,  -41.47,    0.00 /
      DATA B(28981), B(28982), B(28983) /    26.35,  -41.41,    0.00 /
      DATA B(29272), B(29273), B(29274) /    26.34,  -41.34,    0.00 /
      DATA B(29563), B(29564), B(29565) /    26.33,  -41.27,    0.00 /
      DATA B(29854), B(29855), B(29856) /    26.32,  -41.21,    0.00 /
      DATA B(30145), B(30146), B(30147) /    26.32,  -41.14,    0.00 /
      DATA B(30436), B(30437), B(30438) /    26.31,  -41.07,    0.00 /
      DATA B(30727), B(30728), B(30729) /    26.30,  -41.00,    0.00 /
      DATA B(31018), B(31019), B(31020) /    26.29,  -40.93,    0.00 /
      DATA B(31309), B(31310), B(31311) /    26.28,  -40.85,    0.00 /
      DATA B(31600), B(31601), B(31602) /    26.28,  -40.78,    0.00 /
      DATA B(31891), B(31892), B(31893) /    26.27,  -40.70,    0.00 /
      DATA B(32182), B(32183), B(32184) /    26.26,  -40.63,    0.00 /
      DATA B(32473), B(32474), B(32475) /    26.25,  -40.54,    0.00 /
      DATA B(32764), B(32765), B(32766) /    26.24,  -40.46,    0.00 /
      DATA B(33055), B(33056), B(33057) /    26.23,  -40.38,    0.00 /
      DATA B(33346), B(33347), B(33348) /    26.22,  -40.29,    0.00 /
      DATA B(33637), B(33638), B(33639) /    26.21,  -40.20,    0.00 /
      DATA B(33928), B(33929), B(33930) /    26.19,  -40.11,    0.00 /
      DATA B(34219), B(34220), B(34221) /    26.18,  -40.02,    0.00 /
      DATA B(34510), B(34511), B(34512) /    26.16,  -39.92,    0.00 /
      DATA B(34801), B(34802), B(34803) /    26.14,  -39.83,    0.00 /
      DATA B(35092), B(35093), B(35094) /    26.11,  -39.74,    0.00 /
      DATA B(35383), B(35384), B(35385) /    26.09,  -39.65,    0.00 /
      DATA B(35674), B(35675), B(35676) /    26.05,  -39.56,    0.00 /
      DATA B(35965), B(35966), B(35967) /    26.02,  -39.47,    0.00 /
      DATA B(36256), B(36257), B(36258) /    25.98,  -39.39,    0.00 /
      DATA B(36547), B(36548), B(36549) /    25.94,  -39.31,    0.00 /
      DATA B(36838), B(36839), B(36840) /    25.89,  -39.24,    0.00 /
      DATA B(37129), B(37130), B(37131) /    25.83,  -39.16,    0.00 /
      DATA B(37420), B(37421), B(37422) /    25.77,  -39.09,    0.00 /
      DATA B(37711), B(37712), B(37713) /    25.69,  -39.02,    0.00 /
      DATA B(38002), B(38003), B(38004) /    25.61,  -38.95,    0.00 /
      DATA B(38293), B(38294), B(38295) /    25.50,  -38.88,    0.00 /
      DATA B(38584), B(38585), B(38586) /    25.37,  -38.81,    0.00 /
      DATA B(38875), B(38876), B(38877) /    25.22,  -38.73,    0.00 /
      DATA B(39166), B(39167), B(39168) /    25.03,  -38.63,    0.00 /
      DATA B(39457), B(39458), B(39459) /    24.79,  -38.51,    0.00 /
      DATA B(39748), B(39749), B(39750) /    24.49,  -38.35,    0.00 /
      DATA B(40039), B(40040), B(40041) /    24.09,  -38.12,    0.00 /
      DATA B(40330), B(40331), B(40332) /    23.56,  -37.79,    0.00 /
      DATA B(40621), B(40622), B(40623) /    22.89,  -37.32,    0.00 /
      DATA B(40912), B(40913), B(40914) /    22.06,  -36.59,    0.00 /
      DATA B(41203), B(41204), B(41205) /    19.73,  -35.08,    0.00 /
      DATA B(41494), B(41495), B(41496) /    18.85,  -34.59,    0.00 /
      DATA B(41785), B(41786), B(41787) /    17.99,  -34.17,    0.00 /
      DATA B(42076), B(42077), B(42078) /    17.23,  -33.78,    0.00 /
      DATA B(42367), B(42368), B(42369) /    16.56,  -33.45,    0.00 /
      DATA B(42658), B(42659), B(42660) /    15.97,  -33.17,    0.00 /
      DATA B(42949), B(42950), B(42951) /    15.45,  -32.91,    0.00 /
      DATA B(43240), B(43241), B(43242) /    14.97,  -32.68,    0.00 /
      DATA B(43531), B(43532), B(43533) /    14.51,  -32.44,    0.00 /
      DATA B(43822), B(43823), B(43824) /    14.04,  -32.20,    0.00 /
      DATA B(44113), B(44114), B(44115) /    13.56,  -31.94,    0.00 /
      DATA B(44404), B(44405), B(44406) /    13.04,  -31.64,    0.00 /
      DATA B(44695), B(44696), B(44697) /    12.46,  -31.29,    0.00 /
      DATA B(44986), B(44987), B(44988) /    11.83,  -30.91,    0.00 /
      DATA B(45277), B(45278), B(45279) /     7.27,  -27.62,    0.00 /
      DATA B(45568), B(45569), B(45570) /     6.40,  -27.50,    0.00 /
      DATA B(45859), B(45860), B(45861) /     5.54,  -27.31,    0.00 /
      DATA B(46150), B(46151), B(46152) /     4.68,  -27.02,    0.00 /
      DATA B(27529), B(27530), B(27531) /    26.35,  -41.71,    0.00 /
      DATA B(27820), B(27821), B(27822) /    26.34,  -41.64,    0.00 /
      DATA B(28111), B(28112), B(28113) /    26.33,  -41.58,    0.00 /
      DATA B(28402), B(28403), B(28404) /    26.33,  -41.52,    0.00 /
      DATA B(28693), B(28694), B(28695) /    26.32,  -41.45,    0.00 /
      DATA B(28984), B(28985), B(28986) /    26.31,  -41.39,    0.00 /
      DATA B(29275), B(29276), B(29277) /    26.30,  -41.32,    0.00 /
      DATA B(29566), B(29567), B(29568) /    26.29,  -41.25,    0.00 /
      DATA B(29857), B(29858), B(29859) /    26.29,  -41.19,    0.00 /
      DATA B(30148), B(30149), B(30150) /    26.28,  -41.12,    0.00 /
      DATA B(30439), B(30440), B(30441) /    26.27,  -41.05,    0.00 /
      DATA B(30730), B(30731), B(30732) /    26.26,  -40.98,    0.00 /
      DATA B(31021), B(31022), B(31023) /    26.25,  -40.91,    0.00 /
      DATA B(31312), B(31313), B(31314) /    26.25,  -40.83,    0.00 /
      DATA B(31603), B(31604), B(31605) /    26.24,  -40.76,    0.00 /
      DATA B(31894), B(31895), B(31896) /    26.23,  -40.68,    0.00 /
      DATA B(32185), B(32186), B(32187) /    26.22,  -40.60,    0.00 /
      DATA B(32476), B(32477), B(32478) /    26.21,  -40.52,    0.00 /
      DATA B(32767), B(32768), B(32769) /    26.20,  -40.44,    0.00 /
      DATA B(33058), B(33059), B(33060) /    26.19,  -40.35,    0.00 /
      DATA B(33349), B(33350), B(33351) /    26.18,  -40.26,    0.00 /
      DATA B(33640), B(33641), B(33642) /    26.17,  -40.17,    0.00 /
      DATA B(33931), B(33932), B(33933) /    26.15,  -40.07,    0.00 /
      DATA B(34222), B(34223), B(34224) /    26.14,  -39.98,    0.00 /
      DATA B(34513), B(34514), B(34515) /    26.12,  -39.88,    0.00 /
      DATA B(34804), B(34805), B(34806) /    26.10,  -39.78,    0.00 /
      DATA B(35095), B(35096), B(35097) /    26.07,  -39.69,    0.00 /
      DATA B(35386), B(35387), B(35388) /    26.04,  -39.59,    0.00 /
      DATA B(35677), B(35678), B(35679) /    26.01,  -39.50,    0.00 /
      DATA B(35968), B(35969), B(35970) /    25.97,  -39.41,    0.00 /
      DATA B(36259), B(36260), B(36261) /    25.93,  -39.33,    0.00 /
      DATA B(36550), B(36551), B(36552) /    25.88,  -39.25,    0.00 /
      DATA B(36841), B(36842), B(36843) /    25.83,  -39.17,    0.00 /
      DATA B(37132), B(37133), B(37134) /    25.77,  -39.10,    0.00 /
      DATA B(37423), B(37424), B(37425) /    25.70,  -39.02,    0.00 /
      DATA B(37714), B(37715), B(37716) /    25.63,  -38.95,    0.00 /
      DATA B(38005), B(38006), B(38007) /    25.53,  -38.88,    0.00 /
      DATA B(38296), B(38297), B(38298) /    25.41,  -38.81,    0.00 /
      DATA B(38587), B(38588), B(38589) /    25.27,  -38.73,    0.00 /
      DATA B(38878), B(38879), B(38880) /    25.09,  -38.65,    0.00 /
      DATA B(39169), B(39170), B(39171) /    24.87,  -38.55,    0.00 /
      DATA B(39460), B(39461), B(39462) /    24.58,  -38.41,    0.00 /
      DATA B(39751), B(39752), B(39753) /    24.21,  -38.21,    0.00 /
      DATA B(40042), B(40043), B(40044) /    23.71,  -37.91,    0.00 /
      DATA B(40333), B(40334), B(40335) /    23.08,  -37.45,    0.00 /
      DATA B(40624), B(40625), B(40626) /    22.19,  -36.85,    0.00 /
      DATA B(40915), B(40916), B(40917) /    18.74,  -34.58,    0.00 /
      DATA B(41206), B(41207), B(41208) /    17.98,  -34.32,    0.00 /
      DATA B(41497), B(41498), B(41499) /    17.32,  -33.88,    0.00 /
      DATA B(41788), B(41789), B(41790) /    16.66,  -33.55,    0.00 /
      DATA B(42079), B(42080), B(42081) /    16.06,  -33.26,    0.00 /
      DATA B(42370), B(42371), B(42372) /    15.53,  -32.99,    0.00 /
      DATA B(42661), B(42662), B(42663) /    15.04,  -32.75,    0.00 /
      DATA B(42952), B(42953), B(42954) /    14.59,  -32.52,    0.00 /
      DATA B(43243), B(43244), B(43245) /    14.15,  -32.30,    0.00 /
      DATA B(43534), B(43535), B(43536) /    13.71,  -32.06,    0.00 /
      DATA B(43825), B(43826), B(43827) /    13.23,  -31.80,    0.00 /
      DATA B(44116), B(44117), B(44118) /    12.71,  -31.51,    0.00 /
      DATA B(44407), B(44408), B(44409) /    12.14,  -31.18,    0.00 /
      DATA B(44698), B(44699), B(44700) /     7.78,  -27.76,    0.00 /
      DATA B(44989), B(44990), B(44991) /     6.93,  -27.73,    0.00 /
      DATA B(45280), B(45281), B(45282) /     6.07,  -27.64,    0.00 /
      DATA B(45571), B(45572), B(45573) /     5.21,  -27.51,    0.00 /
      DATA B(45862), B(45863), B(45864) /     4.34,  -27.31,    0.00 /
      DATA B(46153), B(46154), B(46155) /     3.42,  -27.00,    0.00 /
      DATA B(27532), B(27533), B(27534) /    26.32,  -41.69,    0.00 /
      DATA B(27823), B(27824), B(27825) /    26.31,  -41.62,    0.00 /
      DATA B(28114), B(28115), B(28116) /    26.30,  -41.56,    0.00 /
      DATA B(28405), B(28406), B(28407) /    26.29,  -41.50,    0.00 /
      DATA B(28696), B(28697), B(28698) /    26.28,  -41.43,    0.00 /
      DATA B(28987), B(28988), B(28989) /    26.28,  -41.37,    0.00 /
      DATA B(29278), B(29279), B(29280) /    26.27,  -41.30,    0.00 /
      DATA B(29569), B(29570), B(29571) /    26.26,  -41.23,    0.00 /
      DATA B(29860), B(29861), B(29862) /    26.25,  -41.17,    0.00 /
      DATA B(30151), B(30152), B(30153) /    26.24,  -41.10,    0.00 /
      DATA B(30442), B(30443), B(30444) /    26.23,  -41.03,    0.00 /
      DATA B(30733), B(30734), B(30735) /    26.22,  -40.96,    0.00 /
      DATA B(31024), B(31025), B(31026) /    26.21,  -40.89,    0.00 /
      DATA B(31315), B(31316), B(31317) /    26.21,  -40.81,    0.00 /
      DATA B(31606), B(31607), B(31608) /    26.20,  -40.74,    0.00 /
      DATA B(31897), B(31898), B(31899) /    26.19,  -40.66,    0.00 /
      DATA B(32188), B(32189), B(32190) /    26.18,  -40.58,    0.00 /
      DATA B(32479), B(32480), B(32481) /    26.17,  -40.50,    0.00 /
      DATA B(32770), B(32771), B(32772) /    26.16,  -40.41,    0.00 /
      DATA B(33061), B(33062), B(33063) /    26.15,  -40.32,    0.00 /
      DATA B(33352), B(33353), B(33354) /    26.14,  -40.23,    0.00 /
      DATA B(33643), B(33644), B(33645) /    26.12,  -40.13,    0.00 /
      DATA B(33934), B(33935), B(33936) /    26.11,  -40.04,    0.00 /
      DATA B(34225), B(34226), B(34227) /    26.09,  -39.94,    0.00 /
      DATA B(34516), B(34517), B(34518) /    26.07,  -39.83,    0.00 /
      DATA B(34807), B(34808), B(34809) /    26.05,  -39.73,    0.00 /
      DATA B(35098), B(35099), B(35100) /    26.02,  -39.63,    0.00 /
      DATA B(35389), B(35390), B(35391) /    25.99,  -39.53,    0.00 /
      DATA B(35680), B(35681), B(35682) /    25.96,  -39.44,    0.00 /
      DATA B(35971), B(35972), B(35973) /    25.92,  -39.35,    0.00 /
      DATA B(36262), B(36263), B(36264) /    25.87,  -39.26,    0.00 /
      DATA B(36553), B(36554), B(36555) /    25.83,  -39.18,    0.00 /
      DATA B(36844), B(36845), B(36846) /    25.77,  -39.10,    0.00 /
      DATA B(37135), B(37136), B(37137) /    25.71,  -39.03,    0.00 /
      DATA B(37426), B(37427), B(37428) /    25.64,  -38.95,    0.00 /
      DATA B(37717), B(37718), B(37719) /    25.56,  -38.88,    0.00 /
      DATA B(38008), B(38009), B(38010) /    25.45,  -38.80,    0.00 /
      DATA B(38299), B(38300), B(38301) /    25.33,  -38.73,    0.00 /
      DATA B(38590), B(38591), B(38592) /    25.17,  -38.65,    0.00 /
      DATA B(38881), B(38882), B(38883) /    24.96,  -38.56,    0.00 /
      DATA B(39172), B(39173), B(39174) /    24.70,  -38.45,    0.00 /
      DATA B(39463), B(39464), B(39465) /    24.36,  -38.28,    0.00 /
      DATA B(39754), B(39755), B(39756) /    23.91,  -38.03,    0.00 /
      DATA B(40045), B(40046), B(40047) /    23.31,  -37.60,    0.00 /
      DATA B(40336), B(40337), B(40338) /    22.54,  -37.04,    0.00 /
      DATA B(40627), B(40628), B(40629) /    17.80,  -34.14,    0.00 /
      DATA B(40918), B(40919), B(40920) /    17.22,  -33.92,    0.00 /
      DATA B(41209), B(41210), B(41211) /    16.66,  -33.60,    0.00 /
      DATA B(41500), B(41501), B(41502) /    16.10,  -33.31,    0.00 /
      DATA B(41791), B(41792), B(41793) /    15.59,  -33.05,    0.00 /
      DATA B(42082), B(42083), B(42084) /    15.11,  -32.81,    0.00 /
      DATA B(42373), B(42374), B(42375) /    14.67,  -32.59,    0.00 /
      DATA B(42664), B(42665), B(42666) /    14.25,  -32.37,    0.00 /
      DATA B(42955), B(42956), B(42957) /    13.83,  -32.15,    0.00 /
      DATA B(43246), B(43247), B(43248) /    13.39,  -31.92,    0.00 /
      DATA B(43537), B(43538), B(43539) /    12.92,  -31.66,    0.00 /
      DATA B(43828), B(43829), B(43830) /    12.41,  -31.37,    0.00 /
      DATA B(44119), B(44120), B(44121) /    11.83,  -31.05,    0.00 /
      DATA B(44410), B(44411), B(44412) /     7.46,  -27.82,    0.00 /
      DATA B(44701), B(44702), B(44703) /     6.62,  -27.80,    0.00 /
      DATA B(44992), B(44993), B(44994) /     5.78,  -27.74,    0.00 /
      DATA B(45283), B(45284), B(45285) /     4.94,  -27.65,    0.00 /
      DATA B(45574), B(45575), B(45576) /     4.06,  -27.50,    0.00 /
      DATA B(45865), B(45866), B(45867) /     3.12,  -27.27,    0.00 /
      DATA B(46156), B(46157), B(46158) /     2.08,  -26.92,    0.00 /
      DATA B(27535), B(27536), B(27537) /    26.28,  -41.67,    0.00 /
      DATA B(27826), B(27827), B(27828) /    26.27,  -41.60,    0.00 /
      DATA B(28117), B(28118), B(28119) /    26.27,  -41.54,    0.00 /
      DATA B(28408), B(28409), B(28410) /    26.26,  -41.47,    0.00 /
      DATA B(28699), B(28700), B(28701) /    26.25,  -41.41,    0.00 /
      DATA B(28990), B(28991), B(28992) /    26.24,  -41.35,    0.00 /
      DATA B(29281), B(29282), B(29283) /    26.23,  -41.28,    0.00 /
      DATA B(29572), B(29573), B(29574) /    26.22,  -41.21,    0.00 /
      DATA B(29863), B(29864), B(29865) /    26.21,  -41.15,    0.00 /
      DATA B(30154), B(30155), B(30156) /    26.20,  -41.08,    0.00 /
      DATA B(30445), B(30446), B(30447) /    26.19,  -41.01,    0.00 /
      DATA B(30736), B(30737), B(30738) /    26.18,  -40.94,    0.00 /
      DATA B(31027), B(31028), B(31029) /    26.17,  -40.87,    0.00 /
      DATA B(31318), B(31319), B(31320) /    26.16,  -40.79,    0.00 /
      DATA B(31609), B(31610), B(31611) /    26.15,  -40.72,    0.00 /
      DATA B(31900), B(31901), B(31902) /    26.14,  -40.64,    0.00 /
      DATA B(32191), B(32192), B(32193) /    26.13,  -40.56,    0.00 /
      DATA B(32482), B(32483), B(32484) /    26.12,  -40.47,    0.00 /
      DATA B(32773), B(32774), B(32775) /    26.11,  -40.38,    0.00 /
      DATA B(33064), B(33065), B(33066) /    26.10,  -40.29,    0.00 /
      DATA B(33355), B(33356), B(33357) /    26.09,  -40.20,    0.00 /
      DATA B(33646), B(33647), B(33648) /    26.08,  -40.10,    0.00 /
      DATA B(33937), B(33938), B(33939) /    26.06,  -40.00,    0.00 /
      DATA B(34228), B(34229), B(34230) /    26.05,  -39.89,    0.00 /
      DATA B(34519), B(34520), B(34521) /    26.03,  -39.79,    0.00 /
      DATA B(34810), B(34811), B(34812) /    26.00,  -39.68,    0.00 /
      DATA B(35101), B(35102), B(35103) /    25.97,  -39.57,    0.00 /
      DATA B(35392), B(35393), B(35394) /    25.94,  -39.47,    0.00 /
      DATA B(35683), B(35684), B(35685) /    25.91,  -39.37,    0.00 /
      DATA B(35974), B(35975), B(35976) /    25.86,  -39.27,    0.00 /
      DATA B(36265), B(36266), B(36267) /    25.82,  -39.18,    0.00 /
      DATA B(36556), B(36557), B(36558) /    25.77,  -39.10,    0.00 /
      DATA B(36847), B(36848), B(36849) /    25.71,  -39.02,    0.00 /
      DATA B(37138), B(37139), B(37140) /    25.65,  -38.95,    0.00 /
      DATA B(37429), B(37430), B(37431) /    25.57,  -38.87,    0.00 /
      DATA B(37720), B(37721), B(37722) /    25.48,  -38.80,    0.00 /
      DATA B(38011), B(38012), B(38013) /    25.38,  -38.72,    0.00 /
      DATA B(38302), B(38303), B(38304) /    25.24,  -38.63,    0.00 /
      DATA B(38593), B(38594), B(38595) /    25.06,  -38.55,    0.00 /
      DATA B(38884), B(38885), B(38886) /    24.83,  -38.45,    0.00 /
      DATA B(39175), B(39176), B(39177) /    24.52,  -38.32,    0.00 /
      DATA B(39466), B(39467), B(39468) /    24.13,  -38.12,    0.00 /
      DATA B(39757), B(39758), B(39759) /    23.58,  -37.78,    0.00 /
      DATA B(40048), B(40049), B(40050) /    22.95,  -37.17,    0.00 /
      DATA B(40339), B(40340), B(40341) /    16.95,  -33.85,    0.00 /
      DATA B(40630), B(40631), B(40632) /    16.55,  -33.54,    0.00 /
      DATA B(40921), B(40922), B(40923) /    16.04,  -33.32,    0.00 /
      DATA B(41212), B(41213), B(41214) /    15.57,  -33.06,    0.00 /
      DATA B(41503), B(41504), B(41505) /    15.13,  -32.84,    0.00 /
      DATA B(41794), B(41795), B(41796) /    14.71,  -32.63,    0.00 /
      DATA B(42085), B(42086), B(42087) /    14.31,  -32.43,    0.00 /
      DATA B(42376), B(42377), B(42378) /    13.92,  -32.23,    0.00 /
      DATA B(42667), B(42668), B(42669) /    13.52,  -32.01,    0.00 /
      DATA B(42958), B(42959), B(42960) /    13.09,  -31.78,    0.00 /
      DATA B(43249), B(43250), B(43251) /    12.63,  -31.52,    0.00 /
      DATA B(43540), B(43541), B(43542) /    12.11,  -31.23,    0.00 /
      DATA B(43831), B(43832), B(43833) /    11.52,  -30.92,    0.00 /
      DATA B(44122), B(44123), B(44124) /     7.16,  -27.86,    0.00 /
      DATA B(44413), B(44414), B(44415) /     6.33,  -27.86,    0.00 /
      DATA B(44704), B(44705), B(44706) /     5.52,  -27.82,    0.00 /
      DATA B(44995), B(44996), B(44997) /     4.69,  -27.74,    0.00 /
      DATA B(45286), B(45287), B(45288) /     3.83,  -27.62,    0.00 /
      DATA B(45577), B(45578), B(45579) /     2.89,  -27.44,    0.00 /
      DATA B(45868), B(45869), B(45870) /     1.83,  -27.17,    0.00 /
      DATA B(46159), B(46160), B(46161) /     0.66,  -26.75,    0.00 /
      DATA B(27538), B(27539), B(27540) /    26.25,  -41.64,    0.00 /
      DATA B(27829), B(27830), B(27831) /    26.24,  -41.58,    0.00 /
      DATA B(28120), B(28121), B(28122) /    26.23,  -41.52,    0.00 /
      DATA B(28411), B(28412), B(28413) /    26.22,  -41.45,    0.00 /
      DATA B(28702), B(28703), B(28704) /    26.21,  -41.39,    0.00 /
      DATA B(28993), B(28994), B(28995) /    26.20,  -41.32,    0.00 /
      DATA B(29284), B(29285), B(29286) /    26.19,  -41.26,    0.00 /
      DATA B(29575), B(29576), B(29577) /    26.18,  -41.19,    0.00 /
      DATA B(29866), B(29867), B(29868) /    26.17,  -41.12,    0.00 /
      DATA B(30157), B(30158), B(30159) /    26.16,  -41.06,    0.00 /
      DATA B(30448), B(30449), B(30450) /    26.15,  -40.99,    0.00 /
      DATA B(30739), B(30740), B(30741) /    26.14,  -40.92,    0.00 /
      DATA B(31030), B(31031), B(31032) /    26.13,  -40.84,    0.00 /
      DATA B(31321), B(31322), B(31323) /    26.12,  -40.77,    0.00 /
      DATA B(31612), B(31613), B(31614) /    26.11,  -40.69,    0.00 /
      DATA B(31903), B(31904), B(31905) /    26.10,  -40.62,    0.00 /
      DATA B(32194), B(32195), B(32196) /    26.09,  -40.53,    0.00 /
      DATA B(32485), B(32486), B(32487) /    26.08,  -40.45,    0.00 /
      DATA B(32776), B(32777), B(32778) /    26.07,  -40.36,    0.00 /
      DATA B(33067), B(33068), B(33069) /    26.06,  -40.27,    0.00 /
      DATA B(33358), B(33359), B(33360) /    26.04,  -40.17,    0.00 /
      DATA B(33649), B(33650), B(33651) /    26.03,  -40.07,    0.00 /
      DATA B(33940), B(33941), B(33942) /    26.01,  -39.96,    0.00 /
      DATA B(34231), B(34232), B(34233) /    26.00,  -39.85,    0.00 /
      DATA B(34522), B(34523), B(34524) /    25.98,  -39.74,    0.00 /
      DATA B(34813), B(34814), B(34815) /    25.95,  -39.62,    0.00 /
      DATA B(35104), B(35105), B(35106) /    25.92,  -39.51,    0.00 /
      DATA B(35395), B(35396), B(35397) /    25.89,  -39.40,    0.00 /
      DATA B(35686), B(35687), B(35688) /    25.85,  -39.29,    0.00 /
      DATA B(35977), B(35978), B(35979) /    25.81,  -39.19,    0.00 /
      DATA B(36268), B(36269), B(36270) /    25.76,  -39.10,    0.00 /
      DATA B(36559), B(36560), B(36561) /    25.70,  -39.02,    0.00 /
      DATA B(36850), B(36851), B(36852) /    25.64,  -38.94,    0.00 /
      DATA B(37141), B(37142), B(37143) /    25.58,  -38.86,    0.00 /
      DATA B(37432), B(37433), B(37434) /    25.50,  -38.79,    0.00 /
      DATA B(37723), B(37724), B(37725) /    25.41,  -38.71,    0.00 /
      DATA B(38014), B(38015), B(38016) /    25.30,  -38.62,    0.00 /
      DATA B(38305), B(38306), B(38307) /    25.15,  -38.53,    0.00 /
      DATA B(38596), B(38597), B(38598) /    24.96,  -38.43,    0.00 /
      DATA B(38887), B(38888), B(38889) /    24.70,  -38.32,    0.00 /
      DATA B(39178), B(39179), B(39180) /    24.35,  -38.16,    0.00 /
      DATA B(39469), B(39470), B(39471) /    23.90,  -37.92,    0.00 /
      DATA B(39760), B(39761), B(39762) /    23.37,  -37.39,    0.00 /
      DATA B(40051), B(40052), B(40053) /    16.29,  -33.34,    0.00 /
      DATA B(40342), B(40343), B(40344) /    15.92,  -33.20,    0.00 /
      DATA B(40633), B(40634), B(40635) /    15.47,  -33.02,    0.00 /
      DATA B(40924), B(40925), B(40926) /    15.08,  -32.82,    0.00 /
      DATA B(41215), B(41216), B(41217) /    14.70,  -32.63,    0.00 /
      DATA B(41506), B(41507), B(41508) /    14.33,  -32.45,    0.00 /
      DATA B(41797), B(41798), B(41799) /    13.97,  -32.27,    0.00 /
      DATA B(42088), B(42089), B(42090) /    13.60,  -32.07,    0.00 /
      DATA B(42379), B(42380), B(42381) /    13.22,  -31.87,    0.00 /
      DATA B(42670), B(42671), B(42672) /    12.80,  -31.64,    0.00 /
      DATA B(42961), B(42962), B(42963) /    12.34,  -31.38,    0.00 /
      DATA B(43252), B(43253), B(43254) /    11.82,  -31.09,    0.00 /
      DATA B(43543), B(43544), B(43545) /     7.65,  -27.87,    0.00 /
      DATA B(43834), B(43835), B(43836) /     6.86,  -27.90,    0.00 /
      DATA B(44125), B(44126), B(44127) /     6.06,  -27.90,    0.00 /
      DATA B(44416), B(44417), B(44418) /     5.26,  -27.88,    0.00 /
      DATA B(44707), B(44708), B(44709) /     4.46,  -27.82,    0.00 /
      DATA B(44998), B(44999), B(45000) /     3.62,  -27.72,    0.00 /
      DATA B(45289), B(45290), B(45291) /     2.69,  -27.56,    0.00 /
      DATA B(45580), B(45581), B(45582) /     1.64,  -27.33,    0.00 /
      DATA B(45871), B(45872), B(45873) /     0.46,  -27.02,    0.00 /
      DATA B(46162), B(46163), B(46164) /    -1.11,  -26.07,    0.00 /
      DATA B(27541), B(27542), B(27543) /    26.22,  -41.62,    0.00 /
      DATA B(27832), B(27833), B(27834) /    26.21,  -41.56,    0.00 /
      DATA B(28123), B(28124), B(28125) /    26.20,  -41.50,    0.00 /
      DATA B(28414), B(28415), B(28416) /    26.19,  -41.43,    0.00 /
      DATA B(28705), B(28706), B(28707) /    26.18,  -41.37,    0.00 /
      DATA B(28996), B(28997), B(28998) /    26.17,  -41.30,    0.00 /
      DATA B(29287), B(29288), B(29289) /    26.16,  -41.24,    0.00 /
      DATA B(29578), B(29579), B(29580) /    26.15,  -41.17,    0.00 /
      DATA B(29869), B(29870), B(29871) /    26.13,  -41.10,    0.00 /
      DATA B(30160), B(30161), B(30162) /    26.12,  -41.04,    0.00 /
      DATA B(30451), B(30452), B(30453) /    26.11,  -40.97,    0.00 /
      DATA B(30742), B(30743), B(30744) /    26.10,  -40.90,    0.00 /
      DATA B(31033), B(31034), B(31035) /    26.09,  -40.82,    0.00 /
      DATA B(31324), B(31325), B(31326) /    26.07,  -40.75,    0.00 /
      DATA B(31615), B(31616), B(31617) /    26.06,  -40.67,    0.00 /
      DATA B(31906), B(31907), B(31908) /    26.05,  -40.59,    0.00 /
      DATA B(32197), B(32198), B(32199) /    26.04,  -40.51,    0.00 /
      DATA B(32488), B(32489), B(32490) /    26.03,  -40.43,    0.00 /
      DATA B(32779), B(32780), B(32781) /    26.02,  -40.33,    0.00 /
      DATA B(33070), B(33071), B(33072) /    26.00,  -40.24,    0.00 /
      DATA B(33361), B(33362), B(33363) /    25.99,  -40.14,    0.00 /
      DATA B(33652), B(33653), B(33654) /    25.98,  -40.03,    0.00 /
      DATA B(33943), B(33944), B(33945) /    25.96,  -39.92,    0.00 /
      DATA B(34234), B(34235), B(34236) /    25.94,  -39.80,    0.00 /
      DATA B(34525), B(34526), B(34527) /    25.92,  -39.68,    0.00 /
      DATA B(34816), B(34817), B(34818) /    25.90,  -39.56,    0.00 /
      DATA B(35107), B(35108), B(35109) /    25.87,  -39.44,    0.00 /
      DATA B(35398), B(35399), B(35400) /    25.83,  -39.32,    0.00 /
      DATA B(35689), B(35690), B(35691) /    25.79,  -39.21,    0.00 /
      DATA B(35980), B(35981), B(35982) /    25.74,  -39.10,    0.00 /
      DATA B(36271), B(36272), B(36273) /    25.69,  -39.01,    0.00 /
      DATA B(36562), B(36563), B(36564) /    25.63,  -38.92,    0.00 /
      DATA B(36853), B(36854), B(36855) /    25.57,  -38.85,    0.00 /
      DATA B(37144), B(37145), B(37146) /    25.50,  -38.77,    0.00 /
      DATA B(37435), B(37436), B(37437) /    25.42,  -38.69,    0.00 /
      DATA B(37726), B(37727), B(37728) /    25.33,  -38.61,    0.00 /
      DATA B(38017), B(38018), B(38019) /    25.21,  -38.52,    0.00 /
      DATA B(38308), B(38309), B(38310) /    25.06,  -38.41,    0.00 /
      DATA B(38599), B(38600), B(38601) /    24.85,  -38.29,    0.00 /
      DATA B(38890), B(38891), B(38892) /    24.57,  -38.16,    0.00 /
      DATA B(39181), B(39182), B(39183) /    24.23,  -37.96,    0.00 /
      DATA B(39472), B(39473), B(39474) /    23.71,  -37.69,    0.00 /
      DATA B(39763), B(39764), B(39765) /    15.66,  -32.83,    0.00 /
      DATA B(40054), B(40055), B(40056) /    15.29,  -32.88,    0.00 /
      DATA B(40345), B(40346), B(40347) /    14.96,  -32.72,    0.00 /
      DATA B(40636), B(40637), B(40638) /    14.62,  -32.58,    0.00 /
      DATA B(40927), B(40928), B(40929) /    14.29,  -32.42,    0.00 /
      DATA B(41218), B(41219), B(41220) /    13.97,  -32.26,    0.00 /
      DATA B(41509), B(41510), B(41511) /    13.64,  -32.10,    0.00 /
      DATA B(41800), B(41801), B(41802) /    13.30,  -31.92,    0.00 /
      DATA B(42091), B(42092), B(42093) /    12.93,  -31.72,    0.00 /
      DATA B(42382), B(42383), B(42384) /    12.51,  -31.49,    0.00 /
      DATA B(42673), B(42674), B(42675) /    12.05,  -31.23,    0.00 /
      DATA B(42964), B(42965), B(42966) /    11.53,  -30.95,    0.00 /
      DATA B(43255), B(43256), B(43257) /     7.35,  -27.90,    0.00 /
      DATA B(43546), B(43547), B(43548) /     6.57,  -27.93,    0.00 /
      DATA B(43837), B(43838), B(43839) /     5.80,  -27.94,    0.00 /
      DATA B(44128), B(44129), B(44130) /     5.02,  -27.92,    0.00 /
      DATA B(44419), B(44420), B(44421) /     4.23,  -27.88,    0.00 /
      DATA B(44710), B(44711), B(44712) /     3.40,  -27.79,    0.00 /
      DATA B(45001), B(45002), B(45003) /     2.48,  -27.66,    0.00 /
      DATA B(45292), B(45293), B(45294) /     1.44,  -27.46,    0.00 /
      DATA B(45583), B(45584), B(45585) /     0.28,  -27.20,    0.00 /
      DATA B(45874), B(45875), B(45876) /    -1.21,  -26.16,    0.00 /
      DATA B(46165), B(46166), B(46167) /    -2.06,  -25.35,    0.00 /
      DATA B(27544), B(27545), B(27546) /    26.18,  -41.60,    0.00 /
      DATA B(27835), B(27836), B(27837) /    26.17,  -41.54,    0.00 /
      DATA B(28126), B(28127), B(28128) /    26.16,  -41.47,    0.00 /
      DATA B(28417), B(28418), B(28419) /    26.15,  -41.41,    0.00 /
      DATA B(28708), B(28709), B(28710) /    26.14,  -41.35,    0.00 /
      DATA B(28999), B(29000), B(29001) /    26.13,  -41.28,    0.00 /
      DATA B(29290), B(29291), B(29292) /    26.12,  -41.22,    0.00 /
      DATA B(29581), B(29582), B(29583) /    26.11,  -41.15,    0.00 /
      DATA B(29872), B(29873), B(29874) /    26.09,  -41.08,    0.00 /
      DATA B(30163), B(30164), B(30165) /    26.08,  -41.01,    0.00 /
      DATA B(30454), B(30455), B(30456) /    26.07,  -40.94,    0.00 /
      DATA B(30745), B(30746), B(30747) /    26.05,  -40.87,    0.00 /
      DATA B(31036), B(31037), B(31038) /    26.04,  -40.80,    0.00 /
      DATA B(31327), B(31328), B(31329) /    26.03,  -40.73,    0.00 /
      DATA B(31618), B(31619), B(31620) /    26.01,  -40.65,    0.00 /
      DATA B(31909), B(31910), B(31911) /    26.00,  -40.57,    0.00 /
      DATA B(32200), B(32201), B(32202) /    25.99,  -40.49,    0.00 /
      DATA B(32491), B(32492), B(32493) /    25.97,  -40.40,    0.00 /
      DATA B(32782), B(32783), B(32784) /    25.96,  -40.31,    0.00 /
      DATA B(33073), B(33074), B(33075) /    25.95,  -40.21,    0.00 /
      DATA B(33364), B(33365), B(33366) /    25.93,  -40.11,    0.00 /
      DATA B(33655), B(33656), B(33657) /    25.92,  -40.00,    0.00 /
      DATA B(33946), B(33947), B(33948) /    25.90,  -39.88,    0.00 /
      DATA B(34237), B(34238), B(34239) /    25.88,  -39.75,    0.00 /
      DATA B(34528), B(34529), B(34530) /    25.86,  -39.63,    0.00 /
      DATA B(34819), B(34820), B(34821) /    25.84,  -39.49,    0.00 /
      DATA B(35110), B(35111), B(35112) /    25.81,  -39.36,    0.00 /
      DATA B(35401), B(35402), B(35403) /    25.77,  -39.23,    0.00 /
      DATA B(35692), B(35693), B(35694) /    25.72,  -39.11,    0.00 /
      DATA B(35983), B(35984), B(35985) /    25.67,  -39.00,    0.00 /
      DATA B(36274), B(36275), B(36276) /    25.61,  -38.90,    0.00 /
      DATA B(36565), B(36566), B(36567) /    25.55,  -38.82,    0.00 /
      DATA B(36856), B(36857), B(36858) /    25.49,  -38.74,    0.00 /
      DATA B(37147), B(37148), B(37149) /    25.41,  -38.67,    0.00 /
      DATA B(37438), B(37439), B(37440) /    25.33,  -38.59,    0.00 /
      DATA B(37729), B(37730), B(37731) /    25.23,  -38.50,    0.00 /
      DATA B(38020), B(38021), B(38022) /    25.11,  -38.40,    0.00 /
      DATA B(38311), B(38312), B(38313) /    24.95,  -38.27,    0.00 /
      DATA B(38602), B(38603), B(38604) /    24.74,  -38.12,    0.00 /
      DATA B(38893), B(38894), B(38895) /    24.46,  -37.96,    0.00 /
      DATA B(39184), B(39185), B(39186) /    24.12,  -37.77,    0.00 /
      DATA B(39475), B(39476), B(39477) /    14.99,  -32.38,    0.00 /
      DATA B(39766), B(39767), B(39768) /    14.74,  -32.50,    0.00 /
      DATA B(40057), B(40058), B(40059) /    14.50,  -32.43,    0.00 /
      DATA B(40348), B(40349), B(40350) /    14.21,  -32.33,    0.00 /
      DATA B(40639), B(40640), B(40641) /    13.92,  -32.21,    0.00 /
      DATA B(40930), B(40931), B(40932) /    13.63,  -32.07,    0.00 /
      DATA B(41221), B(41222), B(41223) /    13.32,  -31.93,    0.00 /
      DATA B(41512), B(41513), B(41514) /    13.00,  -31.76,    0.00 /
      DATA B(41803), B(41804), B(41805) /    12.64,  -31.56,    0.00 /
      DATA B(42094), B(42095), B(42096) /    12.23,  -31.34,    0.00 /
      DATA B(42385), B(42386), B(42387) /    11.77,  -31.08,    0.00 /
      DATA B(42676), B(42677), B(42678) /    11.24,  -30.79,    0.00 /
      DATA B(42967), B(42968), B(42969) /     7.06,  -27.92,    0.00 /
      DATA B(43258), B(43259), B(43260) /     6.30,  -27.96,    0.00 /
      DATA B(43549), B(43550), B(43551) /     5.54,  -27.97,    0.00 /
      DATA B(43840), B(43841), B(43842) /     4.79,  -27.96,    0.00 /
      DATA B(44131), B(44132), B(44133) /     4.01,  -27.93,    0.00 /
      DATA B(44422), B(44423), B(44424) /     3.18,  -27.85,    0.00 /
      DATA B(44713), B(44714), B(44715) /     2.26,  -27.73,    0.00 /
      DATA B(45004), B(45005), B(45006) /     1.21,  -27.55,    0.00 /
      DATA B(45295), B(45296), B(45297) /     0.07,  -27.32,    0.00 /
      DATA B(45586), B(45587), B(45588) /    -1.32,  -26.25,    0.00 /
      DATA B(45877), B(45878), B(45879) /    -2.15,  -25.51,    0.00 /
      DATA B(46168), B(46169), B(46170) /    -2.83,  -24.78,    0.00 /
      DATA B(27547), B(27548), B(27549) /    26.15,  -41.58,    0.00 /
      DATA B(27838), B(27839), B(27840) /    26.14,  -41.52,    0.00 /
      DATA B(28129), B(28130), B(28131) /    26.13,  -41.45,    0.00 /
      DATA B(28420), B(28421), B(28422) /    26.11,  -41.39,    0.00 /
      DATA B(28711), B(28712), B(28713) /    26.10,  -41.32,    0.00 /
      DATA B(29002), B(29003), B(29004) /    26.09,  -41.26,    0.00 /
      DATA B(29293), B(29294), B(29295) /    26.08,  -41.19,    0.00 /
      DATA B(29584), B(29585), B(29586) /    26.06,  -41.13,    0.00 /
      DATA B(29875), B(29876), B(29877) /    26.05,  -41.06,    0.00 /
      DATA B(30166), B(30167), B(30168) /    26.04,  -40.99,    0.00 /
      DATA B(30457), B(30458), B(30459) /    26.02,  -40.92,    0.00 /
      DATA B(30748), B(30749), B(30750) /    26.01,  -40.85,    0.00 /
      DATA B(31039), B(31040), B(31041) /    25.99,  -40.78,    0.00 /
      DATA B(31330), B(31331), B(31332) /    25.98,  -40.71,    0.00 /
      DATA B(31621), B(31622), B(31623) /    25.96,  -40.63,    0.00 /
      DATA B(31912), B(31913), B(31914) /    25.95,  -40.55,    0.00 /
      DATA B(32203), B(32204), B(32205) /    25.93,  -40.47,    0.00 /
      DATA B(32494), B(32495), B(32496) /    25.92,  -40.38,    0.00 /
      DATA B(32785), B(32786), B(32787) /    25.90,  -40.28,    0.00 /
      DATA B(33076), B(33077), B(33078) /    25.89,  -40.18,    0.00 /
      DATA B(33367), B(33368), B(33369) /    25.87,  -40.08,    0.00 /
      DATA B(33658), B(33659), B(33660) /    25.86,  -39.96,    0.00 /
      DATA B(33949), B(33950), B(33951) /    25.84,  -39.83,    0.00 /
      DATA B(34240), B(34241), B(34242) /    25.82,  -39.70,    0.00 /
      DATA B(34531), B(34532), B(34533) /    25.80,  -39.57,    0.00 /
      DATA B(34822), B(34823), B(34824) /    25.77,  -39.42,    0.00 /
      DATA B(35113), B(35114), B(35115) /    25.74,  -39.28,    0.00 /
      DATA B(35404), B(35405), B(35406) /    25.70,  -39.13,    0.00 /
      DATA B(35695), B(35696), B(35697) /    25.65,  -39.00,    0.00 /
      DATA B(35986), B(35987), B(35988) /    25.59,  -38.88,    0.00 /
      DATA B(36277), B(36278), B(36279) /    25.53,  -38.78,    0.00 /
      DATA B(36568), B(36569), B(36570) /    25.46,  -38.70,    0.00 /
      DATA B(36859), B(36860), B(36861) /    25.39,  -38.63,    0.00 /
      DATA B(37150), B(37151), B(37152) /    25.31,  -38.56,    0.00 /
      DATA B(37441), B(37442), B(37443) /    25.23,  -38.48,    0.00 /
      DATA B(37732), B(37733), B(37734) /    25.12,  -38.38,    0.00 /
      DATA B(38023), B(38024), B(38025) /    24.98,  -38.26,    0.00 /
      DATA B(38314), B(38315), B(38316) /    24.81,  -38.11,    0.00 /
      DATA B(38605), B(38606), B(38607) /    24.60,  -37.93,    0.00 /
      DATA B(38896), B(38897), B(38898) /    24.38,  -37.74,    0.00 /
      DATA B(39187), B(39188), B(39189) /    14.57,  -32.04,    0.00 /
      DATA B(39478), B(39479), B(39480) /    14.39,  -32.10,    0.00 /
      DATA B(39769), B(39770), B(39771) /    14.12,  -32.14,    0.00 /
      DATA B(40060), B(40061), B(40062) /    13.86,  -32.08,    0.00 /
      DATA B(40351), B(40352), B(40353) /    13.59,  -31.99,    0.00 /
      DATA B(40642), B(40643), B(40644) /    13.32,  -31.87,    0.00 /
      DATA B(40933), B(40934), B(40935) /    13.03,  -31.74,    0.00 /
      DATA B(41224), B(41225), B(41226) /    12.72,  -31.59,    0.00 /
      DATA B(41515), B(41516), B(41517) /    12.37,  -31.40,    0.00 /
      DATA B(41806), B(41807), B(41808) /    11.96,  -31.18,    0.00 /
      DATA B(42097), B(42098), B(42099) /    11.49,  -30.92,    0.00 /
      DATA B(42388), B(42389), B(42390) /     7.51,  -27.87,    0.00 /
      DATA B(42679), B(42680), B(42681) /     6.78,  -27.94,    0.00 /
      DATA B(42970), B(42971), B(42972) /     6.03,  -27.98,    0.00 /
      DATA B(43261), B(43262), B(43263) /     5.30,  -28.00,    0.00 /
      DATA B(43552), B(43553), B(43554) /     4.56,  -28.00,    0.00 /
      DATA B(43843), B(43844), B(43845) /     3.79,  -27.97,    0.00 /
      DATA B(44134), B(44135), B(44136) /     2.95,  -27.90,    0.00 /
      DATA B(44425), B(44426), B(44427) /     2.02,  -27.78,    0.00 /
      DATA B(44716), B(44717), B(44718) /     0.97,  -27.62,    0.00 /
      DATA B(45007), B(45008), B(45009) /    -0.58,  -27.00,    0.00 /
      DATA B(45298), B(45299), B(45300) /    -1.46,  -26.28,    0.00 /
      DATA B(45589), B(45590), B(45591) /    -2.25,  -25.60,    0.00 /
      DATA B(45880), B(45881), B(45882) /    -2.90,  -24.93,    0.00 /
      DATA B(46171), B(46172), B(46173) /    -3.40,  -24.32,    0.00 /
      DATA B(27550), B(27551), B(27552) /    26.11,  -41.56,    0.00 /
      DATA B(27841), B(27842), B(27843) /    26.10,  -41.49,    0.00 /
      DATA B(28132), B(28133), B(28134) /    26.09,  -41.43,    0.00 /
      DATA B(28423), B(28424), B(28425) /    26.08,  -41.37,    0.00 /
      DATA B(28714), B(28715), B(28716) /    26.06,  -41.30,    0.00 /
      DATA B(29005), B(29006), B(29007) /    26.05,  -41.24,    0.00 /
      DATA B(29296), B(29297), B(29298) /    26.04,  -41.17,    0.00 /
      DATA B(29587), B(29588), B(29589) /    26.02,  -41.10,    0.00 /
      DATA B(29878), B(29879), B(29880) /    26.01,  -41.04,    0.00 /
      DATA B(30169), B(30170), B(30171) /    25.99,  -40.97,    0.00 /
      DATA B(30460), B(30461), B(30462) /    25.98,  -40.90,    0.00 /
      DATA B(30751), B(30752), B(30753) /    25.96,  -40.83,    0.00 /
      DATA B(31042), B(31043), B(31044) /    25.94,  -40.76,    0.00 /
      DATA B(31333), B(31334), B(31335) /    25.93,  -40.68,    0.00 /
      DATA B(31624), B(31625), B(31626) /    25.91,  -40.61,    0.00 /
      DATA B(31915), B(31916), B(31917) /    25.89,  -40.53,    0.00 /
      DATA B(32206), B(32207), B(32208) /    25.87,  -40.45,    0.00 /
      DATA B(32497), B(32498), B(32499) /    25.86,  -40.36,    0.00 /
      DATA B(32788), B(32789), B(32790) /    25.84,  -40.26,    0.00 /
      DATA B(33079), B(33080), B(33081) /    25.82,  -40.16,    0.00 /
      DATA B(33370), B(33371), B(33372) /    25.81,  -40.04,    0.00 /
      DATA B(33661), B(33662), B(33663) /    25.79,  -39.92,    0.00 /
      DATA B(33952), B(33953), B(33954) /    25.77,  -39.79,    0.00 /
      DATA B(34243), B(34244), B(34245) /    25.74,  -39.65,    0.00 /
      DATA B(34534), B(34535), B(34536) /    25.72,  -39.50,    0.00 /
      DATA B(34825), B(34826), B(34827) /    25.69,  -39.34,    0.00 /
      DATA B(35116), B(35117), B(35118) /    25.66,  -39.18,    0.00 /
      DATA B(35407), B(35408), B(35409) /    25.62,  -39.02,    0.00 /
      DATA B(35698), B(35699), B(35700) /    25.56,  -38.87,    0.00 /
      DATA B(35989), B(35990), B(35991) /    25.50,  -38.74,    0.00 /
      DATA B(36280), B(36281), B(36282) /    25.43,  -38.63,    0.00 /
      DATA B(36571), B(36572), B(36573) /    25.35,  -38.55,    0.00 /
      DATA B(36862), B(36863), B(36864) /    25.28,  -38.49,    0.00 /
      DATA B(37153), B(37154), B(37155) /    25.19,  -38.43,    0.00 /
      DATA B(37444), B(37445), B(37446) /    25.10,  -38.35,    0.00 /
      DATA B(37735), B(37736), B(37737) /    24.97,  -38.24,    0.00 /
      DATA B(38026), B(38027), B(38028) /    24.82,  -38.10,    0.00 /
      DATA B(38317), B(38318), B(38319) /    24.62,  -37.92,    0.00 /
      DATA B(38608), B(38609), B(38610) /    24.39,  -37.71,    0.00 /
      DATA B(38899), B(38900), B(38901) /    14.43,  -31.70,    0.00 /
      DATA B(39190), B(39191), B(39192) /    14.15,  -31.76,    0.00 /
      DATA B(39481), B(39482), B(39483) /    13.87,  -31.80,    0.00 /
      DATA B(39772), B(39773), B(39774) /    13.60,  -31.80,    0.00 /
      DATA B(40063), B(40064), B(40065) /    13.33,  -31.75,    0.00 /
      DATA B(40354), B(40355), B(40356) /    13.06,  -31.66,    0.00 /
      DATA B(40645), B(40646), B(40647) /    12.77,  -31.55,    0.00 /
      DATA B(40936), B(40937), B(40938) /    12.46,  -31.40,    0.00 /
      DATA B(41227), B(41228), B(41229) /    12.10,  -31.23,    0.00 /
      DATA B(41518), B(41519), B(41520) /    11.70,  -31.01,    0.00 /
      DATA B(41809), B(41810), B(41811) /    11.23,  -30.77,    0.00 /
      DATA B(42100), B(42101), B(42102) /     7.23,  -27.88,    0.00 /
      DATA B(42391), B(42392), B(42393) /     6.50,  -27.95,    0.00 /
      DATA B(42682), B(42683), B(42684) /     5.78,  -28.00,    0.00 /
      DATA B(42973), B(42974), B(42975) /     5.06,  -28.02,    0.00 /
      DATA B(43264), B(43265), B(43266) /     4.33,  -28.03,    0.00 /
      DATA B(43555), B(43556), B(43557) /     3.57,  -28.00,    0.00 /
      DATA B(43846), B(43847), B(43848) /     2.73,  -27.93,    0.00 /
      DATA B(44137), B(44138), B(44139) /     1.79,  -27.81,    0.00 /
      DATA B(44428), B(44429), B(44430) /     0.72,  -27.66,    0.00 /
      DATA B(44719), B(44720), B(44721) /    -0.76,  -26.95,    0.00 /
      DATA B(45010), B(45011), B(45012) /    -1.61,  -26.28,    0.00 /
      DATA B(45301), B(45302), B(45303) /    -2.36,  -25.63,    0.00 /
      DATA B(45592), B(45593), B(45594) /    -2.97,  -25.02,    0.00 /
      DATA B(45883), B(45884), B(45885) /    -3.45,  -24.46,    0.00 /
      DATA B(46174), B(46175), B(46176) /    -3.82,  -23.94,    0.00 /
      DATA B(27553), B(27554), B(27555) /    26.08,  -41.53,    0.00 /
      DATA B(27844), B(27845), B(27846) /    26.06,  -41.47,    0.00 /
      DATA B(28135), B(28136), B(28137) /    26.05,  -41.41,    0.00 /
      DATA B(28426), B(28427), B(28428) /    26.04,  -41.34,    0.00 /
      DATA B(28717), B(28718), B(28719) /    26.02,  -41.28,    0.00 /
      DATA B(29008), B(29009), B(29010) /    26.01,  -41.21,    0.00 /
      DATA B(29299), B(29300), B(29301) /    26.00,  -41.15,    0.00 /
      DATA B(29590), B(29591), B(29592) /    25.98,  -41.08,    0.00 /
      DATA B(29881), B(29882), B(29883) /    25.96,  -41.01,    0.00 /
      DATA B(30172), B(30173), B(30174) /    25.95,  -40.95,    0.00 /
      DATA B(30463), B(30464), B(30465) /    25.93,  -40.88,    0.00 /
      DATA B(30754), B(30755), B(30756) /    25.91,  -40.81,    0.00 /
      DATA B(31045), B(31046), B(31047) /    25.89,  -40.73,    0.00 /
      DATA B(31336), B(31337), B(31338) /    25.87,  -40.66,    0.00 /
      DATA B(31627), B(31628), B(31629) /    25.85,  -40.59,    0.00 /
      DATA B(31918), B(31919), B(31920) /    25.83,  -40.51,    0.00 /
      DATA B(32209), B(32210), B(32211) /    25.81,  -40.42,    0.00 /
      DATA B(32500), B(32501), B(32502) /    25.79,  -40.33,    0.00 /
      DATA B(32791), B(32792), B(32793) /    25.77,  -40.24,    0.00 /
      DATA B(33082), B(33083), B(33084) /    25.75,  -40.13,    0.00 /
      DATA B(33373), B(33374), B(33375) /    25.73,  -40.01,    0.00 /
      DATA B(33664), B(33665), B(33666) /    25.71,  -39.88,    0.00 /
      DATA B(33955), B(33956), B(33957) /    25.68,  -39.74,    0.00 /
      DATA B(34246), B(34247), B(34248) /    25.66,  -39.59,    0.00 /
      DATA B(34537), B(34538), B(34539) /    25.63,  -39.43,    0.00 /
      DATA B(34828), B(34829), B(34830) /    25.60,  -39.26,    0.00 /
      DATA B(35119), B(35120), B(35121) /    25.56,  -39.07,    0.00 /
      DATA B(35410), B(35411), B(35412) /    25.52,  -38.89,    0.00 /
      DATA B(35701), B(35702), B(35703) /    25.46,  -38.71,    0.00 /
      DATA B(35992), B(35993), B(35994) /    25.39,  -38.56,    0.00 /
      DATA B(36283), B(36284), B(36285) /    25.31,  -38.45,    0.00 /
      DATA B(36574), B(36575), B(36576) /    25.22,  -38.38,    0.00 /
      DATA B(36865), B(36866), B(36867) /    25.14,  -38.34,    0.00 /
      DATA B(37156), B(37157), B(37158) /    25.05,  -38.28,    0.00 /
      DATA B(37447), B(37448), B(37449) /    24.93,  -38.20,    0.00 /
      DATA B(37738), B(37739), B(37740) /    24.79,  -38.07,    0.00 /
      DATA B(38029), B(38030), B(38031) /    24.60,  -37.90,    0.00 /
      DATA B(38320), B(38321), B(38322) /    24.36,  -37.68,    0.00 /
      DATA B(38611), B(38612), B(38613) /    14.33,  -31.53,    0.00 /
      DATA B(38902), B(38903), B(38904) /    14.01,  -31.48,    0.00 /
      DATA B(39193), B(39194), B(39195) /    13.71,  -31.49,    0.00 /
      DATA B(39484), B(39485), B(39486) /    13.41,  -31.51,    0.00 /
      DATA B(39775), B(39776), B(39777) /    13.13,  -31.49,    0.00 /
      DATA B(40066), B(40067), B(40068) /    12.84,  -31.43,    0.00 /
      DATA B(40357), B(40358), B(40359) /    12.54,  -31.34,    0.00 /
      DATA B(40648), B(40649), B(40650) /    12.22,  -31.21,    0.00 /
      DATA B(40939), B(40940), B(40941) /    11.86,  -31.04,    0.00 /
      DATA B(41230), B(41231), B(41232) /    11.44,  -30.83,    0.00 /
      DATA B(41521), B(41522), B(41523) /    10.96,  -30.60,    0.00 /
      DATA B(41812), B(41813), B(41814) /     6.97,  -27.89,    0.00 /
      DATA B(42103), B(42104), B(42105) /     6.24,  -27.96,    0.00 /
      DATA B(42394), B(42395), B(42396) /     5.53,  -28.01,    0.00 /
      DATA B(42685), B(42686), B(42687) /     4.83,  -28.04,    0.00 /
      DATA B(42976), B(42977), B(42978) /     4.11,  -28.05,    0.00 /
      DATA B(43267), B(43268), B(43269) /     3.35,  -28.02,    0.00 /
      DATA B(43558), B(43559), B(43560) /     2.50,  -27.95,    0.00 /
      DATA B(43849), B(43850), B(43851) /     1.54,  -27.84,    0.00 /
      DATA B(44140), B(44141), B(44142) /     0.47,  -27.69,    0.00 /
      DATA B(44431), B(44432), B(44433) /    -0.94,  -26.89,    0.00 /
      DATA B(44722), B(44723), B(44724) /    -1.76,  -26.25,    0.00 /
      DATA B(45013), B(45014), B(45015) /    -2.47,  -25.64,    0.00 /
      DATA B(45304), B(45305), B(45306) /    -3.04,  -25.07,    0.00 /
      DATA B(45595), B(45596), B(45597) /    -3.49,  -24.55,    0.00 /
      DATA B(45886), B(45887), B(45888) /    -3.85,  -24.08,    0.00 /
      DATA B(46177), B(46178), B(46179) /    -4.13,  -23.64,    0.00 /
      DATA B(27556), B(27557), B(27558) /    26.04,  -41.51,    0.00 /
      DATA B(27847), B(27848), B(27849) /    26.03,  -41.45,    0.00 /
      DATA B(28138), B(28139), B(28140) /    26.01,  -41.38,    0.00 /
      DATA B(28429), B(28430), B(28431) /    26.00,  -41.32,    0.00 /
      DATA B(28720), B(28721), B(28722) /    25.98,  -41.26,    0.00 /
      DATA B(29011), B(29012), B(29013) /    25.97,  -41.19,    0.00 /
      DATA B(29302), B(29303), B(29304) /    25.95,  -41.13,    0.00 /
      DATA B(29593), B(29594), B(29595) /    25.94,  -41.06,    0.00 /
      DATA B(29884), B(29885), B(29886) /    25.92,  -40.99,    0.00 /
      DATA B(30175), B(30176), B(30177) /    25.90,  -40.92,    0.00 /
      DATA B(30466), B(30467), B(30468) /    25.88,  -40.85,    0.00 /
      DATA B(30757), B(30758), B(30759) /    25.86,  -40.78,    0.00 /
      DATA B(31048), B(31049), B(31050) /    25.84,  -40.71,    0.00 /
      DATA B(31339), B(31340), B(31341) /    25.81,  -40.64,    0.00 /
      DATA B(31630), B(31631), B(31632) /    25.79,  -40.56,    0.00 /
      DATA B(31921), B(31922), B(31923) /    25.77,  -40.48,    0.00 /
      DATA B(32212), B(32213), B(32214) /    25.74,  -40.40,    0.00 /
      DATA B(32503), B(32504), B(32505) /    25.72,  -40.31,    0.00 /
      DATA B(32794), B(32795), B(32796) /    25.70,  -40.21,    0.00 /
      DATA B(33085), B(33086), B(33087) /    25.67,  -40.10,    0.00 /
      DATA B(33376), B(33377), B(33378) /    25.64,  -39.98,    0.00 /
      DATA B(33667), B(33668), B(33669) /    25.62,  -39.84,    0.00 /
      DATA B(33958), B(33959), B(33960) /    25.59,  -39.69,    0.00 /
      DATA B(34249), B(34250), B(34251) /    25.55,  -39.53,    0.00 /
      DATA B(34540), B(34541), B(34542) /    25.52,  -39.35,    0.00 /
      DATA B(34831), B(34832), B(34833) /    25.49,  -39.16,    0.00 /
      DATA B(35122), B(35123), B(35124) /    25.45,  -38.96,    0.00 /
      DATA B(35413), B(35414), B(35415) /    25.40,  -38.74,    0.00 /
      DATA B(35704), B(35705), B(35706) /    25.34,  -38.53,    0.00 /
      DATA B(35995), B(35996), B(35997) /    25.26,  -38.35,    0.00 /
      DATA B(36286), B(36287), B(36288) /    25.17,  -38.23,    0.00 /
      DATA B(36577), B(36578), B(36579) /    25.06,  -38.17,    0.00 /
      DATA B(36868), B(36869), B(36870) /    24.97,  -38.15,    0.00 /
      DATA B(37159), B(37160), B(37161) /    24.86,  -38.11,    0.00 /
      DATA B(37450), B(37451), B(37452) /    24.73,  -38.02,    0.00 /
      DATA B(37741), B(37742), B(37743) /    24.55,  -37.87,    0.00 /
      DATA B(38032), B(38033), B(38034) /    24.32,  -37.65,    0.00 /
      DATA B(38323), B(38324), B(38325) /    14.24,  -31.40,    0.00 /
      DATA B(38614), B(38615), B(38616) /    13.89,  -31.30,    0.00 /
      DATA B(38905), B(38906), B(38907) /    13.57,  -31.24,    0.00 /
      DATA B(39196), B(39197), B(39198) /    13.27,  -31.24,    0.00 /
      DATA B(39487), B(39488), B(39489) /    12.97,  -31.23,    0.00 /
      DATA B(39778), B(39779), B(39780) /    12.67,  -31.19,    0.00 /
      DATA B(40069), B(40070), B(40071) /    12.35,  -31.11,    0.00 /
      DATA B(40360), B(40361), B(40362) /    12.01,  -30.99,    0.00 /
      DATA B(40651), B(40652), B(40653) /    11.63,  -30.83,    0.00 /
      DATA B(40942), B(40943), B(40944) /    11.19,  -30.62,    0.00 /
      DATA B(41233), B(41234), B(41235) /     7.39,  -27.75,    0.00 /
      DATA B(41524), B(41525), B(41526) /     6.69,  -27.86,    0.00 /
      DATA B(41815), B(41816), B(41817) /     5.99,  -27.95,    0.00 /
      DATA B(42106), B(42107), B(42108) /     5.30,  -28.01,    0.00 /
      DATA B(42397), B(42398), B(42399) /     4.61,  -28.05,    0.00 /
      DATA B(42688), B(42689), B(42690) /     3.89,  -28.06,    0.00 /
      DATA B(42979), B(42980), B(42981) /     3.13,  -28.04,    0.00 /
      DATA B(43270), B(43271), B(43272) /     2.27,  -27.97,    0.00 /
      DATA B(43561), B(43562), B(43563) /     1.30,  -27.86,    0.00 /
      DATA B(43852), B(43853), B(43854) /     0.23,  -27.72,    0.00 /
      DATA B(44143), B(44144), B(44145) /    -1.11,  -26.83,    0.00 /
      DATA B(44434), B(44435), B(44436) /    -1.90,  -26.21,    0.00 /
      DATA B(44725), B(44726), B(44727) /    -2.57,  -25.62,    0.00 /
      DATA B(45016), B(45017), B(45018) /    -3.11,  -25.08,    0.00 /
      DATA B(45307), B(45308), B(45309) /    -3.53,  -24.60,    0.00 /
      DATA B(45598), B(45599), B(45600) /    -3.86,  -24.17,    0.00 /
      DATA B(45889), B(45890), B(45891) /    -4.14,  -23.77,    0.00 /
      DATA B(46180), B(46181), B(46182) /    -4.36,  -23.40,    0.00 /
      DATA B(27559), B(27560), B(27561) /    26.00,  -41.49,    0.00 /
      DATA B(27850), B(27851), B(27852) /    25.99,  -41.42,    0.00 /
      DATA B(28141), B(28142), B(28143) /    25.97,  -41.36,    0.00 /
      DATA B(28432), B(28433), B(28434) /    25.96,  -41.30,    0.00 /
      DATA B(28723), B(28724), B(28725) /    25.94,  -41.23,    0.00 /
      DATA B(29014), B(29015), B(29016) /    25.93,  -41.17,    0.00 /
      DATA B(29305), B(29306), B(29307) /    25.91,  -41.10,    0.00 /
      DATA B(29596), B(29597), B(29598) /    25.89,  -41.03,    0.00 /
      DATA B(29887), B(29888), B(29889) /    25.87,  -40.97,    0.00 /
      DATA B(30178), B(30179), B(30180) /    25.85,  -40.90,    0.00 /
      DATA B(30469), B(30470), B(30471) /    25.83,  -40.83,    0.00 /
      DATA B(30760), B(30761), B(30762) /    25.80,  -40.76,    0.00 /
      DATA B(31051), B(31052), B(31053) /    25.78,  -40.69,    0.00 /
      DATA B(31342), B(31343), B(31344) /    25.75,  -40.61,    0.00 /
      DATA B(31633), B(31634), B(31635) /    25.73,  -40.54,    0.00 /
      DATA B(31924), B(31925), B(31926) /    25.70,  -40.46,    0.00 /
      DATA B(32215), B(32216), B(32217) /    25.67,  -40.38,    0.00 /
      DATA B(32506), B(32507), B(32508) /    25.64,  -40.29,    0.00 /
      DATA B(32797), B(32798), B(32799) /    25.61,  -40.19,    0.00 /
      DATA B(33088), B(33089), B(33090) /    25.58,  -40.07,    0.00 /
      DATA B(33379), B(33380), B(33381) /    25.55,  -39.95,    0.00 /
      DATA B(33670), B(33671), B(33672) /    25.51,  -39.80,    0.00 /
      DATA B(33961), B(33962), B(33963) /    25.47,  -39.64,    0.00 /
      DATA B(34252), B(34253), B(34254) /    25.43,  -39.46,    0.00 /
      DATA B(34543), B(34544), B(34545) /    25.39,  -39.27,    0.00 /
      DATA B(34834), B(34835), B(34836) /    25.34,  -39.05,    0.00 /
      DATA B(35125), B(35126), B(35127) /    25.30,  -38.82,    0.00 /
      DATA B(35416), B(35417), B(35418) /    25.25,  -38.57,    0.00 /
      DATA B(35707), B(35708), B(35709) /    25.19,  -38.31,    0.00 /
      DATA B(35998), B(35999), B(36000) /    25.10,  -38.08,    0.00 /
      DATA B(36289), B(36290), B(36291) /    24.99,  -37.94,    0.00 /
      DATA B(36580), B(36581), B(36582) /    24.86,  -37.91,    0.00 /
      DATA B(36871), B(36872), B(36873) /    24.76,  -37.94,    0.00 /
      DATA B(37162), B(37163), B(37164) /    24.64,  -37.92,    0.00 /
      DATA B(37453), B(37454), B(37455) /    24.49,  -37.81,    0.00 /
      DATA B(37744), B(37745), B(37746) /    24.27,  -37.61,    0.00 /
      DATA B(38035), B(38036), B(38037) /    14.16,  -31.27,    0.00 /
      DATA B(38326), B(38327), B(38328) /    13.80,  -31.15,    0.00 /
      DATA B(38617), B(38618), B(38619) /    13.46,  -31.07,    0.00 /
      DATA B(38908), B(38909), B(38910) /    13.14,  -31.02,    0.00 /
      DATA B(39199), B(39200), B(39201) /    12.84,  -30.99,    0.00 /
      DATA B(39490), B(39491), B(39492) /    12.52,  -30.94,    0.00 /
      DATA B(39781), B(39782), B(39783) /    12.19,  -30.87,    0.00 /
      DATA B(40072), B(40073), B(40074) /    11.83,  -30.76,    0.00 /
      DATA B(40363), B(40364), B(40365) /    11.42,  -30.60,    0.00 /
      DATA B(40654), B(40655), B(40656) /    10.96,  -30.41,    0.00 /
      DATA B(40945), B(40946), B(40947) /     7.13,  -27.70,    0.00 /
      DATA B(41236), B(41237), B(41238) /     6.43,  -27.82,    0.00 /
      DATA B(41527), B(41528), B(41529) /     5.75,  -27.92,    0.00 /
      DATA B(41818), B(41819), B(41820) /     5.07,  -28.00,    0.00 /
      DATA B(42109), B(42110), B(42111) /     4.39,  -28.05,    0.00 /
      DATA B(42400), B(42401), B(42402) /     3.68,  -28.07,    0.00 /
      DATA B(42691), B(42692), B(42693) /     2.91,  -28.04,    0.00 /
      DATA B(42982), B(42983), B(42984) /     2.04,  -27.97,    0.00 /
      DATA B(43273), B(43274), B(43275) /     1.05,  -27.87,    0.00 /
      DATA B(43564), B(43565), B(43566) /    -0.41,  -27.41,    0.00 /
      DATA B(43855), B(43856), B(43857) /    -1.28,  -26.76,    0.00 /
      DATA B(44146), B(44147), B(44148) /    -2.04,  -26.15,    0.00 /
      DATA B(44437), B(44438), B(44439) /    -2.67,  -25.59,    0.00 /
      DATA B(44728), B(44729), B(44730) /    -3.17,  -25.08,    0.00 /
      DATA B(45019), B(45020), B(45021) /    -3.57,  -24.63,    0.00 /
      DATA B(45310), B(45311), B(45312) /    -3.88,  -24.22,    0.00 /
      DATA B(45601), B(45602), B(45603) /    -4.14,  -23.86,    0.00 /
      DATA B(45892), B(45893), B(45894) /    -4.35,  -23.52,    0.00 /
      DATA B(46183), B(46184), B(46185) /    -4.53,  -23.20,    0.00 /
      DATA B(27562), B(27563), B(27564) /    25.97,  -41.46,    0.00 /
      DATA B(27853), B(27854), B(27855) /    25.95,  -41.40,    0.00 /
      DATA B(28144), B(28145), B(28146) /    25.93,  -41.34,    0.00 /
      DATA B(28435), B(28436), B(28437) /    25.92,  -41.27,    0.00 /
      DATA B(28726), B(28727), B(28728) /    25.90,  -41.21,    0.00 /
      DATA B(29017), B(29018), B(29019) /    25.88,  -41.14,    0.00 /
      DATA B(29308), B(29309), B(29310) /    25.86,  -41.08,    0.00 /
      DATA B(29599), B(29600), B(29601) /    25.84,  -41.01,    0.00 /
      DATA B(29890), B(29891), B(29892) /    25.82,  -40.94,    0.00 /
      DATA B(30181), B(30182), B(30183) /    25.80,  -40.87,    0.00 /
      DATA B(30472), B(30473), B(30474) /    25.77,  -40.80,    0.00 /
      DATA B(30763), B(30764), B(30765) /    25.75,  -40.73,    0.00 /
      DATA B(31054), B(31055), B(31056) /    25.72,  -40.66,    0.00 /
      DATA B(31345), B(31346), B(31347) /    25.69,  -40.59,    0.00 /
      DATA B(31636), B(31637), B(31638) /    25.66,  -40.51,    0.00 /
      DATA B(31927), B(31928), B(31929) /    25.62,  -40.44,    0.00 /
      DATA B(32218), B(32219), B(32220) /    25.59,  -40.36,    0.00 /
      DATA B(32509), B(32510), B(32511) /    25.56,  -40.27,    0.00 /
      DATA B(32800), B(32801), B(32802) /    25.52,  -40.16,    0.00 /
      DATA B(33091), B(33092), B(33093) /    25.48,  -40.05,    0.00 /
      DATA B(33382), B(33383), B(33384) /    25.44,  -39.91,    0.00 /
      DATA B(33673), B(33674), B(33675) /    25.39,  -39.76,    0.00 /
      DATA B(33964), B(33965), B(33966) /    25.34,  -39.58,    0.00 /
      DATA B(34255), B(34256), B(34257) /    25.28,  -39.39,    0.00 /
      DATA B(34546), B(34547), B(34548) /    25.22,  -39.17,    0.00 /
      DATA B(34837), B(34838), B(34839) /    25.16,  -38.93,    0.00 /
      DATA B(35128), B(35129), B(35130) /    25.10,  -38.67,    0.00 /
      DATA B(35419), B(35420), B(35421) /    25.04,  -38.37,    0.00 /
      DATA B(35710), B(35711), B(35712) /    24.99,  -38.05,    0.00 /
      DATA B(36001), B(36002), B(36003) /    24.90,  -37.73,    0.00 /
      DATA B(36292), B(36293), B(36294) /    24.75,  -37.55,    0.00 /
      DATA B(36583), B(36584), B(36585) /    24.60,  -37.59,    0.00 /
      DATA B(36874), B(36875), B(36876) /    24.51,  -37.70,    0.00 /
      DATA B(37165), B(37166), B(37167) /    24.39,  -37.70,    0.00 /
      DATA B(37456), B(37457), B(37458) /    24.20,  -37.56,    0.00 /
      DATA B(37747), B(37748), B(37749) /    14.08,  -31.14,    0.00 /
      DATA B(38038), B(38039), B(38040) /    13.72,  -31.03,    0.00 /
      DATA B(38329), B(38330), B(38331) /    13.37,  -30.93,    0.00 /
      DATA B(38620), B(38621), B(38622) /    13.04,  -30.85,    0.00 /
      DATA B(38911), B(38912), B(38913) /    12.71,  -30.78,    0.00 /
      DATA B(39202), B(39203), B(39204) /    12.39,  -30.72,    0.00 /
      DATA B(39493), B(39494), B(39495) /    12.04,  -30.64,    0.00 /
      DATA B(39784), B(39785), B(39786) /    11.66,  -30.52,    0.00 /
      DATA B(40075), B(40076), B(40077) /    11.23,  -30.36,    0.00 /
      DATA B(40366), B(40367), B(40368) /    10.75,  -30.16,    0.00 /
      DATA B(40657), B(40658), B(40659) /     6.89,  -27.64,    0.00 /
      DATA B(40948), B(40949), B(40950) /     6.19,  -27.77,    0.00 /
      DATA B(41239), B(41240), B(41241) /     5.51,  -27.88,    0.00 /
      DATA B(41530), B(41531), B(41532) /     4.85,  -27.97,    0.00 /
      DATA B(41821), B(41822), B(41823) /     4.18,  -28.03,    0.00 /
      DATA B(42112), B(42113), B(42114) /     3.47,  -28.06,    0.00 /
      DATA B(42403), B(42404), B(42405) /     2.69,  -28.04,    0.00 /
      DATA B(42694), B(42695), B(42696) /     1.81,  -27.97,    0.00 /
      DATA B(42985), B(42986), B(42987) /     0.80,  -27.86,    0.00 /
      DATA B(43276), B(43277), B(43278) /    -0.62,  -27.27,    0.00 /
      DATA B(43567), B(43568), B(43569) /    -1.45,  -26.68,    0.00 /
      DATA B(43858), B(43859), B(43860) /    -2.18,  -26.09,    0.00 /
      DATA B(44149), B(44150), B(44151) /    -2.77,  -25.55,    0.00 /
      DATA B(44440), B(44441), B(44442) /    -3.23,  -25.07,    0.00 /
      DATA B(44731), B(44732), B(44733) /    -3.60,  -24.64,    0.00 /
      DATA B(45022), B(45023), B(45024) /    -3.90,  -24.26,    0.00 /
      DATA B(45313), B(45314), B(45315) /    -4.14,  -23.92,    0.00 /
      DATA B(45604), B(45605), B(45606) /    -4.34,  -23.60,    0.00 /
      DATA B(45895), B(45896), B(45897) /    -4.52,  -23.31,    0.00 /
      DATA B(46186), B(46187), B(46188) /    -4.67,  -23.03,    0.00 /
      DATA B(27565), B(27566), B(27567) /    25.93,  -41.44,    0.00 /
      DATA B(27856), B(27857), B(27858) /    25.91,  -41.38,    0.00 /
      DATA B(28147), B(28148), B(28149) /    25.89,  -41.31,    0.00 /
      DATA B(28438), B(28439), B(28440) /    25.88,  -41.25,    0.00 /
      DATA B(28729), B(28730), B(28731) /    25.86,  -41.18,    0.00 /
      DATA B(29020), B(29021), B(29022) /    25.84,  -41.12,    0.00 /
      DATA B(29311), B(29312), B(29313) /    25.82,  -41.05,    0.00 /
      DATA B(29602), B(29603), B(29604) /    25.79,  -40.98,    0.00 /
      DATA B(29893), B(29894), B(29895) /    25.77,  -40.91,    0.00 /
      DATA B(30184), B(30185), B(30186) /    25.75,  -40.84,    0.00 /
      DATA B(30475), B(30476), B(30477) /    25.72,  -40.77,    0.00 /
      DATA B(30766), B(30767), B(30768) /    25.69,  -40.70,    0.00 /
      DATA B(31057), B(31058), B(31059) /    25.66,  -40.63,    0.00 /
      DATA B(31348), B(31349), B(31350) /    25.62,  -40.56,    0.00 /
      DATA B(31639), B(31640), B(31641) /    25.58,  -40.48,    0.00 /
      DATA B(31930), B(31931), B(31932) /    25.54,  -40.41,    0.00 /
      DATA B(32221), B(32222), B(32223) /    25.50,  -40.33,    0.00 /
      DATA B(32512), B(32513), B(32514) /    25.46,  -40.24,    0.00 /
      DATA B(32803), B(32804), B(32805) /    25.42,  -40.14,    0.00 /
      DATA B(33094), B(33095), B(33096) /    25.37,  -40.02,    0.00 /
      DATA B(33385), B(33386), B(33387) /    25.32,  -39.87,    0.00 /
      DATA B(33676), B(33677), B(33678) /    25.25,  -39.71,    0.00 /
      DATA B(33967), B(33968), B(33969) /    25.18,  -39.51,    0.00 /
      DATA B(34258), B(34259), B(34260) /    25.10,  -39.30,    0.00 /
      DATA B(34549), B(34550), B(34551) /    25.01,  -39.06,    0.00 /
      DATA B(34840), B(34841), B(34842) /    24.91,  -38.79,    0.00 /
      DATA B(35131), B(35132), B(35133) /    24.82,  -38.49,    0.00 /
      DATA B(35422), B(35423), B(35424) /    24.74,  -38.14,    0.00 /
      DATA B(35713), B(35714), B(35715) /    24.68,  -37.73,    0.00 /
      DATA B(36004), B(36005), B(36006) /    24.61,  -37.28,    0.00 /
      DATA B(36295), B(36296), B(36297) /    24.45,  -37.00,    0.00 /
      DATA B(36586), B(36587), B(36588) /    24.28,  -37.17,    0.00 /
      DATA B(36877), B(36878), B(36879) /    24.23,  -37.44,    0.00 /
      DATA B(37168), B(37169), B(37170) /    24.13,  -37.46,    0.00 /
      DATA B(37459), B(37460), B(37461) /    14.02,  -31.01,    0.00 /
      DATA B(37750), B(37751), B(37752) /    13.67,  -30.91,    0.00 /
      DATA B(38041), B(38042), B(38043) /    13.30,  -30.80,    0.00 /
      DATA B(38332), B(38333), B(38334) /    12.95,  -30.70,    0.00 /
      DATA B(38623), B(38624), B(38625) /    12.61,  -30.62,    0.00 /
      DATA B(38914), B(38915), B(38916) /    12.26,  -30.53,    0.00 /
      DATA B(39205), B(39206), B(39207) /    11.89,  -30.42,    0.00 /
      DATA B(39496), B(39497), B(39498) /    11.49,  -30.29,    0.00 /
      DATA B(39787), B(39788), B(39789) /    11.03,  -30.12,    0.00 /
      DATA B(40078), B(40079), B(40080) /     7.36,  -27.41,    0.00 /
      DATA B(40369), B(40370), B(40371) /     6.66,  -27.56,    0.00 /
      DATA B(40660), B(40661), B(40662) /     5.96,  -27.69,    0.00 /
      DATA B(40951), B(40952), B(40953) /     5.29,  -27.81,    0.00 /
      DATA B(41242), B(41243), B(41244) /     4.63,  -27.91,    0.00 /
      DATA B(41533), B(41534), B(41535) /     3.96,  -27.99,    0.00 /
      DATA B(41824), B(41825), B(41826) /     3.25,  -28.03,    0.00 /
      DATA B(42115), B(42116), B(42117) /     2.47,  -28.02,    0.00 /
      DATA B(42406), B(42407), B(42408) /     1.56,  -27.96,    0.00 /
      DATA B(42697), B(42698), B(42699) /     0.55,  -27.85,    0.00 /
      DATA B(42988), B(42989), B(42990) /    -0.83,  -27.18,    0.00 /
      DATA B(43279), B(43280), B(43281) /    -1.62,  -26.59,    0.00 /
      DATA B(43570), B(43571), B(43572) /    -2.30,  -26.02,    0.00 /
      DATA B(43861), B(43862), B(43863) /    -2.86,  -25.51,    0.00 /
      DATA B(44152), B(44153), B(44154) /    -3.29,  -25.04,    0.00 /
      DATA B(44443), B(44444), B(44445) /    -3.63,  -24.64,    0.00 /
      DATA B(44734), B(44735), B(44736) /    -3.91,  -24.28,    0.00 /
      DATA B(45025), B(45026), B(45027) /    -4.14,  -23.96,    0.00 /
      DATA B(45316), B(45317), B(45318) /    -4.33,  -23.66,    0.00 /
      DATA B(45607), B(45608), B(45609) /    -4.50,  -23.39,    0.00 /
      DATA B(45898), B(45899), B(45900) /    -4.65,  -23.13,    0.00 /
      DATA B(46189), B(46190), B(46191) /    -4.77,  -22.88,    0.00 /
      DATA B(27568), B(27569), B(27570) /    25.89,  -41.41,    0.00 /
      DATA B(27859), B(27860), B(27861) /    25.87,  -41.35,    0.00 /
      DATA B(28150), B(28151), B(28152) /    25.85,  -41.29,    0.00 /
      DATA B(28441), B(28442), B(28443) /    25.83,  -41.22,    0.00 /
      DATA B(28732), B(28733), B(28734) /    25.81,  -41.16,    0.00 /
      DATA B(29023), B(29024), B(29025) /    25.79,  -41.09,    0.00 /
      DATA B(29314), B(29315), B(29316) /    25.77,  -41.03,    0.00 /
      DATA B(29605), B(29606), B(29607) /    25.74,  -40.96,    0.00 /
      DATA B(29896), B(29897), B(29898) /    25.72,  -40.89,    0.00 /
      DATA B(30187), B(30188), B(30189) /    25.69,  -40.82,    0.00 /
      DATA B(30478), B(30479), B(30480) /    25.66,  -40.74,    0.00 /
      DATA B(30769), B(30770), B(30771) /    25.63,  -40.67,    0.00 /
      DATA B(31060), B(31061), B(31062) /    25.59,  -40.60,    0.00 /
      DATA B(31351), B(31352), B(31353) /    25.55,  -40.52,    0.00 /
      DATA B(31642), B(31643), B(31644) /    25.51,  -40.45,    0.00 /
      DATA B(31933), B(31934), B(31935) /    25.46,  -40.38,    0.00 /
      DATA B(32224), B(32225), B(32226) /    25.41,  -40.31,    0.00 /
      DATA B(32515), B(32516), B(32517) /    25.36,  -40.22,    0.00 /
      DATA B(32806), B(32807), B(32808) /    25.31,  -40.11,    0.00 /
      DATA B(33097), B(33098), B(33099) /    25.24,  -39.99,    0.00 /
      DATA B(33388), B(33389), B(33390) /    25.17,  -39.83,    0.00 /
      DATA B(33679), B(33680), B(33681) /    25.09,  -39.65,    0.00 /
      DATA B(33970), B(33971), B(33972) /    24.99,  -39.43,    0.00 /
      DATA B(34261), B(34262), B(34263) /    24.87,  -39.19,    0.00 /
      DATA B(34552), B(34553), B(34554) /    24.74,  -38.91,    0.00 /
      DATA B(34843), B(34844), B(34845) /    24.58,  -38.61,    0.00 /
      DATA B(35134), B(35135), B(35136) /    24.42,  -38.27,    0.00 /
      DATA B(35425), B(35426), B(35427) /    24.27,  -37.87,    0.00 /
      DATA B(35716), B(35717), B(35718) /    24.17,  -37.38,    0.00 /
      DATA B(36007), B(36008), B(36009) /    24.14,  -36.73,    0.00 /
      DATA B(36298), B(36299), B(36300) /    24.02,  -36.18,    0.00 /
      DATA B(36589), B(36590), B(36591) /    23.90,  -36.73,    0.00 /
      DATA B(36880), B(36881), B(36882) /    24.04,  -37.25,    0.00 /
      DATA B(37171), B(37172), B(37173) /    14.02,  -30.85,    0.00 /
      DATA B(37462), B(37463), B(37464) /    13.67,  -30.79,    0.00 /
      DATA B(37753), B(37754), B(37755) /    13.29,  -30.68,    0.00 /
      DATA B(38044), B(38045), B(38046) /    12.91,  -30.57,    0.00 /
      DATA B(38335), B(38336), B(38337) /    12.54,  -30.47,    0.00 /
      DATA B(38626), B(38627), B(38628) /    12.16,  -30.36,    0.00 /
      DATA B(38917), B(38918), B(38919) /    11.76,  -30.23,    0.00 /
      DATA B(39208), B(39209), B(39210) /    11.32,  -30.07,    0.00 /
      DATA B(39499), B(39500), B(39501) /    10.84,  -29.88,    0.00 /
      DATA B(39790), B(39791), B(39792) /     7.12,  -27.33,    0.00 /
      DATA B(40081), B(40082), B(40083) /     6.42,  -27.47,    0.00 /
      DATA B(40372), B(40373), B(40374) /     5.74,  -27.60,    0.00 /
      DATA B(40663), B(40664), B(40665) /     5.07,  -27.72,    0.00 /
      DATA B(40954), B(40955), B(40956) /     4.41,  -27.83,    0.00 /
      DATA B(41245), B(41246), B(41247) /     3.74,  -27.93,    0.00 /
      DATA B(41536), B(41537), B(41538) /     3.03,  -27.98,    0.00 /
      DATA B(41827), B(41828), B(41829) /     2.23,  -27.98,    0.00 /
      DATA B(42118), B(42119), B(42120) /     1.32,  -27.93,    0.00 /
      DATA B(42409), B(42410), B(42411) /     0.32,  -27.84,    0.00 /
      DATA B(42700), B(42701), B(42702) /    -1.01,  -27.08,    0.00 /
      DATA B(42991), B(42992), B(42993) /    -1.77,  -26.50,    0.00 /
      DATA B(43282), B(43283), B(43284) /    -2.42,  -25.95,    0.00 /
      DATA B(43573), B(43574), B(43575) /    -2.94,  -25.45,    0.00 /
      DATA B(43864), B(43865), B(43866) /    -3.34,  -25.01,    0.00 /
      DATA B(44155), B(44156), B(44157) /    -3.66,  -24.63,    0.00 /
      DATA B(44446), B(44447), B(44448) /    -3.92,  -24.29,    0.00 /
      DATA B(44737), B(44738), B(44739) /    -4.13,  -23.98,    0.00 /
      DATA B(45028), B(45029), B(45030) /    -4.32,  -23.71,    0.00 /
      DATA B(45319), B(45320), B(45321) /    -4.48,  -23.45,    0.00 /
      DATA B(45610), B(45611), B(45612) /    -4.62,  -23.21,    0.00 /
      DATA B(45901), B(45902), B(45903) /    -4.74,  -22.97,    0.00 /
      DATA B(46192), B(46193), B(46194) /    -4.86,  -22.75,    0.00 /
      DATA B(27571), B(27572), B(27573) /    25.85,  -41.39,    0.00 /
      DATA B(27862), B(27863), B(27864) /    25.83,  -41.32,    0.00 /
      DATA B(28153), B(28154), B(28155) /    25.81,  -41.26,    0.00 /
      DATA B(28444), B(28445), B(28446) /    25.79,  -41.20,    0.00 /
      DATA B(28735), B(28736), B(28737) /    25.76,  -41.13,    0.00 /
      DATA B(29026), B(29027), B(29028) /    25.74,  -41.07,    0.00 /
      DATA B(29317), B(29318), B(29319) /    25.72,  -41.00,    0.00 /
      DATA B(29608), B(29609), B(29610) /    25.69,  -40.93,    0.00 /
      DATA B(29899), B(29900), B(29901) /    25.66,  -40.86,    0.00 /
      DATA B(30190), B(30191), B(30192) /    25.63,  -40.79,    0.00 /
      DATA B(30481), B(30482), B(30483) /    25.60,  -40.71,    0.00 /
      DATA B(30772), B(30773), B(30774) /    25.57,  -40.63,    0.00 /
      DATA B(31063), B(31064), B(31065) /    25.52,  -40.56,    0.00 /
      DATA B(31354), B(31355), B(31356) /    25.48,  -40.49,    0.00 /
      DATA B(31645), B(31646), B(31647) /    25.42,  -40.42,    0.00 /
      DATA B(31936), B(31937), B(31938) /    25.37,  -40.35,    0.00 /
      DATA B(32227), B(32228), B(32229) /    25.31,  -40.28,    0.00 /
      DATA B(32518), B(32519), B(32520) /    25.25,  -40.20,    0.00 /
      DATA B(32809), B(32810), B(32811) /    25.18,  -40.09,    0.00 /
      DATA B(33100), B(33101), B(33102) /    25.10,  -39.95,    0.00 /
      DATA B(33391), B(33392), B(33393) /    25.01,  -39.78,    0.00 /
      DATA B(33682), B(33683), B(33684) /    24.90,  -39.58,    0.00 /
      DATA B(33973), B(33974), B(33975) /    24.76,  -39.33,    0.00 /
      DATA B(34264), B(34265), B(34266) /    24.59,  -39.05,    0.00 /
      DATA B(34555), B(34556), B(34557) /    24.39,  -38.73,    0.00 /
      DATA B(34846), B(34847), B(34848) /    24.14,  -38.37,    0.00 /
      DATA B(35137), B(35138), B(35139) /    23.86,  -37.97,    0.00 /
      DATA B(35428), B(35429), B(35430) /    23.55,  -37.51,    0.00 /
      DATA B(35719), B(35720), B(35721) /    23.25,  -36.94,    0.00 /
      DATA B(36010), B(36011), B(36012) /    23.11,  -36.17,    0.00 /
      DATA B(36301), B(36302), B(36303) /    23.37,  -35.00,    0.00 /
      DATA B(36592), B(36593), B(36594) /    23.88,  -36.67,    0.00 /
      DATA B(36883), B(36884), B(36885) /    14.25,  -30.70,    0.00 /
      DATA B(37174), B(37175), B(37176) /    13.84,  -30.67,    0.00 /
      DATA B(37465), B(37466), B(37467) /    13.38,  -30.57,    0.00 /
      DATA B(37756), B(37757), B(37758) /    12.93,  -30.45,    0.00 /
      DATA B(38047), B(38048), B(38049) /    12.51,  -30.33,    0.00 /
      DATA B(38338), B(38339), B(38340) /    12.09,  -30.20,    0.00 /
      DATA B(38629), B(38630), B(38631) /    11.66,  -30.05,    0.00 /
      DATA B(38920), B(38921), B(38922) /    11.18,  -29.89,    0.00 /
      DATA B(39211), B(39212), B(39213) /    10.66,  -29.66,    0.00 /
      DATA B(39502), B(39503), B(39504) /     6.83,  -27.26,    0.00 /
      DATA B(39793), B(39794), B(39795) /     6.17,  -27.39,    0.00 /
      DATA B(40084), B(40085), B(40086) /     5.51,  -27.51,    0.00 /
      DATA B(40375), B(40376), B(40377) /     4.85,  -27.62,    0.00 /
      DATA B(40666), B(40667), B(40668) /     4.19,  -27.73,    0.00 /
      DATA B(40957), B(40958), B(40959) /     3.51,  -27.82,    0.00 /
      DATA B(41248), B(41249), B(41250) /     2.78,  -27.89,    0.00 /
      DATA B(41539), B(41540), B(41541) /     1.98,  -27.91,    0.00 /
      DATA B(41830), B(41831), B(41832) /     1.05,  -27.88,    0.00 /
      DATA B(42121), B(42122), B(42123) /     0.13,  -27.86,    0.00 /
      DATA B(42412), B(42413), B(42414) /    -1.19,  -26.97,    0.00 /
      DATA B(42703), B(42704), B(42705) /    -1.92,  -26.40,    0.00 /
      DATA B(42994), B(42995), B(42996) /    -2.53,  -25.87,    0.00 /
      DATA B(43285), B(43286), B(43287) /    -3.01,  -25.40,    0.00 /
      DATA B(43576), B(43577), B(43578) /    -3.39,  -24.98,    0.00 /
      DATA B(43867), B(43868), B(43869) /    -3.68,  -24.61,    0.00 /
      DATA B(44158), B(44159), B(44160) /    -3.93,  -24.29,    0.00 /
      DATA B(44449), B(44450), B(44451) /    -4.13,  -24.00,    0.00 /
      DATA B(44740), B(44741), B(44742) /    -4.30,  -23.74,    0.00 /
      DATA B(45031), B(45032), B(45033) /    -4.45,  -23.50,    0.00 /
      DATA B(45322), B(45323), B(45324) /    -4.59,  -23.27,    0.00 /
      DATA B(45613), B(45614), B(45615) /    -4.71,  -23.05,    0.00 /
      DATA B(45904), B(45905), B(45906) /    -4.82,  -22.84,    0.00 /
      DATA B(46195), B(46196), B(46197) /    -4.92,  -22.63,    0.00 /
      DATA B(27574), B(27575), B(27576) /    25.81,  -41.36,    0.00 /
      DATA B(27865), B(27866), B(27867) /    25.79,  -41.30,    0.00 /
      DATA B(28156), B(28157), B(28158) /    25.76,  -41.23,    0.00 /
      DATA B(28447), B(28448), B(28449) /    25.74,  -41.17,    0.00 /
      DATA B(28738), B(28739), B(28740) /    25.72,  -41.11,    0.00 /
      DATA B(29029), B(29030), B(29031) /    25.69,  -41.04,    0.00 /
      DATA B(29320), B(29321), B(29322) /    25.66,  -40.97,    0.00 /
      DATA B(29611), B(29612), B(29613) /    25.63,  -40.90,    0.00 /
      DATA B(29902), B(29903), B(29904) /    25.60,  -40.83,    0.00 /
      DATA B(30193), B(30194), B(30195) /    25.57,  -40.75,    0.00 /
      DATA B(30484), B(30485), B(30486) /    25.54,  -40.68,    0.00 /
      DATA B(30775), B(30776), B(30777) /    25.50,  -40.60,    0.00 /
      DATA B(31066), B(31067), B(31068) /    25.45,  -40.52,    0.00 /
      DATA B(31357), B(31358), B(31359) /    25.40,  -40.44,    0.00 /
      DATA B(31648), B(31649), B(31650) /    25.34,  -40.37,    0.00 /
      DATA B(31939), B(31940), B(31941) /    25.27,  -40.31,    0.00 /
      DATA B(32230), B(32231), B(32232) /    25.20,  -40.25,    0.00 /
      DATA B(32521), B(32522), B(32523) /    25.12,  -40.17,    0.00 /
      DATA B(32812), B(32813), B(32814) /    25.04,  -40.06,    0.00 /
      DATA B(33103), B(33104), B(33105) /    24.94,  -39.92,    0.00 /
      DATA B(33394), B(33395), B(33396) /    24.82,  -39.73,    0.00 /
      DATA B(33685), B(33686), B(33687) /    24.66,  -39.49,    0.00 /
      DATA B(33976), B(33977), B(33978) /    24.47,  -39.20,    0.00 /
      DATA B(34267), B(34268), B(34269) /    24.23,  -38.86,    0.00 /
      DATA B(34558), B(34559), B(34560) /    23.93,  -38.48,    0.00 /
      DATA B(34849), B(34850), B(34851) /    23.55,  -38.05,    0.00 /
      DATA B(35140), B(35141), B(35142) /    23.07,  -37.56,    0.00 /
      DATA B(35431), B(35432), B(35433) /    22.48,  -36.99,    0.00 /
      DATA B(35722), B(35723), B(35724) /    21.75,  -36.29,    0.00 /
      DATA B(36013), B(36014), B(36015) /    20.84,  -35.42,    0.00 /
      DATA B(36304), B(36305), B(36306) /    21.08,  -33.75,    0.00 /
      DATA B(36595), B(36596), B(36597) /    16.27,  -30.41,    0.00 /
      DATA B(36886), B(36887), B(36888) /    14.63,  -30.50,    0.00 /
      DATA B(37177), B(37178), B(37179) /    13.73,  -30.42,    0.00 /
      DATA B(37468), B(37469), B(37470) /    13.09,  -30.31,    0.00 /
      DATA B(37759), B(37760), B(37761) /    12.56,  -30.19,    0.00 /
      DATA B(38050), B(38051), B(38052) /    12.07,  -30.05,    0.00 /
      DATA B(38341), B(38342), B(38343) /    11.58,  -29.89,    0.00 /
      DATA B(38632), B(38633), B(38634) /    11.07,  -29.71,    0.00 /
      DATA B(38923), B(38924), B(38925) /     7.16,  -26.95,    0.00 /
      DATA B(39214), B(39215), B(39216) /     6.52,  -27.16,    0.00 /
      DATA B(39505), B(39506), B(39507) /     5.88,  -27.31,    0.00 /
      DATA B(39796), B(39797), B(39798) /     5.24,  -27.43,    0.00 /
      DATA B(40087), B(40088), B(40089) /     4.60,  -27.52,    0.00 /
      DATA B(40378), B(40379), B(40380) /     3.95,  -27.61,    0.00 /
      DATA B(40669), B(40670), B(40671) /     3.26,  -27.70,    0.00 /
      DATA B(40960), B(40961), B(40962) /     2.51,  -27.76,    0.00 /
      DATA B(41251), B(41252), B(41253) /     1.68,  -27.81,    0.00 /
      DATA B(41542), B(41543), B(41544) /     0.76,  -27.79,    0.00 /
      DATA B(41833), B(41834), B(41835) /    -0.66,  -27.36,    0.00 /
      DATA B(42124), B(42125), B(42126) /    -1.38,  -26.84,    0.00 /
      DATA B(42415), B(42416), B(42417) /    -2.07,  -26.30,    0.00 /
      DATA B(42706), B(42707), B(42708) /    -2.64,  -25.79,    0.00 /
      DATA B(42997), B(42998), B(42999) /    -3.08,  -25.33,    0.00 /
      DATA B(43288), B(43289), B(43290) /    -3.43,  -24.93,    0.00 /
      DATA B(43579), B(43580), B(43581) /    -3.71,  -24.59,    0.00 /
      DATA B(43870), B(43871), B(43872) /    -3.93,  -24.28,    0.00 /
      DATA B(44161), B(44162), B(44163) /    -4.12,  -24.01,    0.00 /
      DATA B(44452), B(44453), B(44454) /    -4.29,  -23.76,    0.00 /
      DATA B(44743), B(44744), B(44745) /    -4.43,  -23.53,    0.00 /
      DATA B(45034), B(45035), B(45036) /    -4.56,  -23.31,    0.00 /
      DATA B(45325), B(45326), B(45327) /    -4.68,  -23.11,    0.00 /
      DATA B(45616), B(45617), B(45618) /    -4.78,  -22.91,    0.00 /
      DATA B(45907), B(45908), B(45909) /    -4.88,  -22.71,    0.00 /
      DATA B(46198), B(46199), B(46200) /    -4.98,  -22.52,    0.00 /
      DATA B(27577), B(27578), B(27579) /    25.76,  -41.33,    0.00 /
      DATA B(27868), B(27869), B(27870) /    25.74,  -41.27,    0.00 /
      DATA B(28159), B(28160), B(28161) /    25.72,  -41.21,    0.00 /
      DATA B(28450), B(28451), B(28452) /    25.69,  -41.14,    0.00 /
      DATA B(28741), B(28742), B(28743) /    25.66,  -41.08,    0.00 /
      DATA B(29032), B(29033), B(29034) /    25.64,  -41.01,    0.00 /
      DATA B(29323), B(29324), B(29325) /    25.61,  -40.94,    0.00 /
      DATA B(29614), B(29615), B(29616) /    25.57,  -40.87,    0.00 /
      DATA B(29905), B(29906), B(29907) /    25.54,  -40.80,    0.00 /
      DATA B(30196), B(30197), B(30198) /    25.51,  -40.72,    0.00 /
      DATA B(30487), B(30488), B(30489) /    25.47,  -40.64,    0.00 /
      DATA B(30778), B(30779), B(30780) /    25.43,  -40.55,    0.00 /
      DATA B(31069), B(31070), B(31071) /    25.38,  -40.47,    0.00 /
      DATA B(31360), B(31361), B(31362) /    25.32,  -40.39,    0.00 /
      DATA B(31651), B(31652), B(31653) /    25.24,  -40.32,    0.00 /
      DATA B(31942), B(31943), B(31944) /    25.16,  -40.27,    0.00 /
      DATA B(32233), B(32234), B(32235) /    25.08,  -40.22,    0.00 /
      DATA B(32524), B(32525), B(32526) /    24.99,  -40.15,    0.00 /
      DATA B(32815), B(32816), B(32817) /    24.88,  -40.04,    0.00 /
      DATA B(33106), B(33107), B(33108) /    24.75,  -39.88,    0.00 /
      DATA B(33397), B(33398), B(33399) /    24.59,  -39.66,    0.00 /
      DATA B(33688), B(33689), B(33690) /    24.38,  -39.38,    0.00 /
      DATA B(33979), B(33980), B(33981) /    24.12,  -39.04,    0.00 /
      DATA B(34270), B(34271), B(34272) /    23.77,  -38.62,    0.00 /
      DATA B(34561), B(34562), B(34563) /    23.32,  -38.14,    0.00 /
      DATA B(34852), B(34853), B(34854) /    22.74,  -37.59,    0.00 /
      DATA B(35143), B(35144), B(35145) /    22.00,  -36.98,    0.00 /
      DATA B(35434), B(35435), B(35436) /    21.04,  -36.23,    0.00 /
      DATA B(35725), B(35726), B(35727) /    21.27,  -35.05,    0.00 /
      DATA B(36016), B(36017), B(36018) /    19.59,  -33.87,    0.00 /
      DATA B(36307), B(36308), B(36309) /    17.39,  -31.70,    0.00 /
      DATA B(36598), B(36599), B(36600) /    15.90,  -29.93,    0.00 /
      DATA B(36889), B(36890), B(36891) /    14.49,  -30.06,    0.00 /
      DATA B(37180), B(37181), B(37182) /    13.46,  -30.09,    0.00 /
      DATA B(37471), B(37472), B(37473) /    12.72,  -30.02,    0.00 /
      DATA B(37762), B(37763), B(37764) /    12.11,  -29.89,    0.00 /
      DATA B(38053), B(38054), B(38055) /    11.54,  -29.73,    0.00 /
      DATA B(38344), B(38345), B(38346) /    10.97,  -29.51,    0.00 /
      DATA B(38635), B(38636), B(38637) /     6.87,  -26.90,    0.00 /
      DATA B(38926), B(38927), B(38928) /     6.23,  -27.08,    0.00 /
      DATA B(39217), B(39218), B(39219) /     5.58,  -27.23,    0.00 /
      DATA B(39508), B(39509), B(39510) /     4.95,  -27.35,    0.00 /
      DATA B(39799), B(39800), B(39801) /     4.31,  -27.44,    0.00 /
      DATA B(40090), B(40091), B(40092) /     3.65,  -27.51,    0.00 /
      DATA B(40381), B(40382), B(40383) /     2.95,  -27.57,    0.00 /
      DATA B(40672), B(40673), B(40674) /     2.19,  -27.63,    0.00 /
      DATA B(40963), B(40964), B(40965) /     1.34,  -27.67,    0.00 /
      DATA B(41254), B(41255), B(41256) /     0.42,  -27.69,    0.00 /
      DATA B(41545), B(41546), B(41547) /    -0.90,  -27.20,    0.00 /
      DATA B(41836), B(41837), B(41838) /    -1.59,  -26.70,    0.00 /
      DATA B(42127), B(42128), B(42129) /    -2.22,  -26.18,    0.00 /
      DATA B(42418), B(42419), B(42420) /    -2.74,  -25.70,    0.00 /
      DATA B(42709), B(42710), B(42711) /    -3.15,  -25.27,    0.00 /
      DATA B(43000), B(43001), B(43002) /    -3.47,  -24.89,    0.00 /
      DATA B(43291), B(43292), B(43293) /    -3.72,  -24.56,    0.00 /
      DATA B(43582), B(43583), B(43584) /    -3.93,  -24.26,    0.00 /
      DATA B(43873), B(43874), B(43875) /    -4.11,  -24.01,    0.00 /
      DATA B(44164), B(44165), B(44166) /    -4.27,  -23.77,    0.00 /
      DATA B(44455), B(44456), B(44457) /    -4.40,  -23.55,    0.00 /
      DATA B(44746), B(44747), B(44748) /    -4.53,  -23.35,    0.00 /
      DATA B(45037), B(45038), B(45039) /    -4.64,  -23.15,    0.00 /
      DATA B(45328), B(45329), B(45330) /    -4.74,  -22.97,    0.00 /
      DATA B(45619), B(45620), B(45621) /    -4.84,  -22.78,    0.00 /
      DATA B(45910), B(45911), B(45912) /    -4.93,  -22.60,    0.00 /
      DATA B(46201), B(46202), B(46203) /    -5.01,  -22.42,    0.00 /
      DATA B(27580), B(27581), B(27582) /    25.72,  -41.30,    0.00 /
      DATA B(27871), B(27872), B(27873) /    25.70,  -41.24,    0.00 /
      DATA B(28162), B(28163), B(28164) /    25.67,  -41.18,    0.00 /
      DATA B(28453), B(28454), B(28455) /    25.64,  -41.11,    0.00 /
      DATA B(28744), B(28745), B(28746) /    25.61,  -41.05,    0.00 /
      DATA B(29035), B(29036), B(29037) /    25.58,  -40.98,    0.00 /
      DATA B(29326), B(29327), B(29328) /    25.54,  -40.91,    0.00 /
      DATA B(29617), B(29618), B(29619) /    25.51,  -40.84,    0.00 /
      DATA B(29908), B(29909), B(29910) /    25.47,  -40.77,    0.00 /
      DATA B(30199), B(30200), B(30201) /    25.43,  -40.69,    0.00 /
      DATA B(30490), B(30491), B(30492) /    25.39,  -40.60,    0.00 /
      DATA B(30781), B(30782), B(30783) /    25.35,  -40.51,    0.00 /
      DATA B(31072), B(31073), B(31074) /    25.30,  -40.41,    0.00 /
      DATA B(31363), B(31364), B(31365) /    25.23,  -40.32,    0.00 /
      DATA B(31654), B(31655), B(31656) /    25.15,  -40.25,    0.00 /
      DATA B(31945), B(31946), B(31947) /    25.05,  -40.22,    0.00 /
      DATA B(32236), B(32237), B(32238) /    24.95,  -40.19,    0.00 /
      DATA B(32527), B(32528), B(32529) /    24.85,  -40.12,    0.00 /
      DATA B(32818), B(32819), B(32820) /    24.71,  -40.01,    0.00 /
      DATA B(33109), B(33110), B(33111) /    24.53,  -39.83,    0.00 /
      DATA B(33400), B(33401), B(33402) /    24.31,  -39.58,    0.00 /
      DATA B(33691), B(33692), B(33693) /    24.02,  -39.25,    0.00 /
      DATA B(33982), B(33983), B(33984) /    23.65,  -38.82,    0.00 /
      DATA B(34273), B(34274), B(34275) /    23.16,  -38.29,    0.00 /
      DATA B(34564), B(34565), B(34566) /    22.51,  -37.67,    0.00 /
      DATA B(34855), B(34856), B(34857) /    21.65,  -36.95,    0.00 /
      DATA B(35146), B(35147), B(35148) /    21.62,  -35.71,    0.00 /
      DATA B(35437), B(35438), B(35439) /    20.43,  -34.83,    0.00 /
      DATA B(35728), B(35729), B(35730) /    18.87,  -33.76,    0.00 /
      DATA B(36019), B(36020), B(36021) /    17.22,  -32.56,    0.00 /
      DATA B(36310), B(36311), B(36312) /    15.69,  -31.02,    0.00 /
      DATA B(36601), B(36602), B(36603) /    14.68,  -29.94,    0.00 /
      DATA B(36892), B(36893), B(36894) /    13.79,  -29.77,    0.00 /
      DATA B(37183), B(37184), B(37185) /    12.94,  -29.77,    0.00 /
      DATA B(37474), B(37475), B(37476) /    12.21,  -29.69,    0.00 /
      DATA B(37765), B(37766), B(37767) /    11.54,  -29.58,    0.00 /
      DATA B(38056), B(38057), B(38058) /     7.28,  -26.57,    0.00 /
      DATA B(38347), B(38348), B(38349) /     6.59,  -26.81,    0.00 /
      DATA B(38638), B(38639), B(38640) /     5.93,  -26.99,    0.00 /
      DATA B(38929), B(38930), B(38931) /     5.28,  -27.14,    0.00 /
      DATA B(39220), B(39221), B(39222) /     4.63,  -27.26,    0.00 /
      DATA B(39511), B(39512), B(39513) /     3.97,  -27.35,    0.00 /
      DATA B(39802), B(39803), B(39804) /     3.29,  -27.42,    0.00 /
      DATA B(40093), B(40094), B(40095) /     2.57,  -27.48,    0.00 /
      DATA B(40384), B(40385), B(40386) /     1.78,  -27.53,    0.00 /
      DATA B(40675), B(40676), B(40677) /     0.92,  -27.57,    0.00 /
      DATA B(40966), B(40967), B(40968) /    -0.06,  -27.64,    0.00 /
      DATA B(41257), B(41258), B(41259) /    -1.15,  -27.02,    0.00 /
      DATA B(41548), B(41549), B(41550) /    -1.82,  -26.55,    0.00 /
      DATA B(41839), B(41840), B(41841) /    -2.39,  -26.07,    0.00 /
      DATA B(42130), B(42131), B(42132) /    -2.85,  -25.61,    0.00 /
      DATA B(42421), B(42422), B(42423) /    -3.22,  -25.20,    0.00 /
      DATA B(42712), B(42713), B(42714) /    -3.51,  -24.84,    0.00 /
      DATA B(43003), B(43004), B(43005) /    -3.74,  -24.52,    0.00 /
      DATA B(43294), B(43295), B(43296) /    -3.94,  -24.25,    0.00 /
      DATA B(43585), B(43586), B(43587) /    -4.10,  -24.00,    0.00 /
      DATA B(43876), B(43877), B(43878) /    -4.25,  -23.77,    0.00 /
      DATA B(44167), B(44168), B(44169) /    -4.38,  -23.57,    0.00 /
      DATA B(44458), B(44459), B(44460) /    -4.49,  -23.37,    0.00 /
      DATA B(44749), B(44750), B(44751) /    -4.60,  -23.19,    0.00 /
      DATA B(45040), B(45041), B(45042) /    -4.70,  -23.01,    0.00 /
      DATA B(45331), B(45332), B(45333) /    -4.79,  -22.84,    0.00 /
      DATA B(45622), B(45623), B(45624) /    -4.88,  -22.67,    0.00 /
      DATA B(45913), B(45914), B(45915) /    -4.97,  -22.50,    0.00 /
      DATA B(46204), B(46205), B(46206) /    -5.04,  -22.33,    0.00 /
      DATA B(27583), B(27584), B(27585) /    25.68,  -41.27,    0.00 /
      DATA B(27874), B(27875), B(27876) /    25.65,  -41.21,    0.00 /
      DATA B(28165), B(28166), B(28167) /    25.62,  -41.15,    0.00 /
      DATA B(28456), B(28457), B(28458) /    25.59,  -41.08,    0.00 /
      DATA B(28747), B(28748), B(28749) /    25.55,  -41.02,    0.00 /
      DATA B(29038), B(29039), B(29040) /    25.52,  -40.95,    0.00 /
      DATA B(29329), B(29330), B(29331) /    25.48,  -40.88,    0.00 /
      DATA B(29620), B(29621), B(29622) /    25.44,  -40.81,    0.00 /
      DATA B(29911), B(29912), B(29913) /    25.39,  -40.73,    0.00 /
      DATA B(30202), B(30203), B(30204) /    25.35,  -40.65,    0.00 /
      DATA B(30493), B(30494), B(30495) /    25.30,  -40.56,    0.00 /
      DATA B(30784), B(30785), B(30786) /    25.26,  -40.46,    0.00 /
      DATA B(31075), B(31076), B(31077) /    25.21,  -40.35,    0.00 /
      DATA B(31366), B(31367), B(31368) /    25.14,  -40.23,    0.00 /
      DATA B(31657), B(31658), B(31659) /    25.04,  -40.16,    0.00 /
      DATA B(31948), B(31949), B(31950) /    24.93,  -40.15,    0.00 /
      DATA B(32239), B(32240), B(32241) /    24.82,  -40.15,    0.00 /
      DATA B(32530), B(32531), B(32532) /    24.69,  -40.10,    0.00 /
      DATA B(32821), B(32822), B(32823) /    24.51,  -39.97,    0.00 /
      DATA B(33112), B(33113), B(33114) /    24.26,  -39.77,    0.00 /
      DATA B(33403), B(33404), B(33405) /    23.95,  -39.49,    0.00 /
      DATA B(33694), B(33695), B(33696) /    23.55,  -39.08,    0.00 /
      DATA B(33985), B(33986), B(33987) /    23.04,  -38.54,    0.00 /
      DATA B(34276), B(34277), B(34278) /    22.40,  -37.88,    0.00 /
      DATA B(34567), B(34568), B(34569) /    22.04,  -36.36,    0.00 /
      DATA B(34858), B(34859), B(34860) /    21.00,  -35.57,    0.00 /
      DATA B(35149), B(35150), B(35151) /    19.76,  -34.62,    0.00 /
      DATA B(35440), B(35441), B(35442) /    18.23,  -33.62,    0.00 /
      DATA B(35731), B(35732), B(35733) /    16.78,  -32.66,    0.00 /
      DATA B(36022), B(36023), B(36024) /    15.48,  -31.64,    0.00 /
      DATA B(36313), B(36314), B(36315) /    14.41,  -30.61,    0.00 /
      DATA B(36604), B(36605), B(36606) /    13.63,  -29.87,    0.00 /
      DATA B(36895), B(36896), B(36897) /    12.94,  -29.58,    0.00 /
      DATA B(37186), B(37187), B(37188) /    12.24,  -29.47,    0.00 /
      DATA B(37477), B(37478), B(37479) /     7.85,  -26.24,    0.00 /
      DATA B(37768), B(37769), B(37770) /     7.07,  -26.50,    0.00 /
      DATA B(38059), B(38060), B(38061) /     6.34,  -26.72,    0.00 /
      DATA B(38350), B(38351), B(38352) /     5.64,  -26.90,    0.00 /
      DATA B(38641), B(38642), B(38643) /     4.96,  -27.04,    0.00 /
      DATA B(38932), B(38933), B(38934) /     4.28,  -27.16,    0.00 /
      DATA B(39223), B(39224), B(39225) /     3.58,  -27.26,    0.00 /
      DATA B(39514), B(39515), B(39516) /     2.85,  -27.33,    0.00 /
      DATA B(39805), B(39806), B(39807) /     2.08,  -27.40,    0.00 /
      DATA B(40096), B(40097), B(40098) /     1.25,  -27.49,    0.00 /
      DATA B(40387), B(40388), B(40389) /     0.37,  -27.53,    0.00 /
      DATA B(40678), B(40679), B(40680) /    -0.78,  -27.03,    0.00 /
      DATA B(40969), B(40970), B(40971) /    -1.47,  -26.76,    0.00 /
      DATA B(41260), B(41261), B(41262) /    -2.07,  -26.40,    0.00 /
      DATA B(41551), B(41552), B(41553) /    -2.57,  -25.95,    0.00 /
      DATA B(41842), B(41843), B(41844) /    -2.97,  -25.51,    0.00 /
      DATA B(42133), B(42134), B(42135) /    -3.29,  -25.12,    0.00 /
      DATA B(42424), B(42425), B(42426) /    -3.54,  -24.78,    0.00 /
      DATA B(42715), B(42716), B(42717) /    -3.75,  -24.48,    0.00 /
      DATA B(43006), B(43007), B(43008) /    -3.93,  -24.22,    0.00 /
      DATA B(43297), B(43298), B(43299) /    -4.09,  -23.99,    0.00 /
      DATA B(43588), B(43589), B(43590) /    -4.23,  -23.77,    0.00 /
      DATA B(43879), B(43880), B(43881) /    -4.35,  -23.58,    0.00 /
      DATA B(44170), B(44171), B(44172) /    -4.46,  -23.39,    0.00 /
      DATA B(44461), B(44462), B(44463) /    -4.56,  -23.22,    0.00 /
      DATA B(44752), B(44753), B(44754) /    -4.66,  -23.05,    0.00 /
      DATA B(45043), B(45044), B(45045) /    -4.75,  -22.89,    0.00 /
      DATA B(45334), B(45335), B(45336) /    -4.83,  -22.73,    0.00 /
      DATA B(45625), B(45626), B(45627) /    -4.91,  -22.57,    0.00 /
      DATA B(45916), B(45917), B(45918) /    -4.99,  -22.41,    0.00 /
      DATA B(46207), B(46208), B(46209) /    -5.06,  -22.25,    0.00 /
      DATA B(27586), B(27587), B(27588) /    25.63,  -41.24,    0.00 /
      DATA B(27877), B(27878), B(27879) /    25.60,  -41.18,    0.00 /
      DATA B(28168), B(28169), B(28170) /    25.57,  -41.11,    0.00 /
      DATA B(28459), B(28460), B(28461) /    25.53,  -41.05,    0.00 /
      DATA B(28750), B(28751), B(28752) /    25.49,  -40.98,    0.00 /
      DATA B(29041), B(29042), B(29043) /    25.45,  -40.91,    0.00 /
      DATA B(29332), B(29333), B(29334) /    25.41,  -40.84,    0.00 /
      DATA B(29623), B(29624), B(29625) /    25.36,  -40.77,    0.00 /
      DATA B(29914), B(29915), B(29916) /    25.30,  -40.70,    0.00 /
      DATA B(30205), B(30206), B(30207) /    25.25,  -40.61,    0.00 /
      DATA B(30496), B(30497), B(30498) /    25.19,  -40.52,    0.00 /
      DATA B(30787), B(30788), B(30789) /    25.14,  -40.41,    0.00 /
      DATA B(31078), B(31079), B(31080) /    25.10,  -40.28,    0.00 /
      DATA B(31369), B(31370), B(31371) /    25.04,  -40.13,    0.00 /
      DATA B(31660), B(31661), B(31662) /    24.94,  -40.03,    0.00 /
      DATA B(31951), B(31952), B(31953) /    24.81,  -40.07,    0.00 /
      DATA B(32242), B(32243), B(32244) /    24.71,  -40.13,    0.00 /
      DATA B(32533), B(32534), B(32535) /    24.54,  -40.09,    0.00 /
      DATA B(32824), B(32825), B(32826) /    24.28,  -39.93,    0.00 /
      DATA B(33115), B(33116), B(33117) /    23.94,  -39.70,    0.00 /
      DATA B(33406), B(33407), B(33408) /    23.50,  -39.38,    0.00 /
      DATA B(33697), B(33698), B(33699) /    22.99,  -37.91,    0.00 /
      DATA B(33988), B(33989), B(33990) /    22.41,  -37.34,    0.00 /
      DATA B(34279), B(34280), B(34281) /    21.61,  -36.47,    0.00 /
      DATA B(34570), B(34571), B(34572) /    20.48,  -35.49,    0.00 /
      DATA B(34861), B(34862), B(34863) /    19.13,  -34.50,    0.00 /
      DATA B(35152), B(35153), B(35154) /    17.64,  -33.46,    0.00 /
      DATA B(35443), B(35444), B(35445) /    16.30,  -32.57,    0.00 /
      DATA B(35734), B(35735), B(35736) /    15.15,  -31.76,    0.00 /
      DATA B(36025), B(36026), B(36027) /    14.17,  -30.99,    0.00 /
      DATA B(36316), B(36317), B(36318) /    13.35,  -30.25,    0.00 /
      DATA B(36607), B(36608), B(36609) /    12.68,  -29.69,    0.00 /
      DATA B(36898), B(36899), B(36900) /    12.06,  -29.36,    0.00 /
      DATA B(37189), B(37190), B(37191) /     7.65,  -26.18,    0.00 /
      DATA B(37480), B(37481), B(37482) /     6.85,  -26.42,    0.00 /
      DATA B(37771), B(37772), B(37773) /     6.08,  -26.62,    0.00 /
      DATA B(38062), B(38063), B(38064) /     5.34,  -26.80,    0.00 /
      DATA B(38353), B(38354), B(38355) /     4.61,  -26.94,    0.00 /
      DATA B(38644), B(38645), B(38646) /     3.88,  -27.06,    0.00 /
      DATA B(38935), B(38936), B(38937) /     3.13,  -27.16,    0.00 /
      DATA B(39226), B(39227), B(39228) /     2.33,  -27.26,    0.00 /
      DATA B(39517), B(39518), B(39519) /     1.49,  -27.34,    0.00 /
      DATA B(39808), B(39809), B(39810) /     0.63,  -27.38,    0.00 /
      DATA B(40099), B(40100), B(40101) /    -0.46,  -26.93,    0.00 /
      DATA B(40390), B(40391), B(40392) /    -1.10,  -26.75,    0.00 /
      DATA B(40681), B(40682), B(40683) /    -1.70,  -26.48,    0.00 /
      DATA B(40972), B(40973), B(40974) /    -2.25,  -26.19,    0.00 /
      DATA B(41263), B(41264), B(41265) /    -2.72,  -25.82,    0.00 /
      DATA B(41554), B(41555), B(41556) /    -3.07,  -25.42,    0.00 /
      DATA B(41845), B(41846), B(41847) /    -3.35,  -25.05,    0.00 /
      DATA B(42136), B(42137), B(42138) /    -3.58,  -24.73,    0.00 /
      DATA B(42427), B(42428), B(42429) /    -3.77,  -24.44,    0.00 /
      DATA B(42718), B(42719), B(42720) /    -3.93,  -24.19,    0.00 /
      DATA B(43009), B(43010), B(43011) /    -4.07,  -23.97,    0.00 /
      DATA B(43300), B(43301), B(43302) /    -4.20,  -23.77,    0.00 /
      DATA B(43591), B(43592), B(43593) /    -4.32,  -23.58,    0.00 /
      DATA B(43882), B(43883), B(43884) /    -4.42,  -23.40,    0.00 /
      DATA B(44173), B(44174), B(44175) /    -4.52,  -23.24,    0.00 /
      DATA B(44464), B(44465), B(44466) /    -4.61,  -23.08,    0.00 /
      DATA B(44755), B(44756), B(44757) /    -4.70,  -22.92,    0.00 /
      DATA B(45046), B(45047), B(45048) /    -4.78,  -22.77,    0.00 /
      DATA B(45337), B(45338), B(45339) /    -4.86,  -22.62,    0.00 /
      DATA B(45628), B(45629), B(45630) /    -4.94,  -22.47,    0.00 /
      DATA B(45919), B(45920), B(45921) /    -5.01,  -22.32,    0.00 /
      DATA B(46210), B(46211), B(46212) /    -5.08,  -22.17,    0.00 /
      DATA B(27589), B(27590), B(27591) /    25.58,  -41.21,    0.00 /
      DATA B(27880), B(27881), B(27882) /    25.55,  -41.14,    0.00 /
      DATA B(28171), B(28172), B(28173) /    25.51,  -41.08,    0.00 /
      DATA B(28462), B(28463), B(28464) /    25.47,  -41.01,    0.00 /
      DATA B(28753), B(28754), B(28755) /    25.43,  -40.95,    0.00 /
      DATA B(29044), B(29045), B(29046) /    25.38,  -40.88,    0.00 /
      DATA B(29335), B(29336), B(29337) /    25.33,  -40.81,    0.00 /
      DATA B(29626), B(29627), B(29628) /    25.27,  -40.73,    0.00 /
      DATA B(29917), B(29918), B(29919) /    25.20,  -40.65,    0.00 /
      DATA B(30208), B(30209), B(30210) /    25.13,  -40.57,    0.00 /
      DATA B(30499), B(30500), B(30501) /    25.06,  -40.48,    0.00 /
      DATA B(30790), B(30791), B(30792) /    24.99,  -40.36,    0.00 /
      DATA B(31081), B(31082), B(31083) /    24.93,  -40.22,    0.00 /
      DATA B(31372), B(31373), B(31374) /    24.91,  -40.02,    0.00 /
      DATA B(31663), B(31664), B(31665) /    24.83,  -39.84,    0.00 /
      DATA B(31954), B(31955), B(31956) /    24.71,  -40.01,    0.00 /
      DATA B(32245), B(32246), B(32247) /    24.64,  -40.15,    0.00 /
      DATA B(32536), B(32537), B(32538) /    24.41,  -40.08,    0.00 /
      DATA B(32827), B(32828), B(32829) /    24.04,  -39.87,    0.00 /
      DATA B(33118), B(33119), B(33120) /    23.14,  -38.46,    0.00 /
      DATA B(33409), B(33410), B(33411) /    22.69,  -38.14,    0.00 /
      DATA B(33700), B(33701), B(33702) /    22.08,  -37.64,    0.00 /
      DATA B(33991), B(33992), B(33993) /    21.25,  -36.83,    0.00 /
      DATA B(34282), B(34283), B(34284) /    20.10,  -35.59,    0.00 /
      DATA B(34573), B(34574), B(34575) /    18.58,  -34.31,    0.00 /
      DATA B(34864), B(34865), B(34866) /    17.12,  -33.32,    0.00 /
      DATA B(35155), B(35156), B(35157) /    15.85,  -32.45,    0.00 /
      DATA B(35446), B(35447), B(35448) /    14.79,  -31.72,    0.00 /
      DATA B(35737), B(35738), B(35739) /    13.88,  -31.08,    0.00 /
      DATA B(36028), B(36029), B(36030) /    13.09,  -30.47,    0.00 /
      DATA B(36319), B(36320), B(36321) /    12.39,  -29.89,    0.00 /
      DATA B(36610), B(36611), B(36612) /    11.75,  -29.42,    0.00 /
      DATA B(36901), B(36902), B(36903) /     7.35,  -26.25,    0.00 /
      DATA B(37192), B(37193), B(37194) /     6.56,  -26.38,    0.00 /
      DATA B(37483), B(37484), B(37485) /     5.78,  -26.55,    0.00 /
      DATA B(37774), B(37775), B(37776) /     5.00,  -26.71,    0.00 /
      DATA B(38065), B(38066), B(38067) /     4.21,  -26.84,    0.00 /
      DATA B(38356), B(38357), B(38358) /     3.42,  -26.96,    0.00 /
      DATA B(38647), B(38648), B(38649) /     2.59,  -27.07,    0.00 /
      DATA B(38938), B(38939), B(38940) /     1.74,  -27.16,    0.00 /
      DATA B(39229), B(39230), B(39231) /     0.47,  -26.97,    0.00 /
      DATA B(39520), B(39521), B(39522) /    -0.22,  -26.83,    0.00 /
      DATA B(39811), B(39812), B(39813) /    -0.82,  -26.61,    0.00 /
      DATA B(40102), B(40103), B(40104) /    -1.41,  -26.41,    0.00 /
      DATA B(40393), B(40394), B(40395) /    -1.93,  -26.18,    0.00 /
      DATA B(40684), B(40685), B(40686) /    -2.39,  -25.92,    0.00 /
      DATA B(40975), B(40976), B(40977) /    -2.79,  -25.63,    0.00 /
      DATA B(41266), B(41267), B(41268) /    -3.13,  -25.30,    0.00 /
      DATA B(41557), B(41558), B(41559) /    -3.39,  -24.97,    0.00 /
      DATA B(41848), B(41849), B(41850) /    -3.60,  -24.67,    0.00 /
      DATA B(42139), B(42140), B(42141) /    -3.77,  -24.40,    0.00 /
      DATA B(42430), B(42431), B(42432) /    -3.92,  -24.16,    0.00 /
      DATA B(42721), B(42722), B(42723) /    -4.06,  -23.95,    0.00 /
      DATA B(43012), B(43013), B(43014) /    -4.18,  -23.75,    0.00 /
      DATA B(43303), B(43304), B(43305) /    -4.29,  -23.58,    0.00 /
      DATA B(43594), B(43595), B(43596) /    -4.39,  -23.41,    0.00 /
      DATA B(43885), B(43886), B(43887) /    -4.48,  -23.25,    0.00 /
      DATA B(44176), B(44177), B(44178) /    -4.57,  -23.10,    0.00 /
      DATA B(44467), B(44468), B(44469) /    -4.65,  -22.95,    0.00 /
      DATA B(44758), B(44759), B(44760) /    -4.73,  -22.80,    0.00 /
      DATA B(45049), B(45050), B(45051) /    -4.81,  -22.66,    0.00 /
      DATA B(45340), B(45341), B(45342) /    -4.88,  -22.52,    0.00 /
      DATA B(45631), B(45632), B(45633) /    -4.95,  -22.38,    0.00 /
      DATA B(45922), B(45923), B(45924) /    -5.02,  -22.24,    0.00 /
      DATA B(46213), B(46214), B(46215) /    -5.09,  -22.09,    0.00 /
      DATA B(27592), B(27593), B(27594) /    25.54,  -41.17,    0.00 /
      DATA B(27883), B(27884), B(27885) /    25.50,  -41.10,    0.00 /
      DATA B(28174), B(28175), B(28176) /    25.46,  -41.04,    0.00 /
      DATA B(28465), B(28466), B(28467) /    25.41,  -40.97,    0.00 /
      DATA B(28756), B(28757), B(28758) /    25.36,  -40.90,    0.00 /
      DATA B(29047), B(29048), B(29049) /    25.31,  -40.83,    0.00 /
      DATA B(29338), B(29339), B(29340) /    25.24,  -40.76,    0.00 /
      DATA B(29629), B(29630), B(29631) /    25.17,  -40.68,    0.00 /
      DATA B(29920), B(29921), B(29922) /    25.09,  -40.60,    0.00 /
      DATA B(30211), B(30212), B(30213) /    24.99,  -40.51,    0.00 /
      DATA B(30502), B(30503), B(30504) /    24.89,  -40.42,    0.00 /
      DATA B(30793), B(30794), B(30795) /    24.77,  -40.30,    0.00 /
      DATA B(31084), B(31085), B(31086) /    24.67,  -40.16,    0.00 /
      DATA B(31375), B(31376), B(31377) /    24.63,  -39.94,    0.00 /
      DATA B(31666), B(31667), B(31668) /    24.71,  -39.56,    0.00 /
      DATA B(31957), B(31958), B(31959) /    24.79,  -40.08,    0.00 /
      DATA B(32248), B(32249), B(32250) /    24.70,  -40.19,    0.00 /
      DATA B(32539), B(32540), B(32541) /    23.46,  -38.66,    0.00 /
      DATA B(32830), B(32831), B(32832) /    23.07,  -38.53,    0.00 /
      DATA B(33121), B(33122), B(33123) /    22.57,  -38.30,    0.00 /
      DATA B(33412), B(33413), B(33414) /    21.92,  -37.91,    0.00 /
      DATA B(33703), B(33704), B(33705) /    21.08,  -37.22,    0.00 /
      DATA B(33994), B(33995), B(33996) /    20.02,  -36.00,    0.00 /
      DATA B(34285), B(34286), B(34287) /    18.05,  -34.37,    0.00 /
      DATA B(34576), B(34577), B(34578) /    16.64,  -33.25,    0.00 /
      DATA B(34867), B(34868), B(34869) /    15.43,  -32.34,    0.00 /
      DATA B(35158), B(35159), B(35160) /    14.42,  -31.62,    0.00 /
      DATA B(35449), B(35450), B(35451) /    13.56,  -31.03,    0.00 /
      DATA B(35740), B(35741), B(35742) /    12.80,  -30.51,    0.00 /
      DATA B(36031), B(36032), B(36033) /    12.10,  -29.99,    0.00 /
      DATA B(36322), B(36323), B(36324) /     7.82,  -26.49,    0.00 /
      DATA B(36613), B(36614), B(36615) /     6.99,  -26.42,    0.00 /
      DATA B(36904), B(36905), B(36906) /     6.18,  -26.44,    0.00 /
      DATA B(37195), B(37196), B(37197) /     5.38,  -26.53,    0.00 /
      DATA B(37486), B(37487), B(37488) /     4.57,  -26.65,    0.00 /
      DATA B(37777), B(37778), B(37779) /     3.73,  -26.77,    0.00 /
      DATA B(38068), B(38069), B(38070) /     2.87,  -26.87,    0.00 /
      DATA B(38359), B(38360), B(38361) /     1.97,  -27.01,    0.00 /
      DATA B(38650), B(38651), B(38652) /     0.69,  -26.82,    0.00 /
      DATA B(38941), B(38942), B(38943) /     0.06,  -26.62,    0.00 /
      DATA B(39232), B(39233), B(39234) /    -0.58,  -26.46,    0.00 /
      DATA B(39523), B(39524), B(39525) /    -1.15,  -26.28,    0.00 /
      DATA B(39814), B(39815), B(39816) /    -1.66,  -26.07,    0.00 /
      DATA B(40105), B(40106), B(40107) /    -2.11,  -25.85,    0.00 /
      DATA B(40396), B(40397), B(40398) /    -2.51,  -25.63,    0.00 /
      DATA B(40687), B(40688), B(40689) /    -2.85,  -25.38,    0.00 /
      DATA B(40978), B(40979), B(40980) /    -3.15,  -25.13,    0.00 /
      DATA B(41269), B(41270), B(41271) /    -3.40,  -24.86,    0.00 /
      DATA B(41560), B(41561), B(41562) /    -3.60,  -24.60,    0.00 /
      DATA B(41851), B(41852), B(41853) /    -3.77,  -24.35,    0.00 /
      DATA B(42142), B(42143), B(42144) /    -3.91,  -24.13,    0.00 /
      DATA B(42433), B(42434), B(42435) /    -4.03,  -23.92,    0.00 /
      DATA B(42724), B(42725), B(42726) /    -4.15,  -23.74,    0.00 /
      DATA B(43015), B(43016), B(43017) /    -4.25,  -23.57,    0.00 /
      DATA B(43306), B(43307), B(43308) /    -4.35,  -23.41,    0.00 /
      DATA B(43597), B(43598), B(43599) /    -4.44,  -23.26,    0.00 /
      DATA B(43888), B(43889), B(43890) /    -4.52,  -23.11,    0.00 /
      DATA B(44179), B(44180), B(44181) /    -4.60,  -22.97,    0.00 /
      DATA B(44470), B(44471), B(44472) /    -4.68,  -22.83,    0.00 /
      DATA B(44761), B(44762), B(44763) /    -4.75,  -22.70,    0.00 /
      DATA B(45052), B(45053), B(45054) /    -4.83,  -22.56,    0.00 /
      DATA B(45343), B(45344), B(45345) /    -4.89,  -22.43,    0.00 /
      DATA B(45634), B(45635), B(45636) /    -4.96,  -22.30,    0.00 /
      DATA B(45925), B(45926), B(45927) /    -5.03,  -22.16,    0.00 /
      DATA B(46216), B(46217), B(46218) /    -5.09,  -22.02,    0.00 /
      DATA B(27595), B(27596), B(27597) /    25.49,  -41.13,    0.00 /
      DATA B(27886), B(27887), B(27888) /    25.44,  -41.07,    0.00 /
      DATA B(28177), B(28178), B(28179) /    25.40,  -41.00,    0.00 /
      DATA B(28468), B(28469), B(28470) /    25.35,  -40.93,    0.00 /
      DATA B(28759), B(28760), B(28761) /    25.29,  -40.86,    0.00 /
      DATA B(29050), B(29051), B(29052) /    25.23,  -40.79,    0.00 /
      DATA B(29341), B(29342), B(29343) /    25.15,  -40.71,    0.00 /
      DATA B(29632), B(29633), B(29634) /    25.06,  -40.63,    0.00 /
      DATA B(29923), B(29924), B(29925) /    24.96,  -40.54,    0.00 /
      DATA B(30214), B(30215), B(30216) /    24.83,  -40.44,    0.00 /
      DATA B(30505), B(30506), B(30507) /    24.68,  -40.34,    0.00 /
      DATA B(30796), B(30797), B(30798) /    24.49,  -40.21,    0.00 /
      DATA B(31087), B(31088), B(31089) /    24.26,  -40.05,    0.00 /
      DATA B(31378), B(31379), B(31380) /    24.00,  -39.81,    0.00 /
      DATA B(31669), B(31670), B(31671) /    23.53,  -39.32,    0.00 /
      DATA B(31960), B(31961), B(31962) /    24.50,  -38.72,    0.00 /
      DATA B(32251), B(32252), B(32253) /    23.81,  -38.69,    0.00 /
      DATA B(32542), B(32543), B(32544) /    23.24,  -38.57,    0.00 /
      DATA B(32833), B(32834), B(32835) /    22.66,  -38.39,    0.00 /
      DATA B(33124), B(33125), B(33126) /    21.98,  -38.09,    0.00 /
      DATA B(33415), B(33416), B(33417) /    21.13,  -37.55,    0.00 /
      DATA B(33706), B(33707), B(33708) /    19.94,  -36.62,    0.00 /
      DATA B(33997), B(33998), B(33999) /    17.50,  -34.30,    0.00 /
      DATA B(34288), B(34289), B(34290) /    16.16,  -33.27,    0.00 /
      DATA B(34579), B(34580), B(34581) /    15.00,  -32.31,    0.00 /
      DATA B(34870), B(34871), B(34872) /    14.03,  -31.54,    0.00 /
      DATA B(35161), B(35162), B(35163) /    13.21,  -30.92,    0.00 /
      DATA B(35452), B(35453), B(35454) /    12.47,  -30.42,    0.00 /
      DATA B(35743), B(35744), B(35745) /    11.78,  -29.98,    0.00 /
      DATA B(36034), B(36035), B(36036) /     7.48,  -26.67,    0.00 /
      DATA B(36325), B(36326), B(36327) /     6.61,  -26.59,    0.00 /
      DATA B(36616), B(36617), B(36618) /     5.76,  -26.55,    0.00 /
      DATA B(36907), B(36908), B(36909) /     4.92,  -26.57,    0.00 /
      DATA B(37198), B(37199), B(37200) /     4.06,  -26.65,    0.00 /
      DATA B(37489), B(37490), B(37491) /     3.17,  -26.75,    0.00 /
      DATA B(37780), B(37781), B(37782) /     2.23,  -26.82,    0.00 /
      DATA B(38071), B(38072), B(38073) /     0.94,  -26.65,    0.00 /
      DATA B(38362), B(38363), B(38364) /     0.29,  -26.43,    0.00 /
      DATA B(38653), B(38654), B(38655) /    -0.34,  -26.28,    0.00 /
      DATA B(38944), B(38945), B(38946) /    -0.92,  -26.10,    0.00 /
      DATA B(39235), B(39236), B(39237) /    -1.43,  -25.92,    0.00 /
      DATA B(39526), B(39527), B(39528) /    -1.87,  -25.73,    0.00 /
      DATA B(39817), B(39818), B(39819) /    -2.26,  -25.53,    0.00 /
      DATA B(40108), B(40109), B(40110) /    -2.60,  -25.33,    0.00 /
      DATA B(40399), B(40400), B(40401) /    -2.89,  -25.13,    0.00 /
      DATA B(40690), B(40691), B(40692) /    -3.15,  -24.92,    0.00 /
      DATA B(40981), B(40982), B(40983) /    -3.38,  -24.71,    0.00 /
      DATA B(41272), B(41273), B(41274) /    -3.57,  -24.50,    0.00 /
      DATA B(41563), B(41564), B(41565) /    -3.74,  -24.28,    0.00 /
      DATA B(41854), B(41855), B(41856) /    -3.88,  -24.08,    0.00 /
      DATA B(42145), B(42146), B(42147) /    -4.00,  -23.89,    0.00 /
      DATA B(42436), B(42437), B(42438) /    -4.11,  -23.72,    0.00 /
      DATA B(42727), B(42728), B(42729) /    -4.21,  -23.55,    0.00 /
      DATA B(43018), B(43019), B(43020) /    -4.30,  -23.40,    0.00 /
      DATA B(43309), B(43310), B(43311) /    -4.39,  -23.26,    0.00 /
      DATA B(43600), B(43601), B(43602) /    -4.47,  -23.12,    0.00 /
      DATA B(43891), B(43892), B(43893) /    -4.55,  -22.98,    0.00 /
      DATA B(44182), B(44183), B(44184) /    -4.63,  -22.85,    0.00 /
      DATA B(44473), B(44474), B(44475) /    -4.70,  -22.72,    0.00 /
      DATA B(44764), B(44765), B(44766) /    -4.77,  -22.60,    0.00 /
      DATA B(45055), B(45056), B(45057) /    -4.84,  -22.47,    0.00 /
      DATA B(45346), B(45347), B(45348) /    -4.90,  -22.34,    0.00 /
      DATA B(45637), B(45638), B(45639) /    -4.96,  -22.21,    0.00 /
      DATA B(45928), B(45929), B(45930) /    -5.03,  -22.09,    0.00 /
      DATA B(46219), B(46220), B(46221) /    -5.09,  -21.95,    0.00 /
      DATA B(27598), B(27599), B(27600) /    25.43,  -41.09,    0.00 /
      DATA B(27889), B(27890), B(27891) /    25.39,  -41.02,    0.00 /
      DATA B(28180), B(28181), B(28182) /    25.34,  -40.95,    0.00 /
      DATA B(28471), B(28472), B(28473) /    25.28,  -40.88,    0.00 /
      DATA B(28762), B(28763), B(28764) /    25.22,  -40.81,    0.00 /
      DATA B(29053), B(29054), B(29055) /    25.14,  -40.73,    0.00 /
      DATA B(29344), B(29345), B(29346) /    25.05,  -40.65,    0.00 /
      DATA B(29635), B(29636), B(29637) /    24.94,  -40.56,    0.00 /
      DATA B(29926), B(29927), B(29928) /    24.81,  -40.46,    0.00 /
      DATA B(30217), B(30218), B(30219) /    24.65,  -40.35,    0.00 /
      DATA B(30508), B(30509), B(30510) /    24.43,  -40.23,    0.00 /
      DATA B(30799), B(30800), B(30801) /    24.16,  -40.07,    0.00 /
      DATA B(31090), B(31091), B(31092) /    23.79,  -39.85,    0.00 /
      DATA B(31381), B(31382), B(31383) /    25.85,  -40.06,    0.00 /
      DATA B(31672), B(31673), B(31674) /    25.08,  -39.24,    0.00 /
      DATA B(31963), B(31964), B(31965) /    24.45,  -38.53,    0.00 /
      DATA B(32254), B(32255), B(32256) /    23.70,  -38.49,    0.00 /
      DATA B(32545), B(32546), B(32547) /    22.97,  -38.39,    0.00 /
      DATA B(32836), B(32837), B(32838) /    22.24,  -38.18,    0.00 /
      DATA B(33127), B(33128), B(33129) /    21.39,  -37.79,    0.00 /
      DATA B(33418), B(33419), B(33420) /    20.32,  -37.09,    0.00 /
      DATA B(33709), B(33710), B(33711) /    16.61,  -34.05,    0.00 /
      DATA B(34000), B(34001), B(34002) /    15.53,  -33.27,    0.00 /
      DATA B(34291), B(34292), B(34293) /    14.55,  -32.33,    0.00 /
      DATA B(34582), B(34583), B(34584) /    13.62,  -31.53,    0.00 /
      DATA B(34873), B(34874), B(34875) /    12.80,  -30.84,    0.00 /
      DATA B(35164), B(35165), B(35166) /    12.07,  -30.29,    0.00 /
      DATA B(35455), B(35456), B(35457) /    11.42,  -29.85,    0.00 /
      DATA B(35746), B(35747), B(35748) /     7.14,  -26.79,    0.00 /
      DATA B(36037), B(36038), B(36039) /     6.22,  -26.70,    0.00 /
      DATA B(36328), B(36329), B(36330) /     5.31,  -26.64,    0.00 /
      DATA B(36619), B(36620), B(36621) /     4.41,  -26.63,    0.00 /
      DATA B(36910), B(36911), B(36912) /     3.51,  -26.67,    0.00 /
      DATA B(37201), B(37202), B(37203) /     2.60,  -26.78,    0.00 /
      DATA B(37492), B(37493), B(37494) /     1.13,  -26.48,    0.00 /
      DATA B(37783), B(37784), B(37785) /     0.48,  -26.29,    0.00 /
      DATA B(38074), B(38075), B(38076) /    -0.12,  -26.08,    0.00 /
      DATA B(38365), B(38366), B(38367) /    -0.70,  -25.92,    0.00 /
      DATA B(38656), B(38657), B(38658) /    -1.21,  -25.75,    0.00 /
      DATA B(38947), B(38948), B(38949) /    -1.65,  -25.57,    0.00 /
      DATA B(39238), B(39239), B(39240) /    -2.03,  -25.40,    0.00 /
      DATA B(39529), B(39530), B(39531) /    -2.37,  -25.22,    0.00 /
      DATA B(39820), B(39821), B(39822) /    -2.66,  -25.05,    0.00 /
      DATA B(40111), B(40112), B(40113) /    -2.92,  -24.88,    0.00 /
      DATA B(40402), B(40403), B(40404) /    -3.15,  -24.71,    0.00 /
      DATA B(40693), B(40694), B(40695) /    -3.35,  -24.54,    0.00 /
      DATA B(40984), B(40985), B(40986) /    -3.53,  -24.37,    0.00 /
      DATA B(41275), B(41276), B(41277) /    -3.70,  -24.19,    0.00 /
      DATA B(41566), B(41567), B(41568) /    -3.84,  -24.02,    0.00 /
      DATA B(41857), B(41858), B(41859) /    -3.96,  -23.85,    0.00 /
      DATA B(42148), B(42149), B(42150) /    -4.07,  -23.69,    0.00 /
      DATA B(42439), B(42440), B(42441) /    -4.17,  -23.53,    0.00 /
      DATA B(42730), B(42731), B(42732) /    -4.26,  -23.39,    0.00 /
      DATA B(43021), B(43022), B(43023) /    -4.34,  -23.25,    0.00 /
      DATA B(43312), B(43313), B(43314) /    -4.42,  -23.12,    0.00 /
      DATA B(43603), B(43604), B(43605) /    -4.50,  -22.99,    0.00 /
      DATA B(43894), B(43895), B(43896) /    -4.57,  -22.87,    0.00 /
      DATA B(44185), B(44186), B(44187) /    -4.64,  -22.74,    0.00 /
      DATA B(44476), B(44477), B(44478) /    -4.71,  -22.62,    0.00 /
      DATA B(44767), B(44768), B(44769) /    -4.78,  -22.50,    0.00 /
      DATA B(45058), B(45059), B(45060) /    -4.84,  -22.38,    0.00 /
      DATA B(45349), B(45350), B(45351) /    -4.90,  -22.26,    0.00 /
      DATA B(45640), B(45641), B(45642) /    -4.96,  -22.14,    0.00 /
      DATA B(45931), B(45932), B(45933) /    -5.02,  -22.01,    0.00 /
      DATA B(46222), B(46223), B(46224) /    -5.08,  -21.89,    0.00 /
      DATA B(27601), B(27602), B(27603) /    25.38,  -41.04,    0.00 /
      DATA B(27892), B(27893), B(27894) /    25.33,  -40.97,    0.00 /
      DATA B(28183), B(28184), B(28185) /    25.27,  -40.90,    0.00 /
      DATA B(28474), B(28475), B(28476) /    25.21,  -40.83,    0.00 /
      DATA B(28765), B(28766), B(28767) /    25.13,  -40.75,    0.00 /
      DATA B(29056), B(29057), B(29058) /    25.05,  -40.67,    0.00 /
      DATA B(29347), B(29348), B(29349) /    24.94,  -40.58,    0.00 /
      DATA B(29638), B(29639), B(29640) /    24.81,  -40.48,    0.00 /
      DATA B(29929), B(29930), B(29931) /    24.65,  -40.37,    0.00 /
      DATA B(30220), B(30221), B(30222) /    24.44,  -40.24,    0.00 /
      DATA B(30511), B(30512), B(30513) /    24.17,  -40.09,    0.00 /
      DATA B(30802), B(30803), B(30804) /    23.81,  -39.89,    0.00 /
      DATA B(31093), B(31094), B(31095) /    25.81,  -40.18,    0.00 /
      DATA B(31384), B(31385), B(31386) /    25.26,  -39.68,    0.00 /
      DATA B(31675), B(31676), B(31677) /    24.61,  -38.95,    0.00 /
      DATA B(31966), B(31967), B(31968) /    24.02,  -38.45,    0.00 /
      DATA B(32257), B(32258), B(32259) /    23.36,  -38.30,    0.00 /
      DATA B(32548), B(32549), B(32550) /    22.62,  -38.18,    0.00 /
      DATA B(32839), B(32840), B(32841) /    21.79,  -37.93,    0.00 /
      DATA B(33130), B(33131), B(33132) /    20.82,  -37.42,    0.00 /
      DATA B(33421), B(33422), B(33423) /    19.83,  -36.49,    0.00 /
      DATA B(33712), B(33713), B(33714) /    14.91,  -33.16,    0.00 /
      DATA B(34003), B(34004), B(34005) /    14.00,  -32.44,    0.00 /
      DATA B(34294), B(34295), B(34296) /    13.16,  -31.63,    0.00 /
      DATA B(34585), B(34586), B(34587) /    12.34,  -30.84,    0.00 /
      DATA B(34876), B(34877), B(34878) /    11.56,  -30.16,    0.00 /
      DATA B(35167), B(35168), B(35169) /    10.84,  -29.65,    0.00 /
      DATA B(35458), B(35459), B(35460) /     6.88,  -26.84,    0.00 /
      DATA B(35749), B(35750), B(35751) /     5.85,  -26.76,    0.00 /
      DATA B(36040), B(36041), B(36042) /     4.84,  -26.69,    0.00 /
      DATA B(36331), B(36332), B(36333) /     3.86,  -26.67,    0.00 /
      DATA B(36622), B(36623), B(36624) /     2.91,  -26.71,    0.00 /
      DATA B(36913), B(36914), B(36915) /     0.28,  -25.52,    0.00 /
      DATA B(37204), B(37205), B(37206) /     0.87,  -26.39,    0.00 /
      DATA B(37495), B(37496), B(37497) /    -0.03,  -25.97,    0.00 /
      DATA B(37786), B(37787), B(37788) /    -0.55,  -25.78,    0.00 /
      DATA B(38077), B(38078), B(38079) /    -1.02,  -25.59,    0.00 /
      DATA B(38368), B(38369), B(38370) /    -1.45,  -25.41,    0.00 /
      DATA B(38659), B(38660), B(38661) /    -1.83,  -25.25,    0.00 /
      DATA B(38950), B(38951), B(38952) /    -2.16,  -25.10,    0.00 /
      DATA B(39241), B(39242), B(39243) /    -2.45,  -24.95,    0.00 /
      DATA B(39532), B(39533), B(39534) /    -2.70,  -24.80,    0.00 /
      DATA B(39823), B(39824), B(39825) /    -2.93,  -24.66,    0.00 /
      DATA B(40114), B(40115), B(40116) /    -3.14,  -24.52,    0.00 /
      DATA B(40405), B(40406), B(40407) /    -3.32,  -24.37,    0.00 /
      DATA B(40696), B(40697), B(40698) /    -3.49,  -24.23,    0.00 /
      DATA B(40987), B(40988), B(40989) /    -3.64,  -24.09,    0.00 /
      DATA B(41278), B(41279), B(41280) /    -3.78,  -23.94,    0.00 /
      DATA B(41569), B(41570), B(41571) /    -3.90,  -23.79,    0.00 /
      DATA B(41860), B(41861), B(41862) /    -4.01,  -23.65,    0.00 /
      DATA B(42151), B(42152), B(42153) /    -4.11,  -23.51,    0.00 /
      DATA B(42442), B(42443), B(42444) /    -4.20,  -23.37,    0.00 /
      DATA B(42733), B(42734), B(42735) /    -4.29,  -23.24,    0.00 /
      DATA B(43024), B(43025), B(43026) /    -4.37,  -23.12,    0.00 /
      DATA B(43315), B(43316), B(43317) /    -4.44,  -22.99,    0.00 /
      DATA B(43606), B(43607), B(43608) /    -4.52,  -22.88,    0.00 /
      DATA B(43897), B(43898), B(43899) /    -4.58,  -22.76,    0.00 /
      DATA B(44188), B(44189), B(44190) /    -4.65,  -22.64,    0.00 /
      DATA B(44479), B(44480), B(44481) /    -4.72,  -22.53,    0.00 /
      DATA B(44770), B(44771), B(44772) /    -4.78,  -22.41,    0.00 /
      DATA B(45061), B(45062), B(45063) /    -4.84,  -22.30,    0.00 /
      DATA B(45352), B(45353), B(45354) /    -4.90,  -22.18,    0.00 /
      DATA B(45643), B(45644), B(45645) /    -4.96,  -22.06,    0.00 /
      DATA B(45934), B(45935), B(45936) /    -5.02,  -21.94,    0.00 /
      DATA B(46225), B(46226), B(46227) /    -5.07,  -21.82,    0.00 /
      DATA B(27604), B(27605), B(27606) /    25.32,  -40.99,    0.00 /
      DATA B(27895), B(27896), B(27897) /    25.27,  -40.92,    0.00 /
      DATA B(28186), B(28187), B(28188) /    25.20,  -40.85,    0.00 /
      DATA B(28477), B(28478), B(28479) /    25.13,  -40.77,    0.00 /
      DATA B(28768), B(28769), B(28770) /    25.05,  -40.69,    0.00 /
      DATA B(29059), B(29060), B(29061) /    24.94,  -40.59,    0.00 /
      DATA B(29350), B(29351), B(29352) /    24.82,  -40.49,    0.00 /
      DATA B(29641), B(29642), B(29643) /    24.66,  -40.38,    0.00 /
      DATA B(29932), B(29933), B(29934) /    24.46,  -40.25,    0.00 /
      DATA B(30223), B(30224), B(30225) /    24.21,  -40.11,    0.00 /
      DATA B(30514), B(30515), B(30516) /    23.87,  -39.92,    0.00 /
      DATA B(30805), B(30806), B(30807) /    25.80,  -40.29,    0.00 /
      DATA B(31096), B(31097), B(31098) /    25.31,  -39.88,    0.00 /
      DATA B(31387), B(31388), B(31389) /    24.76,  -39.31,    0.00 /
      DATA B(31678), B(31679), B(31680) /    24.19,  -38.72,    0.00 /
      DATA B(31969), B(31970), B(31971) /    23.61,  -38.33,    0.00 /
      DATA B(32260), B(32261), B(32262) /    22.98,  -38.15,    0.00 /
      DATA B(32551), B(32552), B(32553) /    22.24,  -37.98,    0.00 /
      DATA B(32842), B(32843), B(32844) /    21.36,  -37.63,    0.00 /
      DATA B(33133), B(33134), B(33135) /    20.24,  -36.96,    0.00 /
      DATA B(33424), B(33425), B(33426) /    14.41,  -32.84,    0.00 /
      DATA B(33715), B(33716), B(33717) /    13.43,  -32.46,    0.00 /
      DATA B(34006), B(34007), B(34008) /    12.63,  -31.88,    0.00 /
      DATA B(34297), B(34298), B(34299) /    11.85,  -31.04,    0.00 /
      DATA B(34588), B(34589), B(34590) /    10.99,  -30.14,    0.00 /
      DATA B(34879), B(34880), B(34881) /    10.07,  -29.44,    0.00 /
      DATA B(35170), B(35171), B(35172) /     6.69,  -26.93,    0.00 /
      DATA B(35461), B(35462), B(35463) /     5.47,  -26.78,    0.00 /
      DATA B(35752), B(35753), B(35754) /     4.35,  -26.71,    0.00 /
      DATA B(36043), B(36044), B(36045) /     3.28,  -26.68,    0.00 /
      DATA B(36334), B(36335), B(36336) /     0.88,  -25.60,    0.00 /
      DATA B(36625), B(36626), B(36627) /    -0.09,  -25.28,    0.00 /
      DATA B(36916), B(36917), B(36918) /     0.37,  -26.18,    0.00 /
      DATA B(37207), B(37208), B(37209) /    -0.46,  -25.68,    0.00 /
      DATA B(37498), B(37499), B(37500) /    -0.91,  -25.49,    0.00 /
      DATA B(37789), B(37790), B(37791) /    -1.31,  -25.30,    0.00 /
      DATA B(38080), B(38081), B(38082) /    -1.66,  -25.13,    0.00 /
      DATA B(38371), B(38372), B(38373) /    -1.98,  -24.97,    0.00 /
      DATA B(38662), B(38663), B(38664) /    -2.26,  -24.83,    0.00 /
      DATA B(38953), B(38954), B(38955) /    -2.51,  -24.70,    0.00 /
      DATA B(39244), B(39245), B(39246) /    -2.74,  -24.57,    0.00 /
      DATA B(39535), B(39536), B(39537) /    -2.94,  -24.45,    0.00 /
      DATA B(39826), B(39827), B(39828) /    -3.12,  -24.33,    0.00 /
      DATA B(40117), B(40118), B(40119) /    -3.29,  -24.21,    0.00 /
      DATA B(40408), B(40409), B(40410) /    -3.45,  -24.09,    0.00 /
      DATA B(40699), B(40700), B(40701) /    -3.59,  -23.97,    0.00 /
      DATA B(40990), B(40991), B(40992) /    -3.72,  -23.85,    0.00 /
      DATA B(41281), B(41282), B(41283) /    -3.84,  -23.72,    0.00 /
      DATA B(41572), B(41573), B(41574) /    -3.95,  -23.59,    0.00 /
      DATA B(41863), B(41864), B(41865) /    -4.05,  -23.47,    0.00 /
      DATA B(42154), B(42155), B(42156) /    -4.15,  -23.35,    0.00 /
      DATA B(42445), B(42446), B(42447) /    -4.23,  -23.22,    0.00 /
      DATA B(42736), B(42737), B(42738) /    -4.31,  -23.11,    0.00 /
      DATA B(43027), B(43028), B(43029) /    -4.38,  -22.99,    0.00 /
      DATA B(43318), B(43319), B(43320) /    -4.46,  -22.88,    0.00 /
      DATA B(43609), B(43610), B(43611) /    -4.52,  -22.77,    0.00 /
      DATA B(43900), B(43901), B(43902) /    -4.59,  -22.66,    0.00 /
      DATA B(44191), B(44192), B(44193) /    -4.66,  -22.55,    0.00 /
      DATA B(44482), B(44483), B(44484) /    -4.72,  -22.44,    0.00 /
      DATA B(44773), B(44774), B(44775) /    -4.78,  -22.33,    0.00 /
      DATA B(45064), B(45065), B(45066) /    -4.84,  -22.22,    0.00 /
      DATA B(45355), B(45356), B(45357) /    -4.89,  -22.11,    0.00 /
      DATA B(45646), B(45647), B(45648) /    -4.95,  -21.99,    0.00 /
      DATA B(45937), B(45938), B(45939) /    -5.00,  -21.88,    0.00 /
      DATA B(46228), B(46229), B(46230) /    -5.06,  -21.76,    0.00 /
      DATA B(27607), B(27608), B(27609) /    25.26,  -40.94,    0.00 /
      DATA B(27898), B(27899), B(27900) /    25.20,  -40.86,    0.00 /
      DATA B(28189), B(28190), B(28191) /    25.13,  -40.79,    0.00 /
      DATA B(28480), B(28481), B(28482) /    25.05,  -40.70,    0.00 /
      DATA B(28771), B(28772), B(28773) /    24.95,  -40.61,    0.00 /
      DATA B(29062), B(29063), B(29064) /    24.83,  -40.51,    0.00 /
      DATA B(29353), B(29354), B(29355) /    24.68,  -40.40,    0.00 /
      DATA B(29644), B(29645), B(29646) /    24.49,  -40.27,    0.00 /
      DATA B(29935), B(29936), B(29937) /    24.25,  -40.12,    0.00 /
      DATA B(30226), B(30227), B(30228) /    26.19,  -40.60,    0.00 /
      DATA B(30517), B(30518), B(30519) /    25.80,  -40.36,    0.00 /
      DATA B(30808), B(30809), B(30810) /    25.35,  -40.03,    0.00 /
      DATA B(31099), B(31100), B(31101) /    24.90,  -39.56,    0.00 /
      DATA B(31390), B(31391), B(31392) /    24.35,  -38.98,    0.00 /
      DATA B(31681), B(31682), B(31683) /    23.81,  -38.51,    0.00 /
      DATA B(31972), B(31973), B(31974) /    23.24,  -38.20,    0.00 /
      DATA B(32263), B(32264), B(32265) /    22.61,  -38.01,    0.00 /
      DATA B(32554), B(32555), B(32556) /    21.88,  -37.77,    0.00 /
      DATA B(32845), B(32846), B(32847) /    20.91,  -37.35,    0.00 /
      DATA B(33136), B(33137), B(33138) /    14.01,  -32.32,    0.00 /
      DATA B(33427), B(33428), B(33429) /    13.03,  -32.17,    0.00 /
      DATA B(33718), B(33719), B(33720) /    12.14,  -31.94,    0.00 /
      DATA B(34009), B(34010), B(34011) /    11.32,  -31.52,    0.00 /
      DATA B(34300), B(34301), B(34302) /    10.45,  -30.45,    0.00 /
      DATA B(34591), B(34592), B(34593) /     9.29,  -29.34,    0.00 /
      DATA B(34882), B(34883), B(34884) /     6.38,  -27.16,    0.00 /
      DATA B(35173), B(35174), B(35175) /     5.01,  -26.81,    0.00 /
      DATA B(35464), B(35465), B(35466) /     3.77,  -26.65,    0.00 /
      DATA B(35755), B(35756), B(35757) /     1.58,  -25.70,    0.00 /
      DATA B(36046), B(36047), B(36048) /     0.52,  -25.36,    0.00 /
      DATA B(36337), B(36338), B(36339) /    -0.42,  -25.04,    0.00 /
      DATA B(36628), B(36629), B(36630) /    -1.27,  -24.77,    0.00 /
      DATA B(36919), B(36920), B(36921) /    -0.81,  -25.44,    0.00 /
      DATA B(37210), B(37211), B(37212) /    -1.20,  -25.24,    0.00 /
      DATA B(37501), B(37502), B(37503) /    -1.54,  -25.05,    0.00 /
      DATA B(37792), B(37793), B(37794) /    -1.84,  -24.89,    0.00 /
      DATA B(38083), B(38084), B(38085) /    -2.10,  -24.74,    0.00 /
      DATA B(38374), B(38375), B(38376) /    -2.34,  -24.60,    0.00 /
      DATA B(38665), B(38666), B(38667) /    -2.56,  -24.48,    0.00 /
      DATA B(38956), B(38957), B(38958) /    -2.76,  -24.37,    0.00 /
      DATA B(39247), B(39248), B(39249) /    -2.94,  -24.27,    0.00 /
      DATA B(39538), B(39539), B(39540) /    -3.11,  -24.16,    0.00 /
      DATA B(39829), B(39830), B(39831) /    -3.26,  -24.06,    0.00 /
      DATA B(40120), B(40121), B(40122) /    -3.41,  -23.96,    0.00 /
      DATA B(40411), B(40412), B(40413) /    -3.54,  -23.86,    0.00 /
      DATA B(40702), B(40703), B(40704) /    -3.67,  -23.75,    0.00 /
      DATA B(40993), B(40994), B(40995) /    -3.78,  -23.64,    0.00 /
      DATA B(41284), B(41285), B(41286) /    -3.89,  -23.53,    0.00 /
      DATA B(41575), B(41576), B(41577) /    -3.99,  -23.42,    0.00 /
      DATA B(41866), B(41867), B(41868) /    -4.08,  -23.31,    0.00 /
      DATA B(42157), B(42158), B(42159) /    -4.17,  -23.20,    0.00 /
      DATA B(42448), B(42449), B(42450) /    -4.25,  -23.09,    0.00 /
      DATA B(42739), B(42740), B(42741) /    -4.32,  -22.98,    0.00 /
      DATA B(43030), B(43031), B(43032) /    -4.39,  -22.88,    0.00 /
      DATA B(43321), B(43322), B(43323) /    -4.46,  -22.77,    0.00 /
      DATA B(43612), B(43613), B(43614) /    -4.53,  -22.67,    0.00 /
      DATA B(43903), B(43904), B(43905) /    -4.59,  -22.56,    0.00 /
      DATA B(44194), B(44195), B(44196) /    -4.65,  -22.46,    0.00 /
      DATA B(44485), B(44486), B(44487) /    -4.71,  -22.35,    0.00 /
      DATA B(44776), B(44777), B(44778) /    -4.77,  -22.25,    0.00 /
      DATA B(45067), B(45068), B(45069) /    -4.83,  -22.14,    0.00 /
      DATA B(45358), B(45359), B(45360) /    -4.89,  -22.03,    0.00 /
      DATA B(45649), B(45650), B(45651) /    -4.94,  -21.93,    0.00 /
      DATA B(45940), B(45941), B(45942) /    -4.99,  -21.81,    0.00 /
      DATA B(46231), B(46232), B(46233) /    -5.04,  -21.70,    0.00 /
      DATA B(27610), B(27611), B(27612) /    25.19,  -40.88,    0.00 /
      DATA B(27901), B(27902), B(27903) /    25.12,  -40.80,    0.00 /
      DATA B(28192), B(28193), B(28194) /    25.04,  -40.71,    0.00 /
      DATA B(28483), B(28484), B(28485) /    24.95,  -40.62,    0.00 /
      DATA B(28774), B(28775), B(28776) /    24.83,  -40.52,    0.00 /
      DATA B(29065), B(29066), B(29067) /    24.69,  -40.41,    0.00 /
      DATA B(29356), B(29357), B(29358) /    24.51,  -40.28,    0.00 /
      DATA B(29647), B(29648), B(29649) /    24.29,  -40.14,    0.00 /
      DATA B(29938), B(29939), B(29940) /    26.13,  -40.62,    0.00 /
      DATA B(30229), B(30230), B(30231) /    25.77,  -40.42,    0.00 /
      DATA B(30520), B(30521), B(30522) /    25.37,  -40.14,    0.00 /
      DATA B(30811), B(30812), B(30813) /    24.93,  -39.74,    0.00 /
      DATA B(31102), B(31103), B(31104) /    24.46,  -39.20,    0.00 /
      DATA B(31393), B(31394), B(31395) /    23.97,  -38.69,    0.00 /
      DATA B(31684), B(31685), B(31686) /    23.46,  -38.31,    0.00 /
      DATA B(31975), B(31976), B(31977) /    22.92,  -38.06,    0.00 /
      DATA B(32266), B(32267), B(32268) /    22.31,  -37.85,    0.00 /
      DATA B(32557), B(32558), B(32559) /    21.60,  -37.59,    0.00 /
      DATA B(32848), B(32849), B(32850) /    13.52,  -31.68,    0.00 /
      DATA B(33139), B(33140), B(33141) /    12.82,  -31.69,    0.00 /
      DATA B(33430), B(33431), B(33432) /    12.03,  -31.55,    0.00 /
      DATA B(33721), B(33722), B(33723) /    11.03,  -31.47,    0.00 /
      DATA B(34012), B(34013), B(34014) /     9.91,  -31.33,    0.00 /
      DATA B(34303), B(34304), B(34305) /     8.64,  -29.65,    0.00 /
      DATA B(34594), B(34595), B(34596) /     5.92,  -27.44,    0.00 /
      DATA B(34885), B(34886), B(34887) /     3.68,  -26.45,    0.00 /
      DATA B(35176), B(35177), B(35178) /     2.35,  -25.88,    0.00 /
      DATA B(35467), B(35468), B(35469) /     1.22,  -25.44,    0.00 /
      DATA B(35758), B(35759), B(35760) /     0.20,  -25.09,    0.00 /
      DATA B(36049), B(36050), B(36051) /    -0.70,  -24.79,    0.00 /
      DATA B(36340), B(36341), B(36342) /    -1.50,  -24.52,    0.00 /
      DATA B(36631), B(36632), B(36633) /    -1.08,  -25.23,    0.00 /
      DATA B(36922), B(36923), B(36924) /    -1.43,  -25.02,    0.00 /
      DATA B(37213), B(37214), B(37215) /    -1.72,  -24.85,    0.00 /
      DATA B(37504), B(37505), B(37506) /    -1.98,  -24.69,    0.00 /
      DATA B(37795), B(37796), B(37797) /    -2.21,  -24.54,    0.00 /
      DATA B(38086), B(38087), B(38088) /    -2.42,  -24.42,    0.00 /
      DATA B(38377), B(38378), B(38379) /    -2.60,  -24.30,    0.00 /
      DATA B(38668), B(38669), B(38670) /    -2.78,  -24.20,    0.00 /
      DATA B(38959), B(38960), B(38961) /    -2.94,  -24.11,    0.00 /
      DATA B(39250), B(39251), B(39252) /    -3.09,  -24.01,    0.00 /
      DATA B(39541), B(39542), B(39543) /    -3.23,  -23.92,    0.00 /
      DATA B(39832), B(39833), B(39834) /    -3.37,  -23.84,    0.00 /
      DATA B(40123), B(40124), B(40125) /    -3.49,  -23.75,    0.00 /
      DATA B(40414), B(40415), B(40416) /    -3.61,  -23.65,    0.00 /
      DATA B(40705), B(40706), B(40707) /    -3.72,  -23.56,    0.00 /
      DATA B(40996), B(40997), B(40998) /    -3.83,  -23.47,    0.00 /
      DATA B(41287), B(41288), B(41289) /    -3.92,  -23.37,    0.00 /
      DATA B(41578), B(41579), B(41580) /    -4.02,  -23.27,    0.00 /
      DATA B(41869), B(41870), B(41871) /    -4.10,  -23.17,    0.00 /
      DATA B(42160), B(42161), B(42162) /    -4.18,  -23.07,    0.00 /
      DATA B(42451), B(42452), B(42453) /    -4.26,  -22.97,    0.00 /
      DATA B(42742), B(42743), B(42744) /    -4.33,  -22.87,    0.00 /
      DATA B(43033), B(43034), B(43035) /    -4.40,  -22.77,    0.00 /
      DATA B(43324), B(43325), B(43326) /    -4.46,  -22.67,    0.00 /
      DATA B(43615), B(43616), B(43617) /    -4.53,  -22.57,    0.00 /
      DATA B(43906), B(43907), B(43908) /    -4.59,  -22.47,    0.00 /
      DATA B(44197), B(44198), B(44199) /    -4.65,  -22.37,    0.00 /
      DATA B(44488), B(44489), B(44490) /    -4.71,  -22.27,    0.00 /
      DATA B(44779), B(44780), B(44781) /    -4.76,  -22.17,    0.00 /
      DATA B(45070), B(45071), B(45072) /    -4.82,  -22.07,    0.00 /
      DATA B(45361), B(45362), B(45363) /    -4.87,  -21.96,    0.00 /
      DATA B(45652), B(45653), B(45654) /    -4.93,  -21.86,    0.00 /
      DATA B(45943), B(45944), B(45945) /    -4.98,  -21.75,    0.00 /
      DATA B(46234), B(46235), B(46236) /    -5.03,  -21.64,    0.00 /
      DATA B(27613), B(27614), B(27615) /    25.12,  -40.81,    0.00 /
      DATA B(27904), B(27905), B(27906) /    25.04,  -40.72,    0.00 /
      DATA B(28195), B(28196), B(28197) /    24.95,  -40.63,    0.00 /
      DATA B(28486), B(28487), B(28488) /    24.83,  -40.53,    0.00 /
      DATA B(28777), B(28778), B(28779) /    24.69,  -40.42,    0.00 /
      DATA B(29068), B(29069), B(29070) /    24.52,  -40.30,    0.00 /
      DATA B(29359), B(29360), B(29361) /    24.31,  -40.16,    0.00 /
      DATA B(29650), B(29651), B(29652) /    26.05,  -40.64,    0.00 /
      DATA B(29941), B(29942), B(29943) /    25.73,  -40.46,    0.00 /
      DATA B(30232), B(30233), B(30234) /    25.36,  -40.22,    0.00 /
      DATA B(30523), B(30524), B(30525) /    24.95,  -39.88,    0.00 /
      DATA B(30814), B(30815), B(30816) /    24.68,  -39.46,    0.00 /
      DATA B(31105), B(31106), B(31107) /    24.08,  -38.88,    0.00 /
      DATA B(31396), B(31397), B(31398) /    23.61,  -38.45,    0.00 /
      DATA B(31687), B(31688), B(31689) /    23.14,  -38.13,    0.00 /
      DATA B(31978), B(31979), B(31980) /    22.64,  -37.90,    0.00 /
      DATA B(32269), B(32270), B(32271) /    22.13,  -37.68,    0.00 /
      DATA B(32560), B(32561), B(32562) /    21.76,  -37.50,    0.00 /
      DATA B(32851), B(32852), B(32853) /    12.62,  -31.19,    0.00 /
      DATA B(33142), B(33143), B(33144) /    12.03,  -31.15,    0.00 /
      DATA B(33433), B(33434), B(33435) /    11.34,  -31.02,    0.00 /
      DATA B(33724), B(33725), B(33726) /    10.46,  -30.92,    0.00 /
      DATA B(34015), B(34016), B(34017) /     8.93,  -31.01,    0.00 /
      DATA B(34306), B(34307), B(34308) /     4.31,  -27.40,    0.00 /
      DATA B(34597), B(34598), B(34599) /     2.91,  -26.30,    0.00 /
      DATA B(34888), B(34889), B(34890) /     1.77,  -25.67,    0.00 /
      DATA B(35179), B(35180), B(35181) /     0.76,  -25.20,    0.00 /
      DATA B(35470), B(35471), B(35472) /    -0.14,  -24.84,    0.00 /
      DATA B(35761), B(35762), B(35763) /    -0.96,  -24.55,    0.00 /
      DATA B(36052), B(36053), B(36054) /    -1.68,  -24.29,    0.00 /
      DATA B(36343), B(36344), B(36345) /    -1.31,  -25.04,    0.00 /
      DATA B(36634), B(36635), B(36636) /    -1.61,  -24.84,    0.00 /
      DATA B(36925), B(36926), B(36927) /    -1.86,  -24.67,    0.00 /
      DATA B(37216), B(37217), B(37218) /    -2.09,  -24.52,    0.00 /
      DATA B(37507), B(37508), B(37509) /    -2.29,  -24.39,    0.00 /
      DATA B(37798), B(37799), B(37800) /    -2.48,  -24.26,    0.00 /
      DATA B(38089), B(38090), B(38091) /    -2.64,  -24.16,    0.00 /
      DATA B(38380), B(38381), B(38382) /    -2.80,  -24.06,    0.00 /
      DATA B(38671), B(38672), B(38673) /    -2.94,  -23.97,    0.00 /
      DATA B(38962), B(38963), B(38964) /    -3.08,  -23.88,    0.00 /
      DATA B(39253), B(39254), B(39255) /    -3.21,  -23.80,    0.00 /
      DATA B(39544), B(39545), B(39546) /    -3.33,  -23.72,    0.00 /
      DATA B(39835), B(39836), B(39837) /    -3.45,  -23.64,    0.00 /
      DATA B(40126), B(40127), B(40128) /    -3.56,  -23.56,    0.00 /
      DATA B(40417), B(40418), B(40419) /    -3.66,  -23.48,    0.00 /
      DATA B(40708), B(40709), B(40710) /    -3.76,  -23.39,    0.00 /
      DATA B(40999), B(41000), B(41001) /    -3.86,  -23.31,    0.00 /
      DATA B(41290), B(41291), B(41292) /    -3.95,  -23.22,    0.00 /
      DATA B(41581), B(41582), B(41583) /    -4.03,  -23.13,    0.00 /
      DATA B(41872), B(41873), B(41874) /    -4.11,  -23.04,    0.00 /
      DATA B(42163), B(42164), B(42165) /    -4.19,  -22.94,    0.00 /
      DATA B(42454), B(42455), B(42456) /    -4.26,  -22.85,    0.00 /
      DATA B(42745), B(42746), B(42747) /    -4.33,  -22.76,    0.00 /
      DATA B(43036), B(43037), B(43038) /    -4.40,  -22.67,    0.00 /
      DATA B(43327), B(43328), B(43329) /    -4.46,  -22.57,    0.00 /
      DATA B(43618), B(43619), B(43620) /    -4.52,  -22.48,    0.00 /
      DATA B(43909), B(43910), B(43911) /    -4.58,  -22.38,    0.00 /
      DATA B(44200), B(44201), B(44202) /    -4.64,  -22.29,    0.00 /
      DATA B(44491), B(44492), B(44493) /    -4.70,  -22.19,    0.00 /
      DATA B(44782), B(44783), B(44784) /    -4.75,  -22.10,    0.00 /
      DATA B(45073), B(45074), B(45075) /    -4.81,  -22.00,    0.00 /
      DATA B(45364), B(45365), B(45366) /    -4.86,  -21.90,    0.00 /
      DATA B(45655), B(45656), B(45657) /    -4.91,  -21.79,    0.00 /
      DATA B(45946), B(45947), B(45948) /    -4.96,  -21.69,    0.00 /
      DATA B(46237), B(46238), B(46239) /    -5.01,  -21.58,    0.00 /
      DATA B(27616), B(27617), B(27618) /    25.04,  -40.73,    0.00 /
      DATA B(27907), B(27908), B(27909) /    24.94,  -40.64,    0.00 /
      DATA B(28198), B(28199), B(28200) /    24.83,  -40.53,    0.00 /
      DATA B(28489), B(28490), B(28491) /    24.69,  -40.42,    0.00 /
      DATA B(28780), B(28781), B(28782) /    24.52,  -40.31,    0.00 /
      DATA B(29071), B(29072), B(29073) /    26.20,  -40.81,    0.00 /
      DATA B(29362), B(29363), B(29364) /    25.95,  -40.67,    0.00 /
      DATA B(29653), B(29654), B(29655) /    25.67,  -40.49,    0.00 /
      DATA B(29944), B(29945), B(29946) /    25.34,  -40.28,    0.00 /
      DATA B(30235), B(30236), B(30237) /    24.94,  -39.99,    0.00 /
      DATA B(30526), B(30527), B(30528) /    24.54,  -39.59,    0.00 /
      DATA B(30817), B(30818), B(30819) /    24.11,  -39.08,    0.00 /
      DATA B(31108), B(31109), B(31110) /    23.69,  -38.60,    0.00 /
      DATA B(31399), B(31400), B(31401) /    23.26,  -38.23,    0.00 /
      DATA B(31690), B(31691), B(31692) /    22.84,  -37.95,    0.00 /
      DATA B(31981), B(31982), B(31983) /    22.41,  -37.72,    0.00 /
      DATA B(32272), B(32273), B(32274) /    21.93,  -37.59,    0.00 /
      DATA B(32563), B(32564), B(32565) /    12.41,  -30.68,    0.00 /
      DATA B(32854), B(32855), B(32856) /    11.92,  -30.79,    0.00 /
      DATA B(33145), B(33146), B(33147) /    11.42,  -30.71,    0.00 /
      DATA B(33436), B(33437), B(33438) /    10.88,  -30.60,    0.00 /
      DATA B(33727), B(33728), B(33729) /    10.42,  -30.59,    0.00 /
      DATA B(34018), B(34019), B(34020) /     1.25,  -25.73,    0.00 /
      DATA B(34309), B(34310), B(34311) /     0.97,  -26.58,    0.00 /
      DATA B(34600), B(34601), B(34602) /     0.69,  -25.63,    0.00 /
      DATA B(34891), B(34892), B(34893) /     0.11,  -25.05,    0.00 /
      DATA B(35182), B(35183), B(35184) /    -0.56,  -24.64,    0.00 /
      DATA B(35473), B(35474), B(35475) /    -1.23,  -24.33,    0.00 /
      DATA B(35764), B(35765), B(35766) /    -1.86,  -24.08,    0.00 /
      DATA B(36055), B(36056), B(36057) /    -1.51,  -24.87,    0.00 /
      DATA B(36346), B(36347), B(36348) /    -1.76,  -24.69,    0.00 /
      DATA B(36637), B(36638), B(36639) /    -1.99,  -24.53,    0.00 /
      DATA B(36928), B(36929), B(36930) /    -2.18,  -24.38,    0.00 /
      DATA B(37219), B(37220), B(37221) /    -2.36,  -24.25,    0.00 /
      DATA B(37510), B(37511), B(37512) /    -2.52,  -24.14,    0.00 /
      DATA B(37801), B(37802), B(37803) /    -2.67,  -24.03,    0.00 /
      DATA B(38092), B(38093), B(38094) /    -2.81,  -23.94,    0.00 /
      DATA B(38383), B(38384), B(38385) /    -2.94,  -23.85,    0.00 /
      DATA B(38674), B(38675), B(38676) /    -3.06,  -23.77,    0.00 /
      DATA B(38965), B(38966), B(38967) /    -3.18,  -23.69,    0.00 /
      DATA B(39256), B(39257), B(39258) /    -3.29,  -23.62,    0.00 /
      DATA B(39547), B(39548), B(39549) /    -3.40,  -23.55,    0.00 /
      DATA B(39838), B(39839), B(39840) /    -3.51,  -23.47,    0.00 /
      DATA B(40129), B(40130), B(40131) /    -3.61,  -23.40,    0.00 /
      DATA B(40420), B(40421), B(40422) /    -3.70,  -23.32,    0.00 /
      DATA B(40711), B(40712), B(40713) /    -3.79,  -23.25,    0.00 /
      DATA B(41002), B(41003), B(41004) /    -3.88,  -23.17,    0.00 /
      DATA B(41293), B(41294), B(41295) /    -3.96,  -23.09,    0.00 /
      DATA B(41584), B(41585), B(41586) /    -4.04,  -23.00,    0.00 /
      DATA B(41875), B(41876), B(41877) /    -4.12,  -22.92,    0.00 /
      DATA B(42166), B(42167), B(42168) /    -4.19,  -22.83,    0.00 /
      DATA B(42457), B(42458), B(42459) /    -4.26,  -22.74,    0.00 /
      DATA B(42748), B(42749), B(42750) /    -4.33,  -22.66,    0.00 /
      DATA B(43039), B(43040), B(43041) /    -4.39,  -22.57,    0.00 /
      DATA B(43330), B(43331), B(43332) /    -4.45,  -22.48,    0.00 /
      DATA B(43621), B(43622), B(43623) /    -4.51,  -22.39,    0.00 /
      DATA B(43912), B(43913), B(43914) /    -4.57,  -22.30,    0.00 /
      DATA B(44203), B(44204), B(44205) /    -4.63,  -22.21,    0.00 /
      DATA B(44494), B(44495), B(44496) /    -4.69,  -22.12,    0.00 /
      DATA B(44785), B(44786), B(44787) /    -4.74,  -22.02,    0.00 /
      DATA B(45076), B(45077), B(45078) /    -4.79,  -21.93,    0.00 /
      DATA B(45367), B(45368), B(45369) /    -4.84,  -21.83,    0.00 /
      DATA B(45658), B(45659), B(45660) /    -4.89,  -21.73,    0.00 /
      DATA B(45949), B(45950), B(45951) /    -4.94,  -21.63,    0.00 /
      DATA B(46240), B(46241), B(46242) /    -4.99,  -21.52,    0.00 /
      DATA B(27619), B(27620), B(27621) /    24.94,  -40.63,    0.00 /
      DATA B(27910), B(27911), B(27912) /    24.83,  -40.53,    0.00 /
      DATA B(28201), B(28202), B(28203) /    24.69,  -40.42,    0.00 /
      DATA B(28492), B(28493), B(28494) /    24.52,  -40.31,    0.00 /
      DATA B(28783), B(28784), B(28785) /    26.07,  -40.80,    0.00 /
      DATA B(29074), B(29075), B(29076) /    25.84,  -40.67,    0.00 /
      DATA B(29365), B(29366), B(29367) /    25.58,  -40.52,    0.00 /
      DATA B(29656), B(29657), B(29658) /    25.28,  -40.32,    0.00 /
      DATA B(29947), B(29948), B(29949) /    24.92,  -40.07,    0.00 /
      DATA B(30238), B(30239), B(30240) /    24.50,  -39.72,    0.00 /
      DATA B(30529), B(30530), B(30531) /    24.05,  -39.27,    0.00 /
      DATA B(30820), B(30821), B(30822) /    23.69,  -38.78,    0.00 /
      DATA B(31111), B(31112), B(31113) /    23.29,  -38.36,    0.00 /
      DATA B(31402), B(31403), B(31404) /    22.89,  -38.04,    0.00 /
      DATA B(31693), B(31694), B(31695) /    22.51,  -37.76,    0.00 /
      DATA B(31984), B(31985), B(31986) /    22.16,  -37.52,    0.00 /
      DATA B(32275), B(32276), B(32277) /    12.24,  -30.25,    0.00 /
      DATA B(32566), B(32567), B(32568) /    11.82,  -30.38,    0.00 /
      DATA B(32857), B(32858), B(32859) /    11.34,  -30.39,    0.00 /
      DATA B(33148), B(33149), B(33150) /    10.85,  -30.32,    0.00 /
      DATA B(33439), B(33440), B(33441) /    10.37,  -30.26,    0.00 /
      DATA B(33730), B(33731), B(33732) /     0.83,  -24.79,    0.00 /
      DATA B(34021), B(34022), B(34023) /     0.51,  -25.33,    0.00 /
      DATA B(34312), B(34313), B(34314) /    -0.14,  -25.64,    0.00 /
      DATA B(34603), B(34604), B(34605) /    -0.65,  -25.08,    0.00 /
      DATA B(34894), B(34895), B(34896) /    -1.07,  -24.56,    0.00 /
      DATA B(35185), B(35186), B(35187) /    -1.55,  -24.19,    0.00 /
      DATA B(35476), B(35477), B(35478) /    -1.50,  -24.95,    0.00 /
      DATA B(35767), B(35768), B(35769) /    -1.72,  -24.74,    0.00 /
      DATA B(36058), B(36059), B(36060) /    -1.91,  -24.56,    0.00 /
      DATA B(36349), B(36350), B(36351) /    -2.10,  -24.41,    0.00 /
      DATA B(36640), B(36641), B(36642) /    -2.27,  -24.27,    0.00 /
      DATA B(36931), B(36932), B(36933) /    -2.42,  -24.14,    0.00 /
      DATA B(37222), B(37223), B(37224) /    -2.57,  -24.03,    0.00 /
      DATA B(37513), B(37514), B(37515) /    -2.70,  -23.93,    0.00 /
      DATA B(37804), B(37805), B(37806) /    -2.82,  -23.84,    0.00 /
      DATA B(38095), B(38096), B(38097) /    -2.94,  -23.75,    0.00 /
      DATA B(38386), B(38387), B(38388) /    -3.05,  -23.67,    0.00 /
      DATA B(38677), B(38678), B(38679) /    -3.16,  -23.60,    0.00 /
      DATA B(38968), B(38969), B(38970) /    -3.26,  -23.53,    0.00 /
      DATA B(39259), B(39260), B(39261) /    -3.36,  -23.46,    0.00 /
      DATA B(39550), B(39551), B(39552) /    -3.46,  -23.39,    0.00 /
      DATA B(39841), B(39842), B(39843) /    -3.55,  -23.32,    0.00 /
      DATA B(40132), B(40133), B(40134) /    -3.64,  -23.26,    0.00 /
      DATA B(40423), B(40424), B(40425) /    -3.73,  -23.19,    0.00 /
      DATA B(40714), B(40715), B(40716) /    -3.81,  -23.11,    0.00 /
      DATA B(41005), B(41006), B(41007) /    -3.90,  -23.04,    0.00 /
      DATA B(41296), B(41297), B(41298) /    -3.97,  -22.96,    0.00 /
      DATA B(41587), B(41588), B(41589) /    -4.05,  -22.89,    0.00 /
      DATA B(41878), B(41879), B(41880) /    -4.12,  -22.81,    0.00 /
      DATA B(42169), B(42170), B(42171) /    -4.19,  -22.73,    0.00 /
      DATA B(42460), B(42461), B(42462) /    -4.26,  -22.64,    0.00 /
      DATA B(42751), B(42752), B(42753) /    -4.32,  -22.56,    0.00 /
      DATA B(43042), B(43043), B(43044) /    -4.39,  -22.48,    0.00 /
      DATA B(43333), B(43334), B(43335) /    -4.45,  -22.39,    0.00 /
      DATA B(43624), B(43625), B(43626) /    -4.50,  -22.31,    0.00 /
      DATA B(43915), B(43916), B(43917) /    -4.56,  -22.22,    0.00 /
      DATA B(44206), B(44207), B(44208) /    -4.62,  -22.13,    0.00 /
      DATA B(44497), B(44498), B(44499) /    -4.67,  -22.04,    0.00 /
      DATA B(44788), B(44789), B(44790) /    -4.72,  -21.95,    0.00 /
      DATA B(45079), B(45080), B(45081) /    -4.78,  -21.86,    0.00 /
      DATA B(45370), B(45371), B(45372) /    -4.83,  -21.76,    0.00 /
      DATA B(45661), B(45662), B(45663) /    -4.88,  -21.67,    0.00 /
      DATA B(45952), B(45953), B(45954) /    -4.92,  -21.57,    0.00 /
      DATA B(46243), B(46244), B(46245) /    -4.97,  -21.46,    0.00 /
      DATA B(27622), B(27623), B(27624) /    24.82,  -40.53,    0.00 /
      DATA B(27913), B(27914), B(27915) /    24.68,  -40.42,    0.00 /
      DATA B(28204), B(28205), B(28206) /    24.51,  -40.30,    0.00 /
      DATA B(28495), B(28496), B(28497) /    25.93,  -40.78,    0.00 /
      DATA B(28786), B(28787), B(28788) /    25.71,  -40.67,    0.00 /
      DATA B(29077), B(29078), B(29079) /    25.47,  -40.53,    0.00 /
      DATA B(29368), B(29369), B(29370) /    25.19,  -40.36,    0.00 /
      DATA B(29659), B(29660), B(29661) /    24.86,  -40.13,    0.00 /
      DATA B(29950), B(29951), B(29952) /    24.47,  -39.83,    0.00 /
      DATA B(30241), B(30242), B(30243) /    24.05,  -39.45,    0.00 /
      DATA B(30532), B(30533), B(30534) /    23.61,  -38.96,    0.00 /
      DATA B(30823), B(30824), B(30825) /    23.24,  -38.52,    0.00 /
      DATA B(31114), B(31115), B(31116) /    22.86,  -38.15,    0.00 /
      DATA B(31405), B(31406), B(31407) /    22.48,  -37.83,    0.00 /
      DATA B(31696), B(31697), B(31698) /    22.10,  -37.53,    0.00 /
      DATA B(31987), B(31988), B(31989) /    12.29,  -30.05,    0.00 /
      DATA B(32278), B(32279), B(32280) /    11.80,  -30.01,    0.00 /
      DATA B(32569), B(32570), B(32571) /    11.28,  -30.04,    0.00 /
      DATA B(32860), B(32861), B(32862) /    10.74,  -30.01,    0.00 /
      DATA B(33151), B(33152), B(33153) /     1.34,  -24.46,    0.00 /
      DATA B(33442), B(33443), B(33444) /     0.69,  -24.36,    0.00 /
      DATA B(33733), B(33734), B(33735) /     0.17,  -24.42,    0.00 /
      DATA B(34024), B(34025), B(34026) /    -0.31,  -24.70,    0.00 /
      DATA B(34315), B(34316), B(34317) /    -0.90,  -24.80,    0.00 /
      DATA B(34606), B(34607), B(34608) /    -1.43,  -24.51,    0.00 /
      DATA B(34897), B(34898), B(34899) /    -1.86,  -24.13,    0.00 /
      DATA B(35188), B(35189), B(35190) /    -1.82,  -24.89,    0.00 /
      DATA B(35479), B(35480), B(35481) /    -1.94,  -24.66,    0.00 /
      DATA B(35770), B(35771), B(35772) /    -2.07,  -24.47,    0.00 /
      DATA B(36061), B(36062), B(36063) /    -2.21,  -24.31,    0.00 /
      DATA B(36352), B(36353), B(36354) /    -2.35,  -24.18,    0.00 /
      DATA B(36643), B(36644), B(36645) /    -2.48,  -24.06,    0.00 /
      DATA B(36934), B(36935), B(36936) /    -2.60,  -23.95,    0.00 /
      DATA B(37225), B(37226), B(37227) /    -2.72,  -23.85,    0.00 /
      DATA B(37516), B(37517), B(37518) /    -2.83,  -23.76,    0.00 /
      DATA B(37807), B(37808), B(37809) /    -2.94,  -23.67,    0.00 /
      DATA B(38098), B(38099), B(38100) /    -3.04,  -23.59,    0.00 /
      DATA B(38389), B(38390), B(38391) /    -3.14,  -23.52,    0.00 /
      DATA B(38680), B(38681), B(38682) /    -3.23,  -23.45,    0.00 /
      DATA B(38971), B(38972), B(38973) /    -3.32,  -23.38,    0.00 /
      DATA B(39262), B(39263), B(39264) /    -3.41,  -23.32,    0.00 /
      DATA B(39553), B(39554), B(39555) /    -3.50,  -23.26,    0.00 /
      DATA B(39844), B(39845), B(39846) /    -3.59,  -23.19,    0.00 /
      DATA B(40135), B(40136), B(40137) /    -3.67,  -23.13,    0.00 /
      DATA B(40426), B(40427), B(40428) /    -3.75,  -23.06,    0.00 /
      DATA B(40717), B(40718), B(40719) /    -3.83,  -22.99,    0.00 /
      DATA B(41008), B(41009), B(41010) /    -3.91,  -22.92,    0.00 /
      DATA B(41299), B(41300), B(41301) /    -3.98,  -22.85,    0.00 /
      DATA B(41590), B(41591), B(41592) /    -4.05,  -22.78,    0.00 /
      DATA B(41881), B(41882), B(41883) /    -4.12,  -22.70,    0.00 /
      DATA B(42172), B(42173), B(42174) /    -4.19,  -22.63,    0.00 /
      DATA B(42463), B(42464), B(42465) /    -4.25,  -22.55,    0.00 /
      DATA B(42754), B(42755), B(42756) /    -4.31,  -22.47,    0.00 /
      DATA B(43045), B(43046), B(43047) /    -4.38,  -22.39,    0.00 /
      DATA B(43336), B(43337), B(43338) /    -4.43,  -22.31,    0.00 /
      DATA B(43627), B(43628), B(43629) /    -4.49,  -22.23,    0.00 /
      DATA B(43918), B(43919), B(43920) /    -4.55,  -22.14,    0.00 /
      DATA B(44209), B(44210), B(44211) /    -4.60,  -22.06,    0.00 /
      DATA B(44500), B(44501), B(44502) /    -4.66,  -21.97,    0.00 /
      DATA B(44791), B(44792), B(44793) /    -4.71,  -21.88,    0.00 /
      DATA B(45082), B(45083), B(45084) /    -4.76,  -21.79,    0.00 /
      DATA B(45373), B(45374), B(45375) /    -4.81,  -21.70,    0.00 /
      DATA B(45664), B(45665), B(45666) /    -4.86,  -21.61,    0.00 /
      DATA B(45955), B(45956), B(45957) /    -4.90,  -21.51,    0.00 /
      DATA B(46246), B(46247), B(46248) /    -4.95,  -21.41,    0.00 /
      DATA B(27625), B(27626), B(27627) /    24.67,  -40.41,    0.00 /
      DATA B(27916), B(27917), B(27918) /    25.97,  -40.85,    0.00 /
      DATA B(28207), B(28208), B(28209) /    25.79,  -40.76,    0.00 /
      DATA B(28498), B(28499), B(28500) /    25.58,  -40.65,    0.00 /
      DATA B(28789), B(28790), B(28791) /    25.35,  -40.52,    0.00 /
      DATA B(29080), B(29081), B(29082) /    25.08,  -40.36,    0.00 /
      DATA B(29371), B(29372), B(29373) /    24.77,  -40.16,    0.00 /
      DATA B(29662), B(29663), B(29664) /    24.39,  -39.91,    0.00 /
      DATA B(29953), B(29954), B(29955) /    24.00,  -39.59,    0.00 /
      DATA B(30244), B(30245), B(30246) /    23.52,  -39.16,    0.00 /
      DATA B(30535), B(30536), B(30537) /    23.13,  -38.73,    0.00 /
      DATA B(30826), B(30827), B(30828) /    22.77,  -38.32,    0.00 /
      DATA B(31117), B(31118), B(31119) /    22.40,  -37.94,    0.00 /
      DATA B(31408), B(31409), B(31410) /    22.00,  -37.58,    0.00 /
      DATA B(31699), B(31700), B(31701) /    21.56,  -37.23,    0.00 /
      DATA B(31990), B(31991), B(31992) /    11.79,  -29.82,    0.00 /
      DATA B(32281), B(32282), B(32283) /    11.23,  -29.72,    0.00 /
      DATA B(32572), B(32573), B(32574) /    10.64,  -29.69,    0.00 /
      DATA B(32863), B(32864), B(32865) /     1.36,  -24.15,    0.00 /
      DATA B(33154), B(33155), B(33156) /     0.65,  -24.02,    0.00 /
      DATA B(33445), B(33446), B(33447) /     0.04,  -23.95,    0.00 /
      DATA B(33736), B(33737), B(33738) /    -0.47,  -24.01,    0.00 /
      DATA B(34027), B(34028), B(34029) /    -0.96,  -24.14,    0.00 /
      DATA B(34318), B(34319), B(34320) /    -1.48,  -24.17,    0.00 /
      DATA B(34609), B(34610), B(34611) /    -1.97,  -24.00,    0.00 /
      DATA B(34900), B(34901), B(34902) /    -2.04,  -24.85,    0.00 /
      DATA B(35191), B(35192), B(35193) /    -2.13,  -24.61,    0.00 /
      DATA B(35482), B(35483), B(35484) /    -2.23,  -24.41,    0.00 /
      DATA B(35773), B(35774), B(35775) /    -2.33,  -24.25,    0.00 /
      DATA B(36064), B(36065), B(36066) /    -2.43,  -24.11,    0.00 /
      DATA B(36355), B(36356), B(36357) /    -2.54,  -23.99,    0.00 /
      DATA B(36646), B(36647), B(36648) /    -2.64,  -23.88,    0.00 /
      DATA B(36937), B(36938), B(36939) /    -2.74,  -23.78,    0.00 /
      DATA B(37228), B(37229), B(37230) /    -2.84,  -23.69,    0.00 /
      DATA B(37519), B(37520), B(37521) /    -2.94,  -23.60,    0.00 /
      DATA B(37810), B(37811), B(37812) /    -3.03,  -23.53,    0.00 /
      DATA B(38101), B(38102), B(38103) /    -3.12,  -23.45,    0.00 /
      DATA B(38392), B(38393), B(38394) /    -3.20,  -23.38,    0.00 /
      DATA B(38683), B(38684), B(38685) /    -3.29,  -23.32,    0.00 /
      DATA B(38974), B(38975), B(38976) /    -3.37,  -23.26,    0.00 /
      DATA B(39265), B(39266), B(39267) /    -3.45,  -23.19,    0.00 /
      DATA B(39556), B(39557), B(39558) /    -3.53,  -23.13,    0.00 /
      DATA B(39847), B(39848), B(39849) /    -3.61,  -23.07,    0.00 /
      DATA B(40138), B(40139), B(40140) /    -3.69,  -23.01,    0.00 /
      DATA B(40429), B(40430), B(40431) /    -3.76,  -22.94,    0.00 /
      DATA B(40720), B(40721), B(40722) /    -3.84,  -22.88,    0.00 /
      DATA B(41011), B(41012), B(41013) /    -3.91,  -22.81,    0.00 /
      DATA B(41302), B(41303), B(41304) /    -3.98,  -22.74,    0.00 /
      DATA B(41593), B(41594), B(41595) /    -4.05,  -22.68,    0.00 /
      DATA B(41884), B(41885), B(41886) /    -4.12,  -22.60,    0.00 /
      DATA B(42175), B(42176), B(42177) /    -4.18,  -22.53,    0.00 /
      DATA B(42466), B(42467), B(42468) /    -4.24,  -22.46,    0.00 /
      DATA B(42757), B(42758), B(42759) /    -4.30,  -22.38,    0.00 /
      DATA B(43048), B(43049), B(43050) /    -4.36,  -22.31,    0.00 /
      DATA B(43339), B(43340), B(43341) /    -4.42,  -22.23,    0.00 /
      DATA B(43630), B(43631), B(43632) /    -4.48,  -22.15,    0.00 /
      DATA B(43921), B(43922), B(43923) /    -4.53,  -22.07,    0.00 /
      DATA B(44212), B(44213), B(44214) /    -4.59,  -21.99,    0.00 /
      DATA B(44503), B(44504), B(44505) /    -4.64,  -21.90,    0.00 /
      DATA B(44794), B(44795), B(44796) /    -4.69,  -21.82,    0.00 /
      DATA B(45085), B(45086), B(45087) /    -4.74,  -21.73,    0.00 /
      DATA B(45376), B(45377), B(45378) /    -4.79,  -21.64,    0.00 /
      DATA B(45667), B(45668), B(45669) /    -4.84,  -21.54,    0.00 /
      DATA B(45958), B(45959), B(45960) /    -4.88,  -21.45,    0.00 /
      DATA B(46249), B(46250), B(46251) /    -4.93,  -21.35,    0.00 /
      DATA B(27628), B(27629), B(27630) /    25.82,  -40.81,    0.00 /
      DATA B(27919), B(27920), B(27921) /    25.64,  -40.72,    0.00 /
      DATA B(28210), B(28211), B(28212) /    25.44,  -40.61,    0.00 /
      DATA B(28501), B(28502), B(28503) /    25.22,  -40.49,    0.00 /
      DATA B(28792), B(28793), B(28794) /    24.97,  -40.35,    0.00 /
      DATA B(29083), B(29084), B(29085) /    24.66,  -40.16,    0.00 /
      DATA B(29374), B(29375), B(29376) /    24.30,  -39.93,    0.00 /
      DATA B(29665), B(29666), B(29667) /    24.07,  -39.74,    0.00 /
      DATA B(29956), B(29957), B(29958) /    23.43,  -39.29,    0.00 /
      DATA B(30247), B(30248), B(30249) /    23.02,  -38.93,    0.00 /
      DATA B(30538), B(30539), B(30540) /    22.66,  -38.54,    0.00 /
      DATA B(30829), B(30830), B(30831) /    22.29,  -38.12,    0.00 /
      DATA B(31120), B(31121), B(31122) /    21.88,  -37.69,    0.00 /
      DATA B(31411), B(31412), B(31413) /    21.43,  -37.25,    0.00 /
      DATA B(31702), B(31703), B(31704) /    11.78,  -29.75,    0.00 /
      DATA B(31993), B(31994), B(31995) /    11.17,  -29.52,    0.00 /
      DATA B(32284), B(32285), B(32286) /    10.54,  -29.39,    0.00 /
      DATA B(32575), B(32576), B(32577) /     1.40,  -23.87,    0.00 /
      DATA B(32866), B(32867), B(32868) /     0.67,  -23.72,    0.00 /
      DATA B(33157), B(33158), B(33159) /     0.02,  -23.62,    0.00 /
      DATA B(33448), B(33449), B(33450) /    -0.53,  -23.59,    0.00 /
      DATA B(33739), B(33740), B(33741) /    -1.01,  -23.62,    0.00 /
      DATA B(34030), B(34031), B(34032) /    -1.47,  -23.68,    0.00 /
      DATA B(34321), B(34322), B(34323) /    -1.95,  -23.69,    0.00 /
      DATA B(34612), B(34613), B(34614) /    -2.13,  -24.71,    0.00 /
      DATA B(34903), B(34904), B(34905) /    -2.26,  -24.55,    0.00 /
      DATA B(35194), B(35195), B(35196) /    -2.35,  -24.37,    0.00 /
      DATA B(35485), B(35486), B(35487) /    -2.43,  -24.21,    0.00 /
      DATA B(35776), B(35777), B(35778) /    -2.51,  -24.06,    0.00 /
      DATA B(36067), B(36068), B(36069) /    -2.60,  -23.93,    0.00 /
      DATA B(36358), B(36359), B(36360) /    -2.68,  -23.82,    0.00 /
      DATA B(36649), B(36650), B(36651) /    -2.77,  -23.72,    0.00 /
      DATA B(36940), B(36941), B(36942) /    -2.85,  -23.63,    0.00 /
      DATA B(37231), B(37232), B(37233) /    -2.93,  -23.55,    0.00 /
      DATA B(37522), B(37523), B(37524) /    -3.02,  -23.47,    0.00 /
      DATA B(37813), B(37814), B(37815) /    -3.10,  -23.40,    0.00 /
      DATA B(38104), B(38105), B(38106) /    -3.18,  -23.33,    0.00 /
      DATA B(38395), B(38396), B(38397) /    -3.25,  -23.26,    0.00 /
      DATA B(38686), B(38687), B(38688) /    -3.33,  -23.20,    0.00 /
      DATA B(38977), B(38978), B(38979) /    -3.41,  -23.14,    0.00 /
      DATA B(39268), B(39269), B(39270) /    -3.48,  -23.08,    0.00 /
      DATA B(39559), B(39560), B(39561) /    -3.56,  -23.02,    0.00 /
      DATA B(39850), B(39851), B(39852) /    -3.63,  -22.96,    0.00 /
      DATA B(40141), B(40142), B(40143) /    -3.70,  -22.90,    0.00 /
      DATA B(40432), B(40433), B(40434) /    -3.77,  -22.84,    0.00 /
      DATA B(40723), B(40724), B(40725) /    -3.84,  -22.77,    0.00 /
      DATA B(41014), B(41015), B(41016) /    -3.91,  -22.71,    0.00 /
      DATA B(41305), B(41306), B(41307) /    -3.98,  -22.65,    0.00 /
      DATA B(41596), B(41597), B(41598) /    -4.04,  -22.58,    0.00 /
      DATA B(41887), B(41888), B(41889) /    -4.11,  -22.51,    0.00 /
      DATA B(42178), B(42179), B(42180) /    -4.17,  -22.44,    0.00 /
      DATA B(42469), B(42470), B(42471) /    -4.23,  -22.37,    0.00 /
      DATA B(42760), B(42761), B(42762) /    -4.29,  -22.30,    0.00 /
      DATA B(43051), B(43052), B(43053) /    -4.35,  -22.22,    0.00 /
      DATA B(43342), B(43343), B(43344) /    -4.41,  -22.15,    0.00 /
      DATA B(43633), B(43634), B(43635) /    -4.46,  -22.07,    0.00 /
      DATA B(43924), B(43925), B(43926) /    -4.52,  -22.00,    0.00 /
      DATA B(44215), B(44216), B(44217) /    -4.57,  -21.92,    0.00 /
      DATA B(44506), B(44507), B(44508) /    -4.62,  -21.83,    0.00 /
      DATA B(44797), B(44798), B(44799) /    -4.67,  -21.75,    0.00 /
      DATA B(45088), B(45089), B(45090) /    -4.72,  -21.66,    0.00 /
      DATA B(45379), B(45380), B(45381) /    -4.77,  -21.57,    0.00 /
      DATA B(45670), B(45671), B(45672) /    -4.82,  -21.48,    0.00 /
      DATA B(45961), B(45962), B(45963) /    -4.86,  -21.39,    0.00 /
      DATA B(46252), B(46253), B(46254) /    -4.91,  -21.29,    0.00 /
      DATA B(27631), B(27632), B(27633) /    25.49,  -40.67,    0.00 /
      DATA B(27922), B(27923), B(27924) /    25.30,  -40.57,    0.00 /
      DATA B(28213), B(28214), B(28215) /    25.09,  -40.45,    0.00 /
      DATA B(28504), B(28505), B(28506) /    24.85,  -40.31,    0.00 /
      DATA B(28795), B(28796), B(28797) /    24.56,  -40.14,    0.00 /
      DATA B(29086), B(29087), B(29088) /    24.20,  -39.92,    0.00 /
      DATA B(29377), B(29378), B(29379) /    23.72,  -39.62,    0.00 /
      DATA B(29668), B(29669), B(29670) /    23.34,  -39.35,    0.00 /
      DATA B(29959), B(29960), B(29961) /    22.92,  -39.06,    0.00 /
      DATA B(30250), B(30251), B(30252) /    22.53,  -38.77,    0.00 /
      DATA B(30541), B(30542), B(30543) /    22.23,  -38.37,    0.00 /
      DATA B(30832), B(30833), B(30834) /    21.77,  -37.90,    0.00 /
      DATA B(31123), B(31124), B(31125) /    21.27,  -37.35,    0.00 /
      DATA B(31414), B(31415), B(31416) /    11.80,  -29.76,    0.00 /
      DATA B(31705), B(31706), B(31707) /    11.11,  -29.41,    0.00 /
      DATA B(31996), B(31997), B(31998) /     2.27,  -23.84,    0.00 /
      DATA B(32287), B(32288), B(32289) /     1.45,  -23.62,    0.00 /
      DATA B(32578), B(32579), B(32580) /     0.71,  -23.46,    0.00 /
      DATA B(32869), B(32870), B(32871) /     0.06,  -23.35,    0.00 /
      DATA B(33160), B(33161), B(33162) /    -0.51,  -23.29,    0.00 /
      DATA B(33451), B(33452), B(33453) /    -1.00,  -23.27,    0.00 /
      DATA B(33742), B(33743), B(33744) /    -1.45,  -23.29,    0.00 /
      DATA B(34033), B(34034), B(34035) /    -1.89,  -23.32,    0.00 /
      DATA B(34324), B(34325), B(34326) /    -2.16,  -24.48,    0.00 /
      DATA B(34615), B(34616), B(34617) /    -2.29,  -24.41,    0.00 /
      DATA B(34906), B(34907), B(34908) /    -2.40,  -24.30,    0.00 /
      DATA B(35197), B(35198), B(35199) /    -2.49,  -24.16,    0.00 /
      DATA B(35488), B(35489), B(35490) /    -2.57,  -24.02,    0.00 /
      DATA B(35779), B(35780), B(35781) /    -2.64,  -23.90,    0.00 /
      DATA B(36070), B(36071), B(36072) /    -2.71,  -23.78,    0.00 /
      DATA B(36361), B(36362), B(36363) /    -2.79,  -23.68,    0.00 /
      DATA B(36652), B(36653), B(36654) /    -2.86,  -23.59,    0.00 /
      DATA B(36943), B(36944), B(36945) /    -2.93,  -23.50,    0.00 /
      DATA B(37234), B(37235), B(37236) /    -3.01,  -23.42,    0.00 /
      DATA B(37525), B(37526), B(37527) /    -3.08,  -23.35,    0.00 /
      DATA B(37816), B(37817), B(37818) /    -3.15,  -23.28,    0.00 /
      DATA B(38107), B(38108), B(38109) /    -3.22,  -23.21,    0.00 /
      DATA B(38398), B(38399), B(38400) /    -3.29,  -23.15,    0.00 /
      DATA B(38689), B(38690), B(38691) /    -3.36,  -23.09,    0.00 /
      DATA B(38980), B(38981), B(38982) /    -3.43,  -23.03,    0.00 /
      DATA B(39271), B(39272), B(39273) /    -3.50,  -22.97,    0.00 /
      DATA B(39562), B(39563), B(39564) /    -3.57,  -22.91,    0.00 /
      DATA B(39853), B(39854), B(39855) /    -3.64,  -22.86,    0.00 /
      DATA B(40144), B(40145), B(40146) /    -3.71,  -22.80,    0.00 /
      DATA B(40435), B(40436), B(40437) /    -3.78,  -22.74,    0.00 /
      DATA B(40726), B(40727), B(40728) /    -3.84,  -22.68,    0.00 /
      DATA B(41017), B(41018), B(41019) /    -3.91,  -22.62,    0.00 /
      DATA B(41308), B(41309), B(41310) /    -3.97,  -22.55,    0.00 /
      DATA B(41599), B(41600), B(41601) /    -4.04,  -22.49,    0.00 /
      DATA B(41890), B(41891), B(41892) /    -4.10,  -22.42,    0.00 /
      DATA B(42181), B(42182), B(42183) /    -4.16,  -22.36,    0.00 /
      DATA B(42472), B(42473), B(42474) /    -4.22,  -22.29,    0.00 /
      DATA B(42763), B(42764), B(42765) /    -4.28,  -22.22,    0.00 /
      DATA B(43054), B(43055), B(43056) /    -4.34,  -22.15,    0.00 /
      DATA B(43345), B(43346), B(43347) /    -4.39,  -22.07,    0.00 /
      DATA B(43636), B(43637), B(43638) /    -4.45,  -22.00,    0.00 /
      DATA B(43927), B(43928), B(43929) /    -4.50,  -21.92,    0.00 /
      DATA B(44218), B(44219), B(44220) /    -4.55,  -21.85,    0.00 /
      DATA B(44509), B(44510), B(44511) /    -4.60,  -21.77,    0.00 /
      DATA B(44800), B(44801), B(44802) /    -4.65,  -21.68,    0.00 /
      DATA B(45091), B(45092), B(45093) /    -4.70,  -21.60,    0.00 /
      DATA B(45382), B(45383), B(45384) /    -4.75,  -21.51,    0.00 /
      DATA B(45673), B(45674), B(45675) /    -4.80,  -21.42,    0.00 /
      DATA B(45964), B(45965), B(45966) /    -4.84,  -21.33,    0.00 /
      DATA B(46255), B(46256), B(46257) /    -4.89,  -21.23,    0.00 /
      DATA B(27634), B(27635), B(27636) /    25.16,  -40.51,    0.00 /
      DATA B(27925), B(27926), B(27927) /    24.96,  -40.40,    0.00 /
      DATA B(28216), B(28217), B(28218) /    24.73,  -40.27,    0.00 /
      DATA B(28507), B(28508), B(28509) /    24.44,  -40.10,    0.00 /
      DATA B(28798), B(28799), B(28800) /    24.11,  -39.89,    0.00 /
      DATA B(29089), B(29090), B(29091) /    23.68,  -39.62,    0.00 /
      DATA B(29380), B(29381), B(29382) /    23.28,  -39.35,    0.00 /
      DATA B(29671), B(29672), B(29673) /    22.87,  -39.09,    0.00 /
      DATA B(29962), B(29963), B(29964) /    22.45,  -38.87,    0.00 /
      DATA B(30253), B(30254), B(30255) /    22.05,  -38.65,    0.00 /
      DATA B(30544), B(30545), B(30546) /    21.66,  -38.27,    0.00 /
      DATA B(30835), B(30836), B(30837) /    21.16,  -37.60,    0.00 /
      DATA B(31126), B(31127), B(31128) /    20.49,  -36.89,    0.00 /
      DATA B(31417), B(31418), B(31419) /    11.05,  -29.37,    0.00 /
      DATA B(31708), B(31709), B(31710) /     2.32,  -23.72,    0.00 /
      DATA B(31999), B(32000), B(32001) /     1.49,  -23.44,    0.00 /
      DATA B(32290), B(32291), B(32292) /     0.75,  -23.25,    0.00 /
      DATA B(32581), B(32582), B(32583) /     0.11,  -23.12,    0.00 /
      DATA B(32872), B(32873), B(32874) /    -0.46,  -23.05,    0.00 /
      DATA B(33163), B(33164), B(33165) /    -0.95,  -23.00,    0.00 /
      DATA B(33454), B(33455), B(33456) /    -1.40,  -22.99,    0.00 /
      DATA B(33745), B(33746), B(33747) /    -1.83,  -23.01,    0.00 /
      DATA B(34036), B(34037), B(34038) /    -2.17,  -24.22,    0.00 /
      DATA B(34327), B(34328), B(34329) /    -2.29,  -24.22,    0.00 /
      DATA B(34618), B(34619), B(34620) /    -2.40,  -24.17,    0.00 /
      DATA B(34909), B(34910), B(34911) /    -2.51,  -24.08,    0.00 /
      DATA B(35200), B(35201), B(35202) /    -2.59,  -23.97,    0.00 /
      DATA B(35491), B(35492), B(35493) /    -2.67,  -23.86,    0.00 /
      DATA B(35782), B(35783), B(35784) /    -2.73,  -23.75,    0.00 /
      DATA B(36073), B(36074), B(36075) /    -2.80,  -23.64,    0.00 /
      DATA B(36364), B(36365), B(36366) /    -2.86,  -23.55,    0.00 /
      DATA B(36655), B(36656), B(36657) /    -2.93,  -23.46,    0.00 /
      DATA B(36946), B(36947), B(36948) /    -2.99,  -23.38,    0.00 /
      DATA B(37237), B(37238), B(37239) /    -3.06,  -23.31,    0.00 /
      DATA B(37528), B(37529), B(37530) /    -3.12,  -23.24,    0.00 /
      DATA B(37819), B(37820), B(37821) /    -3.19,  -23.17,    0.00 /
      DATA B(38110), B(38111), B(38112) /    -3.26,  -23.11,    0.00 /
      DATA B(38401), B(38402), B(38403) /    -3.32,  -23.05,    0.00 /
      DATA B(38692), B(38693), B(38694) /    -3.39,  -22.99,    0.00 /
      DATA B(38983), B(38984), B(38985) /    -3.45,  -22.93,    0.00 /
      DATA B(39274), B(39275), B(39276) /    -3.52,  -22.87,    0.00 /
      DATA B(39565), B(39566), B(39567) /    -3.58,  -22.82,    0.00 /
      DATA B(39856), B(39857), B(39858) /    -3.65,  -22.76,    0.00 /
      DATA B(40147), B(40148), B(40149) /    -3.71,  -22.70,    0.00 /
      DATA B(40438), B(40439), B(40440) /    -3.78,  -22.64,    0.00 /
      DATA B(40729), B(40730), B(40731) /    -3.84,  -22.58,    0.00 /
      DATA B(41020), B(41021), B(41022) /    -3.90,  -22.52,    0.00 /
      DATA B(41311), B(41312), B(41313) /    -3.97,  -22.46,    0.00 /
      DATA B(41602), B(41603), B(41604) /    -4.03,  -22.40,    0.00 /
      DATA B(41893), B(41894), B(41895) /    -4.09,  -22.34,    0.00 /
      DATA B(42184), B(42185), B(42186) /    -4.15,  -22.27,    0.00 /
      DATA B(42475), B(42476), B(42477) /    -4.21,  -22.21,    0.00 /
      DATA B(42766), B(42767), B(42768) /    -4.26,  -22.14,    0.00 /
      DATA B(43057), B(43058), B(43059) /    -4.32,  -22.07,    0.00 /
      DATA B(43348), B(43349), B(43350) /    -4.38,  -22.00,    0.00 /
      DATA B(43639), B(43640), B(43641) /    -4.43,  -21.93,    0.00 /
      DATA B(43930), B(43931), B(43932) /    -4.48,  -21.85,    0.00 /
      DATA B(44221), B(44222), B(44223) /    -4.53,  -21.78,    0.00 /
      DATA B(44512), B(44513), B(44514) /    -4.58,  -21.70,    0.00 /
      DATA B(44803), B(44804), B(44805) /    -4.63,  -21.62,    0.00 /
      DATA B(45094), B(45095), B(45096) /    -4.68,  -21.54,    0.00 /
      DATA B(45385), B(45386), B(45387) /    -4.73,  -21.45,    0.00 /
      DATA B(45676), B(45677), B(45678) /    -4.78,  -21.36,    0.00 /
      DATA B(45967), B(45968), B(45969) /    -4.82,  -21.27,    0.00 /
      DATA B(46258), B(46259), B(46260) /    -4.87,  -21.17,    0.00 /
      DATA B(27637), B(27638), B(27639) /    24.82,  -40.33,    0.00 /
      DATA B(27928), B(27929), B(27930) /    24.60,  -40.21,    0.00 /
      DATA B(28219), B(28220), B(28221) /    24.32,  -40.05,    0.00 /
      DATA B(28510), B(28511), B(28512) /    24.00,  -39.85,    0.00 /
      DATA B(28801), B(28802), B(28803) /    23.60,  -39.59,    0.00 /
      DATA B(29092), B(29093), B(29094) /    23.23,  -39.33,    0.00 /
      DATA B(29383), B(29384), B(29385) /    22.85,  -39.09,    0.00 /
      DATA B(29674), B(29675), B(29676) /    22.47,  -38.88,    0.00 /
      DATA B(29965), B(29966), B(29967) /    22.06,  -38.70,    0.00 /
      DATA B(30256), B(30257), B(30258) /    21.57,  -38.54,    0.00 /
      DATA B(30547), B(30548), B(30549) /    21.06,  -38.17,    0.00 /
      DATA B(30838), B(30839), B(30840) /    20.39,  -37.14,    0.00 /
      DATA B(31129), B(31130), B(31131) /    10.96,  -29.36,    0.00 /
      DATA B(31420), B(31421), B(31422) /     2.35,  -23.64,    0.00 /
      DATA B(31711), B(31712), B(31713) /     1.51,  -23.30,    0.00 /
      DATA B(32002), B(32003), B(32004) /     0.78,  -23.08,    0.00 /
      DATA B(32293), B(32294), B(32295) /     0.15,  -22.94,    0.00 /
      DATA B(32584), B(32585), B(32586) /    -0.40,  -22.85,    0.00 /
      DATA B(32875), B(32876), B(32877) /    -0.89,  -22.79,    0.00 /
      DATA B(33166), B(33167), B(33168) /    -1.33,  -22.76,    0.00 /
      DATA B(33457), B(33458), B(33459) /    -1.76,  -22.76,    0.00 /
      DATA B(33748), B(33749), B(33750) /    -2.18,  -24.00,    0.00 /
      DATA B(34039), B(34040), B(34041) /    -2.28,  -24.01,    0.00 /
      DATA B(34330), B(34331), B(34332) /    -2.39,  -24.00,    0.00 /
      DATA B(34621), B(34622), B(34623) /    -2.49,  -23.96,    0.00 /
      DATA B(34912), B(34913), B(34914) /    -2.58,  -23.89,    0.00 /
      DATA B(35203), B(35204), B(35205) /    -2.66,  -23.80,    0.00 /
      DATA B(35494), B(35495), B(35496) /    -2.73,  -23.71,    0.00 /
      DATA B(35785), B(35786), B(35787) /    -2.80,  -23.61,    0.00 /
      DATA B(36076), B(36077), B(36078) /    -2.86,  -23.52,    0.00 /
      DATA B(36367), B(36368), B(36369) /    -2.92,  -23.43,    0.00 /
      DATA B(36658), B(36659), B(36660) /    -2.98,  -23.35,    0.00 /
      DATA B(36949), B(36950), B(36951) /    -3.04,  -23.28,    0.00 /
      DATA B(37240), B(37241), B(37242) /    -3.10,  -23.20,    0.00 /
      DATA B(37531), B(37532), B(37533) /    -3.16,  -23.14,    0.00 /
      DATA B(37822), B(37823), B(37824) /    -3.22,  -23.07,    0.00 /
      DATA B(38113), B(38114), B(38115) /    -3.28,  -23.01,    0.00 /
      DATA B(38404), B(38405), B(38406) /    -3.34,  -22.95,    0.00 /
      DATA B(38695), B(38696), B(38697) /    -3.40,  -22.89,    0.00 /
      DATA B(38986), B(38987), B(38988) /    -3.46,  -22.84,    0.00 /
      DATA B(39277), B(39278), B(39279) /    -3.53,  -22.78,    0.00 /
      DATA B(39568), B(39569), B(39570) /    -3.59,  -22.72,    0.00 /
      DATA B(39859), B(39860), B(39861) /    -3.65,  -22.67,    0.00 /
      DATA B(40150), B(40151), B(40152) /    -3.71,  -22.61,    0.00 /
      DATA B(40441), B(40442), B(40443) /    -3.77,  -22.55,    0.00 /
      DATA B(40732), B(40733), B(40734) /    -3.83,  -22.50,    0.00 /
      DATA B(41023), B(41024), B(41025) /    -3.90,  -22.44,    0.00 /
      DATA B(41314), B(41315), B(41316) /    -3.96,  -22.38,    0.00 /
      DATA B(41605), B(41606), B(41607) /    -4.02,  -22.32,    0.00 /
      DATA B(41896), B(41897), B(41898) /    -4.08,  -22.25,    0.00 /
      DATA B(42187), B(42188), B(42189) /    -4.13,  -22.19,    0.00 /
      DATA B(42478), B(42479), B(42480) /    -4.19,  -22.13,    0.00 /
      DATA B(42769), B(42770), B(42771) /    -4.25,  -22.06,    0.00 /
      DATA B(43060), B(43061), B(43062) /    -4.30,  -22.00,    0.00 /
      DATA B(43351), B(43352), B(43353) /    -4.36,  -21.93,    0.00 /
      DATA B(43642), B(43643), B(43644) /    -4.41,  -21.86,    0.00 /
      DATA B(43933), B(43934), B(43935) /    -4.46,  -21.79,    0.00 /
      DATA B(44224), B(44225), B(44226) /    -4.52,  -21.71,    0.00 /
      DATA B(44515), B(44516), B(44517) /    -4.57,  -21.64,    0.00 /
      DATA B(44806), B(44807), B(44808) /    -4.62,  -21.56,    0.00 /
      DATA B(45097), B(45098), B(45099) /    -4.66,  -21.47,    0.00 /
      DATA B(45388), B(45389), B(45390) /    -4.71,  -21.39,    0.00 /
      DATA B(45679), B(45680), B(45681) /    -4.76,  -21.30,    0.00 /
      DATA B(45970), B(45971), B(45972) /    -4.81,  -21.20,    0.00 /
      DATA B(46261), B(46262), B(46263) /    -4.85,  -21.11,    0.00 /
      DATA B(27640), B(27641), B(27642) /    24.46,  -40.13,    0.00 /
      DATA B(27931), B(27932), B(27933) /    24.19,  -39.98,    0.00 /
      DATA B(28222), B(28223), B(28224) /    23.88,  -39.79,    0.00 /
      DATA B(28513), B(28514), B(28515) /    23.51,  -39.55,    0.00 /
      DATA B(28804), B(28805), B(28806) /    23.16,  -39.30,    0.00 /
      DATA B(29095), B(29096), B(29097) /    22.82,  -39.07,    0.00 /
      DATA B(29386), B(29387), B(29388) /    22.50,  -38.87,    0.00 /
      DATA B(29677), B(29678), B(29679) /    22.18,  -38.69,    0.00 /
      DATA B(29968), B(29969), B(29970) /    21.79,  -38.52,    0.00 /
      DATA B(30259), B(30260), B(30261) /    21.26,  -38.33,    0.00 /
      DATA B(30550), B(30551), B(30552) /    20.36,  -38.18,    0.00 /
      DATA B(30841), B(30842), B(30843) /     3.25,  -24.20,    0.00 /
      DATA B(31132), B(31133), B(31134) /     2.22,  -23.56,    0.00 /
      DATA B(31423), B(31424), B(31425) /     1.44,  -23.19,    0.00 /
      DATA B(31714), B(31715), B(31716) /     0.77,  -22.95,    0.00 /
      DATA B(32005), B(32006), B(32007) /     0.18,  -22.79,    0.00 /
      DATA B(32296), B(32297), B(32298) /    -0.35,  -22.68,    0.00 /
      DATA B(32587), B(32588), B(32589) /    -0.82,  -22.61,    0.00 /
      DATA B(32878), B(32879), B(32880) /    -1.25,  -22.57,    0.00 /
      DATA B(33169), B(33170), B(33171) /    -1.67,  -22.56,    0.00 /
      DATA B(33460), B(33461), B(33462) /    -2.18,  -23.82,    0.00 /
      DATA B(33751), B(33752), B(33753) /    -2.27,  -23.83,    0.00 /
      DATA B(34042), B(34043), B(34044) /    -2.37,  -23.84,    0.00 /
      DATA B(34333), B(34334), B(34335) /    -2.46,  -23.82,    0.00 /
      DATA B(34624), B(34625), B(34626) /    -2.55,  -23.78,    0.00 /
      DATA B(34915), B(34916), B(34917) /    -2.64,  -23.72,    0.00 /
      DATA B(35206), B(35207), B(35208) /    -2.71,  -23.65,    0.00 /
      DATA B(35497), B(35498), B(35499) /    -2.78,  -23.57,    0.00 /
      DATA B(35788), B(35789), B(35790) /    -2.84,  -23.48,    0.00 /
      DATA B(36079), B(36080), B(36081) /    -2.90,  -23.40,    0.00 /
      DATA B(36370), B(36371), B(36372) /    -2.96,  -23.32,    0.00 /
      DATA B(36661), B(36662), B(36663) /    -3.01,  -23.25,    0.00 /
      DATA B(36952), B(36953), B(36954) /    -3.07,  -23.18,    0.00 /
      DATA B(37243), B(37244), B(37245) /    -3.13,  -23.11,    0.00 /
      DATA B(37534), B(37535), B(37536) /    -3.18,  -23.04,    0.00 /
      DATA B(37825), B(37826), B(37827) /    -3.24,  -22.98,    0.00 /
      DATA B(38116), B(38117), B(38118) /    -3.30,  -22.92,    0.00 /
      DATA B(38407), B(38408), B(38409) /    -3.35,  -22.86,    0.00 /
      DATA B(38698), B(38699), B(38700) /    -3.41,  -22.80,    0.00 /
      DATA B(38989), B(38990), B(38991) /    -3.47,  -22.75,    0.00 /
      DATA B(39280), B(39281), B(39282) /    -3.53,  -22.69,    0.00 /
      DATA B(39571), B(39572), B(39573) /    -3.59,  -22.64,    0.00 /
      DATA B(39862), B(39863), B(39864) /    -3.65,  -22.58,    0.00 /
      DATA B(40153), B(40154), B(40155) /    -3.71,  -22.52,    0.00 /
      DATA B(40444), B(40445), B(40446) /    -3.77,  -22.47,    0.00 /
      DATA B(40735), B(40736), B(40737) /    -3.83,  -22.41,    0.00 /
      DATA B(41026), B(41027), B(41028) /    -3.88,  -22.35,    0.00 /
      DATA B(41317), B(41318), B(41319) /    -3.94,  -22.29,    0.00 /
      DATA B(41608), B(41609), B(41610) /    -4.00,  -22.23,    0.00 /
      DATA B(41899), B(41900), B(41901) /    -4.06,  -22.17,    0.00 /
      DATA B(42190), B(42191), B(42192) /    -4.12,  -22.11,    0.00 /
      DATA B(42481), B(42482), B(42483) /    -4.18,  -22.05,    0.00 /
      DATA B(42772), B(42773), B(42774) /    -4.23,  -21.99,    0.00 /
      DATA B(43063), B(43064), B(43065) /    -4.29,  -21.92,    0.00 /
      DATA B(43354), B(43355), B(43356) /    -4.34,  -21.86,    0.00 /
      DATA B(43645), B(43646), B(43647) /    -4.39,  -21.79,    0.00 /
      DATA B(43936), B(43937), B(43938) /    -4.45,  -21.72,    0.00 /
      DATA B(44227), B(44228), B(44229) /    -4.50,  -21.65,    0.00 /
      DATA B(44518), B(44519), B(44520) /    -4.55,  -21.57,    0.00 /
      DATA B(44809), B(44810), B(44811) /    -4.60,  -21.49,    0.00 /
      DATA B(45100), B(45101), B(45102) /    -4.65,  -21.41,    0.00 /
      DATA B(45391), B(45392), B(45393) /    -4.69,  -21.33,    0.00 /
      DATA B(45682), B(45683), B(45684) /    -4.74,  -21.24,    0.00 /
      DATA B(45973), B(45974), B(45975) /    -4.79,  -21.14,    0.00 /
      DATA B(46264), B(46265), B(46266) /    -4.84,  -21.04,    0.00 /
      DATA B(27643), B(27644), B(27645) /    24.06,  -39.89,    0.00 /
      DATA B(27934), B(27935), B(27936) /    23.75,  -39.70,    0.00 /
      DATA B(28225), B(28226), B(28227) /    23.39,  -39.48,    0.00 /
      DATA B(28516), B(28517), B(28518) /    23.06,  -39.25,    0.00 /
      DATA B(28807), B(28808), B(28809) /    22.76,  -39.05,    0.00 /
      DATA B(29098), B(29099), B(29100) /    22.49,  -38.87,    0.00 /
      DATA B(29389), B(29390), B(29391) /    22.23,  -38.71,    0.00 /
      DATA B(29680), B(29681), B(29682) /    21.96,  -38.55,    0.00 /
      DATA B(29971), B(29972), B(29973) /    21.66,  -38.36,    0.00 /
      DATA B(30262), B(30263), B(30264) /    21.35,  -38.16,    0.00 /
      DATA B(30553), B(30554), B(30555) /     1.71,  -23.26,    0.00 /
      DATA B(30844), B(30845), B(30846) /     1.51,  -23.61,    0.00 /
      DATA B(31135), B(31136), B(31137) /     1.15,  -23.15,    0.00 /
      DATA B(31426), B(31427), B(31428) /     0.66,  -22.86,    0.00 /
      DATA B(31717), B(31718), B(31719) /     0.16,  -22.68,    0.00 /
      DATA B(32008), B(32009), B(32010) /    -0.32,  -22.55,    0.00 /
      DATA B(32299), B(32300), B(32301) /    -0.76,  -22.47,    0.00 /
      DATA B(32590), B(32591), B(32592) /    -1.18,  -22.41,    0.00 /
      DATA B(32881), B(32882), B(32883) /    -1.58,  -22.39,    0.00 /
      DATA B(33172), B(33173), B(33174) /    -2.18,  -23.68,    0.00 /
      DATA B(33463), B(33464), B(33465) /    -2.26,  -23.68,    0.00 /
      DATA B(33754), B(33755), B(33756) /    -2.35,  -23.69,    0.00 /
      DATA B(34045), B(34046), B(34047) /    -2.43,  -23.68,    0.00 /
      DATA B(34336), B(34337), B(34338) /    -2.52,  -23.67,    0.00 /
      DATA B(34627), B(34628), B(34629) /    -2.60,  -23.63,    0.00 /
      DATA B(34918), B(34919), B(34920) /    -2.68,  -23.58,    0.00 /
      DATA B(35209), B(35210), B(35211) /    -2.75,  -23.51,    0.00 /
      DATA B(35500), B(35501), B(35502) /    -2.81,  -23.44,    0.00 /
      DATA B(35791), B(35792), B(35793) /    -2.87,  -23.37,    0.00 /
      DATA B(36082), B(36083), B(36084) /    -2.93,  -23.29,    0.00 /
      DATA B(36373), B(36374), B(36375) /    -2.98,  -23.22,    0.00 /
      DATA B(36664), B(36665), B(36666) /    -3.04,  -23.15,    0.00 /
      DATA B(36955), B(36956), B(36957) /    -3.09,  -23.08,    0.00 /
      DATA B(37246), B(37247), B(37248) /    -3.14,  -23.02,    0.00 /
      DATA B(37537), B(37538), B(37539) /    -3.20,  -22.95,    0.00 /
      DATA B(37828), B(37829), B(37830) /    -3.25,  -22.89,    0.00 /
      DATA B(38119), B(38120), B(38121) /    -3.31,  -22.83,    0.00 /
      DATA B(38410), B(38411), B(38412) /    -3.36,  -22.78,    0.00 /
      DATA B(38701), B(38702), B(38703) /    -3.42,  -22.72,    0.00 /
      DATA B(38992), B(38993), B(38994) /    -3.47,  -22.66,    0.00 /
      DATA B(39283), B(39284), B(39285) /    -3.53,  -22.61,    0.00 /
      DATA B(39574), B(39575), B(39576) /    -3.58,  -22.55,    0.00 /
      DATA B(39865), B(39866), B(39867) /    -3.64,  -22.50,    0.00 /
      DATA B(40156), B(40157), B(40158) /    -3.70,  -22.44,    0.00 /
      DATA B(40447), B(40448), B(40449) /    -3.76,  -22.39,    0.00 /
      DATA B(40738), B(40739), B(40740) /    -3.81,  -22.33,    0.00 /
      DATA B(41029), B(41030), B(41031) /    -3.87,  -22.27,    0.00 /
      DATA B(41320), B(41321), B(41322) /    -3.93,  -22.21,    0.00 /
      DATA B(41611), B(41612), B(41613) /    -3.99,  -22.16,    0.00 /
      DATA B(41902), B(41903), B(41904) /    -4.05,  -22.10,    0.00 /
      DATA B(42193), B(42194), B(42195) /    -4.10,  -22.04,    0.00 /
      DATA B(42484), B(42485), B(42486) /    -4.16,  -21.98,    0.00 /
      DATA B(42775), B(42776), B(42777) /    -4.21,  -21.91,    0.00 /
      DATA B(43066), B(43067), B(43068) /    -4.27,  -21.85,    0.00 /
      DATA B(43357), B(43358), B(43359) /    -4.32,  -21.79,    0.00 /
      DATA B(43648), B(43649), B(43650) /    -4.38,  -21.72,    0.00 /
      DATA B(43939), B(43940), B(43941) /    -4.43,  -21.65,    0.00 /
      DATA B(44230), B(44231), B(44232) /    -4.48,  -21.58,    0.00 /
      DATA B(44521), B(44522), B(44523) /    -4.53,  -21.51,    0.00 /
      DATA B(44812), B(44813), B(44814) /    -4.58,  -21.43,    0.00 /
      DATA B(45103), B(45104), B(45105) /    -4.63,  -21.35,    0.00 /
      DATA B(45394), B(45395), B(45396) /    -4.68,  -21.26,    0.00 /
      DATA B(45685), B(45686), B(45687) /    -4.73,  -21.17,    0.00 /
      DATA B(45976), B(45977), B(45978) /    -4.77,  -21.07,    0.00 /
      DATA B(46267), B(46268), B(46269) /    -4.82,  -20.97,    0.00 /
      DATA B(27646), B(27647), B(27648) /    23.61,  -39.59,    0.00 /
      DATA B(27937), B(27938), B(27939) /    23.26,  -39.38,    0.00 /
      DATA B(28228), B(28229), B(28230) /    22.95,  -39.18,    0.00 /
      DATA B(28519), B(28520), B(28521) /    22.67,  -39.00,    0.00 /
      DATA B(28810), B(28811), B(28812) /    22.43,  -38.86,    0.00 /
      DATA B(29101), B(29102), B(29103) /    22.21,  -38.72,    0.00 /
      DATA B(29392), B(29393), B(29394) /    22.00,  -38.58,    0.00 /
      DATA B(29683), B(29684), B(29685) /    21.78,  -38.43,    0.00 /
      DATA B(29974), B(29975), B(29976) /    21.56,  -38.23,    0.00 /
      DATA B(30265), B(30266), B(30267) /     1.62,  -22.70,    0.00 /
      DATA B(30556), B(30557), B(30558) /     1.35,  -23.04,    0.00 /
      DATA B(30847), B(30848), B(30849) /     0.83,  -23.18,    0.00 /
      DATA B(31138), B(31139), B(31140) /     0.44,  -22.87,    0.00 /
      DATA B(31429), B(31430), B(31431) /     0.06,  -22.62,    0.00 /
      DATA B(31720), B(31721), B(31722) /    -0.33,  -22.46,    0.00 /
      DATA B(32011), B(32012), B(32013) /    -0.73,  -22.35,    0.00 /
      DATA B(32302), B(32303), B(32304) /    -1.11,  -22.28,    0.00 /
      DATA B(32593), B(32594), B(32595) /    -1.49,  -22.25,    0.00 /
      DATA B(32884), B(32885), B(32886) /    -2.17,  -23.56,    0.00 /
      DATA B(33175), B(33176), B(33177) /    -2.25,  -23.56,    0.00 /
      DATA B(33466), B(33467), B(33468) /    -2.33,  -23.56,    0.00 /
      DATA B(33757), B(33758), B(33759) /    -2.40,  -23.56,    0.00 /
      DATA B(34048), B(34049), B(34050) /    -2.48,  -23.55,    0.00 /
      DATA B(34339), B(34340), B(34341) /    -2.56,  -23.53,    0.00 /
      DATA B(34630), B(34631), B(34632) /    -2.63,  -23.50,    0.00 /
      DATA B(34921), B(34922), B(34923) /    -2.70,  -23.45,    0.00 /
      DATA B(35212), B(35213), B(35214) /    -2.77,  -23.39,    0.00 /
      DATA B(35503), B(35504), B(35505) /    -2.83,  -23.33,    0.00 /
      DATA B(35794), B(35795), B(35796) /    -2.89,  -23.26,    0.00 /
      DATA B(36085), B(36086), B(36087) /    -2.94,  -23.19,    0.00 /
      DATA B(36376), B(36377), B(36378) /    -3.00,  -23.12,    0.00 /
      DATA B(36667), B(36668), B(36669) /    -3.05,  -23.06,    0.00 /
      DATA B(36958), B(36959), B(36960) /    -3.10,  -22.99,    0.00 /
      DATA B(37249), B(37250), B(37251) /    -3.15,  -22.93,    0.00 /
      DATA B(37540), B(37541), B(37542) /    -3.21,  -22.87,    0.00 /
      DATA B(37831), B(37832), B(37833) /    -3.26,  -22.81,    0.00 /
      DATA B(38122), B(38123), B(38124) /    -3.31,  -22.75,    0.00 /
      DATA B(38413), B(38414), B(38415) /    -3.36,  -22.69,    0.00 /
      DATA B(38704), B(38705), B(38706) /    -3.42,  -22.64,    0.00 /
      DATA B(38995), B(38996), B(38997) /    -3.47,  -22.58,    0.00 /
      DATA B(39286), B(39287), B(39288) /    -3.52,  -22.53,    0.00 /
      DATA B(39577), B(39578), B(39579) /    -3.58,  -22.47,    0.00 /
      DATA B(39868), B(39869), B(39870) /    -3.63,  -22.42,    0.00 /
      DATA B(40159), B(40160), B(40161) /    -3.69,  -22.36,    0.00 /
      DATA B(40450), B(40451), B(40452) /    -3.75,  -22.31,    0.00 /
      DATA B(40741), B(40742), B(40743) /    -3.80,  -22.25,    0.00 /
      DATA B(41032), B(41033), B(41034) /    -3.86,  -22.19,    0.00 /
      DATA B(41323), B(41324), B(41325) /    -3.92,  -22.14,    0.00 /
      DATA B(41614), B(41615), B(41616) /    -3.97,  -22.08,    0.00 /
      DATA B(41905), B(41906), B(41907) /    -4.03,  -22.02,    0.00 /
      DATA B(42196), B(42197), B(42198) /    -4.09,  -21.96,    0.00 /
      DATA B(42487), B(42488), B(42489) /    -4.14,  -21.90,    0.00 /
      DATA B(42778), B(42779), B(42780) /    -4.20,  -21.84,    0.00 /
      DATA B(43069), B(43070), B(43071) /    -4.25,  -21.78,    0.00 /
      DATA B(43360), B(43361), B(43362) /    -4.31,  -21.72,    0.00 /
      DATA B(43651), B(43652), B(43653) /    -4.36,  -21.65,    0.00 /
      DATA B(43942), B(43943), B(43944) /    -4.41,  -21.59,    0.00 /
      DATA B(44233), B(44234), B(44235) /    -4.46,  -21.52,    0.00 /
      DATA B(44524), B(44525), B(44526) /    -4.51,  -21.44,    0.00 /
      DATA B(44815), B(44816), B(44817) /    -4.56,  -21.37,    0.00 /
      DATA B(45106), B(45107), B(45108) /    -4.61,  -21.28,    0.00 /
      DATA B(45397), B(45398), B(45399) /    -4.66,  -21.20,    0.00 /
      DATA B(45688), B(45689), B(45690) /    -4.71,  -21.10,    0.00 /
      DATA B(45979), B(45980), B(45981) /    -4.76,  -21.01,    0.00 /
      DATA B(46270), B(46271), B(46272) /    -4.81,  -20.90,    0.00 /
      DATA B(27649), B(27650), B(27651) /    23.13,  -39.25,    0.00 /
      DATA B(27940), B(27941), B(27942) /    22.82,  -39.06,    0.00 /
      DATA B(28231), B(28232), B(28233) /    22.55,  -38.92,    0.00 /
      DATA B(28522), B(28523), B(28524) /    22.34,  -38.81,    0.00 /
      DATA B(28813), B(28814), B(28815) /    22.15,  -38.71,    0.00 /
      DATA B(29104), B(29105), B(29106) /    21.97,  -38.61,    0.00 /
      DATA B(29395), B(29396), B(29397) /    21.79,  -38.48,    0.00 /
      DATA B(29686), B(29687), B(29688) /    21.60,  -38.31,    0.00 /
      DATA B(29977), B(29978), B(29979) /     1.74,  -22.41,    0.00 /
      DATA B(30268), B(30269), B(30270) /     1.32,  -22.49,    0.00 /
      DATA B(30559), B(30560), B(30561) /     0.91,  -22.69,    0.00 /
      DATA B(30850), B(30851), B(30852) /     0.44,  -22.75,    0.00 /
      DATA B(31141), B(31142), B(31143) /     0.01,  -22.60,    0.00 /
      DATA B(31432), B(31433), B(31434) /    -0.35,  -22.42,    0.00 /
      DATA B(31723), B(31724), B(31725) /    -0.71,  -22.28,    0.00 /
      DATA B(32014), B(32015), B(32016) /    -1.06,  -22.18,    0.00 /
      DATA B(32305), B(32306), B(32307) /    -1.42,  -22.13,    0.00 /
      DATA B(32596), B(32597), B(32598) /    -2.17,  -23.48,    0.00 /
      DATA B(32887), B(32888), B(32889) /    -2.23,  -23.47,    0.00 /
      DATA B(33178), B(33179), B(33180) /    -2.30,  -23.46,    0.00 /
      DATA B(33469), B(33470), B(33471) /    -2.37,  -23.46,    0.00 /
      DATA B(33760), B(33761), B(33762) /    -2.45,  -23.45,    0.00 /
      DATA B(34051), B(34052), B(34053) /    -2.52,  -23.43,    0.00 /
      DATA B(34342), B(34343), B(34344) /    -2.59,  -23.41,    0.00 /
      DATA B(34633), B(34634), B(34635) /    -2.65,  -23.37,    0.00 /
      DATA B(34924), B(34925), B(34926) /    -2.72,  -23.33,    0.00 /
      DATA B(35215), B(35216), B(35217) /    -2.78,  -23.28,    0.00 /
      DATA B(35506), B(35507), B(35508) /    -2.84,  -23.22,    0.00 /
      DATA B(35797), B(35798), B(35799) /    -2.90,  -23.16,    0.00 /
      DATA B(36088), B(36089), B(36090) /    -2.95,  -23.09,    0.00 /
      DATA B(36379), B(36380), B(36381) /    -3.01,  -23.03,    0.00 /
      DATA B(36670), B(36671), B(36672) /    -3.06,  -22.97,    0.00 /
      DATA B(36961), B(36962), B(36963) /    -3.11,  -22.91,    0.00 /
      DATA B(37252), B(37253), B(37254) /    -3.16,  -22.84,    0.00 /
      DATA B(37543), B(37544), B(37545) /    -3.21,  -22.79,    0.00 /
      DATA B(37834), B(37835), B(37836) /    -3.26,  -22.73,    0.00 /
      DATA B(38125), B(38126), B(38127) /    -3.31,  -22.67,    0.00 /
      DATA B(38416), B(38417), B(38418) /    -3.36,  -22.61,    0.00 /
      DATA B(38707), B(38708), B(38709) /    -3.41,  -22.56,    0.00 /
      DATA B(38998), B(38999), B(39000) /    -3.46,  -22.50,    0.00 /
      DATA B(39289), B(39290), B(39291) /    -3.52,  -22.45,    0.00 /
      DATA B(39580), B(39581), B(39582) /    -3.57,  -22.39,    0.00 /
      DATA B(39871), B(39872), B(39873) /    -3.62,  -22.34,    0.00 /
      DATA B(40162), B(40163), B(40164) /    -3.68,  -22.28,    0.00 /
      DATA B(40453), B(40454), B(40455) /    -3.73,  -22.23,    0.00 /
      DATA B(40744), B(40745), B(40746) /    -3.79,  -22.17,    0.00 /
      DATA B(41035), B(41036), B(41037) /    -3.84,  -22.11,    0.00 /
      DATA B(41326), B(41327), B(41328) /    -3.90,  -22.06,    0.00 /
      DATA B(41617), B(41618), B(41619) /    -3.95,  -22.00,    0.00 /
      DATA B(41908), B(41909), B(41910) /    -4.01,  -21.94,    0.00 /
      DATA B(42199), B(42200), B(42201) /    -4.07,  -21.89,    0.00 /
      DATA B(42490), B(42491), B(42492) /    -4.12,  -21.83,    0.00 /
      DATA B(42781), B(42782), B(42783) /    -4.18,  -21.77,    0.00 /
      DATA B(43072), B(43073), B(43074) /    -4.23,  -21.71,    0.00 /
      DATA B(43363), B(43364), B(43365) /    -4.29,  -21.65,    0.00 /
      DATA B(43654), B(43655), B(43656) /    -4.34,  -21.59,    0.00 /
      DATA B(43945), B(43946), B(43947) /    -4.40,  -21.52,    0.00 /
      DATA B(44236), B(44237), B(44238) /    -4.45,  -21.45,    0.00 /
      DATA B(44527), B(44528), B(44529) /    -4.50,  -21.38,    0.00 /
      DATA B(44818), B(44819), B(44820) /    -4.55,  -21.30,    0.00 /
      DATA B(45109), B(45110), B(45111) /    -4.60,  -21.22,    0.00 /
      DATA B(45400), B(45401), B(45402) /    -4.65,  -21.13,    0.00 /
      DATA B(45691), B(45692), B(45693) /    -4.70,  -21.04,    0.00 /
      DATA B(45982), B(45983), B(45984) /    -4.76,  -20.93,    0.00 /
      DATA B(46273), B(46274), B(46275) /    -4.81,  -20.82,    0.00 /
      DATA B(27652), B(27653), B(27654) /    22.69,  -38.90,    0.00 /
      DATA B(27943), B(27944), B(27945) /    22.43,  -38.78,    0.00 /
      DATA B(28234), B(28235), B(28236) /    22.22,  -38.71,    0.00 /
      DATA B(28525), B(28526), B(28527) /    22.06,  -38.66,    0.00 /
      DATA B(28816), B(28817), B(28818) /    21.92,  -38.60,    0.00 /
      DATA B(29107), B(29108), B(29109) /    21.77,  -38.51,    0.00 /
      DATA B(29398), B(29399), B(29400) /    21.59,  -38.39,    0.00 /
      DATA B(29689), B(29690), B(29691) /     1.82,  -22.17,    0.00 /
      DATA B(29980), B(29981), B(29982) /     1.37,  -22.21,    0.00 /
      DATA B(30271), B(30272), B(30273) /     0.97,  -22.27,    0.00 /
      DATA B(30562), B(30563), B(30564) /     0.56,  -22.38,    0.00 /
      DATA B(30853), B(30854), B(30855) /     0.13,  -22.42,    0.00 /
      DATA B(31144), B(31145), B(31146) /    -0.29,  -22.34,    0.00 /
      DATA B(31435), B(31436), B(31437) /    -0.66,  -22.22,    0.00 /
      DATA B(31726), B(31727), B(31728) /    -1.00,  -22.11,    0.00 /
      DATA B(32017), B(32018), B(32019) /    -1.34,  -22.04,    0.00 /
      DATA B(32308), B(32309), B(32310) /    -2.16,  -23.43,    0.00 /
      DATA B(32599), B(32600), B(32601) /    -2.22,  -23.40,    0.00 /
      DATA B(32890), B(32891), B(32892) /    -2.28,  -23.38,    0.00 /
      DATA B(33181), B(33182), B(33183) /    -2.34,  -23.37,    0.00 /
      DATA B(33472), B(33473), B(33474) /    -2.41,  -23.36,    0.00 /
      DATA B(33763), B(33764), B(33765) /    -2.47,  -23.35,    0.00 /
      DATA B(34054), B(34055), B(34056) /    -2.54,  -23.33,    0.00 /
      DATA B(34345), B(34346), B(34347) /    -2.60,  -23.30,    0.00 /
      DATA B(34636), B(34637), B(34638) /    -2.67,  -23.27,    0.00 /
      DATA B(34927), B(34928), B(34929) /    -2.73,  -23.22,    0.00 /
      DATA B(35218), B(35219), B(35220) /    -2.79,  -23.17,    0.00 /
      DATA B(35509), B(35510), B(35511) /    -2.85,  -23.12,    0.00 /
      DATA B(35800), B(35801), B(35802) /    -2.90,  -23.06,    0.00 /
      DATA B(36091), B(36092), B(36093) /    -2.95,  -23.00,    0.00 /
      DATA B(36382), B(36383), B(36384) /    -3.01,  -22.94,    0.00 /
      DATA B(36673), B(36674), B(36675) /    -3.06,  -22.88,    0.00 /
      DATA B(36964), B(36965), B(36966) /    -3.11,  -22.82,    0.00 /
      DATA B(37255), B(37256), B(37257) /    -3.15,  -22.76,    0.00 /
      DATA B(37546), B(37547), B(37548) /    -3.20,  -22.71,    0.00 /
      DATA B(37837), B(37838), B(37839) /    -3.25,  -22.65,    0.00 /
      DATA B(38128), B(38129), B(38130) /    -3.30,  -22.59,    0.00 /
      DATA B(38419), B(38420), B(38421) /    -3.35,  -22.54,    0.00 /
      DATA B(38710), B(38711), B(38712) /    -3.40,  -22.48,    0.00 /
      DATA B(39001), B(39002), B(39003) /    -3.45,  -22.43,    0.00 /
      DATA B(39292), B(39293), B(39294) /    -3.50,  -22.37,    0.00 /
      DATA B(39583), B(39584), B(39585) /    -3.56,  -22.32,    0.00 /
      DATA B(39874), B(39875), B(39876) /    -3.61,  -22.26,    0.00 /
      DATA B(40165), B(40166), B(40167) /    -3.66,  -22.21,    0.00 /
      DATA B(40456), B(40457), B(40458) /    -3.71,  -22.15,    0.00 /
      DATA B(40747), B(40748), B(40749) /    -3.77,  -22.09,    0.00 /
      DATA B(41038), B(41039), B(41040) /    -3.82,  -22.04,    0.00 /
      DATA B(41329), B(41330), B(41331) /    -3.88,  -21.98,    0.00 /
      DATA B(41620), B(41621), B(41622) /    -3.94,  -21.92,    0.00 /
      DATA B(41911), B(41912), B(41913) /    -3.99,  -21.87,    0.00 /
      DATA B(42202), B(42203), B(42204) /    -4.05,  -21.81,    0.00 /
      DATA B(42493), B(42494), B(42495) /    -4.11,  -21.75,    0.00 /
      DATA B(42784), B(42785), B(42786) /    -4.16,  -21.70,    0.00 /
      DATA B(43075), B(43076), B(43077) /    -4.22,  -21.64,    0.00 /
      DATA B(43366), B(43367), B(43368) /    -4.27,  -21.58,    0.00 /
      DATA B(43657), B(43658), B(43659) /    -4.33,  -21.52,    0.00 /
      DATA B(43948), B(43949), B(43950) /    -4.38,  -21.45,    0.00 /
      DATA B(44239), B(44240), B(44241) /    -4.43,  -21.39,    0.00 /
      DATA B(44530), B(44531), B(44532) /    -4.49,  -21.31,    0.00 /
      DATA B(44821), B(44822), B(44823) /    -4.54,  -21.23,    0.00 /
      DATA B(45112), B(45113), B(45114) /    -4.59,  -21.15,    0.00 /
      DATA B(45403), B(45404), B(45405) /    -4.65,  -21.06,    0.00 /
      DATA B(45694), B(45695), B(45696) /    -4.70,  -20.96,    0.00 /
      DATA B(45985), B(45986), B(45987) /    -4.76,  -20.85,    0.00 /
      DATA B(46276), B(46277), B(46278) /    -4.82,  -20.73,    0.00 /
      DATA B(27655), B(27656), B(27657) /    22.30,  -38.57,    0.00 /
      DATA B(27946), B(27947), B(27948) /    22.10,  -38.54,    0.00 /
      DATA B(28237), B(28238), B(28239) /    21.95,  -38.55,    0.00 /
      DATA B(28528), B(28529), B(28530) /    21.83,  -38.55,    0.00 /
      DATA B(28819), B(28820), B(28821) /    21.72,  -38.52,    0.00 /
      DATA B(29110), B(29111), B(29112) /    21.59,  -38.44,    0.00 /
      DATA B(29401), B(29402), B(29403) /     1.88,  -21.93,    0.00 /
      DATA B(29692), B(29693), B(29694) /     1.46,  -22.00,    0.00 /
      DATA B(29983), B(29984), B(29985) /     1.07,  -22.02,    0.00 /
      DATA B(30274), B(30275), B(30276) /     0.67,  -22.08,    0.00 /
      DATA B(30565), B(30566), B(30567) /     0.27,  -22.14,    0.00 /
      DATA B(30856), B(30857), B(30858) /    -0.14,  -22.16,    0.00 /
      DATA B(31147), B(31148), B(31149) /    -0.53,  -22.11,    0.00 /
      DATA B(31438), B(31439), B(31440) /    -0.90,  -22.02,    0.00 /
      DATA B(31729), B(31730), B(31731) /    -1.25,  -21.95,    0.00 /
      DATA B(32020), B(32021), B(32022) /    -2.14,  -23.39,    0.00 /
      DATA B(32311), B(32312), B(32313) /    -2.20,  -23.35,    0.00 /
      DATA B(32602), B(32603), B(32604) /    -2.25,  -23.32,    0.00 /
      DATA B(32893), B(32894), B(32895) /    -2.31,  -23.30,    0.00 /
      DATA B(33184), B(33185), B(33186) /    -2.37,  -23.29,    0.00 /
      DATA B(33475), B(33476), B(33477) /    -2.43,  -23.27,    0.00 /
      DATA B(33766), B(33767), B(33768) /    -2.49,  -23.25,    0.00 /
      DATA B(34057), B(34058), B(34059) /    -2.55,  -23.23,    0.00 /
      DATA B(34348), B(34349), B(34350) /    -2.61,  -23.20,    0.00 /
      DATA B(34639), B(34640), B(34641) /    -2.67,  -23.16,    0.00 /
      DATA B(34930), B(34931), B(34932) /    -2.73,  -23.12,    0.00 /
      DATA B(35221), B(35222), B(35223) /    -2.79,  -23.08,    0.00 /
      DATA B(35512), B(35513), B(35514) /    -2.84,  -23.03,    0.00 /
      DATA B(35803), B(35804), B(35805) /    -2.90,  -22.97,    0.00 /
      DATA B(36094), B(36095), B(36096) /    -2.95,  -22.92,    0.00 /
      DATA B(36385), B(36386), B(36387) /    -3.00,  -22.86,    0.00 /
      DATA B(36676), B(36677), B(36678) /    -3.05,  -22.80,    0.00 /
      DATA B(36967), B(36968), B(36969) /    -3.10,  -22.74,    0.00 /
      DATA B(37258), B(37259), B(37260) /    -3.15,  -22.69,    0.00 /
      DATA B(37549), B(37550), B(37551) /    -3.20,  -22.63,    0.00 /
      DATA B(37840), B(37841), B(37842) /    -3.25,  -22.57,    0.00 /
      DATA B(38131), B(38132), B(38133) /    -3.29,  -22.52,    0.00 /
      DATA B(38422), B(38423), B(38424) /    -3.34,  -22.46,    0.00 /
      DATA B(38713), B(38714), B(38715) /    -3.39,  -22.41,    0.00 /
      DATA B(39004), B(39005), B(39006) /    -3.44,  -22.36,    0.00 /
      DATA B(39295), B(39296), B(39297) /    -3.49,  -22.30,    0.00 /
      DATA B(39586), B(39587), B(39588) /    -3.54,  -22.25,    0.00 /
      DATA B(39877), B(39878), B(39879) /    -3.59,  -22.19,    0.00 /
      DATA B(40168), B(40169), B(40170) /    -3.64,  -22.13,    0.00 /
      DATA B(40459), B(40460), B(40461) /    -3.70,  -22.08,    0.00 /
      DATA B(40750), B(40751), B(40752) /    -3.75,  -22.02,    0.00 /
      DATA B(41041), B(41042), B(41043) /    -3.81,  -21.96,    0.00 /
      DATA B(41332), B(41333), B(41334) /    -3.86,  -21.90,    0.00 /
      DATA B(41623), B(41624), B(41625) /    -3.92,  -21.85,    0.00 /
      DATA B(41914), B(41915), B(41916) /    -3.97,  -21.79,    0.00 /
      DATA B(42205), B(42206), B(42207) /    -4.03,  -21.74,    0.00 /
      DATA B(42496), B(42497), B(42498) /    -4.09,  -21.68,    0.00 /
      DATA B(42787), B(42788), B(42789) /    -4.15,  -21.62,    0.00 /
      DATA B(43078), B(43079), B(43080) /    -4.20,  -21.57,    0.00 /
      DATA B(43369), B(43370), B(43371) /    -4.26,  -21.51,    0.00 /
      DATA B(43660), B(43661), B(43662) /    -4.31,  -21.45,    0.00 /
      DATA B(43951), B(43952), B(43953) /    -4.37,  -21.39,    0.00 /
      DATA B(44242), B(44243), B(44244) /    -4.42,  -21.32,    0.00 /
      DATA B(44533), B(44534), B(44535) /    -4.48,  -21.25,    0.00 /
      DATA B(44824), B(44825), B(44826) /    -4.53,  -21.17,    0.00 /
      DATA B(45115), B(45116), B(45117) /    -4.59,  -21.08,    0.00 /
      DATA B(45406), B(45407), B(45408) /    -4.65,  -20.99,    0.00 /
      DATA B(45697), B(45698), B(45699) /    -4.71,  -20.88,    0.00 /
      DATA B(45988), B(45989), B(45990) /    -4.77,  -20.77,    0.00 /
      DATA B(46279), B(46280), B(46281) /    -4.84,  -20.63,    0.00 /
      DATA B(27658), B(27659), B(27660) /    21.96,  -38.26,    0.00 /
      DATA B(27949), B(27950), B(27951) /    21.82,  -38.33,    0.00 /
      DATA B(28240), B(28241), B(28242) /    21.72,  -38.42,    0.00 /
      DATA B(28531), B(28532), B(28533) /    21.65,  -38.48,    0.00 /
      DATA B(28822), B(28823), B(28824) /    21.58,  -38.45,    0.00 /
      DATA B(29113), B(29114), B(29115) /     1.95,  -21.72,    0.00 /
      DATA B(29404), B(29405), B(29406) /     1.59,  -21.79,    0.00 /
      DATA B(29695), B(29696), B(29697) /     1.20,  -21.83,    0.00 /
      DATA B(29986), B(29987), B(29988) /     0.81,  -21.86,    0.00 /
      DATA B(30277), B(30278), B(30279) /     0.42,  -21.90,    0.00 /
      DATA B(30568), B(30569), B(30570) /     0.02,  -21.94,    0.00 /
      DATA B(30859), B(30860), B(30861) /    -0.37,  -21.94,    0.00 /
      DATA B(31150), B(31151), B(31152) /    -0.75,  -21.90,    0.00 /
      DATA B(31441), B(31442), B(31443) /    -1.12,  -21.86,    0.00 /
      DATA B(31732), B(31733), B(31734) /    -2.10,  -23.36,    0.00 /
      DATA B(32023), B(32024), B(32025) /    -2.16,  -23.31,    0.00 /
      DATA B(32314), B(32315), B(32316) /    -2.22,  -23.28,    0.00 /
      DATA B(32605), B(32606), B(32607) /    -2.27,  -23.25,    0.00 /
      DATA B(32896), B(32897), B(32898) /    -2.33,  -23.23,    0.00 /
      DATA B(33187), B(33188), B(33189) /    -2.38,  -23.21,    0.00 /
      DATA B(33478), B(33479), B(33480) /    -2.44,  -23.18,    0.00 /
      DATA B(33769), B(33770), B(33771) /    -2.50,  -23.16,    0.00 /
      DATA B(34060), B(34061), B(34062) /    -2.56,  -23.14,    0.00 /
      DATA B(34351), B(34352), B(34353) /    -2.61,  -23.11,    0.00 /
      DATA B(34642), B(34643), B(34644) /    -2.67,  -23.07,    0.00 /
      DATA B(34933), B(34934), B(34935) /    -2.73,  -23.03,    0.00 /
      DATA B(35224), B(35225), B(35226) /    -2.78,  -22.99,    0.00 /
      DATA B(35515), B(35516), B(35517) /    -2.84,  -22.94,    0.00 /
      DATA B(35806), B(35807), B(35808) /    -2.89,  -22.89,    0.00 /
      DATA B(36097), B(36098), B(36099) /    -2.94,  -22.83,    0.00 /
      DATA B(36388), B(36389), B(36390) /    -2.99,  -22.78,    0.00 /
      DATA B(36679), B(36680), B(36681) /    -3.04,  -22.72,    0.00 /
      DATA B(36970), B(36971), B(36972) /    -3.09,  -22.67,    0.00 /
      DATA B(37261), B(37262), B(37263) /    -3.14,  -22.61,    0.00 /
      DATA B(37552), B(37553), B(37554) /    -3.19,  -22.56,    0.00 /
      DATA B(37843), B(37844), B(37845) /    -3.23,  -22.50,    0.00 /
      DATA B(38134), B(38135), B(38136) /    -3.28,  -22.45,    0.00 /
      DATA B(38425), B(38426), B(38427) /    -3.33,  -22.39,    0.00 /
      DATA B(38716), B(38717), B(38718) /    -3.38,  -22.34,    0.00 /
      DATA B(39007), B(39008), B(39009) /    -3.43,  -22.28,    0.00 /
      DATA B(39298), B(39299), B(39300) /    -3.48,  -22.23,    0.00 /
      DATA B(39589), B(39590), B(39591) /    -3.52,  -22.17,    0.00 /
      DATA B(39880), B(39881), B(39882) /    -3.57,  -22.12,    0.00 /
      DATA B(40171), B(40172), B(40173) /    -3.63,  -22.06,    0.00 /
      DATA B(40462), B(40463), B(40464) /    -3.68,  -22.00,    0.00 /
      DATA B(40753), B(40754), B(40755) /    -3.73,  -21.94,    0.00 /
      DATA B(41044), B(41045), B(41046) /    -3.79,  -21.89,    0.00 /
      DATA B(41335), B(41336), B(41337) /    -3.84,  -21.83,    0.00 /
      DATA B(41626), B(41627), B(41628) /    -3.90,  -21.77,    0.00 /
      DATA B(41917), B(41918), B(41919) /    -3.96,  -21.71,    0.00 /
      DATA B(42208), B(42209), B(42210) /    -4.01,  -21.66,    0.00 /
      DATA B(42499), B(42500), B(42501) /    -4.07,  -21.61,    0.00 /
      DATA B(42790), B(42791), B(42792) /    -4.13,  -21.55,    0.00 /
      DATA B(43081), B(43082), B(43083) /    -4.19,  -21.50,    0.00 /
      DATA B(43372), B(43373), B(43374) /    -4.25,  -21.44,    0.00 /
      DATA B(43663), B(43664), B(43665) /    -4.30,  -21.38,    0.00 /
      DATA B(43954), B(43955), B(43956) /    -4.36,  -21.32,    0.00 /
      DATA B(44245), B(44246), B(44247) /    -4.42,  -21.25,    0.00 /
      DATA B(44536), B(44537), B(44538) /    -4.47,  -21.18,    0.00 /
      DATA B(44827), B(44828), B(44829) /    -4.53,  -21.10,    0.00 /
      DATA B(45118), B(45119), B(45120) /    -4.59,  -21.01,    0.00 /
      DATA B(45409), B(45410), B(45411) /    -4.66,  -20.91,    0.00 /
      DATA B(45700), B(45701), B(45702) /    -4.72,  -20.80,    0.00 /
      DATA B(45991), B(45992), B(45993) /    -4.80,  -20.67,    0.00 /
      DATA B(46282), B(46283), B(46284) /    -4.89,  -20.52,    0.00 /
      DATA B(27661), B(27662), B(27663) /    21.68,  -37.94,    0.00 /
      DATA B(27952), B(27953), B(27954) /    21.58,  -38.13,    0.00 /
      DATA B(28243), B(28244), B(28245) /    21.56,  -38.34,    0.00 /
      DATA B(28534), B(28535), B(28536) /    21.54,  -38.43,    0.00 /
      DATA B(28825), B(28826), B(28827) /     2.11,  -21.54,    0.00 /
      DATA B(29116), B(29117), B(29118) /     1.75,  -21.61,    0.00 /
      DATA B(29407), B(29408), B(29409) /     1.36,  -21.67,    0.00 /
      DATA B(29698), B(29699), B(29700) /     0.98,  -21.69,    0.00 /
      DATA B(29989), B(29990), B(29991) /     0.59,  -21.72,    0.00 /
      DATA B(30280), B(30281), B(30282) /     0.20,  -21.74,    0.00 /
      DATA B(30571), B(30572), B(30573) /    -0.19,  -21.76,    0.00 /
      DATA B(30862), B(30863), B(30864) /    -0.57,  -21.74,    0.00 /
      DATA B(31153), B(31154), B(31155) /    -0.96,  -21.73,    0.00 /
      DATA B(31444), B(31445), B(31446) /    -2.04,  -23.32,    0.00 /
      DATA B(31735), B(31736), B(31737) /    -2.10,  -23.28,    0.00 /
      DATA B(32026), B(32027), B(32028) /    -2.16,  -23.24,    0.00 /
      DATA B(32317), B(32318), B(32319) /    -2.22,  -23.21,    0.00 /
      DATA B(32608), B(32609), B(32610) /    -2.28,  -23.18,    0.00 /
      DATA B(32899), B(32900), B(32901) /    -2.33,  -23.15,    0.00 /
      DATA B(33190), B(33191), B(33192) /    -2.39,  -23.13,    0.00 /
      DATA B(33481), B(33482), B(33483) /    -2.44,  -23.10,    0.00 /
      DATA B(33772), B(33773), B(33774) /    -2.50,  -23.08,    0.00 /
      DATA B(34063), B(34064), B(34065) /    -2.55,  -23.05,    0.00 /
      DATA B(34354), B(34355), B(34356) /    -2.61,  -23.02,    0.00 /
      DATA B(34645), B(34646), B(34647) /    -2.66,  -22.98,    0.00 /
      DATA B(34936), B(34937), B(34938) /    -2.72,  -22.94,    0.00 /
      DATA B(35227), B(35228), B(35229) /    -2.77,  -22.90,    0.00 /
      DATA B(35518), B(35519), B(35520) /    -2.83,  -22.85,    0.00 /
      DATA B(35809), B(35810), B(35811) /    -2.88,  -22.80,    0.00 /
      DATA B(36100), B(36101), B(36102) /    -2.93,  -22.75,    0.00 /
      DATA B(36391), B(36392), B(36393) /    -2.98,  -22.70,    0.00 /
      DATA B(36682), B(36683), B(36684) /    -3.03,  -22.64,    0.00 /
      DATA B(36973), B(36974), B(36975) /    -3.08,  -22.59,    0.00 /
      DATA B(37264), B(37265), B(37266) /    -3.12,  -22.54,    0.00 /
      DATA B(37555), B(37556), B(37557) /    -3.17,  -22.48,    0.00 /
      DATA B(37846), B(37847), B(37848) /    -3.22,  -22.43,    0.00 /
      DATA B(38137), B(38138), B(38139) /    -3.27,  -22.38,    0.00 /
      DATA B(38428), B(38429), B(38430) /    -3.31,  -22.32,    0.00 /
      DATA B(38719), B(38720), B(38721) /    -3.36,  -22.27,    0.00 /
      DATA B(39010), B(39011), B(39012) /    -3.41,  -22.21,    0.00 /
      DATA B(39301), B(39302), B(39303) /    -3.46,  -22.16,    0.00 /
      DATA B(39592), B(39593), B(39594) /    -3.51,  -22.10,    0.00 /
      DATA B(39883), B(39884), B(39885) /    -3.56,  -22.04,    0.00 /
      DATA B(40174), B(40175), B(40176) /    -3.61,  -21.99,    0.00 /
      DATA B(40465), B(40466), B(40467) /    -3.66,  -21.93,    0.00 /
      DATA B(40756), B(40757), B(40758) /    -3.71,  -21.87,    0.00 /
      DATA B(41047), B(41048), B(41049) /    -3.76,  -21.81,    0.00 /
      DATA B(41338), B(41339), B(41340) /    -3.82,  -21.75,    0.00 /
      DATA B(41629), B(41630), B(41631) /    -3.88,  -21.69,    0.00 /
      DATA B(41920), B(41921), B(41922) /    -3.94,  -21.64,    0.00 /
      DATA B(42211), B(42212), B(42213) /    -4.00,  -21.58,    0.00 /
      DATA B(42502), B(42503), B(42504) /    -4.06,  -21.53,    0.00 /
      DATA B(42793), B(42794), B(42795) /    -4.12,  -21.48,    0.00 /
      DATA B(43084), B(43085), B(43086) /    -4.18,  -21.42,    0.00 /
      DATA B(43375), B(43376), B(43377) /    -4.24,  -21.37,    0.00 /
      DATA B(43666), B(43667), B(43668) /    -4.30,  -21.31,    0.00 /
      DATA B(43957), B(43958), B(43959) /    -4.35,  -21.25,    0.00 /
      DATA B(44248), B(44249), B(44250) /    -4.41,  -21.18,    0.00 /
      DATA B(44539), B(44540), B(44541) /    -4.48,  -21.11,    0.00 /
      DATA B(44830), B(44831), B(44832) /    -4.54,  -21.02,    0.00 /
      DATA B(45121), B(45122), B(45123) /    -4.61,  -20.93,    0.00 /
      DATA B(45412), B(45413), B(45414) /    -4.68,  -20.82,    0.00 /
      DATA B(45703), B(45704), B(45705) /    -4.76,  -20.70,    0.00 /
      DATA B(45994), B(45995), B(45996) /    -4.86,  -20.56,    0.00 /
      DATA B(46285), B(46286), B(46287) /    -4.97,  -20.37,    0.00 /
      DATA B(27664), B(27665), B(27666) /    21.43,  -37.57,    0.00 /
      DATA B(27955), B(27956), B(27957) /    21.40,  -37.97,    0.00 /
      DATA B(28246), B(28247), B(28248) /    21.47,  -38.31,    0.00 /
      DATA B(28537), B(28538), B(28539) /     2.29,  -21.27,    0.00 /
      DATA B(28828), B(28829), B(28830) /     1.95,  -21.44,    0.00 /
      DATA B(29119), B(29120), B(29121) /     1.58,  -21.51,    0.00 /
      DATA B(29410), B(29411), B(29412) /     1.19,  -21.55,    0.00 /
      DATA B(29701), B(29702), B(29703) /     0.79,  -21.57,    0.00 /
      DATA B(29992), B(29993), B(29994) /     0.39,  -21.59,    0.00 /
      DATA B(30283), B(30284), B(30285) /     0.00,  -21.59,    0.00 /
      DATA B(30574), B(30575), B(30576) /    -0.38,  -21.59,    0.00 /
      DATA B(30865), B(30866), B(30867) /    -0.77,  -21.58,    0.00 /
      DATA B(31156), B(31157), B(31158) /    -1.94,  -23.25,    0.00 /
      DATA B(31447), B(31448), B(31449) /    -2.02,  -23.23,    0.00 /
      DATA B(31738), B(31739), B(31740) /    -2.09,  -23.20,    0.00 /
      DATA B(32029), B(32030), B(32031) /    -2.16,  -23.17,    0.00 /
      DATA B(32320), B(32321), B(32322) /    -2.22,  -23.14,    0.00 /
      DATA B(32611), B(32612), B(32613) /    -2.27,  -23.11,    0.00 /
      DATA B(32902), B(32903), B(32904) /    -2.33,  -23.08,    0.00 /
      DATA B(33193), B(33194), B(33195) /    -2.38,  -23.05,    0.00 /
      DATA B(33484), B(33485), B(33486) /    -2.44,  -23.03,    0.00 /
      DATA B(33775), B(33776), B(33777) /    -2.49,  -23.00,    0.00 /
      DATA B(34066), B(34067), B(34068) /    -2.54,  -22.97,    0.00 /
      DATA B(34357), B(34358), B(34359) /    -2.60,  -22.94,    0.00 /
      DATA B(34648), B(34649), B(34650) /    -2.65,  -22.90,    0.00 /
      DATA B(34939), B(34940), B(34941) /    -2.71,  -22.86,    0.00 /
      DATA B(35230), B(35231), B(35232) /    -2.76,  -22.82,    0.00 /
      DATA B(35521), B(35522), B(35523) /    -2.81,  -22.77,    0.00 /
      DATA B(35812), B(35813), B(35814) /    -2.86,  -22.72,    0.00 /
      DATA B(36103), B(36104), B(36105) /    -2.91,  -22.67,    0.00 /
      DATA B(36394), B(36395), B(36396) /    -2.96,  -22.62,    0.00 /
      DATA B(36685), B(36686), B(36687) /    -3.01,  -22.57,    0.00 /
      DATA B(36976), B(36977), B(36978) /    -3.06,  -22.52,    0.00 /
      DATA B(37267), B(37268), B(37269) /    -3.11,  -22.46,    0.00 /
      DATA B(37558), B(37559), B(37560) /    -3.16,  -22.41,    0.00 /
      DATA B(37849), B(37850), B(37851) /    -3.20,  -22.36,    0.00 /
      DATA B(38140), B(38141), B(38142) /    -3.25,  -22.31,    0.00 /
      DATA B(38431), B(38432), B(38433) /    -3.30,  -22.25,    0.00 /
      DATA B(38722), B(38723), B(38724) /    -3.34,  -22.20,    0.00 /
      DATA B(39013), B(39014), B(39015) /    -3.39,  -22.14,    0.00 /
      DATA B(39304), B(39305), B(39306) /    -3.44,  -22.09,    0.00 /
      DATA B(39595), B(39596), B(39597) /    -3.49,  -22.03,    0.00 /
      DATA B(39886), B(39887), B(39888) /    -3.53,  -21.97,    0.00 /
      DATA B(40177), B(40178), B(40179) /    -3.58,  -21.91,    0.00 /
      DATA B(40468), B(40469), B(40470) /    -3.63,  -21.85,    0.00 /
      DATA B(40759), B(40760), B(40761) /    -3.69,  -21.79,    0.00 /
      DATA B(41050), B(41051), B(41052) /    -3.74,  -21.73,    0.00 /
      DATA B(41341), B(41342), B(41343) /    -3.80,  -21.67,    0.00 /
      DATA B(41632), B(41633), B(41634) /    -3.86,  -21.61,    0.00 /
      DATA B(41923), B(41924), B(41925) /    -3.92,  -21.55,    0.00 /
      DATA B(42214), B(42215), B(42216) /    -3.98,  -21.50,    0.00 /
      DATA B(42505), B(42506), B(42507) /    -4.04,  -21.45,    0.00 /
      DATA B(42796), B(42797), B(42798) /    -4.10,  -21.40,    0.00 /
      DATA B(43087), B(43088), B(43089) /    -4.17,  -21.35,    0.00 /
      DATA B(43378), B(43379), B(43380) /    -4.23,  -21.30,    0.00 /
      DATA B(43669), B(43670), B(43671) /    -4.29,  -21.24,    0.00 /
      DATA B(43960), B(43961), B(43962) /    -4.35,  -21.18,    0.00 /
      DATA B(44251), B(44252), B(44253) /    -4.42,  -21.11,    0.00 /
      DATA B(44542), B(44543), B(44544) /    -4.49,  -21.04,    0.00 /
      DATA B(44833), B(44834), B(44835) /    -4.56,  -20.95,    0.00 /
      DATA B(45124), B(45125), B(45126) /    -4.63,  -20.84,    0.00 /
      DATA B(45415), B(45416), B(45417) /    -4.72,  -20.72,    0.00 /
      DATA B(45706), B(45707), B(45708) /    -4.82,  -20.59,    0.00 /
      DATA B(45997), B(45998), B(45999) /    -4.95,  -20.42,    0.00 /
      DATA B(46288), B(46289), B(46290) /    -5.08,  -20.28,    0.00 /
      DATA B(27667), B(27668), B(27669) /    21.22,  -37.10,    0.00 /
      DATA B(27958), B(27959), B(27960) /    21.32,  -37.89,    0.00 /
      DATA B(28249), B(28250), B(28251) /     2.53,  -21.01,    0.00 /
      DATA B(28540), B(28541), B(28542) /     2.25,  -21.26,    0.00 /
      DATA B(28831), B(28832), B(28833) /     1.88,  -21.36,    0.00 /
      DATA B(29122), B(29123), B(29124) /     1.47,  -21.42,    0.00 /
      DATA B(29413), B(29414), B(29415) /     1.05,  -21.44,    0.00 /
      DATA B(29704), B(29705), B(29706) /     0.63,  -21.45,    0.00 /
      DATA B(29995), B(29996), B(29997) /     0.22,  -21.45,    0.00 /
      DATA B(30286), B(30287), B(30288) /    -0.18,  -21.44,    0.00 /
      DATA B(30577), B(30578), B(30579) /    -0.56,  -21.44,    0.00 /
      DATA B(30868), B(30869), B(30870) /    -1.83,  -23.18,    0.00 /
      DATA B(31159), B(31160), B(31161) /    -1.91,  -23.16,    0.00 /
      DATA B(31450), B(31451), B(31452) /    -2.00,  -23.15,    0.00 /
      DATA B(31741), B(31742), B(31743) /    -2.07,  -23.12,    0.00 /
      DATA B(32032), B(32033), B(32034) /    -2.14,  -23.10,    0.00 /
      DATA B(32323), B(32324), B(32325) /    -2.20,  -23.07,    0.00 /
      DATA B(32614), B(32615), B(32616) /    -2.26,  -23.04,    0.00 /
      DATA B(32905), B(32906), B(32907) /    -2.32,  -23.01,    0.00 /
      DATA B(33196), B(33197), B(33198) /    -2.37,  -22.98,    0.00 /
      DATA B(33487), B(33488), B(33489) /    -2.42,  -22.95,    0.00 /
      DATA B(33778), B(33779), B(33780) /    -2.48,  -22.92,    0.00 /
      DATA B(34069), B(34070), B(34071) /    -2.53,  -22.89,    0.00 /
      DATA B(34360), B(34361), B(34362) /    -2.58,  -22.86,    0.00 /
      DATA B(34651), B(34652), B(34653) /    -2.64,  -22.82,    0.00 /
      DATA B(34942), B(34943), B(34944) /    -2.69,  -22.78,    0.00 /
      DATA B(35233), B(35234), B(35235) /    -2.74,  -22.74,    0.00 /
      DATA B(35524), B(35525), B(35526) /    -2.80,  -22.69,    0.00 /
      DATA B(35815), B(35816), B(35817) /    -2.85,  -22.65,    0.00 /
      DATA B(36106), B(36107), B(36108) /    -2.90,  -22.60,    0.00 /
      DATA B(36397), B(36398), B(36399) /    -2.95,  -22.55,    0.00 /
      DATA B(36688), B(36689), B(36690) /    -2.99,  -22.50,    0.00 /
      DATA B(36979), B(36980), B(36981) /    -3.04,  -22.45,    0.00 /
      DATA B(37270), B(37271), B(37272) /    -3.09,  -22.39,    0.00 /
      DATA B(37561), B(37562), B(37563) /    -3.14,  -22.34,    0.00 /
      DATA B(37852), B(37853), B(37854) /    -3.18,  -22.29,    0.00 /
      DATA B(38143), B(38144), B(38145) /    -3.23,  -22.24,    0.00 /
      DATA B(38434), B(38435), B(38436) /    -3.28,  -22.18,    0.00 /
      DATA B(38725), B(38726), B(38727) /    -3.32,  -22.13,    0.00 /
      DATA B(39016), B(39017), B(39018) /    -3.37,  -22.08,    0.00 /
      DATA B(39307), B(39308), B(39309) /    -3.42,  -22.02,    0.00 /
      DATA B(39598), B(39599), B(39600) /    -3.47,  -21.96,    0.00 /
      DATA B(39889), B(39890), B(39891) /    -3.51,  -21.90,    0.00 /
      DATA B(40180), B(40181), B(40182) /    -3.56,  -21.84,    0.00 /
      DATA B(40471), B(40472), B(40473) /    -3.61,  -21.78,    0.00 /
      DATA B(40762), B(40763), B(40764) /    -3.66,  -21.71,    0.00 /
      DATA B(41053), B(41054), B(41055) /    -3.72,  -21.65,    0.00 /
      DATA B(41344), B(41345), B(41346) /    -3.78,  -21.59,    0.00 /
      DATA B(41635), B(41636), B(41637) /    -3.84,  -21.53,    0.00 /
      DATA B(41926), B(41927), B(41928) /    -3.90,  -21.47,    0.00 /
      DATA B(42217), B(42218), B(42219) /    -3.96,  -21.42,    0.00 /
      DATA B(42508), B(42509), B(42510) /    -4.03,  -21.36,    0.00 /
      DATA B(42799), B(42800), B(42801) /    -4.09,  -21.32,    0.00 /
      DATA B(43090), B(43091), B(43092) /    -4.16,  -21.27,    0.00 /
      DATA B(43381), B(43382), B(43383) /    -4.23,  -21.22,    0.00 /
      DATA B(43672), B(43673), B(43674) /    -4.29,  -21.17,    0.00 /
      DATA B(43963), B(43964), B(43965) /    -4.36,  -21.11,    0.00 /
      DATA B(44254), B(44255), B(44256) /    -4.43,  -21.04,    0.00 /
      DATA B(44545), B(44546), B(44547) /    -4.51,  -20.96,    0.00 /
      DATA B(44836), B(44837), B(44838) /    -4.59,  -20.86,    0.00 /
      DATA B(45127), B(45128), B(45129) /    -4.68,  -20.74,    0.00 /
      DATA B(45418), B(45419), B(45420) /    -4.79,  -20.61,    0.00 /
      DATA B(45709), B(45710), B(45711) /    -4.92,  -20.45,    0.00 /
      DATA B(46000), B(46001), B(46002) /    -5.07,  -20.33,    0.00 /
      DATA B(46291), B(46292), B(46293) /    -5.22,  -20.18,    0.00 /
      DATA B(27670), B(27671), B(27672) /    21.09,  -36.42,    0.00 /
      DATA B(27961), B(27962), B(27963) /     2.94,  -20.70,    0.00 /
      DATA B(28252), B(28253), B(28254) /     2.81,  -21.13,    0.00 /
      DATA B(28543), B(28544), B(28545) /     2.35,  -21.24,    0.00 /
      DATA B(28834), B(28835), B(28836) /     1.86,  -21.29,    0.00 /
      DATA B(29125), B(29126), B(29127) /     1.38,  -21.32,    0.00 /
      DATA B(29416), B(29417), B(29418) /     0.92,  -21.33,    0.00 /
      DATA B(29707), B(29708), B(29709) /     0.48,  -21.32,    0.00 /
      DATA B(29998), B(29999), B(30000) /     0.06,  -21.31,    0.00 /
      DATA B(30289), B(30290), B(30291) /    -0.35,  -21.30,    0.00 /
      DATA B(30580), B(30581), B(30582) /    -1.70,  -23.11,    0.00 /
      DATA B(30871), B(30872), B(30873) /    -1.80,  -23.10,    0.00 /
      DATA B(31162), B(31163), B(31164) /    -1.89,  -23.09,    0.00 /
      DATA B(31453), B(31454), B(31455) /    -1.97,  -23.07,    0.00 /
      DATA B(31744), B(31745), B(31746) /    -2.05,  -23.05,    0.00 /
      DATA B(32035), B(32036), B(32037) /    -2.12,  -23.03,    0.00 /
      DATA B(32326), B(32327), B(32328) /    -2.18,  -23.00,    0.00 /
      DATA B(32617), B(32618), B(32619) /    -2.24,  -22.97,    0.00 /
      DATA B(32908), B(32909), B(32910) /    -2.30,  -22.94,    0.00 /
      DATA B(33199), B(33200), B(33201) /    -2.35,  -22.91,    0.00 /
      DATA B(33490), B(33491), B(33492) /    -2.41,  -22.88,    0.00 /
      DATA B(33781), B(33782), B(33783) /    -2.46,  -22.85,    0.00 /
      DATA B(34072), B(34073), B(34074) /    -2.51,  -22.82,    0.00 /
      DATA B(34363), B(34364), B(34365) /    -2.57,  -22.78,    0.00 /
      DATA B(34654), B(34655), B(34656) /    -2.62,  -22.74,    0.00 /
      DATA B(34945), B(34946), B(34947) /    -2.67,  -22.70,    0.00 /
      DATA B(35236), B(35237), B(35238) /    -2.72,  -22.66,    0.00 /
      DATA B(35527), B(35528), B(35529) /    -2.78,  -22.62,    0.00 /
      DATA B(35818), B(35819), B(35820) /    -2.83,  -22.57,    0.00 /
      DATA B(36109), B(36110), B(36111) /    -2.88,  -22.52,    0.00 /
      DATA B(36400), B(36401), B(36402) /    -2.93,  -22.48,    0.00 /
      DATA B(36691), B(36692), B(36693) /    -2.97,  -22.43,    0.00 /
      DATA B(36982), B(36983), B(36984) /    -3.02,  -22.38,    0.00 /
      DATA B(37273), B(37274), B(37275) /    -3.07,  -22.32,    0.00 /
      DATA B(37564), B(37565), B(37566) /    -3.12,  -22.27,    0.00 /
      DATA B(37855), B(37856), B(37857) /    -3.16,  -22.22,    0.00 /
      DATA B(38146), B(38147), B(38148) /    -3.21,  -22.17,    0.00 /
      DATA B(38437), B(38438), B(38439) /    -3.26,  -22.12,    0.00 /
      DATA B(38728), B(38729), B(38730) /    -3.30,  -22.06,    0.00 /
      DATA B(39019), B(39020), B(39021) /    -3.35,  -22.01,    0.00 /
      DATA B(39310), B(39311), B(39312) /    -3.40,  -21.95,    0.00 /
      DATA B(39601), B(39602), B(39603) /    -3.44,  -21.89,    0.00 /
      DATA B(39892), B(39893), B(39894) /    -3.49,  -21.83,    0.00 /
      DATA B(40183), B(40184), B(40185) /    -3.54,  -21.77,    0.00 /
      DATA B(40474), B(40475), B(40476) /    -3.59,  -21.70,    0.00 /
      DATA B(40765), B(40766), B(40767) /    -3.64,  -21.64,    0.00 /
      DATA B(41056), B(41057), B(41058) /    -3.69,  -21.57,    0.00 /
      DATA B(41347), B(41348), B(41349) /    -3.75,  -21.50,    0.00 /
      DATA B(41638), B(41639), B(41640) /    -3.81,  -21.44,    0.00 /
      DATA B(41929), B(41930), B(41931) /    -3.88,  -21.38,    0.00 /
      DATA B(42220), B(42221), B(42222) /    -3.95,  -21.33,    0.00 /
      DATA B(42511), B(42512), B(42513) /    -4.01,  -21.28,    0.00 /
      DATA B(42802), B(42803), B(42804) /    -4.08,  -21.23,    0.00 /
      DATA B(43093), B(43094), B(43095) /    -4.16,  -21.18,    0.00 /
      DATA B(43384), B(43385), B(43386) /    -4.23,  -21.14,    0.00 /
      DATA B(43675), B(43676), B(43677) /    -4.31,  -21.09,    0.00 /
      DATA B(43966), B(43967), B(43968) /    -4.38,  -21.03,    0.00 /
      DATA B(44257), B(44258), B(44259) /    -4.46,  -20.96,    0.00 /
      DATA B(44548), B(44549), B(44550) /    -4.55,  -20.87,    0.00 /
      DATA B(44839), B(44840), B(44841) /    -4.65,  -20.76,    0.00 /
      DATA B(45130), B(45131), B(45132) /    -4.76,  -20.61,    0.00 /
      DATA B(45421), B(45422), B(45423) /    -4.89,  -20.48,    0.00 /
      DATA B(45712), B(45713), B(45714) /    -5.06,  -20.36,    0.00 /
      DATA B(46003), B(46004), B(46005) /    -5.21,  -20.22,    0.00 /
      DATA B(46294), B(46295), B(46296) /    -5.37,  -20.07,    0.00 /
      DATA B(27673), B(27674), B(27675) /    19.49,  -35.64,    0.00 /
      DATA B(27964), B(27965), B(27966) /     4.30,  -21.04,    0.00 /
      DATA B(28255), B(28256), B(28257) /     3.23,  -21.14,    0.00 /
      DATA B(28546), B(28547), B(28548) /     2.46,  -21.18,    0.00 /
      DATA B(28837), B(28838), B(28839) /     1.83,  -21.21,    0.00 /
      DATA B(29128), B(29129), B(29130) /     1.29,  -21.21,    0.00 /
      DATA B(29419), B(29420), B(29421) /     0.79,  -21.21,    0.00 /
      DATA B(29710), B(29711), B(29712) /     0.34,  -21.19,    0.00 /
      DATA B(30001), B(30002), B(30003) /    -0.10,  -21.18,    0.00 /
      DATA B(30292), B(30293), B(30294) /    -1.55,  -23.04,    0.00 /
      DATA B(30583), B(30584), B(30585) /    -1.66,  -23.03,    0.00 /
      DATA B(30874), B(30875), B(30876) /    -1.76,  -23.03,    0.00 /
      DATA B(31165), B(31166), B(31167) /    -1.86,  -23.02,    0.00 /
      DATA B(31456), B(31457), B(31458) /    -1.94,  -23.00,    0.00 /
      DATA B(31747), B(31748), B(31749) /    -2.02,  -22.98,    0.00 /
      DATA B(32038), B(32039), B(32040) /    -2.09,  -22.96,    0.00 /
      DATA B(32329), B(32330), B(32331) /    -2.16,  -22.93,    0.00 /
      DATA B(32620), B(32621), B(32622) /    -2.22,  -22.90,    0.00 /
      DATA B(32911), B(32912), B(32913) /    -2.27,  -22.87,    0.00 /
      DATA B(33202), B(33203), B(33204) /    -2.33,  -22.84,    0.00 /
      DATA B(33493), B(33494), B(33495) /    -2.39,  -22.81,    0.00 /
      DATA B(33784), B(33785), B(33786) /    -2.44,  -22.78,    0.00 /
      DATA B(34075), B(34076), B(34077) /    -2.49,  -22.74,    0.00 /
      DATA B(34366), B(34367), B(34368) /    -2.55,  -22.71,    0.00 /
      DATA B(34657), B(34658), B(34659) /    -2.60,  -22.67,    0.00 /
      DATA B(34948), B(34949), B(34950) /    -2.65,  -22.63,    0.00 /
      DATA B(35239), B(35240), B(35241) /    -2.70,  -22.59,    0.00 /
      DATA B(35530), B(35531), B(35532) /    -2.75,  -22.55,    0.00 /
      DATA B(35821), B(35822), B(35823) /    -2.80,  -22.50,    0.00 /
      DATA B(36112), B(36113), B(36114) /    -2.85,  -22.45,    0.00 /
      DATA B(36403), B(36404), B(36405) /    -2.90,  -22.41,    0.00 /
      DATA B(36694), B(36695), B(36696) /    -2.95,  -22.36,    0.00 /
      DATA B(36985), B(36986), B(36987) /    -3.00,  -22.31,    0.00 /
      DATA B(37276), B(37277), B(37278) /    -3.05,  -22.26,    0.00 /
      DATA B(37567), B(37568), B(37569) /    -3.10,  -22.21,    0.00 /
      DATA B(37858), B(37859), B(37860) /    -3.14,  -22.15,    0.00 /
      DATA B(38149), B(38150), B(38151) /    -3.19,  -22.10,    0.00 /
      DATA B(38440), B(38441), B(38442) /    -3.24,  -22.05,    0.00 /
      DATA B(38731), B(38732), B(38733) /    -3.28,  -22.00,    0.00 /
      DATA B(39022), B(39023), B(39024) /    -3.33,  -21.94,    0.00 /
      DATA B(39313), B(39314), B(39315) /    -3.38,  -21.88,    0.00 /
      DATA B(39604), B(39605), B(39606) /    -3.42,  -21.83,    0.00 /
      DATA B(39895), B(39896), B(39897) /    -3.47,  -21.76,    0.00 /
      DATA B(40186), B(40187), B(40188) /    -3.51,  -21.70,    0.00 /
      DATA B(40477), B(40478), B(40479) /    -3.56,  -21.63,    0.00 /
      DATA B(40768), B(40769), B(40770) /    -3.61,  -21.56,    0.00 /
      DATA B(41059), B(41060), B(41061) /    -3.67,  -21.48,    0.00 /
      DATA B(41350), B(41351), B(41352) /    -3.73,  -21.41,    0.00 /
      DATA B(41641), B(41642), B(41643) /    -3.79,  -21.34,    0.00 /
      DATA B(41932), B(41933), B(41934) /    -3.86,  -21.28,    0.00 /
      DATA B(42223), B(42224), B(42225) /    -3.93,  -21.23,    0.00 /
      DATA B(42514), B(42515), B(42516) /    -4.01,  -21.18,    0.00 /
      DATA B(42805), B(42806), B(42807) /    -4.08,  -21.13,    0.00 /
      DATA B(43096), B(43097), B(43098) /    -4.16,  -21.09,    0.00 /
      DATA B(43387), B(43388), B(43389) /    -4.24,  -21.05,    0.00 /
      DATA B(43678), B(43679), B(43680) /    -4.33,  -21.00,    0.00 /
      DATA B(43969), B(43970), B(43971) /    -4.42,  -20.94,    0.00 /
      DATA B(44260), B(44261), B(44262) /    -4.51,  -20.87,    0.00 /
      DATA B(44551), B(44552), B(44553) /    -4.62,  -20.77,    0.00 /
      DATA B(44842), B(44843), B(44844) /    -4.74,  -20.63,    0.00 /
      DATA B(45133), B(45134), B(45135) /    -4.87,  -20.51,    0.00 /
      DATA B(45424), B(45425), B(45426) /    -5.04,  -20.38,    0.00 /
      DATA B(45715), B(45716), B(45717) /    -5.19,  -20.25,    0.00 /
      DATA B(46006), B(46007), B(46008) /    -5.35,  -20.11,    0.00 /
      DATA B(46297), B(46298), B(46299) /    -5.49,  -19.97,    0.00 /
      DATA B(27676), B(27677), B(27678) /     5.72,  -22.18,    0.00 /
      DATA B(27967), B(27968), B(27969) /     4.42,  -21.07,    0.00 /
      DATA B(28258), B(28259), B(28260) /     3.34,  -21.03,    0.00 /
      DATA B(28549), B(28550), B(28551) /     2.46,  -21.07,    0.00 /
      DATA B(28840), B(28841), B(28842) /     1.76,  -21.09,    0.00 /
      DATA B(29131), B(29132), B(29133) /     1.18,  -21.09,    0.00 /
      DATA B(29422), B(29423), B(29424) /     0.66,  -21.07,    0.00 /
      DATA B(29713), B(29714), B(29715) /     0.18,  -21.06,    0.00 /
      DATA B(30004), B(30005), B(30006) /    -1.37,  -22.98,    0.00 /
      DATA B(30295), B(30296), B(30297) /    -1.51,  -22.97,    0.00 /
      DATA B(30586), B(30587), B(30588) /    -1.63,  -22.97,    0.00 /
      DATA B(30877), B(30878), B(30879) /    -1.73,  -22.97,    0.00 /
      DATA B(31168), B(31169), B(31170) /    -1.83,  -22.95,    0.00 /
      DATA B(31459), B(31460), B(31461) /    -1.91,  -22.94,    0.00 /
      DATA B(31750), B(31751), B(31752) /    -1.99,  -22.92,    0.00 /
      DATA B(32041), B(32042), B(32043) /    -2.06,  -22.89,    0.00 /
      DATA B(32332), B(32333), B(32334) /    -2.13,  -22.86,    0.00 /
      DATA B(32623), B(32624), B(32625) /    -2.19,  -22.84,    0.00 /
      DATA B(32914), B(32915), B(32916) /    -2.25,  -22.81,    0.00 /
      DATA B(33205), B(33206), B(33207) /    -2.31,  -22.77,    0.00 /
      DATA B(33496), B(33497), B(33498) /    -2.36,  -22.74,    0.00 /
      DATA B(33787), B(33788), B(33789) /    -2.42,  -22.71,    0.00 /
      DATA B(34078), B(34079), B(34080) /    -2.47,  -22.67,    0.00 /
      DATA B(34369), B(34370), B(34371) /    -2.52,  -22.64,    0.00 /
      DATA B(34660), B(34661), B(34662) /    -2.58,  -22.60,    0.00 /
      DATA B(34951), B(34952), B(34953) /    -2.63,  -22.56,    0.00 /
      DATA B(35242), B(35243), B(35244) /    -2.68,  -22.52,    0.00 /
      DATA B(35533), B(35534), B(35535) /    -2.73,  -22.47,    0.00 /
      DATA B(35824), B(35825), B(35826) /    -2.78,  -22.43,    0.00 /
      DATA B(36115), B(36116), B(36117) /    -2.83,  -22.38,    0.00 /
      DATA B(36406), B(36407), B(36408) /    -2.88,  -22.34,    0.00 /
      DATA B(36697), B(36698), B(36699) /    -2.93,  -22.29,    0.00 /
      DATA B(36988), B(36989), B(36990) /    -2.98,  -22.24,    0.00 /
      DATA B(37279), B(37280), B(37281) /    -3.03,  -22.19,    0.00 /
      DATA B(37570), B(37571), B(37572) /    -3.07,  -22.14,    0.00 /
      DATA B(37861), B(37862), B(37863) /    -3.12,  -22.09,    0.00 /
      DATA B(38152), B(38153), B(38154) /    -3.17,  -22.04,    0.00 /
      DATA B(38443), B(38444), B(38445) /    -3.22,  -21.98,    0.00 /
      DATA B(38734), B(38735), B(38736) /    -3.26,  -21.93,    0.00 /
      DATA B(39025), B(39026), B(39027) /    -3.31,  -21.88,    0.00 /
      DATA B(39316), B(39317), B(39318) /    -3.35,  -21.82,    0.00 /
      DATA B(39607), B(39608), B(39609) /    -3.40,  -21.76,    0.00 /
      DATA B(39898), B(39899), B(39900) /    -3.44,  -21.69,    0.00 /
      DATA B(40189), B(40190), B(40191) /    -3.49,  -21.63,    0.00 /
      DATA B(40480), B(40481), B(40482) /    -3.54,  -21.55,    0.00 /
      DATA B(40771), B(40772), B(40773) /    -3.59,  -21.47,    0.00 /
      DATA B(41062), B(41063), B(41064) /    -3.64,  -21.39,    0.00 /
      DATA B(41353), B(41354), B(41355) /    -3.70,  -21.31,    0.00 /
      DATA B(41644), B(41645), B(41646) /    -3.77,  -21.24,    0.00 /
      DATA B(41935), B(41936), B(41937) /    -3.84,  -21.18,    0.00 /
      DATA B(42226), B(42227), B(42228) /    -3.92,  -21.12,    0.00 /
      DATA B(42517), B(42518), B(42519) /    -4.00,  -21.07,    0.00 /
      DATA B(42808), B(42809), B(42810) /    -4.08,  -21.03,    0.00 /
      DATA B(43099), B(43100), B(43101) /    -4.17,  -20.99,    0.00 /
      DATA B(43390), B(43391), B(43392) /    -4.27,  -20.95,    0.00 /
      DATA B(43681), B(43682), B(43683) /    -4.37,  -20.91,    0.00 /
      DATA B(43972), B(43973), B(43974) /    -4.47,  -20.85,    0.00 /
      DATA B(44263), B(44264), B(44265) /    -4.58,  -20.77,    0.00 /
      DATA B(44554), B(44555), B(44556) /    -4.71,  -20.63,    0.00 /
      DATA B(44845), B(44846), B(44847) /    -4.87,  -20.54,    0.00 /
      DATA B(45136), B(45137), B(45138) /    -5.02,  -20.40,    0.00 /
      DATA B(45427), B(45428), B(45429) /    -5.18,  -20.27,    0.00 /
      DATA B(45718), B(45719), B(45720) /    -5.33,  -20.14,    0.00 /
      DATA B(46009), B(46010), B(46011) /    -5.47,  -20.01,    0.00 /
      DATA B(46300), B(46301), B(46302) /    -5.59,  -19.88,    0.00 /
      DATA B(27679), B(27680), B(27681) /     5.39,  -21.75,    0.00 /
      DATA B(27970), B(27971), B(27972) /     4.12,  -21.09,    0.00 /
      DATA B(28261), B(28262), B(28263) /     3.14,  -20.95,    0.00 /
      DATA B(28552), B(28553), B(28554) /     2.32,  -20.96,    0.00 /
      DATA B(28843), B(28844), B(28845) /     1.63,  -20.96,    0.00 /
      DATA B(29134), B(29135), B(29136) /     1.03,  -20.95,    0.00 /
      DATA B(29425), B(29426), B(29427) /     0.50,  -20.94,    0.00 /
      DATA B(29716), B(29717), B(29718) /    -1.16,  -22.92,    0.00 /
      DATA B(30007), B(30008), B(30009) /    -1.33,  -22.92,    0.00 /
      DATA B(30298), B(30299), B(30300) /    -1.47,  -22.91,    0.00 /
      DATA B(30589), B(30590), B(30591) /    -1.59,  -22.91,    0.00 /
      DATA B(30880), B(30881), B(30882) /    -1.70,  -22.90,    0.00 /
      DATA B(31171), B(31172), B(31173) /    -1.79,  -22.89,    0.00 /
      DATA B(31462), B(31463), B(31464) /    -1.88,  -22.87,    0.00 /
      DATA B(31753), B(31754), B(31755) /    -1.96,  -22.85,    0.00 /
      DATA B(32044), B(32045), B(32046) /    -2.03,  -22.83,    0.00 /
      DATA B(32335), B(32336), B(32337) /    -2.10,  -22.80,    0.00 /
      DATA B(32626), B(32627), B(32628) /    -2.16,  -22.77,    0.00 /
      DATA B(32917), B(32918), B(32919) /    -2.22,  -22.74,    0.00 /
      DATA B(33208), B(33209), B(33210) /    -2.28,  -22.71,    0.00 /
      DATA B(33499), B(33500), B(33501) /    -2.34,  -22.68,    0.00 /
      DATA B(33790), B(33791), B(33792) /    -2.39,  -22.64,    0.00 /
      DATA B(34081), B(34082), B(34083) /    -2.44,  -22.61,    0.00 /
      DATA B(34372), B(34373), B(34374) /    -2.50,  -22.57,    0.00 /
      DATA B(34663), B(34664), B(34665) /    -2.55,  -22.53,    0.00 /
      DATA B(34954), B(34955), B(34956) /    -2.60,  -22.49,    0.00 /
      DATA B(35245), B(35246), B(35247) /    -2.65,  -22.45,    0.00 /
      DATA B(35536), B(35537), B(35538) /    -2.71,  -22.41,    0.00 /
      DATA B(35827), B(35828), B(35829) /    -2.76,  -22.36,    0.00 /
      DATA B(36118), B(36119), B(36120) /    -2.81,  -22.31,    0.00 /
      DATA B(36409), B(36410), B(36411) /    -2.86,  -22.27,    0.00 /
      DATA B(36700), B(36701), B(36702) /    -2.91,  -22.22,    0.00 /
      DATA B(36991), B(36992), B(36993) /    -2.95,  -22.17,    0.00 /
      DATA B(37282), B(37283), B(37284) /    -3.00,  -22.12,    0.00 /
      DATA B(37573), B(37574), B(37575) /    -3.05,  -22.07,    0.00 /
      DATA B(37864), B(37865), B(37866) /    -3.10,  -22.02,    0.00 /
      DATA B(38155), B(38156), B(38157) /    -3.15,  -21.97,    0.00 /
      DATA B(38446), B(38447), B(38448) /    -3.19,  -21.92,    0.00 /
      DATA B(38737), B(38738), B(38739) /    -3.24,  -21.86,    0.00 /
      DATA B(39028), B(39029), B(39030) /    -3.29,  -21.81,    0.00 /
      DATA B(39319), B(39320), B(39321) /    -3.33,  -21.75,    0.00 /
      DATA B(39610), B(39611), B(39612) /    -3.38,  -21.69,    0.00 /
      DATA B(39901), B(39902), B(39903) /    -3.42,  -21.63,    0.00 /
      DATA B(40192), B(40193), B(40194) /    -3.47,  -21.55,    0.00 /
      DATA B(40483), B(40484), B(40485) /    -3.51,  -21.47,    0.00 /
      DATA B(40774), B(40775), B(40776) /    -3.56,  -21.39,    0.00 /
      DATA B(41065), B(41066), B(41067) /    -3.61,  -21.29,    0.00 /
      DATA B(41356), B(41357), B(41358) /    -3.68,  -21.20,    0.00 /
      DATA B(41647), B(41648), B(41649) /    -3.75,  -21.12,    0.00 /
      DATA B(41938), B(41939), B(41940) /    -3.83,  -21.06,    0.00 /
      DATA B(42229), B(42230), B(42231) /    -3.91,  -21.00,    0.00 /
      DATA B(42520), B(42521), B(42522) /    -4.00,  -20.95,    0.00 /
      DATA B(42811), B(42812), B(42813) /    -4.09,  -20.91,    0.00 /
      DATA B(43102), B(43103), B(43104) /    -4.19,  -20.87,    0.00 /
      DATA B(43393), B(43394), B(43395) /    -4.30,  -20.84,    0.00 /
      DATA B(43684), B(43685), B(43686) /    -4.43,  -20.80,    0.00 /
      DATA B(43975), B(43976), B(43977) /    -4.55,  -20.73,    0.00 /
      DATA B(44266), B(44267), B(44268) /    -4.67,  -20.64,    0.00 /
      DATA B(44557), B(44558), B(44559) /    -4.85,  -20.55,    0.00 /
      DATA B(44848), B(44849), B(44850) /    -5.00,  -20.42,    0.00 /
      DATA B(45139), B(45140), B(45141) /    -5.17,  -20.29,    0.00 /
      DATA B(45430), B(45431), B(45432) /    -5.32,  -20.16,    0.00 /
      DATA B(45721), B(45722), B(45723) /    -5.45,  -20.04,    0.00 /
      DATA B(46012), B(46013), B(46014) /    -5.57,  -19.92,    0.00 /
      DATA B(46303), B(46304), B(46305) /    -5.66,  -19.81,    0.00 /
      DATA B(27682), B(27683), B(27684) /     4.61,  -21.63,    0.00 /
      DATA B(27973), B(27974), B(27975) /     3.65,  -21.07,    0.00 /
      DATA B(28264), B(28265), B(28266) /     2.81,  -20.89,    0.00 /
      DATA B(28555), B(28556), B(28557) /     2.08,  -20.85,    0.00 /
      DATA B(28846), B(28847), B(28848) /     1.43,  -20.83,    0.00 /
      DATA B(29137), B(29138), B(29139) /     0.85,  -20.82,    0.00 /
      DATA B(29428), B(29429), B(29430) /    -0.94,  -22.87,    0.00 /
      DATA B(29719), B(29720), B(29721) /    -1.13,  -22.86,    0.00 /
      DATA B(30010), B(30011), B(30012) /    -1.30,  -22.86,    0.00 /
      DATA B(30301), B(30302), B(30303) /    -1.44,  -22.86,    0.00 /
      DATA B(30592), B(30593), B(30594) /    -1.56,  -22.85,    0.00 /
      DATA B(30883), B(30884), B(30885) /    -1.66,  -22.84,    0.00 /
      DATA B(31174), B(31175), B(31176) /    -1.76,  -22.83,    0.00 /
      DATA B(31465), B(31466), B(31467) /    -1.85,  -22.81,    0.00 /
      DATA B(31756), B(31757), B(31758) /    -1.92,  -22.79,    0.00 /
      DATA B(32047), B(32048), B(32049) /    -2.00,  -22.76,    0.00 /
      DATA B(32338), B(32339), B(32340) /    -2.07,  -22.74,    0.00 /
      DATA B(32629), B(32630), B(32631) /    -2.13,  -22.71,    0.00 /
      DATA B(32920), B(32921), B(32922) /    -2.19,  -22.67,    0.00 /
      DATA B(33211), B(33212), B(33213) /    -2.25,  -22.64,    0.00 /
      DATA B(33502), B(33503), B(33504) /    -2.31,  -22.61,    0.00 /
      DATA B(33793), B(33794), B(33795) /    -2.36,  -22.57,    0.00 /
      DATA B(34084), B(34085), B(34086) /    -2.42,  -22.54,    0.00 /
      DATA B(34375), B(34376), B(34377) /    -2.47,  -22.50,    0.00 /
      DATA B(34666), B(34667), B(34668) /    -2.52,  -22.46,    0.00 /
      DATA B(34957), B(34958), B(34959) /    -2.58,  -22.42,    0.00 /
      DATA B(35248), B(35249), B(35250) /    -2.63,  -22.38,    0.00 /
      DATA B(35539), B(35540), B(35541) /    -2.68,  -22.34,    0.00 /
      DATA B(35830), B(35831), B(35832) /    -2.73,  -22.29,    0.00 /
      DATA B(36121), B(36122), B(36123) /    -2.78,  -22.25,    0.00 /
      DATA B(36412), B(36413), B(36414) /    -2.83,  -22.20,    0.00 /
      DATA B(36703), B(36704), B(36705) /    -2.88,  -22.15,    0.00 /
      DATA B(36994), B(36995), B(36996) /    -2.93,  -22.10,    0.00 /
      DATA B(37285), B(37286), B(37287) /    -2.98,  -22.06,    0.00 /
      DATA B(37576), B(37577), B(37578) /    -3.03,  -22.01,    0.00 /
      DATA B(37867), B(37868), B(37869) /    -3.08,  -21.96,    0.00 /
      DATA B(38158), B(38159), B(38160) /    -3.12,  -21.90,    0.00 /
      DATA B(38449), B(38450), B(38451) /    -3.17,  -21.85,    0.00 /
      DATA B(38740), B(38741), B(38742) /    -3.22,  -21.80,    0.00 /
      DATA B(39031), B(39032), B(39033) /    -3.27,  -21.74,    0.00 /
      DATA B(39322), B(39323), B(39324) /    -3.31,  -21.69,    0.00 /
      DATA B(39613), B(39614), B(39615) /    -3.36,  -21.62,    0.00 /
      DATA B(39904), B(39905), B(39906) /    -3.40,  -21.56,    0.00 /
      DATA B(40195), B(40196), B(40197) /    -3.45,  -21.48,    0.00 /
      DATA B(40486), B(40487), B(40488) /    -3.49,  -21.40,    0.00 /
      DATA B(40777), B(40778), B(40779) /    -3.53,  -21.30,    0.00 /
      DATA B(41068), B(41069), B(41070) /    -3.59,  -21.19,    0.00 /
      DATA B(41359), B(41360), B(41361) /    -3.65,  -21.08,    0.00 /
      DATA B(41650), B(41651), B(41652) /    -3.73,  -20.99,    0.00 /
      DATA B(41941), B(41942), B(41943) /    -3.82,  -20.92,    0.00 /
      DATA B(42232), B(42233), B(42234) /    -3.91,  -20.86,    0.00 /
      DATA B(42523), B(42524), B(42525) /    -4.01,  -20.82,    0.00 /
      DATA B(42814), B(42815), B(42816) /    -4.11,  -20.78,    0.00 /
      DATA B(43105), B(43106), B(43107) /    -4.22,  -20.74,    0.00 /
      DATA B(43396), B(43397), B(43398) /    -4.35,  -20.70,    0.00 /
      DATA B(43687), B(43688), B(43689) /    -4.50,  -20.67,    0.00 /
      DATA B(43978), B(43979), B(43980) /    -4.68,  -20.72,    0.00 /
      DATA B(44269), B(44270), B(44271) /    -4.83,  -20.54,    0.00 /
      DATA B(44560), B(44561), B(44562) /    -4.99,  -20.42,    0.00 /
      DATA B(44851), B(44852), B(44853) /    -5.15,  -20.29,    0.00 /
      DATA B(45142), B(45143), B(45144) /    -5.30,  -20.17,    0.00 /
      DATA B(45433), B(45434), B(45435) /    -5.43,  -20.06,    0.00 /
      DATA B(45724), B(45725), B(45726) /    -5.55,  -19.95,    0.00 /
      DATA B(46015), B(46016), B(46017) /    -5.64,  -19.85,    0.00 /
      DATA B(46306), B(46307), B(46308) /    -5.72,  -19.74,    0.00 /
      DATA B(27685), B(27686), B(27687) /     3.98,  -21.51,    0.00 /
      DATA B(27976), B(27977), B(27978) /     3.17,  -21.04,    0.00 /
      DATA B(28267), B(28268), B(28269) /     2.45,  -20.84,    0.00 /
      DATA B(28558), B(28559), B(28560) /     1.80,  -20.75,    0.00 /
      DATA B(28849), B(28850), B(28851) /     1.20,  -20.72,    0.00 /
      DATA B(29140), B(29141), B(29142) /    -0.71,  -22.82,    0.00 /
      DATA B(29431), B(29432), B(29433) /    -0.92,  -22.81,    0.00 /
      DATA B(29722), B(29723), B(29724) /    -1.11,  -22.81,    0.00 /
      DATA B(30013), B(30014), B(30015) /    -1.27,  -22.81,    0.00 /
      DATA B(30304), B(30305), B(30306) /    -1.40,  -22.81,    0.00 /
      DATA B(30595), B(30596), B(30597) /    -1.52,  -22.80,    0.00 /
      DATA B(30886), B(30887), B(30888) /    -1.63,  -22.79,    0.00 /
      DATA B(31177), B(31178), B(31179) /    -1.72,  -22.77,    0.00 /
      DATA B(31468), B(31469), B(31470) /    -1.81,  -22.75,    0.00 /
      DATA B(31759), B(31760), B(31761) /    -1.89,  -22.73,    0.00 /
      DATA B(32050), B(32051), B(32052) /    -1.96,  -22.70,    0.00 /
      DATA B(32341), B(32342), B(32343) /    -2.03,  -22.67,    0.00 /
      DATA B(32632), B(32633), B(32634) /    -2.10,  -22.64,    0.00 /
      DATA B(32923), B(32924), B(32925) /    -2.16,  -22.61,    0.00 /
      DATA B(33214), B(33215), B(33216) /    -2.22,  -22.58,    0.00 /
      DATA B(33505), B(33506), B(33507) /    -2.28,  -22.54,    0.00 /
      DATA B(33796), B(33797), B(33798) /    -2.33,  -22.51,    0.00 /
      DATA B(34087), B(34088), B(34089) /    -2.39,  -22.47,    0.00 /
      DATA B(34378), B(34379), B(34380) /    -2.44,  -22.43,    0.00 /
      DATA B(34669), B(34670), B(34671) /    -2.50,  -22.40,    0.00 /
      DATA B(34960), B(34961), B(34962) /    -2.55,  -22.36,    0.00 /
      DATA B(35251), B(35252), B(35253) /    -2.60,  -22.31,    0.00 /
      DATA B(35542), B(35543), B(35544) /    -2.65,  -22.27,    0.00 /
      DATA B(35833), B(35834), B(35835) /    -2.70,  -22.23,    0.00 /
      DATA B(36124), B(36125), B(36126) /    -2.76,  -22.18,    0.00 /
      DATA B(36415), B(36416), B(36417) /    -2.81,  -22.13,    0.00 /
      DATA B(36706), B(36707), B(36708) /    -2.86,  -22.09,    0.00 /
      DATA B(36997), B(36998), B(36999) /    -2.91,  -22.04,    0.00 /
      DATA B(37288), B(37289), B(37290) /    -2.95,  -21.99,    0.00 /
      DATA B(37579), B(37580), B(37581) /    -3.00,  -21.94,    0.00 /
      DATA B(37870), B(37871), B(37872) /    -3.05,  -21.89,    0.00 /
      DATA B(38161), B(38162), B(38163) /    -3.10,  -21.84,    0.00 /
      DATA B(38452), B(38453), B(38454) /    -3.15,  -21.79,    0.00 /
      DATA B(38743), B(38744), B(38745) /    -3.20,  -21.73,    0.00 /
      DATA B(39034), B(39035), B(39036) /    -3.25,  -21.68,    0.00 /
      DATA B(39325), B(39326), B(39327) /    -3.30,  -21.62,    0.00 /
      DATA B(39616), B(39617), B(39618) /    -3.34,  -21.56,    0.00 /
      DATA B(39907), B(39908), B(39909) /    -3.39,  -21.49,    0.00 /
      DATA B(40198), B(40199), B(40200) /    -3.43,  -21.41,    0.00 /
      DATA B(40489), B(40490), B(40491) /    -3.47,  -21.32,    0.00 /
      DATA B(40780), B(40781), B(40782) /    -3.51,  -21.21,    0.00 /
      DATA B(41071), B(41072), B(41073) /    -3.56,  -21.07,    0.00 /
      DATA B(41362), B(41363), B(41364) /    -3.63,  -20.94,    0.00 /
      DATA B(41653), B(41654), B(41655) /    -3.72,  -20.84,    0.00 /
      DATA B(41944), B(41945), B(41946) /    -3.82,  -20.76,    0.00 /
      DATA B(42235), B(42236), B(42237) /    -3.92,  -20.71,    0.00 /
      DATA B(42526), B(42527), B(42528) /    -4.02,  -20.66,    0.00 /
      DATA B(42817), B(42818), B(42819) /    -4.14,  -20.62,    0.00 /
      DATA B(43108), B(43109), B(43110) /    -4.26,  -20.57,    0.00 /
      DATA B(43399), B(43400), B(43401) /    -4.62,  -20.89,    0.00 /
      DATA B(43690), B(43691), B(43692) /    -4.75,  -20.72,    0.00 /
      DATA B(43981), B(43982), B(43983) /    -4.88,  -20.57,    0.00 /
      DATA B(44272), B(44273), B(44274) /    -5.02,  -20.41,    0.00 /
      DATA B(44563), B(44564), B(44565) /    -5.16,  -20.29,    0.00 /
      DATA B(44854), B(44855), B(44856) /    -5.30,  -20.18,    0.00 /
      DATA B(45145), B(45146), B(45147) /    -5.42,  -20.07,    0.00 /
      DATA B(45436), B(45437), B(45438) /    -5.53,  -19.98,    0.00 /
      DATA B(45727), B(45728), B(45729) /    -5.62,  -19.88,    0.00 /
      DATA B(46018), B(46019), B(46020) /    -5.70,  -19.78,    0.00 /
      DATA B(46309), B(46310), B(46311) /    -5.77,  -19.68,    0.00 /
      DATA B(27688), B(27689), B(27690) /     3.47,  -21.37,    0.00 /
      DATA B(27979), B(27980), B(27981) /     2.74,  -20.98,    0.00 /
      DATA B(28270), B(28271), B(28272) /     2.10,  -20.76,    0.00 /
      DATA B(28561), B(28562), B(28563) /     1.51,  -20.66,    0.00 /
      DATA B(28852), B(28853), B(28854) /    -0.49,  -22.79,    0.00 /
      DATA B(29143), B(29144), B(29145) /    -0.72,  -22.77,    0.00 /
      DATA B(29434), B(29435), B(29436) /    -0.92,  -22.77,    0.00 /
      DATA B(29725), B(29726), B(29727) /    -1.09,  -22.76,    0.00 /
      DATA B(30016), B(30017), B(30018) /    -1.25,  -22.76,    0.00 /
      DATA B(30307), B(30308), B(30309) /    -1.38,  -22.75,    0.00 /
      DATA B(30598), B(30599), B(30600) /    -1.49,  -22.74,    0.00 /
      DATA B(30889), B(30890), B(30891) /    -1.60,  -22.73,    0.00 /
      DATA B(31180), B(31181), B(31182) /    -1.69,  -22.71,    0.00 /
      DATA B(31471), B(31472), B(31473) /    -1.78,  -22.69,    0.00 /
      DATA B(31762), B(31763), B(31764) /    -1.86,  -22.66,    0.00 /
      DATA B(32053), B(32054), B(32055) /    -1.93,  -22.64,    0.00 /
      DATA B(32344), B(32345), B(32346) /    -2.00,  -22.61,    0.00 /
      DATA B(32635), B(32636), B(32637) /    -2.07,  -22.58,    0.00 /
      DATA B(32926), B(32927), B(32928) /    -2.13,  -22.55,    0.00 /
      DATA B(33217), B(33218), B(33219) /    -2.19,  -22.51,    0.00 /
      DATA B(33508), B(33509), B(33510) /    -2.25,  -22.48,    0.00 /
      DATA B(33799), B(33800), B(33801) /    -2.30,  -22.44,    0.00 /
      DATA B(34090), B(34091), B(34092) /    -2.36,  -22.41,    0.00 /
      DATA B(34381), B(34382), B(34383) /    -2.41,  -22.37,    0.00 /
      DATA B(34672), B(34673), B(34674) /    -2.47,  -22.33,    0.00 /
      DATA B(34963), B(34964), B(34965) /    -2.52,  -22.29,    0.00 /
      DATA B(35254), B(35255), B(35256) /    -2.57,  -22.25,    0.00 /
      DATA B(35545), B(35546), B(35547) /    -2.63,  -22.20,    0.00 /
      DATA B(35836), B(35837), B(35838) /    -2.68,  -22.16,    0.00 /
      DATA B(36127), B(36128), B(36129) /    -2.73,  -22.11,    0.00 /
      DATA B(36418), B(36419), B(36420) /    -2.78,  -22.07,    0.00 /
      DATA B(36709), B(36710), B(36711) /    -2.83,  -22.02,    0.00 /
      DATA B(37000), B(37001), B(37002) /    -2.88,  -21.97,    0.00 /
      DATA B(37291), B(37292), B(37293) /    -2.93,  -21.92,    0.00 /
      DATA B(37582), B(37583), B(37584) /    -2.98,  -21.87,    0.00 /
      DATA B(37873), B(37874), B(37875) /    -3.03,  -21.82,    0.00 /
      DATA B(38164), B(38165), B(38166) /    -3.08,  -21.77,    0.00 /
      DATA B(38455), B(38456), B(38457) /    -3.13,  -21.72,    0.00 /
      DATA B(38746), B(38747), B(38748) /    -3.18,  -21.67,    0.00 /
      DATA B(39037), B(39038), B(39039) /    -3.23,  -21.61,    0.00 /
      DATA B(39328), B(39329), B(39330) /    -3.28,  -21.55,    0.00 /
      DATA B(39619), B(39620), B(39621) /    -3.33,  -21.49,    0.00 /
      DATA B(39910), B(39911), B(39912) /    -3.38,  -21.42,    0.00 /
      DATA B(40201), B(40202), B(40203) /    -3.42,  -21.34,    0.00 /
      DATA B(40492), B(40493), B(40494) /    -3.46,  -21.25,    0.00 /
      DATA B(40783), B(40784), B(40785) /    -3.49,  -21.12,    0.00 /
      DATA B(41074), B(41075), B(41076) /    -3.53,  -20.95,    0.00 /
      DATA B(41365), B(41366), B(41367) /    -3.61,  -20.77,    0.00 /
      DATA B(41656), B(41657), B(41658) /    -3.71,  -20.65,    0.00 /
      DATA B(41947), B(41948), B(41949) /    -3.82,  -20.57,    0.00 /
      DATA B(42238), B(42239), B(42240) /    -3.93,  -20.52,    0.00 /
      DATA B(42529), B(42530), B(42531) /    -4.06,  -20.48,    0.00 /
      DATA B(42820), B(42821), B(42822) /    -4.57,  -21.11,    0.00 /
      DATA B(43111), B(43112), B(43113) /    -4.68,  -20.95,    0.00 /
      DATA B(43402), B(43403), B(43404) /    -4.81,  -20.77,    0.00 /
      DATA B(43693), B(43694), B(43695) /    -4.94,  -20.61,    0.00 /
      DATA B(43984), B(43985), B(43986) /    -5.07,  -20.45,    0.00 /
      DATA B(44275), B(44276), B(44277) /    -5.19,  -20.30,    0.00 /
      DATA B(44566), B(44567), B(44568) /    -5.31,  -20.18,    0.00 /
      DATA B(44857), B(44858), B(44859) /    -5.41,  -20.08,    0.00 /
      DATA B(45148), B(45149), B(45150) /    -5.51,  -19.99,    0.00 /
      DATA B(45439), B(45440), B(45441) /    -5.60,  -19.90,    0.00 /
      DATA B(45730), B(45731), B(45732) /    -5.68,  -19.81,    0.00 /
      DATA B(46021), B(46022), B(46023) /    -5.75,  -19.72,    0.00 /
      DATA B(46312), B(46313), B(46314) /    -5.81,  -19.63,    0.00 /
      DATA B(27691), B(27692), B(27693) /     3.02,  -21.21,    0.00 /
      DATA B(27982), B(27983), B(27984) /     2.36,  -20.88,    0.00 /
      DATA B(28273), B(28274), B(28275) /     1.77,  -20.68,    0.00 /
      DATA B(28564), B(28565), B(28566) /    -0.30,  -22.81,    0.00 /
      DATA B(28855), B(28856), B(28857) /    -0.53,  -22.76,    0.00 /
      DATA B(29146), B(29147), B(29148) /    -0.74,  -22.74,    0.00 /
      DATA B(29437), B(29438), B(29439) /    -0.92,  -22.73,    0.00 /
      DATA B(29728), B(29729), B(29730) /    -1.09,  -22.72,    0.00 /
      DATA B(30019), B(30020), B(30021) /    -1.23,  -22.71,    0.00 /
      DATA B(30310), B(30311), B(30312) /    -1.35,  -22.70,    0.00 /
      DATA B(30601), B(30602), B(30603) /    -1.46,  -22.69,    0.00 /
      DATA B(30892), B(30893), B(30894) /    -1.57,  -22.67,    0.00 /
      DATA B(31183), B(31184), B(31185) /    -1.66,  -22.65,    0.00 /
      DATA B(31474), B(31475), B(31476) /    -1.74,  -22.63,    0.00 /
      DATA B(31765), B(31766), B(31767) /    -1.82,  -22.60,    0.00 /
      DATA B(32056), B(32057), B(32058) /    -1.90,  -22.58,    0.00 /
      DATA B(32347), B(32348), B(32349) /    -1.97,  -22.55,    0.00 /
      DATA B(32638), B(32639), B(32640) /    -2.03,  -22.52,    0.00 /
      DATA B(32929), B(32930), B(32931) /    -2.10,  -22.49,    0.00 /
      DATA B(33220), B(33221), B(33222) /    -2.16,  -22.45,    0.00 /
      DATA B(33511), B(33512), B(33513) /    -2.22,  -22.42,    0.00 /
      DATA B(33802), B(33803), B(33804) /    -2.27,  -22.38,    0.00 /
      DATA B(34093), B(34094), B(34095) /    -2.33,  -22.34,    0.00 /
      DATA B(34384), B(34385), B(34386) /    -2.39,  -22.31,    0.00 /
      DATA B(34675), B(34676), B(34677) /    -2.44,  -22.27,    0.00 /
      DATA B(34966), B(34967), B(34968) /    -2.49,  -22.22,    0.00 /
      DATA B(35257), B(35258), B(35259) /    -2.55,  -22.18,    0.00 /
      DATA B(35548), B(35549), B(35550) /    -2.60,  -22.14,    0.00 /
      DATA B(35839), B(35840), B(35841) /    -2.65,  -22.09,    0.00 /
      DATA B(36130), B(36131), B(36132) /    -2.70,  -22.05,    0.00 /
      DATA B(36421), B(36422), B(36423) /    -2.75,  -22.00,    0.00 /
      DATA B(36712), B(36713), B(36714) /    -2.80,  -21.95,    0.00 /
      DATA B(37003), B(37004), B(37005) /    -2.85,  -21.91,    0.00 /
      DATA B(37294), B(37295), B(37296) /    -2.91,  -21.86,    0.00 /
      DATA B(37585), B(37586), B(37587) /    -2.96,  -21.81,    0.00 /
      DATA B(37876), B(37877), B(37878) /    -3.01,  -21.76,    0.00 /
      DATA B(38167), B(38168), B(38169) /    -3.06,  -21.70,    0.00 /
      DATA B(38458), B(38459), B(38460) /    -3.11,  -21.65,    0.00 /
      DATA B(38749), B(38750), B(38751) /    -3.16,  -21.60,    0.00 /
      DATA B(39040), B(39041), B(39042) /    -3.21,  -21.54,    0.00 /
      DATA B(39331), B(39332), B(39333) /    -3.27,  -21.48,    0.00 /
      DATA B(39622), B(39623), B(39624) /    -3.32,  -21.42,    0.00 /
      DATA B(39913), B(39914), B(39915) /    -3.37,  -21.35,    0.00 /
      DATA B(40204), B(40205), B(40206) /    -3.42,  -21.27,    0.00 /
      DATA B(40495), B(40496), B(40497) /    -3.47,  -21.18,    0.00 /
      DATA B(40786), B(40787), B(40788) /    -3.50,  -21.04,    0.00 /
      DATA B(41077), B(41078), B(41079) /    -3.52,  -20.82,    0.00 /
      DATA B(41368), B(41369), B(41370) /    -3.60,  -20.56,    0.00 /
      DATA B(41659), B(41660), B(41661) /    -3.72,  -20.43,    0.00 /
      DATA B(41950), B(41951), B(41952) /    -3.84,  -20.35,    0.00 /
      DATA B(42241), B(42242), B(42243) /    -4.51,  -21.32,    0.00 /
      DATA B(42532), B(42533), B(42534) /    -4.62,  -21.14,    0.00 /
      DATA B(42823), B(42824), B(42825) /    -4.74,  -20.98,    0.00 /
      DATA B(43114), B(43115), B(43116) /    -4.87,  -20.81,    0.00 /
      DATA B(43405), B(43406), B(43407) /    -5.00,  -20.64,    0.00 /
      DATA B(43696), B(43697), B(43698) /    -5.12,  -20.48,    0.00 /
      DATA B(43987), B(43988), B(43989) /    -5.23,  -20.33,    0.00 /
      DATA B(44278), B(44279), B(44280) /    -5.33,  -20.20,    0.00 /
      DATA B(44569), B(44570), B(44571) /    -5.42,  -20.10,    0.00 /
      DATA B(44860), B(44861), B(44862) /    -5.51,  -20.00,    0.00 /
      DATA B(45151), B(45152), B(45153) /    -5.59,  -19.92,    0.00 /
      DATA B(45442), B(45443), B(45444) /    -5.66,  -19.83,    0.00 /
      DATA B(45733), B(45734), B(45735) /    -5.73,  -19.75,    0.00 /
      DATA B(46024), B(46025), B(46026) /    -5.80,  -19.66,    0.00 /
      DATA B(46315), B(46316), B(46317) /    -5.86,  -19.57,    0.00 /
      DATA B(27694), B(27695), B(27696) /     2.62,  -21.05,    0.00 /
      DATA B(27985), B(27986), B(27987) /     2.01,  -20.78,    0.00 /
      DATA B(28276), B(28277), B(28278) /    -0.14,  -22.90,    0.00 /
      DATA B(28567), B(28568), B(28569) /    -0.37,  -22.80,    0.00 /
      DATA B(28858), B(28859), B(28860) /    -0.58,  -22.74,    0.00 /
      DATA B(29149), B(29150), B(29151) /    -0.76,  -22.71,    0.00 /
      DATA B(29440), B(29441), B(29442) /    -0.93,  -22.69,    0.00 /
      DATA B(29731), B(29732), B(29733) /    -1.08,  -22.68,    0.00 /
      DATA B(30022), B(30023), B(30024) /    -1.21,  -22.67,    0.00 /
      DATA B(30313), B(30314), B(30315) /    -1.33,  -22.65,    0.00 /
      DATA B(30604), B(30605), B(30606) /    -1.44,  -22.64,    0.00 /
      DATA B(30895), B(30896), B(30897) /    -1.54,  -22.62,    0.00 /
      DATA B(31186), B(31187), B(31188) /    -1.63,  -22.60,    0.00 /
      DATA B(31477), B(31478), B(31479) /    -1.71,  -22.57,    0.00 /
      DATA B(31768), B(31769), B(31770) /    -1.79,  -22.55,    0.00 /
      DATA B(32059), B(32060), B(32061) /    -1.87,  -22.52,    0.00 /
      DATA B(32350), B(32351), B(32352) /    -1.93,  -22.49,    0.00 /
      DATA B(32641), B(32642), B(32643) /    -2.00,  -22.46,    0.00 /
      DATA B(32932), B(32933), B(32934) /    -2.07,  -22.42,    0.00 /
      DATA B(33223), B(33224), B(33225) /    -2.13,  -22.39,    0.00 /
      DATA B(33514), B(33515), B(33516) /    -2.19,  -22.36,    0.00 /
      DATA B(33805), B(33806), B(33807) /    -2.24,  -22.32,    0.00 /
      DATA B(34096), B(34097), B(34098) /    -2.30,  -22.28,    0.00 /
      DATA B(34387), B(34388), B(34389) /    -2.36,  -22.24,    0.00 /
      DATA B(34678), B(34679), B(34680) /    -2.41,  -22.20,    0.00 /
      DATA B(34969), B(34970), B(34971) /    -2.46,  -22.16,    0.00 /
      DATA B(35260), B(35261), B(35262) /    -2.52,  -22.12,    0.00 /
      DATA B(35551), B(35552), B(35553) /    -2.57,  -22.07,    0.00 /
      DATA B(35842), B(35843), B(35844) /    -2.62,  -22.03,    0.00 /
      DATA B(36133), B(36134), B(36135) /    -2.67,  -21.98,    0.00 /
      DATA B(36424), B(36425), B(36426) /    -2.73,  -21.94,    0.00 /
      DATA B(36715), B(36716), B(36717) /    -2.78,  -21.89,    0.00 /
      DATA B(37006), B(37007), B(37008) /    -2.83,  -21.84,    0.00 /
      DATA B(37297), B(37298), B(37299) /    -2.88,  -21.79,    0.00 /
      DATA B(37588), B(37589), B(37590) /    -2.93,  -21.74,    0.00 /
      DATA B(37879), B(37880), B(37881) /    -2.99,  -21.69,    0.00 /
      DATA B(38170), B(38171), B(38172) /    -3.04,  -21.64,    0.00 /
      DATA B(38461), B(38462), B(38463) /    -3.09,  -21.58,    0.00 /
      DATA B(38752), B(38753), B(38754) /    -3.15,  -21.53,    0.00 /
      DATA B(39043), B(39044), B(39045) /    -3.20,  -21.47,    0.00 /
      DATA B(39334), B(39335), B(39336) /    -3.26,  -21.41,    0.00 /
      DATA B(39625), B(39626), B(39627) /    -3.32,  -21.35,    0.00 /
      DATA B(39916), B(39917), B(39918) /    -3.38,  -21.28,    0.00 /
      DATA B(40207), B(40208), B(40209) /    -3.44,  -21.20,    0.00 /
      DATA B(40498), B(40499), B(40500) /    -3.50,  -21.11,    0.00 /
      DATA B(40789), B(40790), B(40791) /    -3.56,  -20.99,    0.00 /
      DATA B(41080), B(41081), B(41082) /    -3.55,  -20.74,    0.00 /
      DATA B(41371), B(41372), B(41373) /    -3.61,  -20.27,    0.00 /
      DATA B(41662), B(41663), B(41664) /    -4.44,  -21.48,    0.00 /
      DATA B(41953), B(41954), B(41955) /    -4.54,  -21.34,    0.00 /
      DATA B(42244), B(42245), B(42246) /    -4.65,  -21.16,    0.00 /
      DATA B(42535), B(42536), B(42537) /    -4.78,  -21.00,    0.00 /
      DATA B(42826), B(42827), B(42828) /    -4.91,  -20.83,    0.00 /
      DATA B(43117), B(43118), B(43119) /    -5.04,  -20.67,    0.00 /
      DATA B(43408), B(43409), B(43410) /    -5.15,  -20.52,    0.00 /
      DATA B(43699), B(43700), B(43701) /    -5.26,  -20.37,    0.00 /
      DATA B(43990), B(43991), B(43992) /    -5.35,  -20.24,    0.00 /
      DATA B(44281), B(44282), B(44283) /    -5.43,  -20.12,    0.00 /
      DATA B(44572), B(44573), B(44574) /    -5.50,  -20.02,    0.00 /
      DATA B(44863), B(44864), B(44865) /    -5.58,  -19.93,    0.00 /
      DATA B(45154), B(45155), B(45156) /    -5.65,  -19.85,    0.00 /
      DATA B(45445), B(45446), B(45447) /    -5.71,  -19.77,    0.00 /
      DATA B(45736), B(45737), B(45738) /    -5.78,  -19.68,    0.00 /
      DATA B(46027), B(46028), B(46029) /    -5.84,  -19.61,    0.00 /
      DATA B(46318), B(46319), B(46320) /    -5.89,  -19.52,    0.00 /
      DATA B(27697), B(27698), B(27699) /     2.25,  -20.90,    0.00 /
      DATA B(27988), B(27989), B(27990) /     0.02,  -23.04,    0.00 /
      DATA B(28279), B(28280), B(28281) /    -0.22,  -22.88,    0.00 /
      DATA B(28570), B(28571), B(28572) /    -0.43,  -22.78,    0.00 /
      DATA B(28861), B(28862), B(28863) /    -0.62,  -22.72,    0.00 /
      DATA B(29152), B(29153), B(29154) /    -0.78,  -22.69,    0.00 /
      DATA B(29443), B(29444), B(29445) /    -0.94,  -22.66,    0.00 /
      DATA B(29734), B(29735), B(29736) /    -1.07,  -22.64,    0.00 /
      DATA B(30025), B(30026), B(30027) /    -1.20,  -22.62,    0.00 /
      DATA B(30316), B(30317), B(30318) /    -1.31,  -22.61,    0.00 /
      DATA B(30607), B(30608), B(30609) /    -1.41,  -22.59,    0.00 /
      DATA B(30898), B(30899), B(30900) /    -1.51,  -22.56,    0.00 /
      DATA B(31189), B(31190), B(31191) /    -1.60,  -22.54,    0.00 /
      DATA B(31480), B(31481), B(31482) /    -1.68,  -22.52,    0.00 /
      DATA B(31771), B(31772), B(31773) /    -1.76,  -22.49,    0.00 /
      DATA B(32062), B(32063), B(32064) /    -1.83,  -22.46,    0.00 /
      DATA B(32353), B(32354), B(32355) /    -1.90,  -22.43,    0.00 /
      DATA B(32644), B(32645), B(32646) /    -1.97,  -22.40,    0.00 /
      DATA B(32935), B(32936), B(32937) /    -2.03,  -22.36,    0.00 /
      DATA B(33226), B(33227), B(33228) /    -2.10,  -22.33,    0.00 /
      DATA B(33517), B(33518), B(33519) /    -2.16,  -22.29,    0.00 /
      DATA B(33808), B(33809), B(33810) /    -2.21,  -22.26,    0.00 /
      DATA B(34099), B(34100), B(34101) /    -2.27,  -22.22,    0.00 /
      DATA B(34390), B(34391), B(34392) /    -2.33,  -22.18,    0.00 /
      DATA B(34681), B(34682), B(34683) /    -2.38,  -22.14,    0.00 /
      DATA B(34972), B(34973), B(34974) /    -2.44,  -22.10,    0.00 /
      DATA B(35263), B(35264), B(35265) /    -2.49,  -22.05,    0.00 /
      DATA B(35554), B(35555), B(35556) /    -2.54,  -22.01,    0.00 /
      DATA B(35845), B(35846), B(35847) /    -2.60,  -21.96,    0.00 /
      DATA B(36136), B(36137), B(36138) /    -2.65,  -21.92,    0.00 /
      DATA B(36427), B(36428), B(36429) /    -2.70,  -21.87,    0.00 /
      DATA B(36718), B(36719), B(36720) /    -2.75,  -21.82,    0.00 /
      DATA B(37009), B(37010), B(37011) /    -2.81,  -21.77,    0.00 /
      DATA B(37300), B(37301), B(37302) /    -2.86,  -21.72,    0.00 /
      DATA B(37591), B(37592), B(37593) /    -2.91,  -21.67,    0.00 /
      DATA B(37882), B(37883), B(37884) /    -2.96,  -21.62,    0.00 /
      DATA B(38173), B(38174), B(38175) /    -3.02,  -21.57,    0.00 /
      DATA B(38464), B(38465), B(38466) /    -3.07,  -21.51,    0.00 /
      DATA B(38755), B(38756), B(38757) /    -3.13,  -21.45,    0.00 /
      DATA B(39046), B(39047), B(39048) /    -3.19,  -21.40,    0.00 /
      DATA B(39337), B(39338), B(39339) /    -3.25,  -21.33,    0.00 /
      DATA B(39628), B(39629), B(39630) /    -3.31,  -21.27,    0.00 /
      DATA B(39919), B(39920), B(39921) /    -3.38,  -21.20,    0.00 /
      DATA B(40210), B(40211), B(40212) /    -3.46,  -21.12,    0.00 /
      DATA B(40501), B(40502), B(40503) /    -3.55,  -21.03,    0.00 /
      DATA B(40792), B(40793), B(40794) /    -3.68,  -20.92,    0.00 /
      DATA B(41083), B(41084), B(41085) /    -3.91,  -20.80,    0.00 /
      DATA B(41374), B(41375), B(41376) /    -4.39,  -21.45,    0.00 /
      DATA B(41665), B(41666), B(41667) /    -4.52,  -21.32,    0.00 /
      DATA B(41956), B(41957), B(41958) /    -4.65,  -21.17,    0.00 /
      DATA B(42247), B(42248), B(42249) /    -4.78,  -21.00,    0.00 /
      DATA B(42538), B(42539), B(42540) /    -4.92,  -20.84,    0.00 /
      DATA B(42829), B(42830), B(42831) /    -5.04,  -20.69,    0.00 /
      DATA B(43120), B(43121), B(43122) /    -5.15,  -20.53,    0.00 /
      DATA B(43411), B(43412), B(43413) /    -5.25,  -20.39,    0.00 /
      DATA B(43702), B(43703), B(43704) /    -5.34,  -20.27,    0.00 /
      DATA B(43993), B(43994), B(43995) /    -5.42,  -20.14,    0.00 /
      DATA B(44284), B(44285), B(44286) /    -5.49,  -20.03,    0.00 /
      DATA B(44575), B(44576), B(44577) /    -5.56,  -19.95,    0.00 /
      DATA B(44866), B(44867), B(44868) /    -5.62,  -19.85,    0.00 /
      DATA B(45157), B(45158), B(45159) /    -5.69,  -19.77,    0.00 /
      DATA B(45448), B(45449), B(45450) /    -5.76,  -19.70,    0.00 /
      DATA B(45739), B(45740), B(45741) /    -5.82,  -19.61,    0.00 /
      DATA B(46030), B(46031), B(46032) /    -5.88,  -19.53,    0.00 /
      DATA B(46321), B(46322), B(46323) /    -5.94,  -19.46,    0.00 /
      DATA B(27700), B(27701), B(27702) /    -0.19,  -23.30,    0.00 /
      DATA B(27991), B(27992), B(27993) /    -0.08,  -23.00,    0.00 /
      DATA B(28282), B(28283), B(28284) /    -0.29,  -22.86,    0.00 /
      DATA B(28573), B(28574), B(28575) /    -0.48,  -22.77,    0.00 /
      DATA B(28864), B(28865), B(28866) /    -0.65,  -22.71,    0.00 /
      DATA B(29155), B(29156), B(29157) /    -0.80,  -22.66,    0.00 /
      DATA B(29446), B(29447), B(29448) /    -0.94,  -22.63,    0.00 /
      DATA B(29737), B(29738), B(29739) /    -1.07,  -22.60,    0.00 /
      DATA B(30028), B(30029), B(30030) /    -1.18,  -22.58,    0.00 /
      DATA B(30319), B(30320), B(30321) /    -1.29,  -22.56,    0.00 /
      DATA B(30610), B(30611), B(30612) /    -1.39,  -22.54,    0.00 /
      DATA B(30901), B(30902), B(30903) /    -1.48,  -22.51,    0.00 /
      DATA B(31192), B(31193), B(31194) /    -1.57,  -22.49,    0.00 /
      DATA B(31483), B(31484), B(31485) /    -1.65,  -22.46,    0.00 /
      DATA B(31774), B(31775), B(31776) /    -1.73,  -22.43,    0.00 /
      DATA B(32065), B(32066), B(32067) /    -1.80,  -22.40,    0.00 /
      DATA B(32356), B(32357), B(32358) /    -1.87,  -22.37,    0.00 /
      DATA B(32647), B(32648), B(32649) /    -1.94,  -22.34,    0.00 /
      DATA B(32938), B(32939), B(32940) /    -2.00,  -22.31,    0.00 /
      DATA B(33229), B(33230), B(33231) /    -2.07,  -22.27,    0.00 /
      DATA B(33520), B(33521), B(33522) /    -2.13,  -22.23,    0.00 /
      DATA B(33811), B(33812), B(33813) /    -2.18,  -22.20,    0.00 /
      DATA B(34102), B(34103), B(34104) /    -2.24,  -22.16,    0.00 /
      DATA B(34393), B(34394), B(34395) /    -2.30,  -22.12,    0.00 /
      DATA B(34684), B(34685), B(34686) /    -2.35,  -22.08,    0.00 /
      DATA B(34975), B(34976), B(34977) /    -2.41,  -22.03,    0.00 /
      DATA B(35266), B(35267), B(35268) /    -2.46,  -21.99,    0.00 /
      DATA B(35557), B(35558), B(35559) /    -2.51,  -21.94,    0.00 /
      DATA B(35848), B(35849), B(35850) /    -2.57,  -21.90,    0.00 /
      DATA B(36139), B(36140), B(36141) /    -2.62,  -21.85,    0.00 /
      DATA B(36430), B(36431), B(36432) /    -2.67,  -21.80,    0.00 /
      DATA B(36721), B(36722), B(36723) /    -2.73,  -21.75,    0.00 /
      DATA B(37012), B(37013), B(37014) /    -2.78,  -21.70,    0.00 /
      DATA B(37303), B(37304), B(37305) /    -2.84,  -21.65,    0.00 /
      DATA B(37594), B(37595), B(37596) /    -2.89,  -21.60,    0.00 /
      DATA B(37885), B(37886), B(37887) /    -2.94,  -21.55,    0.00 /
      DATA B(38176), B(38177), B(38178) /    -3.00,  -21.49,    0.00 /
      DATA B(38467), B(38468), B(38469) /    -3.06,  -21.44,    0.00 /
      DATA B(38758), B(38759), B(38760) /    -3.12,  -21.38,    0.00 /
      DATA B(39049), B(39050), B(39051) /    -3.18,  -21.32,    0.00 /
      DATA B(39340), B(39341), B(39342) /    -3.25,  -21.25,    0.00 /
      DATA B(39631), B(39632), B(39633) /    -3.32,  -21.18,    0.00 /
      DATA B(39922), B(39923), B(39924) /    -3.40,  -21.11,    0.00 /
      DATA B(40213), B(40214), B(40215) /    -3.49,  -21.02,    0.00 /
      DATA B(40504), B(40505), B(40506) /    -3.61,  -20.92,    0.00 /
      DATA B(40795), B(40796), B(40797) /    -3.75,  -20.81,    0.00 /
      DATA B(41086), B(41087), B(41088) /    -3.94,  -20.74,    0.00 /
      DATA B(41377), B(41378), B(41379) /    -4.19,  -21.10,    0.00 /
      DATA B(41668), B(41669), B(41670) /    -4.53,  -21.12,    0.00 /
      DATA B(41959), B(41960), B(41961) /    -4.73,  -20.99,    0.00 /
      DATA B(42250), B(42251), B(42252) /    -4.89,  -20.84,    0.00 /
      DATA B(42541), B(42542), B(42543) /    -5.02,  -20.69,    0.00 /
      DATA B(42832), B(42833), B(42834) /    -5.13,  -20.55,    0.00 /
      DATA B(43123), B(43124), B(43125) /    -5.23,  -20.42,    0.00 /
      DATA B(43414), B(43415), B(43416) /    -5.32,  -20.29,    0.00 /
      DATA B(43705), B(43706), B(43707) /    -5.40,  -20.17,    0.00 /
      DATA B(43996), B(43997), B(43998) /    -5.47,  -20.06,    0.00 /
      DATA B(44287), B(44288), B(44289) /    -5.54,  -19.96,    0.00 /
      DATA B(44578), B(44579), B(44580) /    -5.61,  -19.87,    0.00 /
      DATA B(44869), B(44870), B(44871) /    -5.68,  -19.79,    0.00 /
      DATA B(45160), B(45161), B(45162) /    -5.75,  -19.70,    0.00 /
      DATA B(45451), B(45452), B(45453) /    -5.81,  -19.63,    0.00 /
      DATA B(45742), B(45743), B(45744) /    -5.87,  -19.55,    0.00 /
      DATA B(46033), B(46034), B(46035) /    -5.94,  -19.47,    0.00 /
      DATA B(46324), B(46325), B(46326) /    -6.00,  -19.39,    0.00 /
      DATA B(27703), B(27704), B(27705) /     0.06,  -23.14,    0.00 /
      DATA B(27994), B(27995), B(27996) /    -0.17,  -22.97,    0.00 /
      DATA B(28285), B(28286), B(28287) /    -0.35,  -22.84,    0.00 /
      DATA B(28576), B(28577), B(28578) /    -0.52,  -22.75,    0.00 /
      DATA B(28867), B(28868), B(28869) /    -0.68,  -22.69,    0.00 /
      DATA B(29158), B(29159), B(29160) /    -0.81,  -22.64,    0.00 /
      DATA B(29449), B(29450), B(29451) /    -0.94,  -22.60,    0.00 /
      DATA B(29740), B(29741), B(29742) /    -1.06,  -22.57,    0.00 /
      DATA B(30031), B(30032), B(30033) /    -1.17,  -22.54,    0.00 /
      DATA B(30322), B(30323), B(30324) /    -1.27,  -22.51,    0.00 /
      DATA B(30613), B(30614), B(30615) /    -1.37,  -22.49,    0.00 /
      DATA B(30904), B(30905), B(30906) /    -1.46,  -22.46,    0.00 /
      DATA B(31195), B(31196), B(31197) /    -1.54,  -22.43,    0.00 /
      DATA B(31486), B(31487), B(31488) /    -1.62,  -22.41,    0.00 /
      DATA B(31777), B(31778), B(31779) /    -1.70,  -22.38,    0.00 /
      DATA B(32068), B(32069), B(32070) /    -1.77,  -22.35,    0.00 /
      DATA B(32359), B(32360), B(32361) /    -1.84,  -22.31,    0.00 /
      DATA B(32650), B(32651), B(32652) /    -1.91,  -22.28,    0.00 /
      DATA B(32941), B(32942), B(32943) /    -1.97,  -22.25,    0.00 /
      DATA B(33232), B(33233), B(33234) /    -2.03,  -22.21,    0.00 /
      DATA B(33523), B(33524), B(33525) /    -2.10,  -22.17,    0.00 /
      DATA B(33814), B(33815), B(33816) /    -2.15,  -22.14,    0.00 /
      DATA B(34105), B(34106), B(34107) /    -2.21,  -22.10,    0.00 /
      DATA B(34396), B(34397), B(34398) /    -2.27,  -22.06,    0.00 /
      DATA B(34687), B(34688), B(34689) /    -2.32,  -22.01,    0.00 /
      DATA B(34978), B(34979), B(34980) /    -2.38,  -21.97,    0.00 /
      DATA B(35269), B(35270), B(35271) /    -2.43,  -21.93,    0.00 /
      DATA B(35560), B(35561), B(35562) /    -2.49,  -21.88,    0.00 /
      DATA B(35851), B(35852), B(35853) /    -2.54,  -21.83,    0.00 /
      DATA B(36142), B(36143), B(36144) /    -2.59,  -21.79,    0.00 /
      DATA B(36433), B(36434), B(36435) /    -2.65,  -21.74,    0.00 /
      DATA B(36724), B(36725), B(36726) /    -2.70,  -21.69,    0.00 /
      DATA B(37015), B(37016), B(37017) /    -2.76,  -21.63,    0.00 /
      DATA B(37306), B(37307), B(37308) /    -2.81,  -21.58,    0.00 /
      DATA B(37597), B(37598), B(37599) /    -2.87,  -21.53,    0.00 /
      DATA B(37888), B(37889), B(37890) /    -2.93,  -21.48,    0.00 /
      DATA B(38179), B(38180), B(38181) /    -2.99,  -21.42,    0.00 /
      DATA B(38470), B(38471), B(38472) /    -3.05,  -21.36,    0.00 /
      DATA B(38761), B(38762), B(38763) /    -3.11,  -21.30,    0.00 /
      DATA B(39052), B(39053), B(39054) /    -3.18,  -21.24,    0.00 /
      DATA B(39343), B(39344), B(39345) /    -3.25,  -21.17,    0.00 /
      DATA B(39634), B(39635), B(39636) /    -3.33,  -21.09,    0.00 /
      DATA B(39925), B(39926), B(39927) /    -3.42,  -21.00,    0.00 /
      DATA B(40216), B(40217), B(40218) /    -3.53,  -20.90,    0.00 /
      DATA B(40507), B(40508), B(40509) /    -3.66,  -20.79,    0.00 /
      DATA B(40798), B(40799), B(40800) /    -3.84,  -20.68,    0.00 /
      DATA B(41089), B(41090), B(41091) /    -4.00,  -20.66,    0.00 /
      DATA B(41380), B(41381), B(41382) /    -4.23,  -20.84,    0.00 /
      DATA B(41671), B(41672), B(41673) /    -4.54,  -20.90,    0.00 /
      DATA B(41962), B(41963), B(41964) /    -4.77,  -20.82,    0.00 /
      DATA B(42253), B(42254), B(42255) /    -4.93,  -20.70,    0.00 /
      DATA B(42544), B(42545), B(42546) /    -5.06,  -20.57,    0.00 /
      DATA B(42835), B(42836), B(42837) /    -5.17,  -20.44,    0.00 /
      DATA B(43126), B(43127), B(43128) /    -5.26,  -20.32,    0.00 /
      DATA B(43417), B(43418), B(43419) /    -5.35,  -20.21,    0.00 /
      DATA B(43708), B(43709), B(43710) /    -5.43,  -20.10,    0.00 /
      DATA B(43999), B(44000), B(44001) /    -5.50,  -20.00,    0.00 /
      DATA B(44290), B(44291), B(44292) /    -5.58,  -19.90,    0.00 /
      DATA B(44581), B(44582), B(44583) /    -5.65,  -19.81,    0.00 /
      DATA B(44872), B(44873), B(44874) /    -5.72,  -19.73,    0.00 /
      DATA B(45163), B(45164), B(45165) /    -5.79,  -19.65,    0.00 /
      DATA B(45454), B(45455), B(45456) /    -5.86,  -19.57,    0.00 /
      DATA B(45745), B(45746), B(45747) /    -5.92,  -19.49,    0.00 /
      DATA B(46036), B(46037), B(46038) /    -5.99,  -19.41,    0.00 /
      DATA B(46327), B(46328), B(46329) /    -6.06,  -19.34,    0.00 /
      DATA B(27706), B(27707), B(27708) /    -0.03,  -23.09,    0.00 /
      DATA B(27997), B(27998), B(27999) /    -0.23,  -22.94,    0.00 /
      DATA B(28288), B(28289), B(28290) /    -0.40,  -22.82,    0.00 /
      DATA B(28579), B(28580), B(28581) /    -0.56,  -22.73,    0.00 /
      DATA B(28870), B(28871), B(28872) /    -0.70,  -22.66,    0.00 /
      DATA B(29161), B(29162), B(29163) /    -0.82,  -22.61,    0.00 /
      DATA B(29452), B(29453), B(29454) /    -0.94,  -22.57,    0.00 /
      DATA B(29743), B(29744), B(29745) /    -1.05,  -22.53,    0.00 /
      DATA B(30034), B(30035), B(30036) /    -1.16,  -22.50,    0.00 /
      DATA B(30325), B(30326), B(30327) /    -1.26,  -22.47,    0.00 /
      DATA B(30616), B(30617), B(30618) /    -1.35,  -22.44,    0.00 /
      DATA B(30907), B(30908), B(30909) /    -1.44,  -22.41,    0.00 /
      DATA B(31198), B(31199), B(31200) /    -1.52,  -22.38,    0.00 /
      DATA B(31489), B(31490), B(31491) /    -1.60,  -22.35,    0.00 /
      DATA B(31780), B(31781), B(31782) /    -1.67,  -22.32,    0.00 /
      DATA B(32071), B(32072), B(32073) /    -1.74,  -22.29,    0.00 /
      DATA B(32362), B(32363), B(32364) /    -1.81,  -22.26,    0.00 /
      DATA B(32653), B(32654), B(32655) /    -1.88,  -22.22,    0.00 /
      DATA B(32944), B(32945), B(32946) /    -1.94,  -22.19,    0.00 /
      DATA B(33235), B(33236), B(33237) /    -2.01,  -22.15,    0.00 /
      DATA B(33526), B(33527), B(33528) /    -2.07,  -22.11,    0.00 /
      DATA B(33817), B(33818), B(33819) /    -2.12,  -22.08,    0.00 /
      DATA B(34108), B(34109), B(34110) /    -2.18,  -22.04,    0.00 /
      DATA B(34399), B(34400), B(34401) /    -2.24,  -21.99,    0.00 /
      DATA B(34690), B(34691), B(34692) /    -2.30,  -21.95,    0.00 /
      DATA B(34981), B(34982), B(34983) /    -2.35,  -21.91,    0.00 /
      DATA B(35272), B(35273), B(35274) /    -2.41,  -21.86,    0.00 /
      DATA B(35563), B(35564), B(35565) /    -2.46,  -21.82,    0.00 /
      DATA B(35854), B(35855), B(35856) /    -2.51,  -21.77,    0.00 /
      DATA B(36145), B(36146), B(36147) /    -2.57,  -21.72,    0.00 /
      DATA B(36436), B(36437), B(36438) /    -2.62,  -21.67,    0.00 /
      DATA B(36727), B(36728), B(36729) /    -2.68,  -21.62,    0.00 /
      DATA B(37018), B(37019), B(37020) /    -2.74,  -21.56,    0.00 /
      DATA B(37309), B(37310), B(37311) /    -2.79,  -21.51,    0.00 /
      DATA B(37600), B(37601), B(37602) /    -2.85,  -21.46,    0.00 /
      DATA B(37891), B(37892), B(37893) /    -2.91,  -21.40,    0.00 /
      DATA B(38182), B(38183), B(38184) /    -2.97,  -21.34,    0.00 /
      DATA B(38473), B(38474), B(38475) /    -3.04,  -21.28,    0.00 /
      DATA B(38764), B(38765), B(38766) /    -3.10,  -21.22,    0.00 /
      DATA B(39055), B(39056), B(39057) /    -3.18,  -21.15,    0.00 /
      DATA B(39346), B(39347), B(39348) /    -3.26,  -21.07,    0.00 /
      DATA B(39637), B(39638), B(39639) /    -3.35,  -20.98,    0.00 /
      DATA B(39928), B(39929), B(39930) /    -3.46,  -20.89,    0.00 /
      DATA B(40219), B(40220), B(40221) /    -3.59,  -20.77,    0.00 /
      DATA B(40510), B(40511), B(40512) /    -3.77,  -20.65,    0.00 /
      DATA B(40801), B(40802), B(40803) /    -3.96,  -20.55,    0.00 /
      DATA B(41092), B(41093), B(41094) /    -4.13,  -20.53,    0.00 /
      DATA B(41383), B(41384), B(41385) /    -4.34,  -20.61,    0.00 /
      DATA B(41674), B(41675), B(41676) /    -4.58,  -20.65,    0.00 /
      DATA B(41965), B(41966), B(41967) /    -4.79,  -20.61,    0.00 /
      DATA B(42256), B(42257), B(42258) /    -4.95,  -20.51,    0.00 /
      DATA B(42547), B(42548), B(42549) /    -5.08,  -20.41,    0.00 /
      DATA B(42838), B(42839), B(42840) /    -5.18,  -20.30,    0.00 /
      DATA B(43129), B(43130), B(43131) /    -5.28,  -20.19,    0.00 /
      DATA B(43420), B(43421), B(43422) /    -5.37,  -20.09,    0.00 /
      DATA B(43711), B(43712), B(43713) /    -5.45,  -19.99,    0.00 /
      DATA B(44002), B(44003), B(44004) /    -5.53,  -19.89,    0.00 /
      DATA B(44293), B(44294), B(44295) /    -5.60,  -19.80,    0.00 /
      DATA B(44584), B(44585), B(44586) /    -5.68,  -19.72,    0.00 /
      DATA B(44875), B(44876), B(44877) /    -5.75,  -19.63,    0.00 /
      DATA B(45166), B(45167), B(45168) /    -5.82,  -19.55,    0.00 /
      DATA B(45457), B(45458), B(45459) /    -5.89,  -19.48,    0.00 /
      DATA B(45748), B(45749), B(45750) /    -5.96,  -19.40,    0.00 /
      DATA B(46039), B(46040), B(46041) /    -6.03,  -19.32,    0.00 /
      DATA B(46330), B(46331), B(46332) /    -6.10,  -19.25,    0.00 /
      DATA B(27709), B(27710), B(27711) /    -0.11,  -23.05,    0.00 /
      DATA B(28000), B(28001), B(28002) /    -0.28,  -22.90,    0.00 /
      DATA B(28291), B(28292), B(28293) /    -0.44,  -22.79,    0.00 /
      DATA B(28582), B(28583), B(28584) /    -0.58,  -22.70,    0.00 /
      DATA B(28873), B(28874), B(28875) /    -0.71,  -22.63,    0.00 /
      DATA B(29164), B(29165), B(29166) /    -0.83,  -22.58,    0.00 /
      DATA B(29455), B(29456), B(29457) /    -0.94,  -22.53,    0.00 /
      DATA B(29746), B(29747), B(29748) /    -1.05,  -22.49,    0.00 /
      DATA B(30037), B(30038), B(30039) /    -1.15,  -22.46,    0.00 /
      DATA B(30328), B(30329), B(30330) /    -1.24,  -22.42,    0.00 /
      DATA B(30619), B(30620), B(30621) /    -1.33,  -22.39,    0.00 /
      DATA B(30910), B(30911), B(30912) /    -1.41,  -22.36,    0.00 /
      DATA B(31201), B(31202), B(31203) /    -1.49,  -22.33,    0.00 /
      DATA B(31492), B(31493), B(31494) /    -1.57,  -22.30,    0.00 /
      DATA B(31783), B(31784), B(31785) /    -1.65,  -22.27,    0.00 /
      DATA B(32074), B(32075), B(32076) /    -1.72,  -22.23,    0.00 /
      DATA B(32365), B(32366), B(32367) /    -1.78,  -22.20,    0.00 /
      DATA B(32656), B(32657), B(32658) /    -1.85,  -22.17,    0.00 /
      DATA B(32947), B(32948), B(32949) /    -1.91,  -22.13,    0.00 /
      DATA B(33238), B(33239), B(33240) /    -1.98,  -22.09,    0.00 /
      DATA B(33529), B(33530), B(33531) /    -2.04,  -22.05,    0.00 /
      DATA B(33820), B(33821), B(33822) /    -2.10,  -22.02,    0.00 /
      DATA B(34111), B(34112), B(34113) /    -2.15,  -21.97,    0.00 /
      DATA B(34402), B(34403), B(34404) /    -2.21,  -21.93,    0.00 /
      DATA B(34693), B(34694), B(34695) /    -2.27,  -21.89,    0.00 /
      DATA B(34984), B(34985), B(34986) /    -2.32,  -21.85,    0.00 /
      DATA B(35275), B(35276), B(35277) /    -2.38,  -21.80,    0.00 /
      DATA B(35566), B(35567), B(35568) /    -2.43,  -21.75,    0.00 /
      DATA B(35857), B(35858), B(35859) /    -2.49,  -21.70,    0.00 /
      DATA B(36148), B(36149), B(36150) /    -2.54,  -21.65,    0.00 /
      DATA B(36439), B(36440), B(36441) /    -2.60,  -21.60,    0.00 /
      DATA B(36730), B(36731), B(36732) /    -2.66,  -21.55,    0.00 /
      DATA B(37021), B(37022), B(37023) /    -2.72,  -21.49,    0.00 /
      DATA B(37312), B(37313), B(37314) /    -2.78,  -21.44,    0.00 /
      DATA B(37603), B(37604), B(37605) /    -2.84,  -21.38,    0.00 /
      DATA B(37894), B(37895), B(37896) /    -2.90,  -21.32,    0.00 /
      DATA B(38185), B(38186), B(38187) /    -2.96,  -21.26,    0.00 /
      DATA B(38476), B(38477), B(38478) /    -3.03,  -21.19,    0.00 /
      DATA B(38767), B(38768), B(38769) /    -3.11,  -21.12,    0.00 /
      DATA B(39058), B(39059), B(39060) /    -3.19,  -21.05,    0.00 /
      DATA B(39349), B(39350), B(39351) /    -3.28,  -20.96,    0.00 /
      DATA B(39640), B(39641), B(39642) /    -3.39,  -20.86,    0.00 /
      DATA B(39931), B(39932), B(39933) /    -3.52,  -20.75,    0.00 /
      DATA B(40222), B(40223), B(40224) /    -3.71,  -20.62,    0.00 /
      DATA B(40513), B(40514), B(40515) /    -3.91,  -20.50,    0.00 /
      DATA B(40804), B(40805), B(40806) /    -4.10,  -20.40,    0.00 /
      DATA B(41095), B(41096), B(41097) /    -4.27,  -20.36,    0.00 /
      DATA B(41386), B(41387), B(41388) /    -4.44,  -20.39,    0.00 /
      DATA B(41677), B(41678), B(41679) /    -4.64,  -20.41,    0.00 /
      DATA B(41968), B(41969), B(41970) /    -4.81,  -20.37,    0.00 /
      DATA B(42259), B(42260), B(42261) /    -4.96,  -20.30,    0.00 /
      DATA B(42550), B(42551), B(42552) /    -5.09,  -20.22,    0.00 /
      DATA B(42841), B(42842), B(42843) /    -5.20,  -20.12,    0.00 /
      DATA B(43132), B(43133), B(43134) /    -5.29,  -20.03,    0.00 /
      DATA B(43423), B(43424), B(43425) /    -5.38,  -19.93,    0.00 /
      DATA B(43714), B(43715), B(43716) /    -5.46,  -19.84,    0.00 /
      DATA B(44005), B(44006), B(44007) /    -5.54,  -19.75,    0.00 /
      DATA B(44296), B(44297), B(44298) /    -5.62,  -19.67,    0.00 /
      DATA B(44587), B(44588), B(44589) /    -5.70,  -19.59,    0.00 /
      DATA B(44878), B(44879), B(44880) /    -5.77,  -19.51,    0.00 /
      DATA B(45169), B(45170), B(45171) /    -5.85,  -19.43,    0.00 /
      DATA B(45460), B(45461), B(45462) /    -5.92,  -19.36,    0.00 /
      DATA B(45751), B(45752), B(45753) /    -5.99,  -19.28,    0.00 /
      DATA B(46042), B(46043), B(46044) /    -6.07,  -19.21,    0.00 /
      DATA B(46333), B(46334), B(46335) /    -6.14,  -19.14,    0.00 /
      DATA B(27712), B(27713), B(27714) /    -0.17,  -23.00,    0.00 /
      DATA B(28003), B(28004), B(28005) /    -0.33,  -22.87,    0.00 /
      DATA B(28294), B(28295), B(28296) /    -0.47,  -22.76,    0.00 /
      DATA B(28585), B(28586), B(28587) /    -0.60,  -22.68,    0.00 /
      DATA B(28876), B(28877), B(28878) /    -0.72,  -22.61,    0.00 /
      DATA B(29167), B(29168), B(29169) /    -0.83,  -22.55,    0.00 /
      DATA B(29458), B(29459), B(29460) /    -0.94,  -22.50,    0.00 /
      DATA B(29749), B(29750), B(29751) /    -1.04,  -22.45,    0.00 /
      DATA B(30040), B(30041), B(30042) /    -1.13,  -22.42,    0.00 /
      DATA B(30331), B(30332), B(30333) /    -1.22,  -22.38,    0.00 /
      DATA B(30622), B(30623), B(30624) /    -1.31,  -22.35,    0.00 /
      DATA B(30913), B(30914), B(30915) /    -1.39,  -22.31,    0.00 /
      DATA B(31204), B(31205), B(31206) /    -1.47,  -22.28,    0.00 /
      DATA B(31495), B(31496), B(31497) /    -1.55,  -22.25,    0.00 /
      DATA B(31786), B(31787), B(31788) /    -1.62,  -22.21,    0.00 /
      DATA B(32077), B(32078), B(32079) /    -1.69,  -22.18,    0.00 /
      DATA B(32368), B(32369), B(32370) /    -1.76,  -22.15,    0.00 /
      DATA B(32659), B(32660), B(32661) /    -1.82,  -22.11,    0.00 /
      DATA B(32950), B(32951), B(32952) /    -1.89,  -22.07,    0.00 /
      DATA B(33241), B(33242), B(33243) /    -1.95,  -22.04,    0.00 /
      DATA B(33532), B(33533), B(33534) /    -2.01,  -22.00,    0.00 /
      DATA B(33823), B(33824), B(33825) /    -2.07,  -21.96,    0.00 /
      DATA B(34114), B(34115), B(34116) /    -2.13,  -21.91,    0.00 /
      DATA B(34405), B(34406), B(34407) /    -2.18,  -21.87,    0.00 /
      DATA B(34696), B(34697), B(34698) /    -2.24,  -21.83,    0.00 /
      DATA B(34987), B(34988), B(34989) /    -2.30,  -21.78,    0.00 /
      DATA B(35278), B(35279), B(35280) /    -2.35,  -21.73,    0.00 /
      DATA B(35569), B(35570), B(35571) /    -2.41,  -21.69,    0.00 /
      DATA B(35860), B(35861), B(35862) /    -2.46,  -21.64,    0.00 /
      DATA B(36151), B(36152), B(36153) /    -2.52,  -21.58,    0.00 /
      DATA B(36442), B(36443), B(36444) /    -2.58,  -21.53,    0.00 /
      DATA B(36733), B(36734), B(36735) /    -2.64,  -21.47,    0.00 /
      DATA B(37024), B(37025), B(37026) /    -2.70,  -21.42,    0.00 /
      DATA B(37315), B(37316), B(37317) /    -2.76,  -21.36,    0.00 /
      DATA B(37606), B(37607), B(37608) /    -2.82,  -21.30,    0.00 /
      DATA B(37897), B(37898), B(37899) /    -2.89,  -21.24,    0.00 /
      DATA B(38188), B(38189), B(38190) /    -2.96,  -21.17,    0.00 /
      DATA B(38479), B(38480), B(38481) /    -3.04,  -21.10,    0.00 /
      DATA B(38770), B(38771), B(38772) /    -3.12,  -21.02,    0.00 /
      DATA B(39061), B(39062), B(39063) /    -3.21,  -20.94,    0.00 /
      DATA B(39352), B(39353), B(39354) /    -3.32,  -20.84,    0.00 /
      DATA B(39643), B(39644), B(39645) /    -3.46,  -20.72,    0.00 /
      DATA B(39934), B(39935), B(39936) /    -3.65,  -20.59,    0.00 /
      DATA B(40225), B(40226), B(40227) /    -3.85,  -20.46,    0.00 /
      DATA B(40516), B(40517), B(40518) /    -4.05,  -20.33,    0.00 /
      DATA B(40807), B(40808), B(40809) /    -4.23,  -20.24,    0.00 /
      DATA B(41098), B(41099), B(41100) /    -4.38,  -20.20,    0.00 /
      DATA B(41389), B(41390), B(41391) /    -4.53,  -20.19,    0.00 /
      DATA B(41680), B(41681), B(41682) /    -4.69,  -20.19,    0.00 /
      DATA B(41971), B(41972), B(41973) /    -4.84,  -20.16,    0.00 /
      DATA B(42262), B(42263), B(42264) /    -4.98,  -20.10,    0.00 /
      DATA B(42553), B(42554), B(42555) /    -5.10,  -20.03,    0.00 /
      DATA B(42844), B(42845), B(42846) /    -5.21,  -19.95,    0.00 /
      DATA B(43135), B(43136), B(43137) /    -5.30,  -19.86,    0.00 /
      DATA B(43426), B(43427), B(43428) /    -5.39,  -19.78,    0.00 /
      DATA B(43717), B(43718), B(43719) /    -5.48,  -19.69,    0.00 /
      DATA B(44008), B(44009), B(44010) /    -5.56,  -19.61,    0.00 /
      DATA B(44299), B(44300), B(44301) /    -5.64,  -19.53,    0.00 /
      DATA B(44590), B(44591), B(44592) /    -5.72,  -19.46,    0.00 /
      DATA B(44881), B(44882), B(44883) /    -5.79,  -19.38,    0.00 /
      DATA B(45172), B(45173), B(45174) /    -5.87,  -19.31,    0.00 /
      DATA B(45463), B(45464), B(45465) /    -5.94,  -19.24,    0.00 /
      DATA B(45754), B(45755), B(45756) /    -6.02,  -19.16,    0.00 /
      DATA B(46045), B(46046), B(46047) /    -6.09,  -19.09,    0.00 /
      DATA B(46336), B(46337), B(46338) /    -6.17,  -19.02,    0.00 /
      DATA B(27715), B(27716), B(27717) /    -0.21,  -22.96,    0.00 /
      DATA B(28006), B(28007), B(28008) /    -0.36,  -22.83,    0.00 /
      DATA B(28297), B(28298), B(28299) /    -0.49,  -22.73,    0.00 /
      DATA B(28588), B(28589), B(28590) /    -0.61,  -22.65,    0.00 /
      DATA B(28879), B(28880), B(28881) /    -0.73,  -22.57,    0.00 /
      DATA B(29170), B(29171), B(29172) /    -0.83,  -22.51,    0.00 /
      DATA B(29461), B(29462), B(29463) /    -0.93,  -22.46,    0.00 /
      DATA B(29752), B(29753), B(29754) /    -1.03,  -22.42,    0.00 /
      DATA B(30043), B(30044), B(30045) /    -1.12,  -22.37,    0.00 /
      DATA B(30334), B(30335), B(30336) /    -1.21,  -22.34,    0.00 /
      DATA B(30625), B(30626), B(30627) /    -1.29,  -22.30,    0.00 /
      DATA B(30916), B(30917), B(30918) /    -1.37,  -22.27,    0.00 /
      DATA B(31207), B(31208), B(31209) /    -1.45,  -22.23,    0.00 /
      DATA B(31498), B(31499), B(31500) /    -1.52,  -22.20,    0.00 /
      DATA B(31789), B(31790), B(31791) /    -1.59,  -22.16,    0.00 /
      DATA B(32080), B(32081), B(32082) /    -1.66,  -22.13,    0.00 /
      DATA B(32371), B(32372), B(32373) /    -1.73,  -22.09,    0.00 /
      DATA B(32662), B(32663), B(32664) /    -1.80,  -22.05,    0.00 /
      DATA B(32953), B(32954), B(32955) /    -1.86,  -22.02,    0.00 /
      DATA B(33244), B(33245), B(33246) /    -1.92,  -21.98,    0.00 /
      DATA B(33535), B(33536), B(33537) /    -1.98,  -21.94,    0.00 /
      DATA B(33826), B(33827), B(33828) /    -2.04,  -21.90,    0.00 /
      DATA B(34117), B(34118), B(34119) /    -2.10,  -21.85,    0.00 /
      DATA B(34408), B(34409), B(34410) /    -2.16,  -21.81,    0.00 /
      DATA B(34699), B(34700), B(34701) /    -2.21,  -21.77,    0.00 /
      DATA B(34990), B(34991), B(34992) /    -2.27,  -21.72,    0.00 /
      DATA B(35281), B(35282), B(35283) /    -2.33,  -21.67,    0.00 /
      DATA B(35572), B(35573), B(35574) /    -2.38,  -21.62,    0.00 /
      DATA B(35863), B(35864), B(35865) /    -2.44,  -21.57,    0.00 /
      DATA B(36154), B(36155), B(36156) /    -2.50,  -21.51,    0.00 /
      DATA B(36445), B(36446), B(36447) /    -2.56,  -21.46,    0.00 /
      DATA B(36736), B(36737), B(36738) /    -2.62,  -21.40,    0.00 /
      DATA B(37027), B(37028), B(37029) /    -2.68,  -21.34,    0.00 /
      DATA B(37318), B(37319), B(37320) /    -2.75,  -21.28,    0.00 /
      DATA B(37609), B(37610), B(37611) /    -2.82,  -21.21,    0.00 /
      DATA B(37900), B(37901), B(37902) /    -2.89,  -21.15,    0.00 /
      DATA B(38191), B(38192), B(38193) /    -2.97,  -21.08,    0.00 /
      DATA B(38482), B(38483), B(38484) /    -3.05,  -21.00,    0.00 /
      DATA B(38773), B(38774), B(38775) /    -3.15,  -20.91,    0.00 /
      DATA B(39064), B(39065), B(39066) /    -3.26,  -20.81,    0.00 /
      DATA B(39355), B(39356), B(39357) /    -3.39,  -20.69,    0.00 /
      DATA B(39646), B(39647), B(39648) /    -3.59,  -20.56,    0.00 /
      DATA B(39937), B(39938), B(39939) /    -3.80,  -20.42,    0.00 /
      DATA B(40228), B(40229), B(40230) /    -4.00,  -20.29,    0.00 /
      DATA B(40519), B(40520), B(40521) /    -4.18,  -20.18,    0.00 /
      DATA B(40810), B(40811), B(40812) /    -4.34,  -20.10,    0.00 /
      DATA B(41101), B(41102), B(41103) /    -4.48,  -20.05,    0.00 /
      DATA B(41392), B(41393), B(41394) /    -4.61,  -20.02,    0.00 /
      DATA B(41683), B(41684), B(41685) /    -4.74,  -20.00,    0.00 /
      DATA B(41974), B(41975), B(41976) /    -4.88,  -19.97,    0.00 /
      DATA B(42265), B(42266), B(42267) /    -5.00,  -19.92,    0.00 /
      DATA B(42556), B(42557), B(42558) /    -5.12,  -19.86,    0.00 /
      DATA B(42847), B(42848), B(42849) /    -5.22,  -19.78,    0.00 /
      DATA B(43138), B(43139), B(43140) /    -5.32,  -19.71,    0.00 /
      DATA B(43429), B(43430), B(43431) /    -5.41,  -19.63,    0.00 /
      DATA B(43720), B(43721), B(43722) /    -5.49,  -19.56,    0.00 /
      DATA B(44011), B(44012), B(44013) /    -5.57,  -19.48,    0.00 /
      DATA B(44302), B(44303), B(44304) /    -5.66,  -19.40,    0.00 /
      DATA B(44593), B(44594), B(44595) /    -5.73,  -19.33,    0.00 /
      DATA B(44884), B(44885), B(44886) /    -5.81,  -19.26,    0.00 /
      DATA B(45175), B(45176), B(45177) /    -5.89,  -19.19,    0.00 /
      DATA B(45466), B(45467), B(45468) /    -5.97,  -19.12,    0.00 /
      DATA B(45757), B(45758), B(45759) /    -6.04,  -19.05,    0.00 /
      DATA B(46048), B(46049), B(46050) /    -6.12,  -18.98,    0.00 /
      DATA B(46339), B(46340), B(46341) /    -6.19,  -18.91,    0.00 /
      DATA B(27718), B(27719), B(27720) /    -0.25,  -22.92,    0.00 /
      DATA B(28009), B(28010), B(28011) /    -0.38,  -22.80,    0.00 /
      DATA B(28300), B(28301), B(28302) /    -0.51,  -22.70,    0.00 /
      DATA B(28591), B(28592), B(28593) /    -0.62,  -22.61,    0.00 /
      DATA B(28882), B(28883), B(28884) /    -0.73,  -22.54,    0.00 /
      DATA B(29173), B(29174), B(29175) /    -0.83,  -22.48,    0.00 /
      DATA B(29464), B(29465), B(29466) /    -0.93,  -22.43,    0.00 /
      DATA B(29755), B(29756), B(29757) /    -1.02,  -22.38,    0.00 /
      DATA B(30046), B(30047), B(30048) /    -1.11,  -22.33,    0.00 /
      DATA B(30337), B(30338), B(30339) /    -1.19,  -22.29,    0.00 /
      DATA B(30628), B(30629), B(30630) /    -1.27,  -22.25,    0.00 /
      DATA B(30919), B(30920), B(30921) /    -1.35,  -22.22,    0.00 /
      DATA B(31210), B(31211), B(31212) /    -1.43,  -22.18,    0.00 /
      DATA B(31501), B(31502), B(31503) /    -1.50,  -22.15,    0.00 /
      DATA B(31792), B(31793), B(31794) /    -1.57,  -22.11,    0.00 /
      DATA B(32083), B(32084), B(32085) /    -1.64,  -22.07,    0.00 /
      DATA B(32374), B(32375), B(32376) /    -1.71,  -22.04,    0.00 /
      DATA B(32665), B(32666), B(32667) /    -1.77,  -22.00,    0.00 /
      DATA B(32956), B(32957), B(32958) /    -1.83,  -21.96,    0.00 /
      DATA B(33247), B(33248), B(33249) /    -1.90,  -21.92,    0.00 /
      DATA B(33538), B(33539), B(33540) /    -1.96,  -21.88,    0.00 /
      DATA B(33829), B(33830), B(33831) /    -2.02,  -21.84,    0.00 /
      DATA B(34120), B(34121), B(34122) /    -2.07,  -21.79,    0.00 /
      DATA B(34411), B(34412), B(34413) /    -2.13,  -21.75,    0.00 /
      DATA B(34702), B(34703), B(34704) /    -2.19,  -21.70,    0.00 /
      DATA B(34993), B(34994), B(34995) /    -2.25,  -21.66,    0.00 /
      DATA B(35284), B(35285), B(35286) /    -2.30,  -21.61,    0.00 /
      DATA B(35575), B(35576), B(35577) /    -2.36,  -21.55,    0.00 /
      DATA B(35866), B(35867), B(35868) /    -2.42,  -21.50,    0.00 /
      DATA B(36157), B(36158), B(36159) /    -2.48,  -21.44,    0.00 /
      DATA B(36448), B(36449), B(36450) /    -2.54,  -21.38,    0.00 /
      DATA B(36739), B(36740), B(36741) /    -2.61,  -21.32,    0.00 /
      DATA B(37030), B(37031), B(37032) /    -2.67,  -21.26,    0.00 /
      DATA B(37321), B(37322), B(37323) /    -2.74,  -21.19,    0.00 /
      DATA B(37612), B(37613), B(37614) /    -2.82,  -21.12,    0.00 /
      DATA B(37903), B(37904), B(37905) /    -2.89,  -21.05,    0.00 /
      DATA B(38194), B(38195), B(38196) /    -2.98,  -20.97,    0.00 /
      DATA B(38485), B(38486), B(38487) /    -3.08,  -20.88,    0.00 /
      DATA B(38776), B(38777), B(38778) /    -3.19,  -20.78,    0.00 /
      DATA B(39067), B(39068), B(39069) /    -3.33,  -20.67,    0.00 /
      DATA B(39358), B(39359), B(39360) /    -3.53,  -20.53,    0.00 /
      DATA B(39649), B(39650), B(39651) /    -3.74,  -20.39,    0.00 /
      DATA B(39940), B(39941), B(39942) /    -3.95,  -20.25,    0.00 /
      DATA B(40231), B(40232), B(40233) /    -4.13,  -20.13,    0.00 /
      DATA B(40522), B(40523), B(40524) /    -4.29,  -20.03,    0.00 /
      DATA B(40813), B(40814), B(40815) /    -4.42,  -19.96,    0.00 /
      DATA B(41104), B(41105), B(41106) /    -4.55,  -19.91,    0.00 /
      DATA B(41395), B(41396), B(41397) /    -4.67,  -19.88,    0.00 /
      DATA B(41686), B(41687), B(41688) /    -4.79,  -19.85,    0.00 /
      DATA B(41977), B(41978), B(41979) /    -4.91,  -19.81,    0.00 /
      DATA B(42268), B(42269), B(42270) /    -5.02,  -19.76,    0.00 /
      DATA B(42559), B(42560), B(42561) /    -5.13,  -19.70,    0.00 /
      DATA B(42850), B(42851), B(42852) /    -5.23,  -19.64,    0.00 /
      DATA B(43141), B(43142), B(43143) /    -5.33,  -19.57,    0.00 /
      DATA B(43432), B(43433), B(43434) /    -5.42,  -19.50,    0.00 /
      DATA B(43723), B(43724), B(43725) /    -5.51,  -19.43,    0.00 /
      DATA B(44014), B(44015), B(44016) /    -5.59,  -19.36,    0.00 /
      DATA B(44305), B(44306), B(44307) /    -5.67,  -19.29,    0.00 /
      DATA B(44596), B(44597), B(44598) /    -5.75,  -19.22,    0.00 /
      DATA B(44887), B(44888), B(44889) /    -5.83,  -19.15,    0.00 /
      DATA B(45178), B(45179), B(45180) /    -5.91,  -19.08,    0.00 /
      DATA B(45469), B(45470), B(45471) /    -5.98,  -19.01,    0.00 /
      DATA B(45760), B(45761), B(45762) /    -6.06,  -18.95,    0.00 /
      DATA B(46051), B(46052), B(46053) /    -6.14,  -18.88,    0.00 /
      DATA B(46342), B(46343), B(46344) /    -6.21,  -18.82,    0.00 /
      DATA B(27721), B(27722), B(27723) /    -0.27,  -22.87,    0.00 /
      DATA B(28012), B(28013), B(28014) /    -0.40,  -22.76,    0.00 /
      DATA B(28303), B(28304), B(28305) /    -0.52,  -22.66,    0.00 /
      DATA B(28594), B(28595), B(28596) /    -0.63,  -22.58,    0.00 /
      DATA B(28885), B(28886), B(28887) /    -0.73,  -22.51,    0.00 /
      DATA B(29176), B(29177), B(29178) /    -0.83,  -22.44,    0.00 /
      DATA B(29467), B(29468), B(29469) /    -0.92,  -22.39,    0.00 /
      DATA B(29758), B(29759), B(29760) /    -1.01,  -22.34,    0.00 /
      DATA B(30049), B(30050), B(30051) /    -1.09,  -22.29,    0.00 /
      DATA B(30340), B(30341), B(30342) /    -1.18,  -22.25,    0.00 /
      DATA B(30631), B(30632), B(30633) /    -1.26,  -22.21,    0.00 /
      DATA B(30922), B(30923), B(30924) /    -1.33,  -22.17,    0.00 /
      DATA B(31213), B(31214), B(31215) /    -1.41,  -22.13,    0.00 /
      DATA B(31504), B(31505), B(31506) /    -1.48,  -22.09,    0.00 /
      DATA B(31795), B(31796), B(31797) /    -1.55,  -22.06,    0.00 /
      DATA B(32086), B(32087), B(32088) /    -1.62,  -22.02,    0.00 /
      DATA B(32377), B(32378), B(32379) /    -1.68,  -21.98,    0.00 /
      DATA B(32668), B(32669), B(32670) /    -1.75,  -21.94,    0.00 /
      DATA B(32959), B(32960), B(32961) /    -1.81,  -21.90,    0.00 /
      DATA B(33250), B(33251), B(33252) /    -1.87,  -21.86,    0.00 /
      DATA B(33541), B(33542), B(33543) /    -1.93,  -21.82,    0.00 /
      DATA B(33832), B(33833), B(33834) /    -1.99,  -21.78,    0.00 /
      DATA B(34123), B(34124), B(34125) /    -2.05,  -21.73,    0.00 /
      DATA B(34414), B(34415), B(34416) /    -2.11,  -21.69,    0.00 /
      DATA B(34705), B(34706), B(34707) /    -2.17,  -21.64,    0.00 /
      DATA B(34996), B(34997), B(34998) /    -2.22,  -21.59,    0.00 /
      DATA B(35287), B(35288), B(35289) /    -2.28,  -21.54,    0.00 /
      DATA B(35578), B(35579), B(35580) /    -2.34,  -21.49,    0.00 /
      DATA B(35869), B(35870), B(35871) /    -2.40,  -21.43,    0.00 /
      DATA B(36160), B(36161), B(36162) /    -2.46,  -21.37,    0.00 /
      DATA B(36451), B(36452), B(36453) /    -2.53,  -21.30,    0.00 /
      DATA B(36742), B(36743), B(36744) /    -2.60,  -21.24,    0.00 /
      DATA B(37033), B(37034), B(37035) /    -2.67,  -21.17,    0.00 /
      DATA B(37324), B(37325), B(37326) /    -2.74,  -21.10,    0.00 /
      DATA B(37615), B(37616), B(37617) /    -2.82,  -21.02,    0.00 /
      DATA B(37906), B(37907), B(37908) /    -2.91,  -20.94,    0.00 /
      DATA B(38197), B(38198), B(38199) /    -3.01,  -20.85,    0.00 /
      DATA B(38488), B(38489), B(38490) /    -3.13,  -20.75,    0.00 /
      DATA B(38779), B(38780), B(38781) /    -3.27,  -20.64,    0.00 /
      DATA B(39070), B(39071), B(39072) /    -3.47,  -20.50,    0.00 /
      DATA B(39361), B(39362), B(39363) /    -3.69,  -20.35,    0.00 /
      DATA B(39652), B(39653), B(39654) /    -3.89,  -20.22,    0.00 /
      DATA B(39943), B(39944), B(39945) /    -4.08,  -20.09,    0.00 /
      DATA B(40234), B(40235), B(40236) /    -4.24,  -19.98,    0.00 /
      DATA B(40525), B(40526), B(40527) /    -4.37,  -19.90,    0.00 /
      DATA B(40816), B(40817), B(40818) /    -4.49,  -19.83,    0.00 /
      DATA B(41107), B(41108), B(41109) /    -4.61,  -19.79,    0.00 /
      DATA B(41398), B(41399), B(41400) /    -4.72,  -19.75,    0.00 /
      DATA B(41689), B(41690), B(41691) /    -4.83,  -19.71,    0.00 /
      DATA B(41980), B(41981), B(41982) /    -4.94,  -19.67,    0.00 /
      DATA B(42271), B(42272), B(42273) /    -5.05,  -19.62,    0.00 /
      DATA B(42562), B(42563), B(42564) /    -5.15,  -19.57,    0.00 /
      DATA B(42853), B(42854), B(42855) /    -5.25,  -19.51,    0.00 /
      DATA B(43144), B(43145), B(43146) /    -5.34,  -19.45,    0.00 /
      DATA B(43435), B(43436), B(43437) /    -5.43,  -19.38,    0.00 /
      DATA B(43726), B(43727), B(43728) /    -5.52,  -19.31,    0.00 /
      DATA B(44017), B(44018), B(44019) /    -5.60,  -19.25,    0.00 /
      DATA B(44308), B(44309), B(44310) /    -5.69,  -19.18,    0.00 /
      DATA B(44599), B(44600), B(44601) /    -5.77,  -19.11,    0.00 /
      DATA B(44890), B(44891), B(44892) /    -5.85,  -19.05,    0.00 /
      DATA B(45181), B(45182), B(45183) /    -5.92,  -18.98,    0.00 /
      DATA B(45472), B(45473), B(45474) /    -6.00,  -18.92,    0.00 /
      DATA B(45763), B(45764), B(45765) /    -6.08,  -18.85,    0.00 /
      DATA B(46054), B(46055), B(46056) /    -6.16,  -18.79,    0.00 /
      DATA B(46345), B(46346), B(46347) /    -6.23,  -18.72,    0.00 /
      DATA B(27724), B(27725), B(27726) /    -0.29,  -22.83,    0.00 /
      DATA B(28015), B(28016), B(28017) /    -0.41,  -22.72,    0.00 /
      DATA B(28306), B(28307), B(28308) /    -0.52,  -22.62,    0.00 /
      DATA B(28597), B(28598), B(28599) /    -0.63,  -22.54,    0.00 /
      DATA B(28888), B(28889), B(28890) /    -0.73,  -22.47,    0.00 /
      DATA B(29179), B(29180), B(29181) /    -0.82,  -22.41,    0.00 /
      DATA B(29470), B(29471), B(29472) /    -0.91,  -22.35,    0.00 /
      DATA B(29761), B(29762), B(29763) /    -1.00,  -22.30,    0.00 /
      DATA B(30052), B(30053), B(30054) /    -1.08,  -22.25,    0.00 /
      DATA B(30343), B(30344), B(30345) /    -1.16,  -22.21,    0.00 /
      DATA B(30634), B(30635), B(30636) /    -1.24,  -22.16,    0.00 /
      DATA B(30925), B(30926), B(30927) /    -1.31,  -22.12,    0.00 /
      DATA B(31216), B(31217), B(31218) /    -1.38,  -22.08,    0.00 /
      DATA B(31507), B(31508), B(31509) /    -1.46,  -22.04,    0.00 /
      DATA B(31798), B(31799), B(31800) /    -1.52,  -22.01,    0.00 /
      DATA B(32089), B(32090), B(32091) /    -1.59,  -21.97,    0.00 /
      DATA B(32380), B(32381), B(32382) /    -1.66,  -21.93,    0.00 /
      DATA B(32671), B(32672), B(32673) /    -1.72,  -21.89,    0.00 /
      DATA B(32962), B(32963), B(32964) /    -1.79,  -21.85,    0.00 /
      DATA B(33253), B(33254), B(33255) /    -1.85,  -21.81,    0.00 /
      DATA B(33544), B(33545), B(33546) /    -1.91,  -21.76,    0.00 /
      DATA B(33835), B(33836), B(33837) /    -1.97,  -21.72,    0.00 /
      DATA B(34126), B(34127), B(34128) /    -2.03,  -21.67,    0.00 /
      DATA B(34417), B(34418), B(34419) /    -2.09,  -21.63,    0.00 /
      DATA B(34708), B(34709), B(34710) /    -2.14,  -21.58,    0.00 /
      DATA B(34999), B(35000), B(35001) /    -2.20,  -21.53,    0.00 /
      DATA B(35290), B(35291), B(35292) /    -2.26,  -21.47,    0.00 /
      DATA B(35581), B(35582), B(35583) /    -2.32,  -21.42,    0.00 /
      DATA B(35872), B(35873), B(35874) /    -2.38,  -21.35,    0.00 /
      DATA B(36163), B(36164), B(36165) /    -2.45,  -21.29,    0.00 /
      DATA B(36454), B(36455), B(36456) /    -2.52,  -21.22,    0.00 /
      DATA B(36745), B(36746), B(36747) /    -2.59,  -21.15,    0.00 /
      DATA B(37036), B(37037), B(37038) /    -2.67,  -21.07,    0.00 /
      DATA B(37327), B(37328), B(37329) /    -2.75,  -20.99,    0.00 /
      DATA B(37618), B(37619), B(37620) /    -2.85,  -20.91,    0.00 /
      DATA B(37909), B(37910), B(37911) /    -2.95,  -20.82,    0.00 /
      DATA B(38200), B(38201), B(38202) /    -3.07,  -20.71,    0.00 /
      DATA B(38491), B(38492), B(38493) /    -3.22,  -20.60,    0.00 /
      DATA B(38782), B(38783), B(38784) /    -3.42,  -20.46,    0.00 /
      DATA B(39073), B(39074), B(39075) /    -3.63,  -20.32,    0.00 /
      DATA B(39364), B(39365), B(39366) /    -3.84,  -20.18,    0.00 /
      DATA B(39655), B(39656), B(39657) /    -4.02,  -20.05,    0.00 /
      DATA B(39946), B(39947), B(39948) /    -4.18,  -19.94,    0.00 /
      DATA B(40237), B(40238), B(40239) /    -4.32,  -19.85,    0.00 /
      DATA B(40528), B(40529), B(40530) /    -4.44,  -19.78,    0.00 /
      DATA B(40819), B(40820), B(40821) /    -4.55,  -19.72,    0.00 /
      DATA B(41110), B(41111), B(41112) /    -4.66,  -19.67,    0.00 /
      DATA B(41401), B(41402), B(41403) /    -4.76,  -19.63,    0.00 /
      DATA B(41692), B(41693), B(41694) /    -4.87,  -19.59,    0.00 /
      DATA B(41983), B(41984), B(41985) /    -4.97,  -19.54,    0.00 /
      DATA B(42274), B(42275), B(42276) /    -5.07,  -19.50,    0.00 /
      DATA B(42565), B(42566), B(42567) /    -5.17,  -19.45,    0.00 /
      DATA B(42856), B(42857), B(42858) /    -5.27,  -19.39,    0.00 /
      DATA B(43147), B(43148), B(43149) /    -5.36,  -19.33,    0.00 /
      DATA B(43438), B(43439), B(43440) /    -5.45,  -19.27,    0.00 /
      DATA B(43729), B(43730), B(43731) /    -5.54,  -19.21,    0.00 /
      DATA B(44020), B(44021), B(44022) /    -5.62,  -19.14,    0.00 /
      DATA B(44311), B(44312), B(44313) /    -5.70,  -19.08,    0.00 /
      DATA B(44602), B(44603), B(44604) /    -5.78,  -19.01,    0.00 /
      DATA B(44893), B(44894), B(44895) /    -5.86,  -18.95,    0.00 /
      DATA B(45184), B(45185), B(45186) /    -5.94,  -18.89,    0.00 /
      DATA B(45475), B(45476), B(45477) /    -6.02,  -18.82,    0.00 /
      DATA B(45766), B(45767), B(45768) /    -6.10,  -18.76,    0.00 /
      DATA B(46057), B(46058), B(46059) /    -6.17,  -18.70,    0.00 /
      DATA B(46348), B(46349), B(46350) /    -6.25,  -18.64,    0.00 /
      DATA B(27727), B(27728), B(27729) /    -0.30,  -22.78,    0.00 /
      DATA B(28018), B(28019), B(28020) /    -0.42,  -22.68,    0.00 /
      DATA B(28309), B(28310), B(28311) /    -0.52,  -22.58,    0.00 /
      DATA B(28600), B(28601), B(28602) /    -0.63,  -22.50,    0.00 /
      DATA B(28891), B(28892), B(28893) /    -0.72,  -22.43,    0.00 /
      DATA B(29182), B(29183), B(29184) /    -0.81,  -22.37,    0.00 /
      DATA B(29473), B(29474), B(29475) /    -0.90,  -22.31,    0.00 /
      DATA B(29764), B(29765), B(29766) /    -0.98,  -22.26,    0.00 /
      DATA B(30055), B(30056), B(30057) /    -1.07,  -22.21,    0.00 /
      DATA B(30346), B(30347), B(30348) /    -1.14,  -22.16,    0.00 /
      DATA B(30637), B(30638), B(30639) /    -1.22,  -22.12,    0.00 /
      DATA B(30928), B(30929), B(30930) /    -1.29,  -22.08,    0.00 /
      DATA B(31219), B(31220), B(31221) /    -1.37,  -22.03,    0.00 /
      DATA B(31510), B(31511), B(31512) /    -1.44,  -21.99,    0.00 /
      DATA B(31801), B(31802), B(31803) /    -1.50,  -21.95,    0.00 /
      DATA B(32092), B(32093), B(32094) /    -1.57,  -21.91,    0.00 /
      DATA B(32383), B(32384), B(32385) /    -1.64,  -21.87,    0.00 /
      DATA B(32674), B(32675), B(32676) /    -1.70,  -21.83,    0.00 /
      DATA B(32965), B(32966), B(32967) /    -1.76,  -21.79,    0.00 /
      DATA B(33256), B(33257), B(33258) /    -1.83,  -21.75,    0.00 /
      DATA B(33547), B(33548), B(33549) /    -1.89,  -21.70,    0.00 /
      DATA B(33838), B(33839), B(33840) /    -1.95,  -21.66,    0.00 /
      DATA B(34129), B(34130), B(34131) /    -2.01,  -21.61,    0.00 /
      DATA B(34420), B(34421), B(34422) /    -2.06,  -21.57,    0.00 /
      DATA B(34711), B(34712), B(34713) /    -2.12,  -21.52,    0.00 /
      DATA B(35002), B(35003), B(35004) /    -2.18,  -21.46,    0.00 /
      DATA B(35293), B(35294), B(35295) /    -2.24,  -21.41,    0.00 /
      DATA B(35584), B(35585), B(35586) /    -2.31,  -21.34,    0.00 /
      DATA B(35875), B(35876), B(35877) /    -2.37,  -21.28,    0.00 /
      DATA B(36166), B(36167), B(36168) /    -2.44,  -21.21,    0.00 /
      DATA B(36457), B(36458), B(36459) /    -2.52,  -21.13,    0.00 /
      DATA B(36748), B(36749), B(36750) /    -2.60,  -21.05,    0.00 /
      DATA B(37039), B(37040), B(37041) /    -2.68,  -20.96,    0.00 /
      DATA B(37330), B(37331), B(37332) /    -2.78,  -20.88,    0.00 /
      DATA B(37621), B(37622), B(37623) /    -2.89,  -20.78,    0.00 /
      DATA B(37912), B(37913), B(37914) /    -3.01,  -20.68,    0.00 /
      DATA B(38203), B(38204), B(38205) /    -3.17,  -20.56,    0.00 /
      DATA B(38494), B(38495), B(38496) /    -3.36,  -20.42,    0.00 /
      DATA B(38785), B(38786), B(38787) /    -3.58,  -20.28,    0.00 /
      DATA B(39076), B(39077), B(39078) /    -3.78,  -20.14,    0.00 /
      DATA B(39367), B(39368), B(39369) /    -3.97,  -20.01,    0.00 /
      DATA B(39658), B(39659), B(39660) /    -4.12,  -19.90,    0.00 /
      DATA B(39949), B(39950), B(39951) /    -4.26,  -19.81,    0.00 /
      DATA B(40240), B(40241), B(40242) /    -4.38,  -19.73,    0.00 /
      DATA B(40531), B(40532), B(40533) /    -4.50,  -19.67,    0.00 /
      DATA B(40822), B(40823), B(40824) /    -4.60,  -19.61,    0.00 /
      DATA B(41113), B(41114), B(41115) /    -4.70,  -19.56,    0.00 /
      DATA B(41404), B(41405), B(41406) /    -4.80,  -19.52,    0.00 /
      DATA B(41695), B(41696), B(41697) /    -4.90,  -19.47,    0.00 /
      DATA B(41986), B(41987), B(41988) /    -5.00,  -19.43,    0.00 /
      DATA B(42277), B(42278), B(42279) /    -5.10,  -19.38,    0.00 /
      DATA B(42568), B(42569), B(42570) /    -5.20,  -19.33,    0.00 /
      DATA B(42859), B(42860), B(42861) /    -5.29,  -19.28,    0.00 /
      DATA B(43150), B(43151), B(43152) /    -5.38,  -19.22,    0.00 /
      DATA B(43441), B(43442), B(43443) /    -5.47,  -19.16,    0.00 /
      DATA B(43732), B(43733), B(43734) /    -5.55,  -19.10,    0.00 /
      DATA B(44023), B(44024), B(44025) /    -5.64,  -19.04,    0.00 /
      DATA B(44314), B(44315), B(44316) /    -5.72,  -18.98,    0.00 /
      DATA B(44605), B(44606), B(44607) /    -5.80,  -18.92,    0.00 /
      DATA B(44896), B(44897), B(44898) /    -5.88,  -18.86,    0.00 /
      DATA B(45187), B(45188), B(45189) /    -5.96,  -18.80,    0.00 /
      DATA B(45478), B(45479), B(45480) /    -6.04,  -18.74,    0.00 /
      DATA B(45769), B(45770), B(45771) /    -6.11,  -18.68,    0.00 /
      DATA B(46060), B(46061), B(46062) /    -6.19,  -18.62,    0.00 /
      DATA B(46351), B(46352), B(46353) /    -6.27,  -18.55,    0.00 /
      DATA B(27730), B(27731), B(27732) /    -0.30,  -22.73,    0.00 /
      DATA B(28021), B(28022), B(28023) /    -0.42,  -22.63,    0.00 /
      DATA B(28312), B(28313), B(28314) /    -0.52,  -22.54,    0.00 /
      DATA B(28603), B(28604), B(28605) /    -0.62,  -22.46,    0.00 /
      DATA B(28894), B(28895), B(28896) /    -0.72,  -22.39,    0.00 /
      DATA B(29185), B(29186), B(29187) /    -0.80,  -22.33,    0.00 /
      DATA B(29476), B(29477), B(29478) /    -0.89,  -22.27,    0.00 /
      DATA B(29767), B(29768), B(29769) /    -0.97,  -22.22,    0.00 /
      DATA B(30058), B(30059), B(30060) /    -1.05,  -22.17,    0.00 /
      DATA B(30349), B(30350), B(30351) /    -1.13,  -22.12,    0.00 /
      DATA B(30640), B(30641), B(30642) /    -1.20,  -22.07,    0.00 /
      DATA B(30931), B(30932), B(30933) /    -1.27,  -22.03,    0.00 /
      DATA B(31222), B(31223), B(31224) /    -1.35,  -21.99,    0.00 /
      DATA B(31513), B(31514), B(31515) /    -1.42,  -21.94,    0.00 /
      DATA B(31804), B(31805), B(31806) /    -1.48,  -21.90,    0.00 /
      DATA B(32095), B(32096), B(32097) /    -1.55,  -21.86,    0.00 /
      DATA B(32386), B(32387), B(32388) /    -1.62,  -21.82,    0.00 /
      DATA B(32677), B(32678), B(32679) /    -1.68,  -21.78,    0.00 /
      DATA B(32968), B(32969), B(32970) /    -1.74,  -21.73,    0.00 /
      DATA B(33259), B(33260), B(33261) /    -1.80,  -21.69,    0.00 /
      DATA B(33550), B(33551), B(33552) /    -1.87,  -21.65,    0.00 /
      DATA B(33841), B(33842), B(33843) /    -1.93,  -21.60,    0.00 /
      DATA B(34132), B(34133), B(34134) /    -1.99,  -21.55,    0.00 /
      DATA B(34423), B(34424), B(34425) /    -2.05,  -21.50,    0.00 /
      DATA B(34714), B(34715), B(34716) /    -2.11,  -21.45,    0.00 /
      DATA B(35005), B(35006), B(35007) /    -2.17,  -21.40,    0.00 /
      DATA B(35296), B(35297), B(35298) /    -2.23,  -21.34,    0.00 /
      DATA B(35587), B(35588), B(35589) /    -2.29,  -21.27,    0.00 /
      DATA B(35878), B(35879), B(35880) /    -2.36,  -21.20,    0.00 /
      DATA B(36169), B(36170), B(36171) /    -2.44,  -21.12,    0.00 /
      DATA B(36460), B(36461), B(36462) /    -2.52,  -21.03,    0.00 /
      DATA B(36751), B(36752), B(36753) /    -2.61,  -20.94,    0.00 /
      DATA B(37042), B(37043), B(37044) /    -2.71,  -20.84,    0.00 /
      DATA B(37333), B(37334), B(37335) /    -2.83,  -20.74,    0.00 /
      DATA B(37624), B(37625), B(37626) /    -2.95,  -20.64,    0.00 /
      DATA B(37915), B(37916), B(37917) /    -3.11,  -20.52,    0.00 /
      DATA B(38206), B(38207), B(38208) /    -3.31,  -20.38,    0.00 /
      DATA B(38497), B(38498), B(38499) /    -3.53,  -20.24,    0.00 /
      DATA B(38788), B(38789), B(38790) /    -3.73,  -20.10,    0.00 /
      DATA B(39079), B(39080), B(39081) /    -3.91,  -19.97,    0.00 /
      DATA B(39370), B(39371), B(39372) /    -4.07,  -19.86,    0.00 /
      DATA B(39661), B(39662), B(39663) /    -4.21,  -19.77,    0.00 /
      DATA B(39952), B(39953), B(39954) /    -4.33,  -19.69,    0.00 /
      DATA B(40243), B(40244), B(40245) /    -4.44,  -19.62,    0.00 /
      DATA B(40534), B(40535), B(40536) /    -4.55,  -19.56,    0.00 /
      DATA B(40825), B(40826), B(40827) /    -4.65,  -19.50,    0.00 /
      DATA B(41116), B(41117), B(41118) /    -4.74,  -19.46,    0.00 /
      DATA B(41407), B(41408), B(41409) /    -4.84,  -19.41,    0.00 /
      DATA B(41698), B(41699), B(41700) /    -4.94,  -19.37,    0.00 /
      DATA B(41989), B(41990), B(41991) /    -5.03,  -19.32,    0.00 /
      DATA B(42280), B(42281), B(42282) /    -5.13,  -19.28,    0.00 /
      DATA B(42571), B(42572), B(42573) /    -5.22,  -19.23,    0.00 /
      DATA B(42862), B(42863), B(42864) /    -5.31,  -19.18,    0.00 /
      DATA B(43153), B(43154), B(43155) /    -5.40,  -19.12,    0.00 /
      DATA B(43444), B(43445), B(43446) /    -5.49,  -19.07,    0.00 /
      DATA B(43735), B(43736), B(43737) /    -5.57,  -19.01,    0.00 /
      DATA B(44026), B(44027), B(44028) /    -5.65,  -18.95,    0.00 /
      DATA B(44317), B(44318), B(44319) /    -5.73,  -18.89,    0.00 /
      DATA B(44608), B(44609), B(44610) /    -5.82,  -18.83,    0.00 /
      DATA B(44899), B(44900), B(44901) /    -5.89,  -18.77,    0.00 /
      DATA B(45190), B(45191), B(45192) /    -5.97,  -18.71,    0.00 /
      DATA B(45481), B(45482), B(45483) /    -6.05,  -18.65,    0.00 /
      DATA B(45772), B(45773), B(45774) /    -6.13,  -18.59,    0.00 /
      DATA B(46063), B(46064), B(46065) /    -6.21,  -18.53,    0.00 /
      DATA B(46354), B(46355), B(46356) /    -6.28,  -18.48,    0.00 /
      DATA B(27733), B(27734), B(27735) /    -0.30,  -22.69,    0.00 /
      DATA B(28024), B(28025), B(28026) /    -0.42,  -22.59,    0.00 /
      DATA B(28315), B(28316), B(28317) /    -0.52,  -22.50,    0.00 /
      DATA B(28606), B(28607), B(28608) /    -0.61,  -22.42,    0.00 /
      DATA B(28897), B(28898), B(28899) /    -0.71,  -22.35,    0.00 /
      DATA B(29188), B(29189), B(29190) /    -0.79,  -22.29,    0.00 /
      DATA B(29479), B(29480), B(29481) /    -0.88,  -22.23,    0.00 /
      DATA B(29770), B(29771), B(29772) /    -0.96,  -22.17,    0.00 /
      DATA B(30061), B(30062), B(30063) /    -1.04,  -22.12,    0.00 /
      DATA B(30352), B(30353), B(30354) /    -1.11,  -22.07,    0.00 /
      DATA B(30643), B(30644), B(30645) /    -1.18,  -22.03,    0.00 /
      DATA B(30934), B(30935), B(30936) /    -1.26,  -21.98,    0.00 /
      DATA B(31225), B(31226), B(31227) /    -1.33,  -21.94,    0.00 /
      DATA B(31516), B(31517), B(31518) /    -1.40,  -21.89,    0.00 /
      DATA B(31807), B(31808), B(31809) /    -1.46,  -21.85,    0.00 /
      DATA B(32098), B(32099), B(32100) /    -1.53,  -21.81,    0.00 /
      DATA B(32389), B(32390), B(32391) /    -1.60,  -21.76,    0.00 /
      DATA B(32680), B(32681), B(32682) /    -1.66,  -21.72,    0.00 /
      DATA B(32971), B(32972), B(32973) /    -1.72,  -21.68,    0.00 /
      DATA B(33262), B(33263), B(33264) /    -1.79,  -21.63,    0.00 /
      DATA B(33553), B(33554), B(33555) /    -1.85,  -21.59,    0.00 /
      DATA B(33844), B(33845), B(33846) /    -1.91,  -21.54,    0.00 /
      DATA B(34135), B(34136), B(34137) /    -1.97,  -21.49,    0.00 /
      DATA B(34426), B(34427), B(34428) /    -2.03,  -21.44,    0.00 /
      DATA B(34717), B(34718), B(34719) /    -2.09,  -21.39,    0.00 /
      DATA B(35008), B(35009), B(35010) /    -2.15,  -21.33,    0.00 /
      DATA B(35299), B(35300), B(35301) /    -2.22,  -21.26,    0.00 /
      DATA B(35590), B(35591), B(35592) /    -2.28,  -21.19,    0.00 /
      DATA B(35881), B(35882), B(35883) /    -2.36,  -21.11,    0.00 /
      DATA B(36172), B(36173), B(36174) /    -2.44,  -21.02,    0.00 /
      DATA B(36463), B(36464), B(36465) /    -2.54,  -20.92,    0.00 /
      DATA B(36754), B(36755), B(36756) /    -2.65,  -20.82,    0.00 /
      DATA B(37045), B(37046), B(37047) /    -2.77,  -20.69,    0.00 /
      DATA B(37336), B(37337), B(37338) /    -2.90,  -20.59,    0.00 /
      DATA B(37627), B(37628), B(37629) /    -3.07,  -20.47,    0.00 /
      DATA B(37918), B(37919), B(37920) /    -3.27,  -20.33,    0.00 /
      DATA B(38209), B(38210), B(38211) /    -3.48,  -20.19,    0.00 /
      DATA B(38500), B(38501), B(38502) /    -3.68,  -20.05,    0.00 /
      DATA B(38791), B(38792), B(38793) /    -3.86,  -19.93,    0.00 /
      DATA B(39082), B(39083), B(39084) /    -4.02,  -19.82,    0.00 /
      DATA B(39373), B(39374), B(39375) /    -4.15,  -19.73,    0.00 /
      DATA B(39664), B(39665), B(39666) /    -4.27,  -19.65,    0.00 /
      DATA B(39955), B(39956), B(39957) /    -4.39,  -19.58,    0.00 /
      DATA B(40246), B(40247), B(40248) /    -4.49,  -19.51,    0.00 /
      DATA B(40537), B(40538), B(40539) /    -4.59,  -19.45,    0.00 /
      DATA B(40828), B(40829), B(40830) /    -4.69,  -19.40,    0.00 /
      DATA B(41119), B(41120), B(41121) /    -4.78,  -19.36,    0.00 /
      DATA B(41410), B(41411), B(41412) /    -4.88,  -19.31,    0.00 /
      DATA B(41701), B(41702), B(41703) /    -4.97,  -19.27,    0.00 /
      DATA B(41992), B(41993), B(41994) /    -5.06,  -19.22,    0.00 /
      DATA B(42283), B(42284), B(42285) /    -5.15,  -19.18,    0.00 /
      DATA B(42574), B(42575), B(42576) /    -5.24,  -19.13,    0.00 /
      DATA B(42865), B(42866), B(42867) /    -5.33,  -19.08,    0.00 /
      DATA B(43156), B(43157), B(43158) /    -5.42,  -19.02,    0.00 /
      DATA B(43447), B(43448), B(43449) /    -5.50,  -18.97,    0.00 /
      DATA B(43738), B(43739), B(43740) /    -5.59,  -18.92,    0.00 /
      DATA B(44029), B(44030), B(44031) /    -5.67,  -18.86,    0.00 /
      DATA B(44320), B(44321), B(44322) /    -5.75,  -18.80,    0.00 /
      DATA B(44611), B(44612), B(44613) /    -5.83,  -18.74,    0.00 /
      DATA B(44902), B(44903), B(44904) /    -5.91,  -18.69,    0.00 /
      DATA B(45193), B(45194), B(45195) /    -5.99,  -18.63,    0.00 /
      DATA B(45484), B(45485), B(45486) /    -6.07,  -18.57,    0.00 /
      DATA B(45775), B(45776), B(45777) /    -6.15,  -18.51,    0.00 /
      DATA B(46066), B(46067), B(46068) /    -6.22,  -18.46,    0.00 /
      DATA B(46357), B(46358), B(46359) /    -6.30,  -18.40,    0.00 /
      DATA B(27736), B(27737), B(27738) /    -0.30,  -22.64,    0.00 /
      DATA B(28027), B(28028), B(28029) /    -0.41,  -22.55,    0.00 /
      DATA B(28318), B(28319), B(28320) /    -0.51,  -22.46,    0.00 /
      DATA B(28609), B(28610), B(28611) /    -0.61,  -22.38,    0.00 /
      DATA B(28900), B(28901), B(28902) /    -0.70,  -22.31,    0.00 /
      DATA B(29191), B(29192), B(29193) /    -0.78,  -22.25,    0.00 /
      DATA B(29482), B(29483), B(29484) /    -0.86,  -22.19,    0.00 /
      DATA B(29773), B(29774), B(29775) /    -0.94,  -22.13,    0.00 /
      DATA B(30064), B(30065), B(30066) /    -1.02,  -22.08,    0.00 /
      DATA B(30355), B(30356), B(30357) /    -1.10,  -22.03,    0.00 /
      DATA B(30646), B(30647), B(30648) /    -1.17,  -21.98,    0.00 /
      DATA B(30937), B(30938), B(30939) /    -1.24,  -21.93,    0.00 /
      DATA B(31228), B(31229), B(31230) /    -1.31,  -21.89,    0.00 /
      DATA B(31519), B(31520), B(31521) /    -1.38,  -21.84,    0.00 /
      DATA B(31810), B(31811), B(31812) /    -1.45,  -21.80,    0.00 /
      DATA B(32101), B(32102), B(32103) /    -1.51,  -21.75,    0.00 /
      DATA B(32392), B(32393), B(32394) /    -1.58,  -21.71,    0.00 /
      DATA B(32683), B(32684), B(32685) /    -1.64,  -21.66,    0.00 /
      DATA B(32974), B(32975), B(32976) /    -1.71,  -21.62,    0.00 /
      DATA B(33265), B(33266), B(33267) /    -1.77,  -21.57,    0.00 /
      DATA B(33556), B(33557), B(33558) /    -1.83,  -21.53,    0.00 /
      DATA B(33847), B(33848), B(33849) /    -1.89,  -21.48,    0.00 /
      DATA B(34138), B(34139), B(34140) /    -1.96,  -21.43,    0.00 /
      DATA B(34429), B(34430), B(34431) /    -2.02,  -21.37,    0.00 /
      DATA B(34720), B(34721), B(34722) /    -2.08,  -21.32,    0.00 /
      DATA B(35011), B(35012), B(35013) /    -2.14,  -21.26,    0.00 /
      DATA B(35302), B(35303), B(35304) /    -2.21,  -21.19,    0.00 /
      DATA B(35593), B(35594), B(35595) /    -2.28,  -21.11,    0.00 /
      DATA B(35884), B(35885), B(35886) /    -2.36,  -21.02,    0.00 /
      DATA B(36175), B(36176), B(36177) /    -2.46,  -20.91,    0.00 /
      DATA B(36466), B(36467), B(36468) /    -2.57,  -20.80,    0.00 /
      DATA B(36757), B(36758), B(36759) /    -2.71,  -20.67,    0.00 /
      DATA B(37048), B(37049), B(37050) /    -2.87,  -20.43,    0.00 /
      DATA B(37339), B(37340), B(37341) /    -3.03,  -20.41,    0.00 /
      DATA B(37630), B(37631), B(37632) /    -3.24,  -20.28,    0.00 /
      DATA B(37921), B(37922), B(37923) /    -3.44,  -20.14,    0.00 /
      DATA B(38212), B(38213), B(38214) /    -3.64,  -20.01,    0.00 /
      DATA B(38503), B(38504), B(38505) /    -3.81,  -19.88,    0.00 /
      DATA B(38794), B(38795), B(38796) /    -3.97,  -19.78,    0.00 /
      DATA B(39085), B(39086), B(39087) /    -4.10,  -19.68,    0.00 /
      DATA B(39376), B(39377), B(39378) /    -4.22,  -19.60,    0.00 /
      DATA B(39667), B(39668), B(39669) /    -4.33,  -19.53,    0.00 /
      DATA B(39958), B(39959), B(39960) /    -4.44,  -19.47,    0.00 /
      DATA B(40249), B(40250), B(40251) /    -4.54,  -19.41,    0.00 /
      DATA B(40540), B(40541), B(40542) /    -4.64,  -19.35,    0.00 /
      DATA B(40831), B(40832), B(40833) /    -4.73,  -19.30,    0.00 /
      DATA B(41122), B(41123), B(41124) /    -4.82,  -19.26,    0.00 /
      DATA B(41413), B(41414), B(41415) /    -4.91,  -19.21,    0.00 /
      DATA B(41704), B(41705), B(41706) /    -5.00,  -19.17,    0.00 /
      DATA B(41995), B(41996), B(41997) /    -5.09,  -19.12,    0.00 /
      DATA B(42286), B(42287), B(42288) /    -5.18,  -19.08,    0.00 /
      DATA B(42577), B(42578), B(42579) /    -5.27,  -19.03,    0.00 /
      DATA B(42868), B(42869), B(42870) /    -5.35,  -18.98,    0.00 /
      DATA B(43159), B(43160), B(43161) /    -5.44,  -18.93,    0.00 /
      DATA B(43450), B(43451), B(43452) /    -5.53,  -18.88,    0.00 /
      DATA B(43741), B(43742), B(43743) /    -5.61,  -18.82,    0.00 /
      DATA B(44032), B(44033), B(44034) /    -5.69,  -18.77,    0.00 /
      DATA B(44323), B(44324), B(44325) /    -5.77,  -18.72,    0.00 /
      DATA B(44614), B(44615), B(44616) /    -5.85,  -18.66,    0.00 /
      DATA B(44905), B(44906), B(44907) /    -5.93,  -18.60,    0.00 /
      DATA B(45196), B(45197), B(45198) /    -6.01,  -18.55,    0.00 /
      DATA B(45487), B(45488), B(45489) /    -6.09,  -18.49,    0.00 /
      DATA B(45778), B(45779), B(45780) /    -6.16,  -18.44,    0.00 /
      DATA B(46069), B(46070), B(46071) /    -6.24,  -18.38,    0.00 /
      DATA B(46360), B(46361), B(46362) /    -6.32,  -18.32,    0.00 /
      DATA B(27739), B(27740), B(27741) /    -0.30,  -22.59,    0.00 /
      DATA B(28030), B(28031), B(28032) /    -0.40,  -22.50,    0.00 /
      DATA B(28321), B(28322), B(28323) /    -0.50,  -22.42,    0.00 /
      DATA B(28612), B(28613), B(28614) /    -0.60,  -22.34,    0.00 /
      DATA B(28903), B(28904), B(28905) /    -0.68,  -22.27,    0.00 /
      DATA B(29194), B(29195), B(29196) /    -0.77,  -22.21,    0.00 /
      DATA B(29485), B(29486), B(29487) /    -0.85,  -22.14,    0.00 /
      DATA B(29776), B(29777), B(29778) /    -0.93,  -22.09,    0.00 /
      DATA B(30067), B(30068), B(30069) /    -1.01,  -22.03,    0.00 /
      DATA B(30358), B(30359), B(30360) /    -1.08,  -21.98,    0.00 /
      DATA B(30649), B(30650), B(30651) /    -1.15,  -21.93,    0.00 /
      DATA B(30940), B(30941), B(30942) /    -1.22,  -21.88,    0.00 /
      DATA B(31231), B(31232), B(31233) /    -1.29,  -21.84,    0.00 /
      DATA B(31522), B(31523), B(31524) /    -1.36,  -21.79,    0.00 /
      DATA B(31813), B(31814), B(31815) /    -1.43,  -21.74,    0.00 /
      DATA B(32104), B(32105), B(32106) /    -1.50,  -21.70,    0.00 /
      DATA B(32395), B(32396), B(32397) /    -1.56,  -21.65,    0.00 /
      DATA B(32686), B(32687), B(32688) /    -1.63,  -21.61,    0.00 /
      DATA B(32977), B(32978), B(32979) /    -1.69,  -21.56,    0.00 /
      DATA B(33268), B(33269), B(33270) /    -1.76,  -21.51,    0.00 /
      DATA B(33559), B(33560), B(33561) /    -1.82,  -21.46,    0.00 /
      DATA B(33850), B(33851), B(33852) /    -1.88,  -21.41,    0.00 /
      DATA B(34141), B(34142), B(34143) /    -1.95,  -21.36,    0.00 /
      DATA B(34432), B(34433), B(34434) /    -2.01,  -21.31,    0.00 /
      DATA B(34723), B(34724), B(34725) /    -2.07,  -21.25,    0.00 /
      DATA B(35014), B(35015), B(35016) /    -2.14,  -21.19,    0.00 /
      DATA B(35305), B(35306), B(35307) /    -2.21,  -21.12,    0.00 /
      DATA B(35596), B(35597), B(35598) /    -2.28,  -21.03,    0.00 /
      DATA B(35887), B(35888), B(35889) /    -2.37,  -20.92,    0.00 /
      DATA B(36178), B(36179), B(36180) /    -2.49,  -20.79,    0.00 /
      DATA B(36469), B(36470), B(36471) /    -2.63,  -20.65,    0.00 /
      DATA B(36760), B(36761), B(36762) /    -2.89,  -20.45,    0.00 /
      DATA B(37051), B(37052), B(37053) /    -3.04,  -20.39,    0.00 /
      DATA B(37342), B(37343), B(37344) /    -3.23,  -20.22,    0.00 /
      DATA B(37633), B(37634), B(37635) /    -3.42,  -20.08,    0.00 /
      DATA B(37924), B(37925), B(37926) /    -3.61,  -19.95,    0.00 /
      DATA B(38215), B(38216), B(38217) /    -3.77,  -19.83,    0.00 /
      DATA B(38506), B(38507), B(38508) /    -3.92,  -19.73,    0.00 /
      DATA B(38797), B(38798), B(38799) /    -4.05,  -19.63,    0.00 /
      DATA B(39088), B(39089), B(39090) /    -4.17,  -19.55,    0.00 /
      DATA B(39379), B(39380), B(39381) /    -4.29,  -19.48,    0.00 /
      DATA B(39670), B(39671), B(39672) /    -4.39,  -19.42,    0.00 /
      DATA B(39961), B(39962), B(39963) /    -4.49,  -19.36,    0.00 /
      DATA B(40252), B(40253), B(40254) /    -4.58,  -19.30,    0.00 /
      DATA B(40543), B(40544), B(40545) /    -4.68,  -19.25,    0.00 /
      DATA B(40834), B(40835), B(40836) /    -4.77,  -19.20,    0.00 /
      DATA B(41125), B(41126), B(41127) /    -4.86,  -19.16,    0.00 /
      DATA B(41416), B(41417), B(41418) /    -4.95,  -19.11,    0.00 /
      DATA B(41707), B(41708), B(41709) /    -5.03,  -19.07,    0.00 /
      DATA B(41998), B(41999), B(42000) /    -5.12,  -19.03,    0.00 /
      DATA B(42289), B(42290), B(42291) /    -5.21,  -18.98,    0.00 /
      DATA B(42580), B(42581), B(42582) /    -5.29,  -18.93,    0.00 /
      DATA B(42871), B(42872), B(42873) /    -5.38,  -18.89,    0.00 /
      DATA B(43162), B(43163), B(43164) /    -5.46,  -18.84,    0.00 /
      DATA B(43453), B(43454), B(43455) /    -5.55,  -18.79,    0.00 /
      DATA B(43744), B(43745), B(43746) /    -5.63,  -18.74,    0.00 /
      DATA B(44035), B(44036), B(44037) /    -5.71,  -18.68,    0.00 /
      DATA B(44326), B(44327), B(44328) /    -5.79,  -18.63,    0.00 /
      DATA B(44617), B(44618), B(44619) /    -5.87,  -18.58,    0.00 /
      DATA B(44908), B(44909), B(44910) /    -5.95,  -18.52,    0.00 /
      DATA B(45199), B(45200), B(45201) /    -6.03,  -18.47,    0.00 /
      DATA B(45490), B(45491), B(45492) /    -6.10,  -18.41,    0.00 /
      DATA B(45781), B(45782), B(45783) /    -6.18,  -18.36,    0.00 /
      DATA B(46072), B(46073), B(46074) /    -6.26,  -18.30,    0.00 /
      DATA B(46363), B(46364), B(46365) /    -6.33,  -18.25,    0.00 /
      DATA B(27742), B(27743), B(27744) /    -0.29,  -22.54,    0.00 /
      DATA B(28033), B(28034), B(28035) /    -0.39,  -22.45,    0.00 /
      DATA B(28324), B(28325), B(28326) /    -0.49,  -22.37,    0.00 /
      DATA B(28615), B(28616), B(28617) /    -0.58,  -22.30,    0.00 /
      DATA B(28906), B(28907), B(28908) /    -0.67,  -22.23,    0.00 /
      DATA B(29197), B(29198), B(29199) /    -0.76,  -22.16,    0.00 /
      DATA B(29488), B(29489), B(29490) /    -0.84,  -22.10,    0.00 /
      DATA B(29779), B(29780), B(29781) /    -0.91,  -22.04,    0.00 /
      DATA B(30070), B(30071), B(30072) /    -0.99,  -21.99,    0.00 /
      DATA B(30361), B(30362), B(30363) /    -1.06,  -21.94,    0.00 /
      DATA B(30652), B(30653), B(30654) /    -1.14,  -21.88,    0.00 /
      DATA B(30943), B(30944), B(30945) /    -1.21,  -21.83,    0.00 /
      DATA B(31234), B(31235), B(31236) /    -1.28,  -21.78,    0.00 /
      DATA B(31525), B(31526), B(31527) /    -1.35,  -21.74,    0.00 /
      DATA B(31816), B(31817), B(31818) /    -1.42,  -21.69,    0.00 /
      DATA B(32107), B(32108), B(32109) /    -1.48,  -21.64,    0.00 /
      DATA B(32398), B(32399), B(32400) /    -1.55,  -21.59,    0.00 /
      DATA B(32689), B(32690), B(32691) /    -1.62,  -21.55,    0.00 /
      DATA B(32980), B(32981), B(32982) /    -1.68,  -21.50,    0.00 /
      DATA B(33271), B(33272), B(33273) /    -1.75,  -21.45,    0.00 /
      DATA B(33562), B(33563), B(33564) /    -1.81,  -21.40,    0.00 /
      DATA B(33853), B(33854), B(33855) /    -1.88,  -21.35,    0.00 /
      DATA B(34144), B(34145), B(34146) /    -1.94,  -21.30,    0.00 /
      DATA B(34435), B(34436), B(34437) /    -2.00,  -21.24,    0.00 /
      DATA B(34726), B(34727), B(34728) /    -2.07,  -21.18,    0.00 /
      DATA B(35017), B(35018), B(35019) /    -2.13,  -21.11,    0.00 /
      DATA B(35308), B(35309), B(35310) /    -2.21,  -21.04,    0.00 /
      DATA B(35599), B(35600), B(35601) /    -2.29,  -20.93,    0.00 /
      DATA B(35890), B(35891), B(35892) /    -2.65,  -20.57,    0.00 /
      DATA B(36181), B(36182), B(36183) /    -2.77,  -20.45,    0.00 /
      DATA B(36472), B(36473), B(36474) /    -2.91,  -20.37,    0.00 /
      DATA B(36763), B(36764), B(36765) /    -3.06,  -20.29,    0.00 /
      DATA B(37054), B(37055), B(37056) /    -3.24,  -20.18,    0.00 /
      DATA B(37345), B(37346), B(37347) /    -3.43,  -20.04,    0.00 /
      DATA B(37636), B(37637), B(37638) /    -3.59,  -19.90,    0.00 /
      DATA B(37927), B(37928), B(37929) /    -3.74,  -19.78,    0.00 /
      DATA B(38218), B(38219), B(38220) /    -3.89,  -19.67,    0.00 /
      DATA B(38509), B(38510), B(38511) /    -4.01,  -19.58,    0.00 /
      DATA B(38800), B(38801), B(38802) /    -4.13,  -19.50,    0.00 /
      DATA B(39091), B(39092), B(39093) /    -4.24,  -19.43,    0.00 /
      DATA B(39382), B(39383), B(39384) /    -4.34,  -19.36,    0.00 /
      DATA B(39673), B(39674), B(39675) /    -4.44,  -19.30,    0.00 /
      DATA B(39964), B(39965), B(39966) /    -4.54,  -19.25,    0.00 /
      DATA B(40255), B(40256), B(40257) /    -4.63,  -19.20,    0.00 /
      DATA B(40546), B(40547), B(40548) /    -4.72,  -19.15,    0.00 /
      DATA B(40837), B(40838), B(40839) /    -4.81,  -19.10,    0.00 /
      DATA B(41128), B(41129), B(41130) /    -4.90,  -19.06,    0.00 /
      DATA B(41419), B(41420), B(41421) /    -4.98,  -19.02,    0.00 /
      DATA B(41710), B(41711), B(41712) /    -5.07,  -18.97,    0.00 /
      DATA B(42001), B(42002), B(42003) /    -5.15,  -18.93,    0.00 /
      DATA B(42292), B(42293), B(42294) /    -5.24,  -18.89,    0.00 /
      DATA B(42583), B(42584), B(42585) /    -5.32,  -18.84,    0.00 /
      DATA B(42874), B(42875), B(42876) /    -5.41,  -18.79,    0.00 /
      DATA B(43165), B(43166), B(43167) /    -5.49,  -18.75,    0.00 /
      DATA B(43456), B(43457), B(43458) /    -5.57,  -18.70,    0.00 /
      DATA B(43747), B(43748), B(43749) /    -5.65,  -18.65,    0.00 /
      DATA B(44038), B(44039), B(44040) /    -5.73,  -18.60,    0.00 /
      DATA B(44329), B(44330), B(44331) /    -5.81,  -18.55,    0.00 /
      DATA B(44620), B(44621), B(44622) /    -5.89,  -18.49,    0.00 /
      DATA B(44911), B(44912), B(44913) /    -5.97,  -18.44,    0.00 /
      DATA B(45202), B(45203), B(45204) /    -6.05,  -18.39,    0.00 /
      DATA B(45493), B(45494), B(45495) /    -6.12,  -18.34,    0.00 /
      DATA B(45784), B(45785), B(45786) /    -6.20,  -18.28,    0.00 /
      DATA B(46075), B(46076), B(46077) /    -6.27,  -18.23,    0.00 /
      DATA B(46366), B(46367), B(46368) /    -6.35,  -18.18,    0.00 /
      DATA B(27745), B(27746), B(27747) /    -0.28,  -22.49,    0.00 /
      DATA B(28036), B(28037), B(28038) /    -0.38,  -22.41,    0.00 /
      DATA B(28327), B(28328), B(28329) /    -0.48,  -22.33,    0.00 /
      DATA B(28618), B(28619), B(28620) /    -0.57,  -22.25,    0.00 /
      DATA B(28909), B(28910), B(28911) /    -0.66,  -22.19,    0.00 /
      DATA B(29200), B(29201), B(29202) /    -0.74,  -22.12,    0.00 /
      DATA B(29491), B(29492), B(29493) /    -0.82,  -22.06,    0.00 /
      DATA B(29782), B(29783), B(29784) /    -0.90,  -22.00,    0.00 /
      DATA B(30073), B(30074), B(30075) /    -0.98,  -21.94,    0.00 /
      DATA B(30364), B(30365), B(30366) /    -1.05,  -21.89,    0.00 /
      DATA B(30655), B(30656), B(30657) /    -1.12,  -21.83,    0.00 /
      DATA B(30946), B(30947), B(30948) /    -1.19,  -21.78,    0.00 /
      DATA B(31237), B(31238), B(31239) /    -1.26,  -21.73,    0.00 /
      DATA B(31528), B(31529), B(31530) /    -1.33,  -21.68,    0.00 /
      DATA B(31819), B(31820), B(31821) /    -1.40,  -21.63,    0.00 /
      DATA B(32110), B(32111), B(32112) /    -1.47,  -21.58,    0.00 /
      DATA B(32401), B(32402), B(32403) /    -1.54,  -21.54,    0.00 /
      DATA B(32692), B(32693), B(32694) /    -1.61,  -21.49,    0.00 /
      DATA B(32983), B(32984), B(32985) /    -1.67,  -21.44,    0.00 /
      DATA B(33274), B(33275), B(33276) /    -1.74,  -21.39,    0.00 /
      DATA B(33565), B(33566), B(33567) /    -1.81,  -21.34,    0.00 /
      DATA B(33856), B(33857), B(33858) /    -1.87,  -21.28,    0.00 /
      DATA B(34147), B(34148), B(34149) /    -1.94,  -21.23,    0.00 /
      DATA B(34438), B(34439), B(34440) /    -2.01,  -21.17,    0.00 /
      DATA B(34729), B(34730), B(34731) /    -2.08,  -21.10,    0.00 /
      DATA B(35020), B(35021), B(35022) /    -2.14,  -21.03,    0.00 /
      DATA B(35311), B(35312), B(35313) /    -2.16,  -20.96,    0.00 /
      DATA B(35602), B(35603), B(35604) /    -2.70,  -20.55,    0.00 /
      DATA B(35893), B(35894), B(35895) /    -2.76,  -20.44,    0.00 /
      DATA B(36184), B(36185), B(36186) /    -2.90,  -20.32,    0.00 /
      DATA B(36475), B(36476), B(36477) /    -3.06,  -20.22,    0.00 /
      DATA B(36766), B(36767), B(36768) /    -3.24,  -20.11,    0.00 /
      DATA B(37057), B(37058), B(37059) /    -3.41,  -19.99,    0.00 /
      DATA B(37348), B(37349), B(37350) /    -3.58,  -19.86,    0.00 /
      DATA B(37639), B(37640), B(37641) /    -3.73,  -19.72,    0.00 /
      DATA B(37930), B(37931), B(37932) /    -3.86,  -19.61,    0.00 /
      DATA B(38221), B(38222), B(38223) /    -3.98,  -19.52,    0.00 /
      DATA B(38512), B(38513), B(38514) /    -4.09,  -19.44,    0.00 /
      DATA B(38803), B(38804), B(38805) /    -4.20,  -19.37,    0.00 /
      DATA B(39094), B(39095), B(39096) /    -4.31,  -19.30,    0.00 /
      DATA B(39385), B(39386), B(39387) /    -4.40,  -19.25,    0.00 /
      DATA B(39676), B(39677), B(39678) /    -4.50,  -19.19,    0.00 /
      DATA B(39967), B(39968), B(39969) /    -4.59,  -19.14,    0.00 /
      DATA B(40258), B(40259), B(40260) /    -4.68,  -19.09,    0.00 /
      DATA B(40549), B(40550), B(40551) /    -4.76,  -19.05,    0.00 /
      DATA B(40840), B(40841), B(40842) /    -4.85,  -19.00,    0.00 /
      DATA B(41131), B(41132), B(41133) /    -4.94,  -18.96,    0.00 /
      DATA B(41422), B(41423), B(41424) /    -5.02,  -18.92,    0.00 /
      DATA B(41713), B(41714), B(41715) /    -5.10,  -18.87,    0.00 /
      DATA B(42004), B(42005), B(42006) /    -5.19,  -18.83,    0.00 /
      DATA B(42295), B(42296), B(42297) /    -5.27,  -18.79,    0.00 /
      DATA B(42586), B(42587), B(42588) /    -5.35,  -18.75,    0.00 /
      DATA B(42877), B(42878), B(42879) /    -5.44,  -18.70,    0.00 /
      DATA B(43168), B(43169), B(43170) /    -5.52,  -18.65,    0.00 /
      DATA B(43459), B(43460), B(43461) /    -5.60,  -18.61,    0.00 /
      DATA B(43750), B(43751), B(43752) /    -5.68,  -18.56,    0.00 /
      DATA B(44041), B(44042), B(44043) /    -5.76,  -18.51,    0.00 /
      DATA B(44332), B(44333), B(44334) /    -5.84,  -18.46,    0.00 /
      DATA B(44623), B(44624), B(44625) /    -5.91,  -18.41,    0.00 /
      DATA B(44914), B(44915), B(44916) /    -5.99,  -18.36,    0.00 /
      DATA B(45205), B(45206), B(45207) /    -6.07,  -18.31,    0.00 /
      DATA B(45496), B(45497), B(45498) /    -6.14,  -18.26,    0.00 /
      DATA B(45787), B(45788), B(45789) /    -6.22,  -18.21,    0.00 /
      DATA B(46078), B(46079), B(46080) /    -6.29,  -18.15,    0.00 /
      DATA B(46369), B(46370), B(46371) /    -6.37,  -18.10,    0.00 /
      DATA B(27748), B(27749), B(27750) /    -0.27,  -22.45,    0.00 /
      DATA B(28039), B(28040), B(28041) /    -0.37,  -22.36,    0.00 /
      DATA B(28330), B(28331), B(28332) /    -0.47,  -22.28,    0.00 /
      DATA B(28621), B(28622), B(28623) /    -0.56,  -22.21,    0.00 /
      DATA B(28912), B(28913), B(28914) /    -0.65,  -22.14,    0.00 /
      DATA B(29203), B(29204), B(29205) /    -0.73,  -22.08,    0.00 /
      DATA B(29494), B(29495), B(29496) /    -0.81,  -22.01,    0.00 /
      DATA B(29785), B(29786), B(29787) /    -0.89,  -21.95,    0.00 /
      DATA B(30076), B(30077), B(30078) /    -0.96,  -21.90,    0.00 /
      DATA B(30367), B(30368), B(30369) /    -1.04,  -21.84,    0.00 /
      DATA B(30658), B(30659), B(30660) /    -1.11,  -21.79,    0.00 /
      DATA B(30949), B(30950), B(30951) /    -1.18,  -21.73,    0.00 /
      DATA B(31240), B(31241), B(31242) /    -1.25,  -21.68,    0.00 /
      DATA B(31531), B(31532), B(31533) /    -1.32,  -21.63,    0.00 /
      DATA B(31822), B(31823), B(31824) /    -1.39,  -21.58,    0.00 /
      DATA B(32113), B(32114), B(32115) /    -1.46,  -21.52,    0.00 /
      DATA B(32404), B(32405), B(32406) /    -1.53,  -21.47,    0.00 /
      DATA B(32695), B(32696), B(32697) /    -1.60,  -21.42,    0.00 /
      DATA B(32986), B(32987), B(32988) /    -1.67,  -21.37,    0.00 /
      DATA B(33277), B(33278), B(33279) /    -1.74,  -21.32,    0.00 /
      DATA B(33568), B(33569), B(33570) /    -1.81,  -21.27,    0.00 /
      DATA B(33859), B(33860), B(33861) /    -1.88,  -21.22,    0.00 /
      DATA B(34150), B(34151), B(34152) /    -1.95,  -21.16,    0.00 /
      DATA B(34441), B(34442), B(34443) /    -2.02,  -21.09,    0.00 /
      DATA B(34732), B(34733), B(34734) /    -2.10,  -21.03,    0.00 /
      DATA B(35023), B(35024), B(35025) /    -2.18,  -20.95,    0.00 /
      DATA B(35314), B(35315), B(35316) /    -2.27,  -20.84,    0.00 /
      DATA B(35605), B(35606), B(35607) /    -2.70,  -20.42,    0.00 /
      DATA B(35896), B(35897), B(35898) /    -2.85,  -20.30,    0.00 /
      DATA B(36187), B(36188), B(36189) /    -3.03,  -20.17,    0.00 /
      DATA B(36478), B(36479), B(36480) /    -3.21,  -20.04,    0.00 /
      DATA B(36769), B(36770), B(36771) /    -3.38,  -19.92,    0.00 /
      DATA B(37060), B(37061), B(37062) /    -3.55,  -19.80,    0.00 /
      DATA B(37351), B(37352), B(37353) /    -3.70,  -19.67,    0.00 /
      DATA B(37642), B(37643), B(37644) /    -3.83,  -19.55,    0.00 /
      DATA B(37933), B(37934), B(37935) /    -3.95,  -19.45,    0.00 /
      DATA B(38224), B(38225), B(38226) /    -4.07,  -19.37,    0.00 /
      DATA B(38515), B(38516), B(38517) /    -4.17,  -19.30,    0.00 /
      DATA B(38806), B(38807), B(38808) /    -4.27,  -19.23,    0.00 /
      DATA B(39097), B(39098), B(39099) /    -4.37,  -19.18,    0.00 /
      DATA B(39388), B(39389), B(39390) /    -4.46,  -19.12,    0.00 /
      DATA B(39679), B(39680), B(39681) /    -4.55,  -19.08,    0.00 /
      DATA B(39970), B(39971), B(39972) /    -4.64,  -19.03,    0.00 /
      DATA B(40261), B(40262), B(40263) /    -4.73,  -18.98,    0.00 /
      DATA B(40552), B(40553), B(40554) /    -4.81,  -18.94,    0.00 /
      DATA B(40843), B(40844), B(40845) /    -4.89,  -18.90,    0.00 /
      DATA B(41134), B(41135), B(41136) /    -4.98,  -18.86,    0.00 /
      DATA B(41425), B(41426), B(41427) /    -5.06,  -18.82,    0.00 /
      DATA B(41716), B(41717), B(41718) /    -5.14,  -18.77,    0.00 /
      DATA B(42007), B(42008), B(42009) /    -5.22,  -18.73,    0.00 /
      DATA B(42298), B(42299), B(42300) /    -5.31,  -18.69,    0.00 /
      DATA B(42589), B(42590), B(42591) /    -5.39,  -18.65,    0.00 /
      DATA B(42880), B(42881), B(42882) /    -5.47,  -18.61,    0.00 /
      DATA B(43171), B(43172), B(43173) /    -5.55,  -18.56,    0.00 /
      DATA B(43462), B(43463), B(43464) /    -5.63,  -18.52,    0.00 /
      DATA B(43753), B(43754), B(43755) /    -5.71,  -18.47,    0.00 /
      DATA B(44044), B(44045), B(44046) /    -5.78,  -18.42,    0.00 /
      DATA B(44335), B(44336), B(44337) /    -5.86,  -18.38,    0.00 /
      DATA B(44626), B(44627), B(44628) /    -5.94,  -18.33,    0.00 /
      DATA B(44917), B(44918), B(44919) /    -6.01,  -18.28,    0.00 /
      DATA B(45208), B(45209), B(45210) /    -6.09,  -18.23,    0.00 /
      DATA B(45499), B(45500), B(45501) /    -6.17,  -18.18,    0.00 /
      DATA B(45790), B(45791), B(45792) /    -6.24,  -18.13,    0.00 /
      DATA B(46081), B(46082), B(46083) /    -6.32,  -18.08,    0.00 /
      DATA B(46372), B(46373), B(46374) /    -6.39,  -18.03,    0.00 /
      DATA GRDLX( 3) / 235.00000000000 /,
     *     GRDUX( 3) / 238.00000000000 /,
     *     GRDLY( 3) /  40.00000000000 /,
     *     GRDUY( 3) /  49.00000000000 /,
     *     ICNTX( 3) / 48 /,
     *     ICNTY( 3) /144 /,
     *     NBASE( 3) /46374 /
      DATA B(46375), B(46376), B(46377) /    27.29,  -36.98,    0.00 /
      DATA B(46522), B(46523), B(46524) /    27.47,  -36.75,    0.00 /
      DATA B(46669), B(46670), B(46671) /    27.72,  -36.45,    0.00 /
      DATA B(46816), B(46817), B(46818) /    28.10,  -36.02,    0.00 /
      DATA B(46963), B(46964), B(46965) /    28.67,  -35.32,    0.00 /
      DATA B(47110), B(47111), B(47112) /    29.59,  -33.98,    0.00 /
      DATA B(47257), B(47258), B(47259) /    31.04,  -30.86,    0.00 /
      DATA B(47404), B(47405), B(47406) /    31.43,  -22.81,    0.00 /
      DATA B(47551), B(47552), B(47553) /    15.75,   -7.14,    0.00 /
      DATA B(47698), B(47699), B(47700) /    16.17,   -1.52,    0.00 /
      DATA B(47845), B(47846), B(47847) /    17.15,   -0.22,    0.00 /
      DATA B(47992), B(47993), B(47994) /    17.94,   -0.23,    0.00 /
      DATA B(48139), B(48140), B(48141) /    18.73,   -0.62,    0.00 /
      DATA B(48286), B(48287), B(48288) /    19.61,   -1.06,    0.00 /
      DATA B(48433), B(48434), B(48435) /    20.48,   -1.46,    0.00 /
      DATA B(48580), B(48581), B(48582) /    21.31,   -1.78,    0.00 /
      DATA B(48727), B(48728), B(48729) /    15.64,   10.51,    0.00 /
      DATA B(48874), B(48875), B(48876) /    16.31,    5.61,    0.00 /
      DATA B(49021), B(49022), B(49023) /    16.03,    4.35,    0.00 /
      DATA B(49168), B(49169), B(49170) /    15.80,    3.01,    0.00 /
      DATA B(49315), B(49316), B(49317) /    15.45,    1.63,    0.00 /
      DATA B(49462), B(49463), B(49464) /    15.17,    0.15,    0.00 /
      DATA B(49609), B(49610), B(49611) /    14.74,   -1.36,    0.00 /
      DATA B(49756), B(49757), B(49758) /    14.43,   -2.90,    0.00 /
      DATA B(49903), B(49904), B(49905) /    14.27,   -4.46,    0.00 /
      DATA B(50050), B(50051), B(50052) /    14.29,   -5.97,    0.00 /
      DATA B(50197), B(50198), B(50199) /     8.12,    5.97,    0.00 /
      DATA B(50344), B(50345), B(50346) /     9.12,    5.27,    0.00 /
      DATA B(50491), B(50492), B(50493) /    10.30,    5.02,    0.00 /
      DATA B(50638), B(50639), B(50640) /    11.42,    4.96,    0.00 /
      DATA B(50785), B(50786), B(50787) /    12.62,    4.97,    0.00 /
      DATA B(50932), B(50933), B(50934) /    13.44,    5.03,    0.00 /
      DATA B(51079), B(51080), B(51081) /    14.19,    5.07,    0.00 /
      DATA B(51226), B(51227), B(51228) /    14.67,    5.14,    0.00 /
      DATA B(51373), B(51374), B(51375) /    15.00,    5.15,    0.00 /
      DATA B(51520), B(51521), B(51522) /    15.13,    5.12,    0.00 /
      DATA B(51667), B(51668), B(51669) /    15.13,    5.09,    0.00 /
      DATA B(51814), B(51815), B(51816) /    15.06,    5.03,    0.00 /
      DATA B(51961), B(51962), B(51963) /    14.91,    4.95,    0.00 /
      DATA B(52108), B(52109), B(52110) /    14.68,    4.83,    0.00 /
      DATA B(52255), B(52256), B(52257) /    14.41,    4.61,    0.00 /
      DATA B(52402), B(52403), B(52404) /    14.06,    4.30,    0.00 /
      DATA B(52549), B(52550), B(52551) /    13.73,    3.92,    0.00 /
      DATA B(52696), B(52697), B(52698) /    13.35,    3.53,    0.00 /
      DATA B(52843), B(52844), B(52845) /    12.98,    3.13,    0.00 /
      DATA B(52990), B(52991), B(52992) /    12.66,    2.76,    0.00 /
      DATA B(53137), B(53138), B(53139) /    12.36,    2.44,    0.00 /
      DATA B(53284), B(53285), B(53286) /    12.19,    2.21,    0.00 /
      DATA B(53431), B(53432), B(53433) /    12.08,    2.14,    0.00 /
      DATA B(53578), B(53579), B(53580) /    12.01,    2.18,    0.00 /
      DATA B(53725), B(53726), B(53727) /    11.95,    2.31,    0.00 /
      DATA B(53872), B(53873), B(53874) /    11.88,    2.46,    0.00 /
      DATA B(54019), B(54020), B(54021) /    11.83,    2.62,    0.00 /
      DATA B(54166), B(54167), B(54168) /    11.84,    2.80,    0.00 /
      DATA B(54313), B(54314), B(54315) /    11.90,    2.97,    0.00 /
      DATA B(54460), B(54461), B(54462) /    12.04,    3.17,    0.00 /
      DATA B(54607), B(54608), B(54609) /    12.23,    3.51,    0.00 /
      DATA B(54754), B(54755), B(54756) /    12.55,    4.00,    0.00 /
      DATA B(54901), B(54902), B(54903) /    12.91,    4.68,    0.00 /
      DATA B(55048), B(55049), B(55050) /    13.46,    5.42,    0.00 /
      DATA B(55195), B(55196), B(55197) /    14.04,    6.21,    0.00 /
      DATA B(55342), B(55343), B(55344) /    14.62,    7.00,    0.00 /
      DATA B(55489), B(55490), B(55491) /    15.22,    7.77,    0.00 /
      DATA B(55636), B(55637), B(55638) /    15.64,    8.49,    0.00 /
      DATA B(55783), B(55784), B(55785) /    16.06,    9.04,    0.00 /
      DATA B(55930), B(55931), B(55932) /    16.39,    9.42,    0.00 /
      DATA B(56077), B(56078), B(56079) /    16.66,    9.65,    0.00 /
      DATA B(56224), B(56225), B(56226) /    16.82,    9.80,    0.00 /
      DATA B(56371), B(56372), B(56373) /    16.92,    9.94,    0.00 /
      DATA B(56518), B(56519), B(56520) /    16.98,   10.06,    0.00 /
      DATA B(56665), B(56666), B(56667) /    17.01,   10.17,    0.00 /
      DATA B(56812), B(56813), B(56814) /    17.02,   10.28,    0.00 /
      DATA B(56959), B(56960), B(56961) /    17.02,   10.38,    0.00 /
      DATA B(57106), B(57107), B(57108) /    17.00,   10.48,    0.00 /
      DATA B(57253), B(57254), B(57255) /    16.97,   10.58,    0.00 /
      DATA B(57400), B(57401), B(57402) /    16.93,   10.67,    0.00 /
      DATA B(57547), B(57548), B(57549) /    16.86,   10.75,    0.00 /
      DATA B(57694), B(57695), B(57696) /    16.77,   10.83,    0.00 /
      DATA B(57841), B(57842), B(57843) /    16.63,   10.88,    0.00 /
      DATA B(57988), B(57989), B(57990) /    16.41,   10.88,    0.00 /
      DATA B(58135), B(58136), B(58137) /    16.16,   10.80,    0.00 /
      DATA B(58282), B(58283), B(58284) /    15.90,   10.63,    0.00 /
      DATA B(58429), B(58430), B(58431) /    15.63,   10.39,    0.00 /
      DATA B(58576), B(58577), B(58578) /    15.33,   10.12,    0.00 /
      DATA B(58723), B(58724), B(58725) /    15.03,    9.85,    0.00 /
      DATA B(58870), B(58871), B(58872) /    14.76,    9.58,    0.00 /
      DATA B(59017), B(59018), B(59019) /    14.53,    9.34,    0.00 /
      DATA B(59164), B(59165), B(59166) /    14.38,    9.16,    0.00 /
      DATA B(59311), B(59312), B(59313) /    14.26,    9.08,    0.00 /
      DATA B(59458), B(59459), B(59460) /    14.18,    9.10,    0.00 /
      DATA B(59605), B(59606), B(59607) /    14.11,    9.21,    0.00 /
      DATA B(59752), B(59753), B(59754) /    14.08,    9.34,    0.00 /
      DATA B(59899), B(59900), B(59901) /    14.06,    9.49,    0.00 /
      DATA B(60046), B(60047), B(60048) /    14.05,    9.65,    0.00 /
      DATA B(60193), B(60194), B(60195) /    14.05,    9.80,    0.00 /
      DATA B(60340), B(60341), B(60342) /    14.05,    9.96,    0.00 /
      DATA B(60487), B(60488), B(60489) /    14.02,   10.09,    0.00 /
      DATA B(60634), B(60635), B(60636) /    13.99,   10.19,    0.00 /
      DATA B(60781), B(60782), B(60783) /    13.92,   10.28,    0.00 /
      DATA B(60928), B(60929), B(60930) /    13.86,   10.37,    0.00 /
      DATA B(61075), B(61076), B(61077) /    13.80,   10.47,    0.00 /
      DATA B(61222), B(61223), B(61224) /    13.73,   10.57,    0.00 /
      DATA B(61369), B(61370), B(61371) /    13.68,   10.67,    0.00 /
      DATA B(61516), B(61517), B(61518) /    13.63,   10.77,    0.00 /
      DATA B(61663), B(61664), B(61665) /    13.60,   10.85,    0.00 /
      DATA B(61810), B(61811), B(61812) /    13.61,   10.92,    0.00 /
      DATA B(61957), B(61958), B(61959) /    13.61,   10.98,    0.00 /
      DATA B(62104), B(62105), B(62106) /    13.64,   11.06,    0.00 /
      DATA B(62251), B(62252), B(62253) /    13.72,   11.18,    0.00 /
      DATA B(62398), B(62399), B(62400) /    13.82,   11.35,    0.00 /
      DATA B(62545), B(62546), B(62547) /    13.90,   11.58,    0.00 /
      DATA B(62692), B(62693), B(62694) /    13.92,   11.73,    0.00 /
      DATA B(62839), B(62840), B(62841) /     9.76,   11.26,    0.00 /
      DATA B(62986), B(62987), B(62988) /     9.80,   11.35,    0.00 /
      DATA B(63133), B(63134), B(63135) /     9.73,   11.33,    0.00 /
      DATA B(63280), B(63281), B(63282) /     9.54,   11.20,    0.00 /
      DATA B(63427), B(63428), B(63429) /     9.24,   10.91,    0.00 /
      DATA B(63574), B(63575), B(63576) /     8.81,   10.45,    0.00 /
      DATA B(63721), B(63722), B(63723) /     8.27,    9.87,    0.00 /
      DATA B(63868), B(63869), B(63870) /     7.65,    9.23,    0.00 /
      DATA B(64015), B(64016), B(64017) /     6.99,    8.58,    0.00 /
      DATA B(64162), B(64163), B(64164) /     6.31,    7.93,    0.00 /
      DATA B(64309), B(64310), B(64311) /     5.64,    7.29,    0.00 /
      DATA B(64456), B(64457), B(64458) /     4.94,    6.63,    0.00 /
      DATA B(64603), B(64604), B(64605) /     4.18,    5.96,    0.00 /
      DATA B(64750), B(64751), B(64752) /     3.42,    5.29,    0.00 /
      DATA B(64897), B(64898), B(64899) /     2.71,    4.63,    0.00 /
      DATA B(65044), B(65045), B(65046) /     2.04,    3.98,    0.00 /
      DATA B(65191), B(65192), B(65193) /     1.40,    3.31,    0.00 /
      DATA B(65338), B(65339), B(65340) /     0.78,    2.65,    0.00 /
      DATA B(65485), B(65486), B(65487) /     0.19,    2.00,    0.00 /
      DATA B(65632), B(65633), B(65634) /    -0.34,    1.38,    0.00 /
      DATA B(65779), B(65780), B(65781) /    -0.84,    0.79,    0.00 /
      DATA B(65926), B(65927), B(65928) /    -1.31,    0.20,    0.00 /
      DATA B(66073), B(66074), B(66075) /    -1.76,   -0.38,    0.00 /
      DATA B(66220), B(66221), B(66222) /    -2.20,   -0.97,    0.00 /
      DATA B(66367), B(66368), B(66369) /    -2.63,   -1.56,    0.00 /
      DATA B(66514), B(66515), B(66516) /    -3.03,   -2.18,    0.00 /
      DATA B(66661), B(66662), B(66663) /    -3.37,   -2.79,    0.00 /
      DATA B(66808), B(66809), B(66810) /    -3.64,   -3.33,    0.00 /
      DATA B(66955), B(66956), B(66957) /    -3.79,   -3.80,    0.00 /
      DATA B(67102), B(67103), B(67104) /    -3.93,   -4.26,    0.00 /
      DATA B(67249), B(67250), B(67251) /    -4.15,   -4.75,    0.00 /
      DATA B(67396), B(67397), B(67398) /    -4.44,   -5.23,    0.00 /
      DATA B(67543), B(67544), B(67545) /    -4.73,   -5.68,    0.00 /
      DATA B(46378), B(46379), B(46380) /    27.20,  -36.87,    0.00 /
      DATA B(46525), B(46526), B(46527) /    27.39,  -36.62,    0.00 /
      DATA B(46672), B(46673), B(46674) /    27.65,  -36.28,    0.00 /
      DATA B(46819), B(46820), B(46821) /    28.02,  -35.80,    0.00 /
      DATA B(46966), B(46967), B(46968) /    28.60,  -34.97,    0.00 /
      DATA B(47113), B(47114), B(47115) /    29.52,  -33.31,    0.00 /
      DATA B(47260), B(47261), B(47262) /    30.76,  -29.22,    0.00 /
      DATA B(47407), B(47408), B(47409) /    29.29,  -19.41,    0.00 /
      DATA B(47554), B(47555), B(47556) /    14.59,   -5.19,    0.00 /
      DATA B(47701), B(47702), B(47703) /    15.49,   -1.09,    0.00 /
      DATA B(47848), B(47849), B(47850) /    16.66,   -0.17,    0.00 /
      DATA B(47995), B(47996), B(47997) /    17.70,   -0.26,    0.00 /
      DATA B(48142), B(48143), B(48144) /    18.62,   -0.69,    0.00 /
      DATA B(48289), B(48290), B(48291) /    19.47,   -1.13,    0.00 /
      DATA B(48436), B(48437), B(48438) /    20.18,   -1.41,    0.00 /
      DATA B(48583), B(48584), B(48585) /    20.50,   -1.40,    0.00 /
      DATA B(48730), B(48731), B(48732) /    16.34,    4.99,    0.00 /
      DATA B(48877), B(48878), B(48879) /    16.38,    4.92,    0.00 /
      DATA B(49024), B(49025), B(49026) /    15.95,    3.70,    0.00 /
      DATA B(49171), B(49172), B(49173) /    15.58,    2.32,    0.00 /
      DATA B(49318), B(49319), B(49320) /    15.10,    0.86,    0.00 /
      DATA B(49465), B(49466), B(49467) /    14.72,   -0.74,    0.00 /
      DATA B(49612), B(49613), B(49614) /    14.22,   -2.35,    0.00 /
      DATA B(49759), B(49760), B(49761) /    13.83,   -3.98,    0.00 /
      DATA B(49906), B(49907), B(49908) /    13.65,   -5.58,    0.00 /
      DATA B(50053), B(50054), B(50055) /    13.54,   -7.14,    0.00 /
      DATA B(50200), B(50201), B(50202) /     7.52,    4.90,    0.00 /
      DATA B(50347), B(50348), B(50349) /     8.51,    3.83,    0.00 /
      DATA B(50494), B(50495), B(50496) /     9.61,    3.52,    0.00 /
      DATA B(50641), B(50642), B(50643) /    10.56,    3.49,    0.00 /
      DATA B(50788), B(50789), B(50790) /    11.53,    3.54,    0.00 /
      DATA B(50935), B(50936), B(50937) /    12.20,    3.66,    0.00 /
      DATA B(51082), B(51083), B(51084) /    12.79,    3.76,    0.00 /
      DATA B(51229), B(51230), B(51231) /    13.17,    3.87,    0.00 /
      DATA B(51376), B(51377), B(51378) /    13.42,    3.90,    0.00 /
      DATA B(51523), B(51524), B(51525) /    13.49,    3.89,    0.00 /
      DATA B(51670), B(51671), B(51672) /    13.44,    3.85,    0.00 /
      DATA B(51817), B(51818), B(51819) /    13.32,    3.79,    0.00 /
      DATA B(51964), B(51965), B(51966) /    13.13,    3.71,    0.00 /
      DATA B(52111), B(52112), B(52113) /    12.87,    3.57,    0.00 /
      DATA B(52258), B(52259), B(52260) /    12.55,    3.34,    0.00 /
      DATA B(52405), B(52406), B(52407) /    12.17,    3.01,    0.00 /
      DATA B(52552), B(52553), B(52554) /    11.80,    2.60,    0.00 /
      DATA B(52699), B(52700), B(52701) /    11.39,    2.18,    0.00 /
      DATA B(52846), B(52847), B(52848) /    11.00,    1.76,    0.00 /
      DATA B(52993), B(52994), B(52995) /    10.66,    1.36,    0.00 /
      DATA B(53140), B(53141), B(53142) /    10.37,    1.02,    0.00 /
      DATA B(53287), B(53288), B(53289) /    10.25,    0.79,    0.00 /
      DATA B(53434), B(53435), B(53436) /    10.21,    0.74,    0.00 /
      DATA B(53581), B(53582), B(53583) /    10.24,    0.84,    0.00 /
      DATA B(53728), B(53729), B(53730) /    10.27,    1.05,    0.00 /
      DATA B(53875), B(53876), B(53877) /    10.35,    1.30,    0.00 /
      DATA B(54022), B(54023), B(54024) /    10.44,    1.55,    0.00 /
      DATA B(54169), B(54170), B(54171) /    10.57,    1.81,    0.00 /
      DATA B(54316), B(54317), B(54318) /    10.76,    2.06,    0.00 /
      DATA B(54463), B(54464), B(54465) /    10.97,    2.33,    0.00 /
      DATA B(54610), B(54611), B(54612) /    11.22,    2.69,    0.00 /
      DATA B(54757), B(54758), B(54759) /    11.57,    3.16,    0.00 /
      DATA B(54904), B(54905), B(54906) /    11.96,    3.78,    0.00 /
      DATA B(55051), B(55052), B(55053) /    12.51,    4.46,    0.00 /
      DATA B(55198), B(55199), B(55200) /    13.10,    5.18,    0.00 /
      DATA B(55345), B(55346), B(55347) /    13.68,    5.90,    0.00 /
      DATA B(55492), B(55493), B(55494) /    14.27,    6.61,    0.00 /
      DATA B(55639), B(55640), B(55641) /    14.73,    7.29,    0.00 /
      DATA B(55786), B(55787), B(55788) /    15.18,    7.83,    0.00 /
      DATA B(55933), B(55934), B(55935) /    15.54,    8.24,    0.00 /
      DATA B(56080), B(56081), B(56082) /    15.84,    8.49,    0.00 /
      DATA B(56227), B(56228), B(56229) /    16.03,    8.68,    0.00 /
      DATA B(56374), B(56375), B(56376) /    16.14,    8.83,    0.00 /
      DATA B(56521), B(56522), B(56523) /    16.20,    8.98,    0.00 /
      DATA B(56668), B(56669), B(56670) /    16.24,    9.11,    0.00 /
      DATA B(56815), B(56816), B(56817) /    16.24,    9.23,    0.00 /
      DATA B(56962), B(56963), B(56964) /    16.24,    9.35,    0.00 /
      DATA B(57109), B(57110), B(57111) /    16.22,    9.46,    0.00 /
      DATA B(57256), B(57257), B(57258) /    16.18,    9.57,    0.00 /
      DATA B(57403), B(57404), B(57405) /    16.13,    9.67,    0.00 /
      DATA B(57550), B(57551), B(57552) /    16.06,    9.77,    0.00 /
      DATA B(57697), B(57698), B(57699) /    15.95,    9.86,    0.00 /
      DATA B(57844), B(57845), B(57846) /    15.79,    9.92,    0.00 /
      DATA B(57991), B(57992), B(57993) /    15.56,    9.93,    0.00 /
      DATA B(58138), B(58139), B(58140) /    15.29,    9.86,    0.00 /
      DATA B(58285), B(58286), B(58287) /    15.01,    9.69,    0.00 /
      DATA B(58432), B(58433), B(58434) /    14.72,    9.43,    0.00 /
      DATA B(58579), B(58580), B(58581) /    14.40,    9.14,    0.00 /
      DATA B(58726), B(58727), B(58728) /    14.08,    8.85,    0.00 /
      DATA B(58873), B(58874), B(58875) /    13.79,    8.55,    0.00 /
      DATA B(59020), B(59021), B(59022) /    13.54,    8.28,    0.00 /
      DATA B(59167), B(59168), B(59169) /    13.37,    8.07,    0.00 /
      DATA B(59314), B(59315), B(59316) /    13.23,    7.97,    0.00 /
      DATA B(59461), B(59462), B(59463) /    13.14,    7.98,    0.00 /
      DATA B(59608), B(59609), B(59610) /    13.07,    8.08,    0.00 /
      DATA B(59755), B(59756), B(59757) /    13.03,    8.21,    0.00 /
      DATA B(59902), B(59903), B(59904) /    13.03,    8.36,    0.00 /
      DATA B(60049), B(60050), B(60051) /    13.03,    8.53,    0.00 /
      DATA B(60196), B(60197), B(60198) /    13.05,    8.69,    0.00 /
      DATA B(60343), B(60344), B(60345) /    13.07,    8.87,    0.00 /
      DATA B(60490), B(60491), B(60492) /    13.07,    9.03,    0.00 /
      DATA B(60637), B(60638), B(60639) /    13.07,    9.16,    0.00 /
      DATA B(60784), B(60785), B(60786) /    13.04,    9.29,    0.00 /
      DATA B(60931), B(60932), B(60933) /    13.00,    9.43,    0.00 /
      DATA B(61078), B(61079), B(61080) /    12.97,    9.57,    0.00 /
      DATA B(61225), B(61226), B(61227) /    12.92,    9.71,    0.00 /
      DATA B(61372), B(61373), B(61374) /    12.89,    9.85,    0.00 /
      DATA B(61519), B(61520), B(61521) /    12.85,    9.99,    0.00 /
      DATA B(61666), B(61667), B(61668) /    12.83,   10.10,    0.00 /
      DATA B(61813), B(61814), B(61815) /    12.83,   10.19,    0.00 /
      DATA B(61960), B(61961), B(61962) /    12.82,   10.27,    0.00 /
      DATA B(62107), B(62108), B(62109) /    12.83,   10.35,    0.00 /
      DATA B(62254), B(62255), B(62256) /    12.88,   10.46,    0.00 /
      DATA B(62401), B(62402), B(62403) /    12.99,   10.64,    0.00 /
      DATA B(62548), B(62549), B(62550) /    13.15,   10.96,    0.00 /
      DATA B(62695), B(62696), B(62697) /    13.13,   11.13,    0.00 /
      DATA B(62842), B(62843), B(62844) /     8.94,   10.60,    0.00 /
      DATA B(62989), B(62990), B(62991) /     8.96,   10.62,    0.00 /
      DATA B(63136), B(63137), B(63138) /     8.88,   10.57,    0.00 /
      DATA B(63283), B(63284), B(63285) /     8.69,   10.41,    0.00 /
      DATA B(63430), B(63431), B(63432) /     8.38,   10.07,    0.00 /
      DATA B(63577), B(63578), B(63579) /     7.93,    9.54,    0.00 /
      DATA B(63724), B(63725), B(63726) /     7.39,    8.92,    0.00 /
      DATA B(63871), B(63872), B(63873) /     6.80,    8.31,    0.00 /
      DATA B(64018), B(64019), B(64020) /     6.18,    7.71,    0.00 /
      DATA B(64165), B(64166), B(64167) /     5.55,    7.14,    0.00 /
      DATA B(64312), B(64313), B(64314) /     4.92,    6.56,    0.00 /
      DATA B(64459), B(64460), B(64461) /     4.27,    5.97,    0.00 /
      DATA B(64606), B(64607), B(64608) /     3.57,    5.36,    0.00 /
      DATA B(64753), B(64754), B(64755) /     2.87,    4.73,    0.00 /
      DATA B(64900), B(64901), B(64902) /     2.19,    4.09,    0.00 /
      DATA B(65047), B(65048), B(65049) /     1.54,    3.45,    0.00 /
      DATA B(65194), B(65195), B(65196) /     0.92,    2.80,    0.00 /
      DATA B(65341), B(65342), B(65343) /     0.33,    2.16,    0.00 /
      DATA B(65488), B(65489), B(65490) /    -0.22,    1.54,    0.00 /
      DATA B(65635), B(65636), B(65637) /    -0.73,    0.94,    0.00 /
      DATA B(65782), B(65783), B(65784) /    -1.20,    0.36,    0.00 /
      DATA B(65929), B(65930), B(65931) /    -1.66,   -0.21,    0.00 /
      DATA B(66076), B(66077), B(66078) /    -2.10,   -0.79,    0.00 /
      DATA B(66223), B(66224), B(66225) /    -2.53,   -1.37,    0.00 /
      DATA B(66370), B(66371), B(66372) /    -2.95,   -1.98,    0.00 /
      DATA B(66517), B(66518), B(66519) /    -3.31,   -2.61,    0.00 /
      DATA B(66664), B(66665), B(66666) /    -3.60,   -3.15,    0.00 /
      DATA B(66811), B(66812), B(66813) /    -3.81,   -3.67,    0.00 /
      DATA B(66958), B(66959), B(66960) /    -3.93,   -4.12,    0.00 /
      DATA B(67105), B(67106), B(67107) /    -4.11,   -4.59,    0.00 /
      DATA B(67252), B(67253), B(67254) /    -4.37,   -5.06,    0.00 /
      DATA B(67399), B(67400), B(67401) /    -4.65,   -5.51,    0.00 /
      DATA B(67546), B(67547), B(67548) /    -4.93,   -5.92,    0.00 /
      DATA B(46381), B(46382), B(46383) /    27.10,  -36.75,    0.00 /
      DATA B(46528), B(46529), B(46530) /    27.28,  -36.47,    0.00 /
      DATA B(46675), B(46676), B(46677) /    27.54,  -36.09,    0.00 /
      DATA B(46822), B(46823), B(46824) /    27.90,  -35.53,    0.00 /
      DATA B(46969), B(46970), B(46971) /    28.45,  -34.56,    0.00 /
      DATA B(47116), B(47117), B(47118) /    29.29,  -32.52,    0.00 /
      DATA B(47263), B(47264), B(47265) /    30.01,  -27.37,    0.00 /
      DATA B(47410), B(47411), B(47412) /    15.09,  -13.19,    0.00 /
      DATA B(47557), B(47558), B(47559) /    13.94,   -4.68,    0.00 /
      DATA B(47704), B(47705), B(47706) /    15.19,   -1.69,    0.00 /
      DATA B(47851), B(47852), B(47853) /    16.51,   -1.00,    0.00 /
      DATA B(47998), B(47999), B(48000) /    17.70,   -1.03,    0.00 /
      DATA B(48145), B(48146), B(48147) /    18.68,   -1.32,    0.00 /
      DATA B(48292), B(48293), B(48294) /    19.42,   -1.58,    0.00 /
      DATA B(48439), B(48440), B(48441) /    19.95,   -1.62,    0.00 /
      DATA B(48586), B(48587), B(48588) /    16.30,    3.86,    0.00 /
      DATA B(48733), B(48734), B(48735) /    16.05,    4.08,    0.00 /
      DATA B(48880), B(48881), B(48882) /    16.06,    3.87,    0.00 /
      DATA B(49027), B(49028), B(49029) /    15.72,    2.82,    0.00 /
      DATA B(49174), B(49175), B(49176) /    15.29,    1.44,    0.00 /
      DATA B(49321), B(49322), B(49323) /    14.71,   -0.08,    0.00 /
      DATA B(49468), B(49469), B(49470) /    14.20,   -1.79,    0.00 /
      DATA B(49615), B(49616), B(49617) /    13.58,   -3.54,    0.00 /
      DATA B(49762), B(49763), B(49764) /    13.07,   -5.28,    0.00 /
      DATA B(49909), B(49910), B(49911) /    12.83,   -6.95,    0.00 /
      DATA B(50056), B(50057), B(50058) /    12.75,   -8.38,    0.00 /
      DATA B(50203), B(50204), B(50205) /     7.00,    3.53,    0.00 /
      DATA B(50350), B(50351), B(50352) /     8.11,    2.14,    0.00 /
      DATA B(50497), B(50498), B(50499) /     8.92,    1.91,    0.00 /
      DATA B(50644), B(50645), B(50646) /     9.57,    1.92,    0.00 /
      DATA B(50791), B(50792), B(50793) /    10.24,    1.99,    0.00 /
      DATA B(50938), B(50939), B(50940) /    10.72,    2.13,    0.00 /
      DATA B(51085), B(51086), B(51087) /    11.13,    2.26,    0.00 /
      DATA B(51232), B(51233), B(51234) /    11.40,    2.38,    0.00 /
      DATA B(51379), B(51380), B(51381) /    11.56,    2.43,    0.00 /
      DATA B(51526), B(51527), B(51528) /    11.57,    2.42,    0.00 /
      DATA B(51673), B(51674), B(51675) /    11.49,    2.38,    0.00 /
      DATA B(51820), B(51821), B(51822) /    11.34,    2.32,    0.00 /
      DATA B(51967), B(51968), B(51969) /    11.12,    2.23,    0.00 /
      DATA B(52114), B(52115), B(52116) /    10.83,    2.10,    0.00 /
      DATA B(52261), B(52262), B(52263) /    10.50,    1.87,    0.00 /
      DATA B(52408), B(52409), B(52410) /    10.11,    1.54,    0.00 /
      DATA B(52555), B(52556), B(52557) /     9.73,    1.13,    0.00 /
      DATA B(52702), B(52703), B(52704) /     9.31,    0.70,    0.00 /
      DATA B(52849), B(52850), B(52851) /     8.91,    0.28,    0.00 /
      DATA B(52996), B(52997), B(52998) /     8.57,   -0.13,    0.00 /
      DATA B(53143), B(53144), B(53145) /     8.31,   -0.46,    0.00 /
      DATA B(53290), B(53291), B(53292) /     8.25,   -0.69,    0.00 /
      DATA B(53437), B(53438), B(53439) /     8.27,   -0.71,    0.00 /
      DATA B(53584), B(53585), B(53586) /     8.40,   -0.56,    0.00 /
      DATA B(53731), B(53732), B(53733) /     8.52,   -0.26,    0.00 /
      DATA B(53878), B(53879), B(53880) /     8.72,    0.07,    0.00 /
      DATA B(54025), B(54026), B(54027) /     8.94,    0.42,    0.00 /
      DATA B(54172), B(54173), B(54174) /     9.19,    0.76,    0.00 /
      DATA B(54319), B(54320), B(54321) /     9.48,    1.09,    0.00 /
      DATA B(54466), B(54467), B(54468) /     9.76,    1.41,    0.00 /
      DATA B(54613), B(54614), B(54615) /    10.05,    1.78,    0.00 /
      DATA B(54760), B(54761), B(54762) /    10.42,    2.22,    0.00 /
      DATA B(54907), B(54908), B(54909) /    10.81,    2.76,    0.00 /
      DATA B(55054), B(55055), B(55056) /    11.33,    3.35,    0.00 /
      DATA B(55201), B(55202), B(55203) /    11.89,    3.97,    0.00 /
      DATA B(55348), B(55349), B(55350) /    12.44,    4.61,    0.00 /
      DATA B(55495), B(55496), B(55497) /    13.00,    5.24,    0.00 /
      DATA B(55642), B(55643), B(55644) /    13.47,    5.86,    0.00 /
      DATA B(55789), B(55790), B(55791) /    13.94,    6.39,    0.00 /
      DATA B(55936), B(55937), B(55938) /    14.33,    6.81,    0.00 /
      DATA B(56083), B(56084), B(56085) /    14.65,    7.11,    0.00 /
      DATA B(56230), B(56231), B(56232) /    14.85,    7.32,    0.00 /
      DATA B(56377), B(56378), B(56379) /    14.98,    7.51,    0.00 /
      DATA B(56524), B(56525), B(56526) /    15.04,    7.68,    0.00 /
      DATA B(56671), B(56672), B(56673) /    15.08,    7.83,    0.00 /
      DATA B(56818), B(56819), B(56820) /    15.09,    7.98,    0.00 /
      DATA B(56965), B(56966), B(56967) /    15.09,    8.11,    0.00 /
      DATA B(57112), B(57113), B(57114) /    15.06,    8.23,    0.00 /
      DATA B(57259), B(57260), B(57261) /    15.02,    8.35,    0.00 /
      DATA B(57406), B(57407), B(57408) /    14.97,    8.45,    0.00 /
      DATA B(57553), B(57554), B(57555) /    14.89,    8.55,    0.00 /
      DATA B(57700), B(57701), B(57702) /    14.78,    8.64,    0.00 /
      DATA B(57847), B(57848), B(57849) /    14.61,    8.71,    0.00 /
      DATA B(57994), B(57995), B(57996) /    14.36,    8.73,    0.00 /
      DATA B(58141), B(58142), B(58143) /    14.09,    8.66,    0.00 /
      DATA B(58288), B(58289), B(58290) /    13.80,    8.51,    0.00 /
      DATA B(58435), B(58436), B(58437) /    13.51,    8.26,    0.00 /
      DATA B(58582), B(58583), B(58584) /    13.19,    7.97,    0.00 /
      DATA B(58729), B(58730), B(58731) /    12.87,    7.67,    0.00 /
      DATA B(58876), B(58877), B(58878) /    12.57,    7.36,    0.00 /
      DATA B(59023), B(59024), B(59025) /    12.31,    7.09,    0.00 /
      DATA B(59170), B(59171), B(59172) /    12.13,    6.86,    0.00 /
      DATA B(59317), B(59318), B(59319) /    11.99,    6.74,    0.00 /
      DATA B(59464), B(59465), B(59466) /    11.89,    6.74,    0.00 /
      DATA B(59611), B(59612), B(59613) /    11.81,    6.84,    0.00 /
      DATA B(59758), B(59759), B(59760) /    11.78,    6.98,    0.00 /
      DATA B(59905), B(59906), B(59907) /    11.79,    7.13,    0.00 /
      DATA B(60052), B(60053), B(60054) /    11.81,    7.31,    0.00 /
      DATA B(60199), B(60200), B(60201) /    11.86,    7.49,    0.00 /
      DATA B(60346), B(60347), B(60348) /    11.91,    7.68,    0.00 /
      DATA B(60493), B(60494), B(60495) /    11.95,    7.87,    0.00 /
      DATA B(60640), B(60641), B(60642) /    11.98,    8.03,    0.00 /
      DATA B(60787), B(60788), B(60789) /    11.98,    8.21,    0.00 /
      DATA B(60934), B(60935), B(60936) /    11.98,    8.38,    0.00 /
      DATA B(61081), B(61082), B(61083) /    11.97,    8.55,    0.00 /
      DATA B(61228), B(61229), B(61230) /    11.96,    8.72,    0.00 /
      DATA B(61375), B(61376), B(61377) /    11.95,    8.88,    0.00 /
      DATA B(61522), B(61523), B(61524) /    11.93,    9.04,    0.00 /
      DATA B(61669), B(61670), B(61671) /    11.92,    9.17,    0.00 /
      DATA B(61816), B(61817), B(61818) /    11.91,    9.27,    0.00 /
      DATA B(61963), B(61964), B(61965) /    11.88,    9.34,    0.00 /
      DATA B(62110), B(62111), B(62112) /    11.87,    9.41,    0.00 /
      DATA B(62257), B(62258), B(62259) /    11.88,    9.50,    0.00 /
      DATA B(62404), B(62405), B(62406) /    11.95,    9.65,    0.00 /
      DATA B(62551), B(62552), B(62553) /    12.25,   10.06,    0.00 /
      DATA B(62698), B(62699), B(62700) /     7.86,    9.67,    0.00 /
      DATA B(62845), B(62846), B(62847) /     8.12,    9.61,    0.00 /
      DATA B(62992), B(62993), B(62994) /     8.12,    9.61,    0.00 /
      DATA B(63139), B(63140), B(63141) /     7.99,    9.55,    0.00 /
      DATA B(63286), B(63287), B(63288) /     7.77,    9.38,    0.00 /
      DATA B(63433), B(63434), B(63435) /     7.45,    9.04,    0.00 /
      DATA B(63580), B(63581), B(63582) /     7.02,    8.52,    0.00 /
      DATA B(63727), B(63728), B(63729) /     6.52,    7.95,    0.00 /
      DATA B(63874), B(63875), B(63876) /     5.97,    7.41,    0.00 /
      DATA B(64021), B(64022), B(64023) /     5.40,    6.89,    0.00 /
      DATA B(64168), B(64169), B(64170) /     4.81,    6.38,    0.00 /
      DATA B(64315), B(64316), B(64317) /     4.22,    5.87,    0.00 /
      DATA B(64462), B(64463), B(64464) /     3.62,    5.34,    0.00 /
      DATA B(64609), B(64610), B(64611) /     2.99,    4.77,    0.00 /
      DATA B(64756), B(64757), B(64758) /     2.33,    4.18,    0.00 /
      DATA B(64903), B(64904), B(64905) /     1.69,    3.56,    0.00 /
      DATA B(65050), B(65051), B(65052) /     1.06,    2.93,    0.00 /
      DATA B(65197), B(65198), B(65199) /     0.46,    2.29,    0.00 /
      DATA B(65344), B(65345), B(65346) /    -0.10,    1.68,    0.00 /
      DATA B(65491), B(65492), B(65493) /    -0.62,    1.09,    0.00 /
      DATA B(65638), B(65639), B(65640) /    -1.10,    0.52,    0.00 /
      DATA B(65785), B(65786), B(65787) /    -1.55,   -0.05,    0.00 /
      DATA B(65932), B(65933), B(65934) /    -2.00,   -0.61,    0.00 /
      DATA B(66079), B(66080), B(66081) /    -2.43,   -1.18,    0.00 /
      DATA B(66226), B(66227), B(66228) /    -2.84,   -1.76,    0.00 /
      DATA B(66373), B(66374), B(66375) /    -3.24,   -2.38,    0.00 /
      DATA B(66520), B(66521), B(66522) /    -3.57,   -3.00,    0.00 /
      DATA B(66667), B(66668), B(66669) /    -3.83,   -3.52,    0.00 /
      DATA B(66814), B(66815), B(66816) /    -3.95,   -3.99,    0.00 /
      DATA B(66961), B(66962), B(66963) /    -4.09,   -4.45,    0.00 /
      DATA B(67108), B(67109), B(67110) /    -4.31,   -4.91,    0.00 /
      DATA B(67255), B(67256), B(67257) /    -4.58,   -5.36,    0.00 /
      DATA B(67402), B(67403), B(67404) /    -4.86,   -5.77,    0.00 /
      DATA B(67549), B(67550), B(67551) /    -5.12,   -6.15,    0.00 /
      DATA B(46384), B(46385), B(46386) /    26.96,  -36.61,    0.00 /
      DATA B(46531), B(46532), B(46533) /    27.14,  -36.30,    0.00 /
      DATA B(46678), B(46679), B(46680) /    27.39,  -35.87,    0.00 /
      DATA B(46825), B(46826), B(46827) /    27.73,  -35.22,    0.00 /
      DATA B(46972), B(46973), B(46974) /    28.23,  -34.07,    0.00 /
      DATA B(47119), B(47120), B(47121) /    28.88,  -31.59,    0.00 /
      DATA B(47266), B(47267), B(47268) /    28.67,  -25.44,    0.00 /
      DATA B(47413), B(47414), B(47415) /    13.60,  -11.63,    0.00 /
      DATA B(47560), B(47561), B(47562) /    13.86,   -5.21,    0.00 /
      DATA B(47707), B(47708), B(47709) /    15.42,   -2.90,    0.00 /
      DATA B(47854), B(47855), B(47856) /    16.84,   -2.23,    0.00 /
      DATA B(48001), B(48002), B(48003) /    18.04,   -2.11,    0.00 /
      DATA B(48148), B(48149), B(48150) /    18.96,   -2.16,    0.00 /
      DATA B(48295), B(48296), B(48297) /    19.55,   -2.20,    0.00 /
      DATA B(48442), B(48443), B(48444) /    19.91,   -1.97,    0.00 /
      DATA B(48589), B(48590), B(48591) /    16.07,    3.10,    0.00 /
      DATA B(48736), B(48737), B(48738) /    15.91,    3.07,    0.00 /
      DATA B(48883), B(48884), B(48885) /    15.79,    2.72,    0.00 /
      DATA B(49030), B(49031), B(49032) /    15.39,    1.77,    0.00 /
      DATA B(49177), B(49178), B(49179) /    14.86,    0.40,    0.00 /
      DATA B(49324), B(49325), B(49326) /    14.15,   -1.20,    0.00 /
      DATA B(49471), B(49472), B(49473) /    13.47,   -3.04,    0.00 /
      DATA B(49618), B(49619), B(49620) /    12.65,   -4.96,    0.00 /
      DATA B(49765), B(49766), B(49767) /    11.88,   -6.89,    0.00 /
      DATA B(49912), B(49913), B(49914) /    11.34,   -8.75,    0.00 /
      DATA B(50059), B(50060), B(50061) /    11.23,  -10.06,    0.00 /
      DATA B(50206), B(50207), B(50208) /     7.81,    1.13,    0.00 /
      DATA B(50353), B(50354), B(50355) /     8.09,    0.39,    0.00 /
      DATA B(50500), B(50501), B(50502) /     8.26,    0.29,    0.00 /
      DATA B(50647), B(50648), B(50649) /     8.53,    0.31,    0.00 /
      DATA B(50794), B(50795), B(50796) /     8.88,    0.38,    0.00 /
      DATA B(50941), B(50942), B(50943) /     9.15,    0.52,    0.00 /
      DATA B(51088), B(51089), B(51090) /     9.40,    0.66,    0.00 /
      DATA B(51235), B(51236), B(51237) /     9.55,    0.78,    0.00 /
      DATA B(51382), B(51383), B(51384) /     9.63,    0.84,    0.00 /
      DATA B(51529), B(51530), B(51531) /     9.59,    0.85,    0.00 /
      DATA B(51676), B(51677), B(51678) /     9.48,    0.82,    0.00 /
      DATA B(51823), B(51824), B(51825) /     9.31,    0.77,    0.00 /
      DATA B(51970), B(51971), B(51972) /     9.08,    0.70,    0.00 /
      DATA B(52117), B(52118), B(52119) /     8.78,    0.58,    0.00 /
      DATA B(52264), B(52265), B(52266) /     8.45,    0.37,    0.00 /
      DATA B(52411), B(52412), B(52413) /     8.07,    0.07,    0.00 /
      DATA B(52558), B(52559), B(52560) /     7.70,   -0.32,    0.00 /
      DATA B(52705), B(52706), B(52707) /     7.29,   -0.72,    0.00 /
      DATA B(52852), B(52853), B(52854) /     6.91,   -1.12,    0.00 /
      DATA B(52999), B(53000), B(53001) /     6.60,   -1.50,    0.00 /
      DATA B(53146), B(53147), B(53148) /     6.38,   -1.83,    0.00 /
      DATA B(53293), B(53294), B(53295) /     6.36,   -2.04,    0.00 /
      DATA B(53440), B(53441), B(53442) /     6.43,   -2.04,    0.00 /
      DATA B(53587), B(53588), B(53589) /     6.62,   -1.86,    0.00 /
      DATA B(53734), B(53735), B(53736) /     6.82,   -1.50,    0.00 /
      DATA B(53881), B(53882), B(53883) /     7.11,   -1.11,    0.00 /
      DATA B(54028), B(54029), B(54030) /     7.43,   -0.70,    0.00 /
      DATA B(54175), B(54176), B(54177) /     7.76,   -0.29,    0.00 /
      DATA B(54322), B(54323), B(54324) /     8.12,    0.08,    0.00 /
      DATA B(54469), B(54470), B(54471) /     8.43,    0.43,    0.00 /
      DATA B(54616), B(54617), B(54618) /     8.73,    0.79,    0.00 /
      DATA B(54763), B(54764), B(54765) /     9.07,    1.17,    0.00 /
      DATA B(54910), B(54911), B(54912) /     9.43,    1.62,    0.00 /
      DATA B(55057), B(55058), B(55059) /     9.89,    2.10,    0.00 /
      DATA B(55204), B(55205), B(55206) /    10.37,    2.61,    0.00 /
      DATA B(55351), B(55352), B(55353) /    10.85,    3.14,    0.00 /
      DATA B(55498), B(55499), B(55500) /    11.35,    3.68,    0.00 /
      DATA B(55645), B(55646), B(55647) /    11.80,    4.24,    0.00 /
      DATA B(55792), B(55793), B(55794) /    12.26,    4.74,    0.00 /
      DATA B(55939), B(55940), B(55941) /    12.67,    5.18,    0.00 /
      DATA B(56086), B(56087), B(56088) /    13.00,    5.50,    0.00 /
      DATA B(56233), B(56234), B(56235) /    13.22,    5.75,    0.00 /
      DATA B(56380), B(56381), B(56382) /    13.35,    5.95,    0.00 /
      DATA B(56527), B(56528), B(56529) /    13.44,    6.14,    0.00 /
      DATA B(56674), B(56675), B(56676) /    13.49,    6.30,    0.00 /
      DATA B(56821), B(56822), B(56823) /    13.51,    6.46,    0.00 /
      DATA B(56968), B(56969), B(56970) /    13.51,    6.59,    0.00 /
      DATA B(57115), B(57116), B(57117) /    13.49,    6.72,    0.00 /
      DATA B(57262), B(57263), B(57264) /    13.46,    6.83,    0.00 /
      DATA B(57409), B(57410), B(57411) /    13.41,    6.94,    0.00 /
      DATA B(57556), B(57557), B(57558) /    13.34,    7.04,    0.00 /
      DATA B(57703), B(57704), B(57705) /    13.23,    7.13,    0.00 /
      DATA B(57850), B(57851), B(57852) /    13.06,    7.19,    0.00 /
      DATA B(57997), B(57998), B(57999) /    12.82,    7.22,    0.00 /
      DATA B(58144), B(58145), B(58146) /    12.56,    7.17,    0.00 /
      DATA B(58291), B(58292), B(58293) /    12.28,    7.04,    0.00 /
      DATA B(58438), B(58439), B(58440) /    12.01,    6.81,    0.00 /
      DATA B(58585), B(58586), B(58587) /    11.70,    6.54,    0.00 /
      DATA B(58732), B(58733), B(58734) /    11.38,    6.24,    0.00 /
      DATA B(58879), B(58880), B(58881) /    11.09,    5.95,    0.00 /
      DATA B(59026), B(59027), B(59028) /    10.84,    5.67,    0.00 /
      DATA B(59173), B(59174), B(59175) /    10.66,    5.45,    0.00 /
      DATA B(59320), B(59321), B(59322) /    10.52,    5.32,    0.00 /
      DATA B(59467), B(59468), B(59469) /    10.41,    5.31,    0.00 /
      DATA B(59614), B(59615), B(59616) /    10.33,    5.40,    0.00 /
      DATA B(59761), B(59762), B(59763) /    10.31,    5.54,    0.00 /
      DATA B(59908), B(59909), B(59910) /    10.32,    5.70,    0.00 /
      DATA B(60055), B(60056), B(60057) /    10.37,    5.89,    0.00 /
      DATA B(60202), B(60203), B(60204) /    10.44,    6.08,    0.00 /
      DATA B(60349), B(60350), B(60351) /    10.53,    6.30,    0.00 /
      DATA B(60496), B(60497), B(60498) /    10.62,    6.50,    0.00 /
      DATA B(60643), B(60644), B(60645) /    10.69,    6.69,    0.00 /
      DATA B(60790), B(60791), B(60792) /    10.73,    6.88,    0.00 /
      DATA B(60937), B(60938), B(60939) /    10.76,    7.08,    0.00 /
      DATA B(61084), B(61085), B(61086) /    10.79,    7.27,    0.00 /
      DATA B(61231), B(61232), B(61233) /    10.82,    7.46,    0.00 /
      DATA B(61378), B(61379), B(61380) /    10.84,    7.65,    0.00 /
      DATA B(61525), B(61526), B(61527) /    10.85,    7.83,    0.00 /
      DATA B(61672), B(61673), B(61674) /    10.86,    7.98,    0.00 /
      DATA B(61819), B(61820), B(61821) /    10.85,    8.10,    0.00 /
      DATA B(61966), B(61967), B(61968) /    10.82,    8.19,    0.00 /
      DATA B(62113), B(62114), B(62115) /    10.78,    8.27,    0.00 /
      DATA B(62260), B(62261), B(62262) /    10.75,    8.36,    0.00 /
      DATA B(62407), B(62408), B(62409) /    10.70,    8.51,    0.00 /
      DATA B(62554), B(62555), B(62556) /    10.76,    8.78,    0.00 /
      DATA B(62701), B(62702), B(62703) /     7.55,    8.56,    0.00 /
      DATA B(62848), B(62849), B(62850) /     7.55,    8.53,    0.00 /
      DATA B(62995), B(62996), B(62997) /     7.38,    8.52,    0.00 /
      DATA B(63142), B(63143), B(63144) /     7.16,    8.47,    0.00 /
      DATA B(63289), B(63290), B(63291) /     6.89,    8.32,    0.00 /
      DATA B(63436), B(63437), B(63438) /     6.55,    8.01,    0.00 /
      DATA B(63583), B(63584), B(63585) /     6.14,    7.52,    0.00 /
      DATA B(63730), B(63731), B(63732) /     5.69,    7.02,    0.00 /
      DATA B(63877), B(63878), B(63879) /     5.19,    6.55,    0.00 /
      DATA B(64024), B(64025), B(64026) /     4.65,    6.10,    0.00 /
      DATA B(64171), B(64172), B(64173) /     4.10,    5.65,    0.00 /
      DATA B(64318), B(64319), B(64320) /     3.55,    5.19,    0.00 /
      DATA B(64465), B(64466), B(64467) /     3.00,    4.71,    0.00 /
      DATA B(64612), B(64613), B(64614) /     2.42,    4.19,    0.00 /
      DATA B(64759), B(64760), B(64761) /     1.81,    3.63,    0.00 /
      DATA B(64906), B(64907), B(64908) /     1.19,    3.03,    0.00 /
      DATA B(65053), B(65054), B(65055) /     0.58,    2.41,    0.00 /
      DATA B(65200), B(65201), B(65202) /     0.02,    1.81,    0.00 /
      DATA B(65347), B(65348), B(65349) /    -0.50,    1.23,    0.00 /
      DATA B(65494), B(65495), B(65496) /    -0.99,    0.66,    0.00 /
      DATA B(65641), B(65642), B(65643) /    -1.45,    0.11,    0.00 /
      DATA B(65788), B(65789), B(65790) /    -1.89,   -0.45,    0.00 /
      DATA B(65935), B(65936), B(65937) /    -2.32,   -1.01,    0.00 /
      DATA B(66082), B(66083), B(66084) /    -2.73,   -1.57,    0.00 /
      DATA B(66229), B(66230), B(66231) /    -3.12,   -2.13,    0.00 /
      DATA B(66376), B(66377), B(66378) /    -3.50,   -2.79,    0.00 /
      DATA B(66523), B(66524), B(66525) /    -3.80,   -3.34,    0.00 /
      DATA B(66670), B(66671), B(66672) /    -3.99,   -3.85,    0.00 /
      DATA B(66817), B(66818), B(66819) /    -4.10,   -4.31,    0.00 /
      DATA B(66964), B(66965), B(66966) /    -4.27,   -4.77,    0.00 /
      DATA B(67111), B(67112), B(67113) /    -4.52,   -5.23,    0.00 /
      DATA B(67258), B(67259), B(67260) /    -4.79,   -5.64,    0.00 /
      DATA B(67405), B(67406), B(67407) /    -5.05,   -6.02,    0.00 /
      DATA B(67552), B(67553), B(67554) /    -5.30,   -6.36,    0.00 /
      DATA B(46387), B(46388), B(46389) /    26.78,  -36.47,    0.00 /
      DATA B(46534), B(46535), B(46536) /    26.96,  -36.12,    0.00 /
      DATA B(46681), B(46682), B(46683) /    27.20,  -35.63,    0.00 /
      DATA B(46828), B(46829), B(46830) /    27.52,  -34.86,    0.00 /
      DATA B(46975), B(46976), B(46977) /    27.95,  -33.49,    0.00 /
      DATA B(47122), B(47123), B(47124) /    28.34,  -30.51,    0.00 /
      DATA B(47269), B(47270), B(47271) /    27.18,  -23.57,    0.00 /
      DATA B(47416), B(47417), B(47418) /    13.17,  -10.96,    0.00 /
      DATA B(47563), B(47564), B(47565) /    14.40,   -6.15,    0.00 /
      DATA B(47710), B(47711), B(47712) /    16.09,   -4.27,    0.00 /
      DATA B(47857), B(47858), B(47859) /    17.47,   -3.56,    0.00 /
      DATA B(48004), B(48005), B(48006) /    18.53,   -3.29,    0.00 /
      DATA B(48151), B(48152), B(48153) /    19.29,   -3.11,    0.00 /
      DATA B(48298), B(48299), B(48300) /    19.72,   -2.87,    0.00 /
      DATA B(48445), B(48446), B(48447) /    16.03,    2.21,    0.00 /
      DATA B(48592), B(48593), B(48594) /    15.93,    2.13,    0.00 /
      DATA B(48739), B(48740), B(48741) /    15.75,    1.98,    0.00 /
      DATA B(48886), B(48887), B(48888) /    15.44,    1.54,    0.00 /
      DATA B(49033), B(49034), B(49035) /    14.88,    0.62,    0.00 /
      DATA B(49180), B(49181), B(49182) /    14.16,   -0.79,    0.00 /
      DATA B(49327), B(49328), B(49329) /    13.30,   -2.51,    0.00 /
      DATA B(49474), B(49475), B(49476) /    12.38,   -4.52,    0.00 /
      DATA B(49621), B(49622), B(49623) /    11.36,   -6.53,    0.00 /
      DATA B(49768), B(49769), B(49770) /    10.24,   -8.50,    0.00 /
      DATA B(49915), B(49916), B(49917) /     8.19,  -11.48,    0.00 /
      DATA B(50062), B(50063), B(50064) /     6.32,  -12.48,    0.00 /
      DATA B(50209), B(50210), B(50211) /     8.64,   -0.49,    0.00 /
      DATA B(50356), B(50357), B(50358) /     7.80,   -1.00,    0.00 /
      DATA B(50503), B(50504), B(50505) /     7.47,   -1.17,    0.00 /
      DATA B(50650), B(50651), B(50652) /     7.42,   -1.18,    0.00 /
      DATA B(50797), B(50798), B(50799) /     7.51,   -1.13,    0.00 /
      DATA B(50944), B(50945), B(50946) /     7.60,   -1.01,    0.00 /
      DATA B(51091), B(51092), B(51093) /     7.71,   -0.88,    0.00 /
      DATA B(51238), B(51239), B(51240) /     7.76,   -0.76,    0.00 /
      DATA B(51385), B(51386), B(51387) /     7.76,   -0.69,    0.00 /
      DATA B(51532), B(51533), B(51534) /     7.69,   -0.67,    0.00 /
      DATA B(51679), B(51680), B(51681) /     7.56,   -0.68,    0.00 /
      DATA B(51826), B(51827), B(51828) /     7.38,   -0.71,    0.00 /
      DATA B(51973), B(51974), B(51975) /     7.15,   -0.76,    0.00 /
      DATA B(52120), B(52121), B(52122) /     6.86,   -0.86,    0.00 /
      DATA B(52267), B(52268), B(52269) /     6.56,   -1.04,    0.00 /
      DATA B(52414), B(52415), B(52416) /     6.21,   -1.31,    0.00 /
      DATA B(52561), B(52562), B(52563) /     5.87,   -1.66,    0.00 /
      DATA B(52708), B(52709), B(52710) /     5.50,   -2.03,    0.00 /
      DATA B(52855), B(52856), B(52857) /     5.15,   -2.41,    0.00 /
      DATA B(53002), B(53003), B(53004) /     4.89,   -2.77,    0.00 /
      DATA B(53149), B(53150), B(53151) /     4.72,   -3.08,    0.00 /
      DATA B(53296), B(53297), B(53298) /     4.74,   -3.30,    0.00 /
      DATA B(53443), B(53444), B(53445) /     4.85,   -3.32,    0.00 /
      DATA B(53590), B(53591), B(53592) /     5.07,   -3.15,    0.00 /
      DATA B(53737), B(53738), B(53739) /     5.30,   -2.79,    0.00 /
      DATA B(53884), B(53885), B(53886) /     5.64,   -2.37,    0.00 /
      DATA B(54031), B(54032), B(54033) /     6.01,   -1.93,    0.00 /
      DATA B(54178), B(54179), B(54180) /     6.38,   -1.50,    0.00 /
      DATA B(54325), B(54326), B(54327) /     6.75,   -1.10,    0.00 /
      DATA B(54472), B(54473), B(54474) /     7.04,   -0.73,    0.00 /
      DATA B(54619), B(54620), B(54621) /     7.31,   -0.39,    0.00 /
      DATA B(54766), B(54767), B(54768) /     7.59,   -0.05,    0.00 /
      DATA B(54913), B(54914), B(54915) /     7.88,    0.32,    0.00 /
      DATA B(55060), B(55061), B(55062) /     8.24,    0.72,    0.00 /
      DATA B(55207), B(55208), B(55209) /     8.62,    1.15,    0.00 /
      DATA B(55354), B(55355), B(55356) /     9.00,    1.60,    0.00 /
      DATA B(55501), B(55502), B(55503) /     9.42,    2.08,    0.00 /
      DATA B(55648), B(55649), B(55650) /     9.83,    2.59,    0.00 /
      DATA B(55795), B(55796), B(55797) /    10.27,    3.08,    0.00 /
      DATA B(55942), B(55943), B(55944) /    10.68,    3.52,    0.00 /
      DATA B(56089), B(56090), B(56091) /    11.00,    3.86,    0.00 /
      DATA B(56236), B(56237), B(56238) /    11.23,    4.13,    0.00 /
      DATA B(56383), B(56384), B(56385) /    11.39,    4.35,    0.00 /
      DATA B(56530), B(56531), B(56532) /    11.50,    4.55,    0.00 /
      DATA B(56677), B(56678), B(56679) /    11.57,    4.73,    0.00 /
      DATA B(56824), B(56825), B(56826) /    11.62,    4.89,    0.00 /
      DATA B(56971), B(56972), B(56973) /    11.64,    5.03,    0.00 /
      DATA B(57118), B(57119), B(57120) /    11.64,    5.16,    0.00 /
      DATA B(57265), B(57266), B(57267) /    11.63,    5.28,    0.00 /
      DATA B(57412), B(57413), B(57414) /    11.60,    5.39,    0.00 /
      DATA B(57559), B(57560), B(57561) /    11.55,    5.50,    0.00 /
      DATA B(57706), B(57707), B(57708) /    11.45,    5.59,    0.00 /
      DATA B(57853), B(57854), B(57855) /    11.30,    5.67,    0.00 /
      DATA B(58000), B(58001), B(58002) /    11.08,    5.71,    0.00 /
      DATA B(58147), B(58148), B(58149) /    10.84,    5.68,    0.00 /
      DATA B(58294), B(58295), B(58296) /    10.58,    5.57,    0.00 /
      DATA B(58441), B(58442), B(58443) /    10.33,    5.37,    0.00 /
      DATA B(58588), B(58589), B(58590) /    10.05,    5.12,    0.00 /
      DATA B(58735), B(58736), B(58737) /     9.75,    4.84,    0.00 /
      DATA B(58882), B(58883), B(58884) /     9.47,    4.55,    0.00 /
      DATA B(59029), B(59030), B(59031) /     9.23,    4.28,    0.00 /
      DATA B(59176), B(59177), B(59178) /     9.05,    4.05,    0.00 /
      DATA B(59323), B(59324), B(59325) /     8.91,    3.92,    0.00 /
      DATA B(59470), B(59471), B(59472) /     8.79,    3.89,    0.00 /
      DATA B(59617), B(59618), B(59619) /     8.71,    3.96,    0.00 /
      DATA B(59764), B(59765), B(59766) /     8.68,    4.09,    0.00 /
      DATA B(59911), B(59912), B(59913) /     8.71,    4.24,    0.00 /
      DATA B(60058), B(60059), B(60060) /     8.77,    4.41,    0.00 /
      DATA B(60205), B(60206), B(60207) /     8.86,    4.61,    0.00 /
      DATA B(60352), B(60353), B(60354) /     8.99,    4.83,    0.00 /
      DATA B(60499), B(60500), B(60501) /     9.12,    5.05,    0.00 /
      DATA B(60646), B(60647), B(60648) /     9.23,    5.26,    0.00 /
      DATA B(60793), B(60794), B(60795) /     9.32,    5.48,    0.00 /
      DATA B(60940), B(60941), B(60942) /     9.40,    5.70,    0.00 /
      DATA B(61087), B(61088), B(61089) /     9.48,    5.93,    0.00 /
      DATA B(61234), B(61235), B(61236) /     9.55,    6.15,    0.00 /
      DATA B(61381), B(61382), B(61383) /     9.61,    6.37,    0.00 /
      DATA B(61528), B(61529), B(61530) /     9.66,    6.58,    0.00 /
      DATA B(61675), B(61676), B(61677) /     9.70,    6.77,    0.00 /
      DATA B(61822), B(61823), B(61824) /     9.71,    6.93,    0.00 /
      DATA B(61969), B(61970), B(61971) /     9.68,    7.05,    0.00 /
      DATA B(62116), B(62117), B(62118) /     9.63,    7.15,    0.00 /
      DATA B(62263), B(62264), B(62265) /     9.56,    7.27,    0.00 /
      DATA B(62410), B(62411), B(62412) /     9.42,    7.46,    0.00 /
      DATA B(62557), B(62558), B(62559) /     9.09,    7.82,    0.00 /
      DATA B(62704), B(62705), B(62706) /     8.59,    7.79,    0.00 /
      DATA B(62851), B(62852), B(62853) /     8.11,    7.71,    0.00 /
      DATA B(62998), B(62999), B(63000) /     6.79,    7.57,    0.00 /
      DATA B(63145), B(63146), B(63147) /     6.45,    7.49,    0.00 /
      DATA B(63292), B(63293), B(63294) /     6.11,    7.33,    0.00 /
      DATA B(63439), B(63440), B(63441) /     5.74,    7.05,    0.00 /
      DATA B(63586), B(63587), B(63588) /     5.35,    6.57,    0.00 /
      DATA B(63733), B(63734), B(63735) /     4.94,    6.12,    0.00 /
      DATA B(63880), B(63881), B(63882) /     4.45,    5.72,    0.00 /
      DATA B(64027), B(64028), B(64029) /     3.93,    5.33,    0.00 /
      DATA B(64174), B(64175), B(64176) /     3.42,    4.93,    0.00 /
      DATA B(64321), B(64322), B(64323) /     2.91,    4.52,    0.00 /
      DATA B(64468), B(64469), B(64470) /     2.40,    4.09,    0.00 /
      DATA B(64615), B(64616), B(64617) /     1.86,    3.61,    0.00 /
      DATA B(64762), B(64763), B(64764) /     1.29,    3.07,    0.00 /
      DATA B(64909), B(64910), B(64911) /     0.70,    2.50,    0.00 /
      DATA B(65056), B(65057), B(65058) /     0.13,    1.92,    0.00 /
      DATA B(65203), B(65204), B(65205) /    -0.40,    1.35,    0.00 /
      DATA B(65350), B(65351), B(65352) /    -0.89,    0.79,    0.00 /
      DATA B(65497), B(65498), B(65499) /    -1.35,    0.25,    0.00 /
      DATA B(65644), B(65645), B(65646) /    -1.79,   -0.30,    0.00 /
      DATA B(65791), B(65792), B(65793) /    -2.22,   -0.84,    0.00 /
      DATA B(65938), B(65939), B(65940) /    -2.63,   -1.39,    0.00 /
      DATA B(66085), B(66086), B(66087) /    -3.03,   -1.94,    0.00 /
      DATA B(66232), B(66233), B(66234) /    -3.40,   -2.51,    0.00 /
      DATA B(66379), B(66380), B(66381) /    -3.76,   -3.16,    0.00 /
      DATA B(66526), B(66527), B(66528) /    -4.02,   -3.68,    0.00 /
      DATA B(66673), B(66674), B(66675) /    -4.14,   -4.17,    0.00 /
      DATA B(66820), B(66821), B(66822) /    -4.26,   -4.63,    0.00 /
      DATA B(66967), B(66968), B(66969) /    -4.47,   -5.09,    0.00 /
      DATA B(67114), B(67115), B(67116) /    -4.73,   -5.52,    0.00 /
      DATA B(67261), B(67262), B(67263) /    -4.99,   -5.90,    0.00 /
      DATA B(67408), B(67409), B(67410) /    -5.24,   -6.24,    0.00 /
      DATA B(67555), B(67556), B(67557) /    -5.46,   -6.55,    0.00 /
      DATA B(46390), B(46391), B(46392) /    26.56,  -36.32,    0.00 /
      DATA B(46537), B(46538), B(46539) /    26.73,  -35.93,    0.00 /
      DATA B(46684), B(46685), B(46686) /    26.97,  -35.36,    0.00 /
      DATA B(46831), B(46832), B(46833) /    27.28,  -34.45,    0.00 /
      DATA B(46978), B(46979), B(46980) /    27.64,  -32.83,    0.00 /
      DATA B(47125), B(47126), B(47127) /    27.75,  -29.37,    0.00 /
      DATA B(47272), B(47273), B(47274) /    26.15,  -22.22,    0.00 /
      DATA B(47419), B(47420), B(47421) /    13.47,  -11.25,    0.00 /
      DATA B(47566), B(47567), B(47568) /    15.15,   -7.53,    0.00 /
      DATA B(47713), B(47714), B(47715) /    16.80,   -5.87,    0.00 /
      DATA B(47860), B(47861), B(47862) /    18.06,   -5.05,    0.00 /
      DATA B(48007), B(48008), B(48009) /    18.93,   -4.55,    0.00 /
      DATA B(48154), B(48155), B(48156) /    19.50,   -4.10,    0.00 /
      DATA B(48301), B(48302), B(48303) /    15.92,    1.13,    0.00 /
      DATA B(48448), B(48449), B(48450) /    15.85,    1.12,    0.00 /
      DATA B(48595), B(48596), B(48597) /    15.74,    1.07,    0.00 /
      DATA B(48742), B(48743), B(48744) /    15.45,    0.85,    0.00 /
      DATA B(48889), B(48890), B(48891) /    14.90,    0.37,    0.00 /
      DATA B(49036), B(49037), B(49038) /    14.11,   -0.61,    0.00 /
      DATA B(49183), B(49184), B(49185) /    13.16,   -2.07,    0.00 /
      DATA B(49330), B(49331), B(49332) /    12.16,   -3.85,    0.00 /
      DATA B(49477), B(49478), B(49479) /    10.32,   -6.51,    0.00 /
      DATA B(49624), B(49625), B(49626) /     8.90,   -8.82,    0.00 /
      DATA B(49771), B(49772), B(49773) /     7.36,  -11.02,    0.00 /
      DATA B(49918), B(49919), B(49920) /     5.77,  -12.98,    0.00 /
      DATA B(50065), B(50066), B(50067) /     8.00,   -3.04,    0.00 /
      DATA B(50212), B(50213), B(50214) /     7.27,   -2.30,    0.00 /
      DATA B(50359), B(50360), B(50361) /     6.85,   -2.32,    0.00 /
      DATA B(50506), B(50507), B(50508) /     6.49,   -2.47,    0.00 /
      DATA B(50653), B(50654), B(50655) /     6.29,   -2.52,    0.00 /
      DATA B(50800), B(50801), B(50802) /     6.20,   -2.50,    0.00 /
      DATA B(50947), B(50948), B(50949) /     6.15,   -2.42,    0.00 /
      DATA B(51094), B(51095), B(51096) /     6.14,   -2.33,    0.00 /
      DATA B(51241), B(51242), B(51243) /     6.11,   -2.23,    0.00 /
      DATA B(51388), B(51389), B(51390) /     6.06,   -2.17,    0.00 /
      DATA B(51535), B(51536), B(51537) /     5.96,   -2.15,    0.00 /
      DATA B(51682), B(51683), B(51684) /     5.82,   -2.16,    0.00 /
      DATA B(51829), B(51830), B(51831) /     5.65,   -2.19,    0.00 /
      DATA B(51976), B(51977), B(51978) /     5.44,   -2.24,    0.00 /
      DATA B(52123), B(52124), B(52125) /     5.18,   -2.33,    0.00 /
      DATA B(52270), B(52271), B(52272) /     4.92,   -2.50,    0.00 /
      DATA B(52417), B(52418), B(52419) /     4.62,   -2.74,    0.00 /
      DATA B(52564), B(52565), B(52566) /     4.33,   -3.07,    0.00 /
      DATA B(52711), B(52712), B(52713) /     4.02,   -3.42,    0.00 /
      DATA B(52858), B(52859), B(52860) /     3.74,   -3.79,    0.00 /
      DATA B(53005), B(53006), B(53007) /     3.53,   -4.14,    0.00 /
      DATA B(53152), B(53153), B(53154) /     3.43,   -4.45,    0.00 /
      DATA B(53299), B(53300), B(53301) /     3.47,   -4.67,    0.00 /
      DATA B(53446), B(53447), B(53448) /     3.58,   -4.72,    0.00 /
      DATA B(53593), B(53594), B(53595) /     3.79,   -4.55,    0.00 /
      DATA B(53740), B(53741), B(53742) /     4.03,   -4.20,    0.00 /
      DATA B(53887), B(53888), B(53889) /     4.37,   -3.76,    0.00 /
      DATA B(54034), B(54035), B(54036) /     4.74,   -3.28,    0.00 /
      DATA B(54181), B(54182), B(54183) /     5.10,   -2.80,    0.00 /
      DATA B(54328), B(54329), B(54330) /     5.43,   -2.35,    0.00 /
      DATA B(54475), B(54476), B(54477) /     5.68,   -1.94,    0.00 /
      DATA B(54622), B(54623), B(54624) /     5.88,   -1.58,    0.00 /
      DATA B(54769), B(54770), B(54771) /     6.08,   -1.24,    0.00 /
      DATA B(54916), B(54917), B(54918) /     6.29,   -0.90,    0.00 /
      DATA B(55063), B(55064), B(55065) /     6.55,   -0.54,    0.00 /
      DATA B(55210), B(55211), B(55212) /     6.82,   -0.16,    0.00 /
      DATA B(55357), B(55358), B(55359) /     7.11,    0.25,    0.00 /
      DATA B(55504), B(55505), B(55506) /     7.44,    0.68,    0.00 /
      DATA B(55651), B(55652), B(55653) /     7.80,    1.15,    0.00 /
      DATA B(55798), B(55799), B(55800) /     8.20,    1.61,    0.00 /
      DATA B(55945), B(55946), B(55947) /     8.58,    2.04,    0.00 /
      DATA B(56092), B(56093), B(56094) /     8.89,    2.39,    0.00 /
      DATA B(56239), B(56240), B(56241) /     9.12,    2.67,    0.00 /
      DATA B(56386), B(56387), B(56388) /     9.30,    2.90,    0.00 /
      DATA B(56533), B(56534), B(56535) /     9.43,    3.11,    0.00 /
      DATA B(56680), B(56681), B(56682) /     9.53,    3.29,    0.00 /
      DATA B(56827), B(56828), B(56829) /     9.60,    3.46,    0.00 /
      DATA B(56974), B(56975), B(56976) /     9.65,    3.61,    0.00 /
      DATA B(57121), B(57122), B(57123) /     9.68,    3.74,    0.00 /
      DATA B(57268), B(57269), B(57270) /     9.70,    3.86,    0.00 /
      DATA B(57415), B(57416), B(57417) /     9.69,    3.97,    0.00 /
      DATA B(57562), B(57563), B(57564) /     9.66,    4.08,    0.00 /
      DATA B(57709), B(57710), B(57711) /     9.59,    4.18,    0.00 /
      DATA B(57856), B(57857), B(57858) /     9.46,    4.27,    0.00 /
      DATA B(58003), B(58004), B(58005) /     9.28,    4.32,    0.00 /
      DATA B(58150), B(58151), B(58152) /     9.07,    4.32,    0.00 /
      DATA B(58297), B(58298), B(58299) /     8.85,    4.24,    0.00 /
      DATA B(58444), B(58445), B(58446) /     8.63,    4.07,    0.00 /
      DATA B(58591), B(58592), B(58593) /     8.37,    3.85,    0.00 /
      DATA B(58738), B(58739), B(58740) /     8.10,    3.59,    0.00 /
      DATA B(58885), B(58886), B(58887) /     7.84,    3.33,    0.00 /
      DATA B(59032), B(59033), B(59034) /     7.61,    3.07,    0.00 /
      DATA B(59179), B(59180), B(59181) /     7.43,    2.84,    0.00 /
      DATA B(59326), B(59327), B(59328) /     7.28,    2.70,    0.00 /
      DATA B(59473), B(59474), B(59475) /     7.16,    2.65,    0.00 /
      DATA B(59620), B(59621), B(59622) /     7.07,    2.70,    0.00 /
      DATA B(59767), B(59768), B(59769) /     7.04,    2.81,    0.00 /
      DATA B(59914), B(59915), B(59916) /     7.06,    2.95,    0.00 /
      DATA B(60061), B(60062), B(60063) /     7.13,    3.11,    0.00 /
      DATA B(60208), B(60209), B(60210) /     7.25,    3.29,    0.00 /
      DATA B(60355), B(60356), B(60357) /     7.40,    3.50,    0.00 /
      DATA B(60502), B(60503), B(60504) /     7.56,    3.72,    0.00 /
      DATA B(60649), B(60650), B(60651) /     7.71,    3.95,    0.00 /
      DATA B(60796), B(60797), B(60798) /     7.84,    4.19,    0.00 /
      DATA B(60943), B(60944), B(60945) /     7.97,    4.44,    0.00 /
      DATA B(61090), B(61091), B(61092) /     8.10,    4.69,    0.00 /
      DATA B(61237), B(61238), B(61239) /     8.22,    4.93,    0.00 /
      DATA B(61384), B(61385), B(61386) /     8.33,    5.18,    0.00 /
      DATA B(61531), B(61532), B(61533) /     8.42,    5.41,    0.00 /
      DATA B(61678), B(61679), B(61680) /     8.48,    5.63,    0.00 /
      DATA B(61825), B(61826), B(61827) /     8.51,    5.82,    0.00 /
      DATA B(61972), B(61973), B(61974) /     8.50,    5.97,    0.00 /
      DATA B(62119), B(62120), B(62121) /     8.45,    6.11,    0.00 /
      DATA B(62266), B(62267), B(62268) /     8.37,    6.26,    0.00 /
      DATA B(62413), B(62414), B(62415) /     8.23,    6.47,    0.00 /
      DATA B(62560), B(62561), B(62562) /     8.01,    6.76,    0.00 /
      DATA B(62707), B(62708), B(62709) /     7.73,    6.82,    0.00 /
      DATA B(62854), B(62855), B(62856) /     7.35,    6.79,    0.00 /
      DATA B(63001), B(63002), B(63003) /     6.95,    6.76,    0.00 /
      DATA B(63148), B(63149), B(63150) /    10.32,    7.44,    0.00 /
      DATA B(63295), B(63296), B(63297) /     5.40,    6.48,    0.00 /
      DATA B(63442), B(63443), B(63444) /     5.02,    6.19,    0.00 /
      DATA B(63589), B(63590), B(63591) /     4.68,    5.65,    0.00 /
      DATA B(63736), B(63737), B(63738) /     4.26,    5.27,    0.00 /
      DATA B(63883), B(63884), B(63885) /     3.76,    4.92,    0.00 /
      DATA B(64030), B(64031), B(64032) /     3.26,    4.58,    0.00 /
      DATA B(64177), B(64178), B(64179) /     2.76,    4.22,    0.00 /
      DATA B(64324), B(64325), B(64326) /     2.29,    3.85,    0.00 /
      DATA B(64471), B(64472), B(64473) /     1.81,    3.46,    0.00 /
      DATA B(64618), B(64619), B(64620) /     1.32,    3.02,    0.00 /
      DATA B(64765), B(64766), B(64767) /     0.78,    2.52,    0.00 /
      DATA B(64912), B(64913), B(64914) /     0.23,    1.99,    0.00 /
      DATA B(65059), B(65060), B(65061) /    -0.30,    1.44,    0.00 /
      DATA B(65206), B(65207), B(65208) /    -0.80,    0.90,    0.00 /
      DATA B(65353), B(65354), B(65355) /    -1.26,    0.37,    0.00 /
      DATA B(65500), B(65501), B(65502) /    -1.70,   -0.16,    0.00 /
      DATA B(65647), B(65648), B(65649) /    -2.12,   -0.69,    0.00 /
      DATA B(65794), B(65795), B(65796) /    -2.54,   -1.22,    0.00 /
      DATA B(65941), B(65942), B(65943) /    -2.93,   -1.76,    0.00 /
      DATA B(66088), B(66089), B(66090) /    -3.31,   -2.31,    0.00 /
      DATA B(66235), B(66236), B(66237) /    -3.68,   -2.90,    0.00 /
      DATA B(66382), B(66383), B(66384) /    -4.02,   -3.53,    0.00 /
      DATA B(66529), B(66530), B(66531) /    -4.21,   -4.01,    0.00 /
      DATA B(66676), B(66677), B(66678) /    -4.29,   -4.49,    0.00 /
      DATA B(66823), B(66824), B(66825) /    -4.44,   -4.95,    0.00 /
      DATA B(66970), B(66971), B(66972) /    -4.68,   -5.40,    0.00 /
      DATA B(67117), B(67118), B(67119) /    -4.93,   -5.79,    0.00 /
      DATA B(67264), B(67265), B(67266) /    -5.18,   -6.14,    0.00 /
      DATA B(67411), B(67412), B(67413) /    -5.41,   -6.45,    0.00 /
      DATA B(67558), B(67559), B(67560) /    -5.62,   -6.74,    0.00 /
      DATA B(46393), B(46394), B(46395) /    26.28,  -36.16,    0.00 /
      DATA B(46540), B(46541), B(46542) /    26.43,  -35.73,    0.00 /
      DATA B(46687), B(46688), B(46689) /    26.67,  -35.08,    0.00 /
      DATA B(46834), B(46835), B(46836) /    26.99,  -34.01,    0.00 /
      DATA B(46981), B(46982), B(46983) /    27.31,  -32.11,    0.00 /
      DATA B(47128), B(47129), B(47130) /    27.14,  -28.31,    0.00 /
      DATA B(47275), B(47276), B(47277) /    13.26,  -18.12,    0.00 /
      DATA B(47422), B(47423), B(47424) /    14.05,  -12.27,    0.00 /
      DATA B(47569), B(47570), B(47571) /    15.87,   -9.21,    0.00 /
      DATA B(47716), B(47717), B(47718) /    17.36,   -7.58,    0.00 /
      DATA B(47863), B(47864), B(47865) /    18.47,   -6.55,    0.00 /
      DATA B(48010), B(48011), B(48012) /    19.14,   -5.77,    0.00 /
      DATA B(48157), B(48158), B(48159) /    19.56,   -5.02,    0.00 /
      DATA B(48304), B(48305), B(48306) /    15.73,   -0.04,    0.00 /
      DATA B(48451), B(48452), B(48453) /    15.58,    0.03,    0.00 /
      DATA B(48598), B(48599), B(48600) /    15.39,    0.02,    0.00 /
      DATA B(48745), B(48746), B(48747) /    14.92,   -0.35,    0.00 /
      DATA B(48892), B(48893), B(48894) /    14.14,   -0.74,    0.00 /
      DATA B(49039), B(49040), B(49041) /    12.62,   -1.85,    0.00 /
      DATA B(49186), B(49187), B(49188) /    11.27,   -3.64,    0.00 /
      DATA B(49333), B(49334), B(49335) /     9.96,   -5.70,    0.00 /
      DATA B(49480), B(49481), B(49482) /     8.53,   -8.06,    0.00 /
      DATA B(49627), B(49628), B(49629) /     7.04,  -10.41,    0.00 /
      DATA B(49774), B(49775), B(49776) /     5.42,  -12.62,    0.00 /
      DATA B(49921), B(49922), B(49923) /     7.92,   -3.55,    0.00 /
      DATA B(50068), B(50069), B(50070) /     6.81,   -4.06,    0.00 /
      DATA B(50215), B(50216), B(50217) /     6.17,   -3.78,    0.00 /
      DATA B(50362), B(50363), B(50364) /     5.77,   -3.70,    0.00 /
      DATA B(50509), B(50510), B(50511) /     5.43,   -3.79,    0.00 /
      DATA B(50656), B(50657), B(50658) /     5.16,   -3.87,    0.00 /
      DATA B(50803), B(50804), B(50805) /     4.97,   -3.90,    0.00 /
      DATA B(50950), B(50951), B(50952) /     4.84,   -3.89,    0.00 /
      DATA B(51097), B(51098), B(51099) /     4.76,   -3.84,    0.00 /
      DATA B(51244), B(51245), B(51246) /     4.68,   -3.79,    0.00 /
      DATA B(51391), B(51392), B(51393) /     4.59,   -3.76,    0.00 /
      DATA B(51538), B(51539), B(51540) /     4.48,   -3.75,    0.00 /
      DATA B(51685), B(51686), B(51687) /     4.34,   -3.76,    0.00 /
      DATA B(51832), B(51833), B(51834) /     4.18,   -3.79,    0.00 /
      DATA B(51979), B(51980), B(51981) /     3.99,   -3.83,    0.00 /
      DATA B(52126), B(52127), B(52128) /     3.78,   -3.90,    0.00 /
      DATA B(52273), B(52274), B(52275) /     3.56,   -4.04,    0.00 /
      DATA B(52420), B(52421), B(52422) /     3.32,   -4.26,    0.00 /
      DATA B(52567), B(52568), B(52569) /     3.10,   -4.54,    0.00 /
      DATA B(52714), B(52715), B(52716) /     2.86,   -4.85,    0.00 /
      DATA B(52861), B(52862), B(52863) /     2.64,   -5.18,    0.00 /
      DATA B(53008), B(53009), B(53010) /     2.49,   -5.49,    0.00 /
      DATA B(53155), B(53156), B(53157) /     2.44,   -5.77,    0.00 /
      DATA B(53302), B(53303), B(53304) /     2.49,   -5.97,    0.00 /
      DATA B(53449), B(53450), B(53451) /     2.60,   -6.00,    0.00 /
      DATA B(53596), B(53597), B(53598) /     2.77,   -5.83,    0.00 /
      DATA B(53743), B(53744), B(53745) /     2.98,   -5.46,    0.00 /
      DATA B(53890), B(53891), B(53892) /     3.28,   -4.98,    0.00 /
      DATA B(54037), B(54038), B(54039) /     3.62,   -4.46,    0.00 /
      DATA B(54184), B(54185), B(54186) /     3.94,   -3.94,    0.00 /
      DATA B(54331), B(54332), B(54333) /     4.21,   -3.44,    0.00 /
      DATA B(54478), B(54479), B(54480) /     4.40,   -2.98,    0.00 /
      DATA B(54625), B(54626), B(54627) /     4.54,   -2.59,    0.00 /
      DATA B(54772), B(54773), B(54774) /     4.66,   -2.24,    0.00 /
      DATA B(54919), B(54920), B(54921) /     4.80,   -1.91,    0.00 /
      DATA B(55066), B(55067), B(55068) /     4.97,   -1.58,    0.00 /
      DATA B(55213), B(55214), B(55215) /     5.14,   -1.23,    0.00 /
      DATA B(55360), B(55361), B(55362) /     5.35,   -0.86,    0.00 /
      DATA B(55507), B(55508), B(55509) /     5.59,   -0.46,    0.00 /
      DATA B(55654), B(55655), B(55656) /     5.90,   -0.05,    0.00 /
      DATA B(55801), B(55802), B(55803) /     6.24,    0.37,    0.00 /
      DATA B(55948), B(55949), B(55950) /     6.56,    0.76,    0.00 /
      DATA B(56095), B(56096), B(56097) /     6.84,    1.10,    0.00 /
      DATA B(56242), B(56243), B(56244) /     7.07,    1.37,    0.00 /
      DATA B(56389), B(56390), B(56391) /     7.25,    1.60,    0.00 /
      DATA B(56536), B(56537), B(56538) /     7.40,    1.81,    0.00 /
      DATA B(56683), B(56684), B(56685) /     7.52,    1.99,    0.00 /
      DATA B(56830), B(56831), B(56832) /     7.62,    2.15,    0.00 /
      DATA B(56977), B(56978), B(56979) /     7.70,    2.30,    0.00 /
      DATA B(57124), B(57125), B(57126) /     7.75,    2.43,    0.00 /
      DATA B(57271), B(57272), B(57273) /     7.79,    2.56,    0.00 /
      DATA B(57418), B(57419), B(57420) /     7.81,    2.67,    0.00 /
      DATA B(57565), B(57566), B(57567) /     7.80,    2.78,    0.00 /
      DATA B(57712), B(57713), B(57714) /     7.76,    2.88,    0.00 /
      DATA B(57859), B(57860), B(57861) /     7.66,    2.98,    0.00 /
      DATA B(58006), B(58007), B(58008) /     7.52,    3.05,    0.00 /
      DATA B(58153), B(58154), B(58155) /     7.36,    3.07,    0.00 /
      DATA B(58300), B(58301), B(58302) /     7.19,    3.03,    0.00 /
      DATA B(58447), B(58448), B(58449) /     7.00,    2.90,    0.00 /
      DATA B(58594), B(58595), B(58596) /     6.78,    2.72,    0.00 /
      DATA B(58741), B(58742), B(58743) /     6.53,    2.49,    0.00 /
      DATA B(58888), B(58889), B(58890) /     6.29,    2.25,    0.00 /
      DATA B(59035), B(59036), B(59037) /     6.08,    2.01,    0.00 /
      DATA B(59182), B(59183), B(59184) /     5.90,    1.80,    0.00 /
      DATA B(59329), B(59330), B(59331) /     5.74,    1.65,    0.00 /
      DATA B(59476), B(59477), B(59478) /     5.60,    1.60,    0.00 /
      DATA B(59623), B(59624), B(59625) /     5.51,    1.63,    0.00 /
      DATA B(59770), B(59771), B(59772) /     5.47,    1.71,    0.00 /
      DATA B(59917), B(59918), B(59919) /     5.49,    1.83,    0.00 /
      DATA B(60064), B(60065), B(60066) /     5.56,    1.98,    0.00 /
      DATA B(60211), B(60212), B(60213) /     5.68,    2.14,    0.00 /
      DATA B(60358), B(60359), B(60360) /     5.85,    2.34,    0.00 /
      DATA B(60505), B(60506), B(60507) /     6.03,    2.55,    0.00 /
      DATA B(60652), B(60653), B(60654) /     6.21,    2.78,    0.00 /
      DATA B(60799), B(60800), B(60801) /     6.38,    3.03,    0.00 /
      DATA B(60946), B(60947), B(60948) /     6.54,    3.28,    0.00 /
      DATA B(61093), B(61094), B(61095) /     6.71,    3.54,    0.00 /
      DATA B(61240), B(61241), B(61242) /     6.87,    3.80,    0.00 /
      DATA B(61387), B(61388), B(61389) /     7.02,    4.06,    0.00 /
      DATA B(61534), B(61535), B(61536) /     7.15,    4.31,    0.00 /
      DATA B(61681), B(61682), B(61683) /     7.25,    4.55,    0.00 /
      DATA B(61828), B(61829), B(61830) /     7.30,    4.77,    0.00 /
      DATA B(61975), B(61976), B(61977) /     7.31,    4.95,    0.00 /
      DATA B(62122), B(62123), B(62124) /     7.28,    5.11,    0.00 /
      DATA B(62269), B(62270), B(62271) /     7.21,    5.29,    0.00 /
      DATA B(62416), B(62417), B(62418) /     7.10,    5.52,    0.00 /
      DATA B(62563), B(62564), B(62565) /     6.94,    5.73,    0.00 /
      DATA B(62710), B(62711), B(62712) /     6.71,    5.82,    0.00 /
      DATA B(62857), B(62858), B(62859) /     6.42,    5.85,    0.00 /
      DATA B(63004), B(63005), B(63006) /     6.07,    5.85,    0.00 /
      DATA B(63151), B(63152), B(63153) /     5.66,    5.82,    0.00 /
      DATA B(63298), B(63299), B(63300) /     5.15,    5.71,    0.00 /
      DATA B(63445), B(63446), B(63447) /     8.09,    6.29,    0.00 /
      DATA B(63592), B(63593), B(63594) /     4.07,    4.89,    0.00 /
      DATA B(63739), B(63740), B(63741) /     3.59,    4.50,    0.00 /
      DATA B(63886), B(63887), B(63888) /     3.10,    4.16,    0.00 /
      DATA B(64033), B(64034), B(64035) /     2.61,    3.84,    0.00 /
      DATA B(64180), B(64181), B(64182) /     2.14,    3.52,    0.00 /
      DATA B(64327), B(64328), B(64329) /     1.68,    3.19,    0.00 /
      DATA B(64474), B(64475), B(64476) /     1.24,    2.84,    0.00 /
      DATA B(64621), B(64622), B(64623) /     0.78,    2.44,    0.00 /
      DATA B(64768), B(64769), B(64770) /     0.28,    1.98,    0.00 /
      DATA B(64915), B(64916), B(64917) /    -0.23,    1.49,    0.00 /
      DATA B(65062), B(65063), B(65064) /    -0.72,    0.98,    0.00 /
      DATA B(65209), B(65210), B(65211) /    -1.18,    0.47,    0.00 /
      DATA B(65356), B(65357), B(65358) /    -1.61,   -0.04,    0.00 /
      DATA B(65503), B(65504), B(65505) /    -2.04,   -0.56,    0.00 /
      DATA B(65650), B(65651), B(65652) /    -2.44,   -1.08,    0.00 /
      DATA B(65797), B(65798), B(65799) /    -2.84,   -1.59,    0.00 /
      DATA B(65944), B(65945), B(65946) /    -3.21,   -2.12,    0.00 /
      DATA B(66091), B(66092), B(66093) /    -3.58,   -2.66,    0.00 /
      DATA B(66238), B(66239), B(66240) /    -3.91,   -3.24,    0.00 /
      DATA B(66385), B(66386), B(66387) /    -4.19,   -3.83,    0.00 /
      DATA B(66532), B(66533), B(66534) /    -4.35,   -4.34,    0.00 /
      DATA B(66679), B(66680), B(66681) /    -4.45,   -4.81,    0.00 /
      DATA B(66826), B(66827), B(66828) /    -4.63,   -5.27,    0.00 /
      DATA B(66973), B(66974), B(66975) /    -4.87,   -5.68,    0.00 /
      DATA B(67120), B(67121), B(67122) /    -5.12,   -6.04,    0.00 /
      DATA B(67267), B(67268), B(67269) /    -5.35,   -6.36,    0.00 /
      DATA B(67414), B(67415), B(67416) /    -5.57,   -6.65,    0.00 /
      DATA B(67561), B(67562), B(67563) /    -5.77,   -6.91,    0.00 /
      DATA B(46396), B(46397), B(46398) /    25.91,  -35.99,    0.00 /
      DATA B(46543), B(46544), B(46545) /    26.03,  -35.53,    0.00 /
      DATA B(46690), B(46691), B(46692) /    26.25,  -34.80,    0.00 /
      DATA B(46837), B(46838), B(46839) /    26.60,  -33.57,    0.00 /
      DATA B(46984), B(46985), B(46986) /    26.95,  -31.33,    0.00 /
      DATA B(47131), B(47132), B(47133) /    26.55,  -27.37,    0.00 /
      DATA B(47278), B(47279), B(47280) /    13.27,  -18.17,    0.00 /
      DATA B(47425), B(47426), B(47427) /    14.72,  -13.61,    0.00 /
      DATA B(47572), B(47573), B(47574) /    16.47,  -10.90,    0.00 /
      DATA B(47719), B(47720), B(47721) /    17.75,   -9.19,    0.00 /
      DATA B(47866), B(47867), B(47868) /    18.65,   -7.93,    0.00 /
      DATA B(48013), B(48014), B(48015) /    19.16,   -6.85,    0.00 /
      DATA B(48160), B(48161), B(48162) /    15.47,   -1.53,    0.00 /
      DATA B(48307), B(48308), B(48309) /    15.36,   -1.18,    0.00 /
      DATA B(48454), B(48455), B(48456) /    15.14,   -0.99,    0.00 /
      DATA B(48601), B(48602), B(48603) /    14.78,   -0.98,    0.00 /
      DATA B(48748), B(48749), B(48750) /    13.73,   -0.97,    0.00 /
      DATA B(48895), B(48896), B(48897) /    12.44,   -1.92,    0.00 /
      DATA B(49042), B(49043), B(49044) /    11.08,   -3.28,    0.00 /
      DATA B(49189), B(49190), B(49191) /     9.65,   -5.11,    0.00 /
      DATA B(49336), B(49337), B(49338) /     8.30,   -7.27,    0.00 /
      DATA B(49483), B(49484), B(49485) /     6.84,   -9.63,    0.00 /
      DATA B(49630), B(49631), B(49632) /     5.32,  -11.94,    0.00 /
      DATA B(49777), B(49778), B(49779) /     3.72,  -14.08,    0.00 /
      DATA B(49924), B(49925), B(49926) /     6.71,   -4.69,    0.00 /
      DATA B(50071), B(50072), B(50073) /     5.86,   -5.07,    0.00 /
      DATA B(50218), B(50219), B(50220) /     5.23,   -5.10,    0.00 /
      DATA B(50365), B(50366), B(50367) /     4.77,   -5.09,    0.00 /
      DATA B(50512), B(50513), B(50514) /     4.40,   -5.16,    0.00 /
      DATA B(50659), B(50660), B(50661) /     4.10,   -5.25,    0.00 /
      DATA B(50806), B(50807), B(50808) /     3.86,   -5.32,    0.00 /
      DATA B(50953), B(50954), B(50955) /     3.69,   -5.34,    0.00 /
      DATA B(51100), B(51101), B(51102) /     3.56,   -5.33,    0.00 /
      DATA B(51247), B(51248), B(51249) /     3.44,   -5.30,    0.00 /
      DATA B(51394), B(51395), B(51396) /     3.33,   -5.26,    0.00 /
      DATA B(51541), B(51542), B(51543) /     3.21,   -5.24,    0.00 /
      DATA B(51688), B(51689), B(51690) /     3.08,   -5.23,    0.00 /
      DATA B(51835), B(51836), B(51837) /     2.93,   -5.24,    0.00 /
      DATA B(51982), B(51983), B(51984) /     2.77,   -5.26,    0.00 /
      DATA B(52129), B(52130), B(52131) /     2.60,   -5.31,    0.00 /
      DATA B(52276), B(52277), B(52278) /     2.43,   -5.40,    0.00 /
      DATA B(52423), B(52424), B(52425) /     2.25,   -5.57,    0.00 /
      DATA B(52570), B(52571), B(52572) /     2.09,   -5.80,    0.00 /
      DATA B(52717), B(52718), B(52719) /     1.91,   -6.07,    0.00 /
      DATA B(52864), B(52865), B(52866) /     1.76,   -6.34,    0.00 /
      DATA B(53011), B(53012), B(53013) /     1.66,   -6.61,    0.00 /
      DATA B(53158), B(53159), B(53160) /     1.64,   -6.85,    0.00 /
      DATA B(53305), B(53306), B(53307) /     1.70,   -7.02,    0.00 /
      DATA B(53452), B(53453), B(53454) /     1.79,   -7.03,    0.00 /
      DATA B(53599), B(53600), B(53601) /     1.93,   -6.84,    0.00 /
      DATA B(53746), B(53747), B(53748) /     2.10,   -6.46,    0.00 /
      DATA B(53893), B(53894), B(53895) /     2.36,   -5.97,    0.00 /
      DATA B(54040), B(54041), B(54042) /     2.64,   -5.43,    0.00 /
      DATA B(54187), B(54188), B(54189) /     2.91,   -4.88,    0.00 /
      DATA B(54334), B(54335), B(54336) /     3.12,   -4.35,    0.00 /
      DATA B(54481), B(54482), B(54483) /     3.25,   -3.86,    0.00 /
      DATA B(54628), B(54629), B(54630) /     3.34,   -3.43,    0.00 /
      DATA B(54775), B(54776), B(54777) /     3.41,   -3.07,    0.00 /
      DATA B(54922), B(54923), B(54924) /     3.49,   -2.75,    0.00 /
      DATA B(55069), B(55070), B(55071) /     3.58,   -2.44,    0.00 /
      DATA B(55216), B(55217), B(55218) /     3.69,   -2.12,    0.00 /
      DATA B(55363), B(55364), B(55365) /     3.82,   -1.78,    0.00 /
      DATA B(55510), B(55511), B(55512) /     4.00,   -1.44,    0.00 /
      DATA B(55657), B(55658), B(55659) /     4.23,   -1.09,    0.00 /
      DATA B(55804), B(55805), B(55806) /     4.50,   -0.74,    0.00 /
      DATA B(55951), B(55952), B(55953) /     4.76,   -0.40,    0.00 /
      DATA B(56098), B(56099), B(56100) /     4.99,   -0.10,    0.00 /
      DATA B(56245), B(56246), B(56247) /     5.19,    0.16,    0.00 /
      DATA B(56392), B(56393), B(56394) /     5.37,    0.38,    0.00 /
      DATA B(56539), B(56540), B(56541) /     5.52,    0.58,    0.00 /
      DATA B(56686), B(56687), B(56688) /     5.66,    0.76,    0.00 /
      DATA B(56833), B(56834), B(56835) /     5.77,    0.92,    0.00 /
      DATA B(56980), B(56981), B(56982) /     5.86,    1.07,    0.00 /
      DATA B(57127), B(57128), B(57129) /     5.94,    1.20,    0.00 /
      DATA B(57274), B(57275), B(57276) /     6.00,    1.33,    0.00 /
      DATA B(57421), B(57422), B(57423) /     6.04,    1.44,    0.00 /
      DATA B(57568), B(57569), B(57570) /     6.05,    1.56,    0.00 /
      DATA B(57715), B(57716), B(57717) /     6.03,    1.67,    0.00 /
      DATA B(57862), B(57863), B(57864) /     5.97,    1.77,    0.00 /
      DATA B(58009), B(58010), B(58011) /     5.87,    1.86,    0.00 /
      DATA B(58156), B(58157), B(58158) /     5.76,    1.91,    0.00 /
      DATA B(58303), B(58304), B(58305) /     5.64,    1.91,    0.00 /
      DATA B(58450), B(58451), B(58452) /     5.50,    1.82,    0.00 /
      DATA B(58597), B(58598), B(58599) /     5.32,    1.67,    0.00 /
      DATA B(58744), B(58745), B(58746) /     5.11,    1.48,    0.00 /
      DATA B(58891), B(58892), B(58893) /     4.90,    1.27,    0.00 /
      DATA B(59038), B(59039), B(59040) /     4.70,    1.05,    0.00 /
      DATA B(59185), B(59186), B(59187) /     4.52,    0.85,    0.00 /
      DATA B(59332), B(59333), B(59334) /     4.35,    0.71,    0.00 /
      DATA B(59479), B(59480), B(59481) /     4.21,    0.64,    0.00 /
      DATA B(59626), B(59627), B(59628) /     4.10,    0.66,    0.00 /
      DATA B(59773), B(59774), B(59775) /     4.05,    0.73,    0.00 /
      DATA B(59920), B(59921), B(59922) /     4.06,    0.84,    0.00 /
      DATA B(60067), B(60068), B(60069) /     4.13,    0.97,    0.00 /
      DATA B(60214), B(60215), B(60216) /     4.25,    1.12,    0.00 /
      DATA B(60361), B(60362), B(60363) /     4.42,    1.29,    0.00 /
      DATA B(60508), B(60509), B(60510) /     4.60,    1.49,    0.00 /
      DATA B(60655), B(60656), B(60657) /     4.79,    1.72,    0.00 /
      DATA B(60802), B(60803), B(60804) /     4.98,    1.96,    0.00 /
      DATA B(60949), B(60950), B(60951) /     5.17,    2.21,    0.00 /
      DATA B(61096), B(61097), B(61098) /     5.36,    2.47,    0.00 /
      DATA B(61243), B(61244), B(61245) /     5.55,    2.74,    0.00 /
      DATA B(61390), B(61391), B(61392) /     5.73,    3.00,    0.00 /
      DATA B(61537), B(61538), B(61539) /     5.89,    3.26,    0.00 /
      DATA B(61684), B(61685), B(61686) /     6.01,    3.52,    0.00 /
      DATA B(61831), B(61832), B(61833) /     6.08,    3.75,    0.00 /
      DATA B(61978), B(61979), B(61980) /     6.12,    3.96,    0.00 /
      DATA B(62125), B(62126), B(62127) /     6.11,    4.15,    0.00 /
      DATA B(62272), B(62273), B(62274) /     6.07,    4.35,    0.00 /
      DATA B(62419), B(62420), B(62421) /     6.00,    4.62,    0.00 /
      DATA B(62566), B(62567), B(62568) /     5.85,    4.76,    0.00 /
      DATA B(62713), B(62714), B(62715) /     5.67,    4.86,    0.00 /
      DATA B(62860), B(62861), B(62862) /     5.42,    4.92,    0.00 /
      DATA B(63007), B(63008), B(63009) /     5.13,    4.95,    0.00 /
      DATA B(63154), B(63155), B(63156) /     4.76,    4.94,    0.00 /
      DATA B(63301), B(63302), B(63303) /     4.31,    4.88,    0.00 /
      DATA B(63448), B(63449), B(63450) /     3.84,    4.63,    0.00 /
      DATA B(63595), B(63596), B(63597) /     3.22,    4.16,    0.00 /
      DATA B(63742), B(63743), B(63744) /     2.90,    3.77,    0.00 /
      DATA B(63889), B(63890), B(63891) /     2.45,    3.43,    0.00 /
      DATA B(64036), B(64037), B(64038) /     1.97,    3.13,    0.00 /
      DATA B(64183), B(64184), B(64185) /     1.53,    2.84,    0.00 /
      DATA B(64330), B(64331), B(64332) /     1.10,    2.54,    0.00 /
      DATA B(64477), B(64478), B(64479) /     0.68,    2.22,    0.00 /
      DATA B(64624), B(64625), B(64626) /     0.26,    1.87,    0.00 /
      DATA B(64771), B(64772), B(64773) /    -0.20,    1.46,    0.00 /
      DATA B(64918), B(64919), B(64920) /    -0.66,    1.01,    0.00 /
      DATA B(65065), B(65066), B(65067) /    -1.12,    0.54,    0.00 /
      DATA B(65212), B(65213), B(65214) /    -1.55,    0.06,    0.00 /
      DATA B(65359), B(65360), B(65361) /    -1.96,   -0.44,    0.00 /
      DATA B(65506), B(65507), B(65508) /    -2.37,   -0.95,    0.00 /
      DATA B(65653), B(65654), B(65655) /    -2.76,   -1.45,    0.00 /
      DATA B(65800), B(65801), B(65802) /    -3.13,   -1.95,    0.00 /
      DATA B(65947), B(65948), B(65949) /    -3.48,   -2.47,    0.00 /
      DATA B(66094), B(66095), B(66096) /    -3.83,   -3.01,    0.00 /
      DATA B(66241), B(66242), B(66243) /    -4.14,   -3.60,    0.00 /
      DATA B(66388), B(66389), B(66390) /    -4.36,   -4.13,    0.00 /
      DATA B(66535), B(66536), B(66537) /    -4.47,   -4.65,    0.00 /
      DATA B(66682), B(66683), B(66684) /    -4.61,   -5.13,    0.00 /
      DATA B(66829), B(66830), B(66831) /    -4.82,   -5.57,    0.00 /
      DATA B(66976), B(66977), B(66978) /    -5.06,   -5.95,    0.00 /
      DATA B(67123), B(67124), B(67125) /    -5.30,   -6.28,    0.00 /
      DATA B(67270), B(67271), B(67272) /    -5.52,   -6.57,    0.00 /
      DATA B(67417), B(67418), B(67419) /    -5.72,   -6.83,    0.00 /
      DATA B(67564), B(67565), B(67566) /    -5.91,   -7.08,    0.00 /
      DATA B(46399), B(46400), B(46401) /    25.43,  -35.79,    0.00 /
      DATA B(46546), B(46547), B(46548) /    25.48,  -35.30,    0.00 /
      DATA B(46693), B(46694), B(46695) /    25.63,  -34.53,    0.00 /
      DATA B(46840), B(46841), B(46842) /    25.99,  -33.16,    0.00 /
      DATA B(46987), B(46988), B(46989) /    26.47,  -30.53,    0.00 /
      DATA B(47134), B(47135), B(47136) /    26.09,  -26.52,    0.00 /
      DATA B(47281), B(47282), B(47283) /    13.75,  -18.65,    0.00 /
      DATA B(47428), B(47429), B(47430) /    15.45,  -14.96,    0.00 /
      DATA B(47575), B(47576), B(47577) /    16.96,  -12.40,    0.00 /
      DATA B(47722), B(47723), B(47724) /    17.96,  -10.56,    0.00 /
      DATA B(47869), B(47870), B(47871) /    18.58,   -9.10,    0.00 /
      DATA B(48016), B(48017), B(48018) /    18.94,   -7.73,    0.00 /
      DATA B(48163), B(48164), B(48165) /    14.96,   -2.79,    0.00 /
      DATA B(48310), B(48311), B(48312) /    14.78,   -2.35,    0.00 /
      DATA B(48457), B(48458), B(48459) /    14.42,   -2.13,    0.00 /
      DATA B(48604), B(48605), B(48606) /    13.46,   -1.88,    0.00 /
      DATA B(48751), B(48752), B(48753) /    12.33,   -2.39,    0.00 /
      DATA B(48898), B(48899), B(48900) /    10.92,   -3.39,    0.00 /
      DATA B(49045), B(49046), B(49047) /     9.51,   -4.85,    0.00 /
      DATA B(49192), B(49193), B(49194) /     8.06,   -6.72,    0.00 /
      DATA B(49339), B(49340), B(49341) /     6.71,   -8.89,    0.00 /
      DATA B(49486), B(49487), B(49488) /     5.28,  -11.19,    0.00 /
      DATA B(49633), B(49634), B(49635) /     3.76,  -13.44,    0.00 /
      DATA B(49780), B(49781), B(49782) /     6.63,   -4.61,    0.00 /
      DATA B(49927), B(49928), B(49929) /     5.81,   -5.52,    0.00 /
      DATA B(50074), B(50075), B(50076) /     5.04,   -6.03,    0.00 /
      DATA B(50221), B(50222), B(50223) /     4.40,   -6.23,    0.00 /
      DATA B(50368), B(50369), B(50370) /     3.88,   -6.31,    0.00 /
      DATA B(50515), B(50516), B(50517) /     3.47,   -6.38,    0.00 /
      DATA B(50662), B(50663), B(50664) /     3.14,   -6.47,    0.00 /
      DATA B(50809), B(50810), B(50811) /     2.87,   -6.54,    0.00 /
      DATA B(50956), B(50957), B(50958) /     2.67,   -6.58,    0.00 /
      DATA B(51103), B(51104), B(51105) /     2.52,   -6.58,    0.00 /
      DATA B(51250), B(51251), B(51252) /     2.38,   -6.55,    0.00 /
      DATA B(51397), B(51398), B(51399) /     2.25,   -6.50,    0.00 /
      DATA B(51544), B(51545), B(51546) /     2.12,   -6.47,    0.00 /
      DATA B(51691), B(51692), B(51693) /     2.00,   -6.44,    0.00 /
      DATA B(51838), B(51839), B(51840) /     1.87,   -6.42,    0.00 /
      DATA B(51985), B(51986), B(51987) /     1.73,   -6.41,    0.00 /
      DATA B(52132), B(52133), B(52134) /     1.59,   -6.43,    0.00 /
      DATA B(52279), B(52280), B(52281) /     1.47,   -6.50,    0.00 /
      DATA B(52426), B(52427), B(52428) /     1.35,   -6.63,    0.00 /
      DATA B(52573), B(52574), B(52575) /     1.23,   -6.81,    0.00 /
      DATA B(52720), B(52721), B(52722) /     1.11,   -7.03,    0.00 /
      DATA B(52867), B(52868), B(52869) /     1.01,   -7.26,    0.00 /
      DATA B(53014), B(53015), B(53016) /     0.96,   -7.49,    0.00 /
      DATA B(53161), B(53162), B(53163) /     0.96,   -7.70,    0.00 /
      DATA B(53308), B(53309), B(53310) /     1.02,   -7.83,    0.00 /
      DATA B(53455), B(53456), B(53457) /     1.10,   -7.81,    0.00 /
      DATA B(53602), B(53603), B(53604) /     1.21,   -7.62,    0.00 /
      DATA B(53749), B(53750), B(53751) /     1.35,   -7.25,    0.00 /
      DATA B(53896), B(53897), B(53898) /     1.55,   -6.76,    0.00 /
      DATA B(54043), B(54044), B(54045) /     1.78,   -6.22,    0.00 /
      DATA B(54190), B(54191), B(54192) /     2.00,   -5.66,    0.00 /
      DATA B(54337), B(54338), B(54339) /     2.15,   -5.12,    0.00 /
      DATA B(54484), B(54485), B(54486) /     2.24,   -4.61,    0.00 /
      DATA B(54631), B(54632), B(54633) /     2.29,   -4.17,    0.00 /
      DATA B(54778), B(54779), B(54780) /     2.33,   -3.80,    0.00 /
      DATA B(54925), B(54926), B(54927) /     2.38,   -3.49,    0.00 /
      DATA B(55072), B(55073), B(55074) /     2.43,   -3.20,    0.00 /
      DATA B(55219), B(55220), B(55221) /     2.49,   -2.93,    0.00 /
      DATA B(55366), B(55367), B(55368) /     2.56,   -2.65,    0.00 /
      DATA B(55513), B(55514), B(55515) /     2.68,   -2.38,    0.00 /
      DATA B(55660), B(55661), B(55662) /     2.85,   -2.10,    0.00 /
      DATA B(55807), B(55808), B(55809) /     3.04,   -1.82,    0.00 /
      DATA B(55954), B(55955), B(55956) /     3.23,   -1.55,    0.00 /
      DATA B(56101), B(56102), B(56103) /     3.40,   -1.29,    0.00 /
      DATA B(56248), B(56249), B(56250) /     3.57,   -1.05,    0.00 /
      DATA B(56395), B(56396), B(56397) /     3.72,   -0.83,    0.00 /
      DATA B(56542), B(56543), B(56544) /     3.87,   -0.64,    0.00 /
      DATA B(56689), B(56690), B(56691) /     4.00,   -0.45,    0.00 /
      DATA B(56836), B(56837), B(56838) /     4.11,   -0.28,    0.00 /
      DATA B(56983), B(56984), B(56985) /     4.22,   -0.13,    0.00 /
      DATA B(57130), B(57131), B(57132) /     4.30,    0.02,    0.00 /
      DATA B(57277), B(57278), B(57279) /     4.37,    0.16,    0.00 /
      DATA B(57424), B(57425), B(57426) /     4.42,    0.28,    0.00 /
      DATA B(57571), B(57572), B(57573) /     4.45,    0.41,    0.00 /
      DATA B(57718), B(57719), B(57720) /     4.45,    0.53,    0.00 /
      DATA B(57865), B(57866), B(57867) /     4.42,    0.65,    0.00 /
      DATA B(58012), B(58013), B(58014) /     4.37,    0.76,    0.00 /
      DATA B(58159), B(58160), B(58161) /     4.31,    0.84,    0.00 /
      DATA B(58306), B(58307), B(58308) /     4.24,    0.86,    0.00 /
      DATA B(58453), B(58454), B(58455) /     4.14,    0.80,    0.00 /
      DATA B(58600), B(58601), B(58602) /     4.01,    0.68,    0.00 /
      DATA B(58747), B(58748), B(58749) /     3.84,    0.52,    0.00 /
      DATA B(58894), B(58895), B(58896) /     3.66,    0.33,    0.00 /
      DATA B(59041), B(59042), B(59043) /     3.49,    0.12,    0.00 /
      DATA B(59188), B(59189), B(59190) /     3.32,   -0.06,    0.00 /
      DATA B(59335), B(59336), B(59337) /     3.15,   -0.20,    0.00 /
      DATA B(59482), B(59483), B(59484) /     3.00,   -0.27,    0.00 /
      DATA B(59629), B(59630), B(59631) /     2.89,   -0.27,    0.00 /
      DATA B(59776), B(59777), B(59778) /     2.83,   -0.21,    0.00 /
      DATA B(59923), B(59924), B(59925) /     2.83,   -0.12,    0.00 /
      DATA B(60070), B(60071), B(60072) /     2.89,    0.00,    0.00 /
      DATA B(60217), B(60218), B(60219) /     3.00,    0.14,    0.00 /
      DATA B(60364), B(60365), B(60366) /     3.15,    0.30,    0.00 /
      DATA B(60511), B(60512), B(60513) /     3.32,    0.48,    0.00 /
      DATA B(60658), B(60659), B(60660) /     3.50,    0.70,    0.00 /
      DATA B(60805), B(60806), B(60807) /     3.69,    0.93,    0.00 /
      DATA B(60952), B(60953), B(60954) /     3.89,    1.18,    0.00 /
      DATA B(61099), B(61100), B(61101) /     4.09,    1.45,    0.00 /
      DATA B(61246), B(61247), B(61248) /     4.29,    1.71,    0.00 /
      DATA B(61393), B(61394), B(61395) /     4.48,    1.98,    0.00 /
      DATA B(61540), B(61541), B(61542) /     4.66,    2.26,    0.00 /
      DATA B(61687), B(61688), B(61689) /     4.80,    2.53,    0.00 /
      DATA B(61834), B(61835), B(61836) /     4.89,    2.78,    0.00 /
      DATA B(61981), B(61982), B(61983) /     4.95,    3.02,    0.00 /
      DATA B(62128), B(62129), B(62130) /     4.97,    3.23,    0.00 /
      DATA B(62275), B(62276), B(62277) /     4.95,    3.46,    0.00 /
      DATA B(62422), B(62423), B(62424) /     4.91,    3.70,    0.00 /
      DATA B(62569), B(62570), B(62571) /     4.78,    3.84,    0.00 /
      DATA B(62716), B(62717), B(62718) /     4.63,    3.95,    0.00 /
      DATA B(62863), B(62864), B(62865) /     4.42,    4.02,    0.00 /
      DATA B(63010), B(63011), B(63012) /     4.17,    4.06,    0.00 /
      DATA B(63157), B(63158), B(63159) /     3.85,    4.08,    0.00 /
      DATA B(63304), B(63305), B(63306) /     3.47,    4.04,    0.00 /
      DATA B(63451), B(63452), B(63453) /     3.06,    3.85,    0.00 /
      DATA B(63598), B(63599), B(63600) /     2.44,    3.45,    0.00 /
      DATA B(63745), B(63746), B(63747) /     2.19,    3.06,    0.00 /
      DATA B(63892), B(63893), B(63894) /     1.80,    2.72,    0.00 /
      DATA B(64039), B(64040), B(64041) /     1.35,    2.44,    0.00 /
      DATA B(64186), B(64187), B(64188) /     0.93,    2.17,    0.00 /
      DATA B(64333), B(64334), B(64335) /     0.53,    1.90,    0.00 /
      DATA B(64480), B(64481), B(64482) /     0.14,    1.62,    0.00 /
      DATA B(64627), B(64628), B(64629) /    -0.26,    1.31,    0.00 /
      DATA B(64774), B(64775), B(64776) /    -0.67,    0.96,    0.00 /
      DATA B(64921), B(64922), B(64923) /    -1.09,    0.55,    0.00 /
      DATA B(65068), B(65069), B(65070) /    -1.51,    0.11,    0.00 /
      DATA B(65215), B(65216), B(65217) /    -1.91,   -0.35,    0.00 /
      DATA B(65362), B(65363), B(65364) /    -2.31,   -0.84,    0.00 /
      DATA B(65509), B(65510), B(65511) /    -2.69,   -1.33,    0.00 /
      DATA B(65656), B(65657), B(65658) /    -3.05,   -1.81,    0.00 /
      DATA B(65803), B(65804), B(65805) /    -3.40,   -2.30,    0.00 /
      DATA B(65950), B(65951), B(65952) /    -3.74,   -2.81,    0.00 /
      DATA B(66097), B(66098), B(66099) /    -4.06,   -3.35,    0.00 /
      DATA B(66244), B(66245), B(66246) /    -4.33,   -3.91,    0.00 /
      DATA B(66391), B(66392), B(66393) /    -4.51,   -4.44,    0.00 /
      DATA B(66538), B(66539), B(66540) /    -4.61,   -4.96,    0.00 /
      DATA B(66685), B(66686), B(66687) /    -4.77,   -5.43,    0.00 /
      DATA B(66832), B(66833), B(66834) /    -5.00,   -5.84,    0.00 /
      DATA B(66979), B(66980), B(66981) /    -5.24,   -6.19,    0.00 /
      DATA B(67126), B(67127), B(67128) /    -5.47,   -6.50,    0.00 /
      DATA B(67273), B(67274), B(67275) /    -5.68,   -6.77,    0.00 /
      DATA B(67420), B(67421), B(67422) /    -5.87,   -7.01,    0.00 /
      DATA B(67567), B(67568), B(67569) /    -6.05,   -7.23,    0.00 /
      DATA B(46402), B(46403), B(46404) /    24.81,  -35.55,    0.00 /
      DATA B(46549), B(46550), B(46551) /    24.73,  -35.03,    0.00 /
      DATA B(46696), B(46697), B(46698) /    24.71,  -34.21,    0.00 /
      DATA B(46843), B(46844), B(46845) /    24.86,  -32.78,    0.00 /
      DATA B(46990), B(46991), B(46992) /    25.38,  -29.97,    0.00 /
      DATA B(47137), B(47138), B(47139) /    13.26,  -22.31,    0.00 /
      DATA B(47284), B(47285), B(47286) /    14.97,  -19.53,    0.00 /
      DATA B(47431), B(47432), B(47433) /    16.26,  -16.22,    0.00 /
      DATA B(47578), B(47579), B(47580) /    17.27,  -13.77,    0.00 /
      DATA B(47725), B(47726), B(47727) /    17.91,  -11.89,    0.00 /
      DATA B(47872), B(47873), B(47874) /    18.24,  -10.30,    0.00 /
      DATA B(48019), B(48020), B(48021) /    14.39,   -5.00,    0.00 /
      DATA B(48166), B(48167), B(48168) /    14.19,   -4.30,    0.00 /
      DATA B(48313), B(48314), B(48315) /    13.89,   -3.80,    0.00 /
      DATA B(48460), B(48461), B(48462) /    13.12,   -3.18,    0.00 /
      DATA B(48607), B(48608), B(48609) /    11.98,   -3.38,    0.00 /
      DATA B(48754), B(48755), B(48756) /    10.78,   -3.89,    0.00 /
      DATA B(48901), B(48902), B(48903) /     9.37,   -4.88,    0.00 /
      DATA B(49048), B(49049), B(49050) /     7.97,   -6.35,    0.00 /
      DATA B(49195), B(49196), B(49197) /     6.55,   -8.24,    0.00 /
      DATA B(49342), B(49343), B(49344) /     5.23,  -10.40,    0.00 /
      DATA B(49489), B(49490), B(49491) /     3.83,  -12.65,    0.00 /
      DATA B(49636), B(49637), B(49638) /     2.34,  -14.83,    0.00 /
      DATA B(49783), B(49784), B(49785) /     5.81,   -5.35,    0.00 /
      DATA B(49930), B(49931), B(49932) /     5.04,   -6.24,    0.00 /
      DATA B(50077), B(50078), B(50079) /     4.31,   -6.82,    0.00 /
      DATA B(50224), B(50225), B(50226) /     3.66,   -7.13,    0.00 /
      DATA B(50371), B(50372), B(50373) /     3.10,   -7.27,    0.00 /
      DATA B(50518), B(50519), B(50520) /     2.65,   -7.37,    0.00 /
      DATA B(50665), B(50666), B(50667) /     2.29,   -7.45,    0.00 /
      DATA B(50812), B(50813), B(50814) /     2.01,   -7.52,    0.00 /
      DATA B(50959), B(50960), B(50961) /     1.79,   -7.56,    0.00 /
      DATA B(51106), B(51107), B(51108) /     1.61,   -7.56,    0.00 /
      DATA B(51253), B(51254), B(51255) /     1.46,   -7.53,    0.00 /
      DATA B(51400), B(51401), B(51402) /     1.32,   -7.48,    0.00 /
      DATA B(51547), B(51548), B(51549) /     1.19,   -7.43,    0.00 /
      DATA B(51694), B(51695), B(51696) /     1.07,   -7.39,    0.00 /
      DATA B(51841), B(51842), B(51843) /     0.95,   -7.35,    0.00 /
      DATA B(51988), B(51989), B(51990) /     0.84,   -7.33,    0.00 /
      DATA B(52135), B(52136), B(52137) /     0.74,   -7.34,    0.00 /
      DATA B(52282), B(52283), B(52284) /     0.65,   -7.38,    0.00 /
      DATA B(52429), B(52430), B(52431) /     0.57,   -7.48,    0.00 /
      DATA B(52576), B(52577), B(52578) /     0.50,   -7.63,    0.00 /
      DATA B(52723), B(52724), B(52725) /     0.43,   -7.82,    0.00 /
      DATA B(52870), B(52871), B(52872) /     0.37,   -8.02,    0.00 /
      DATA B(53017), B(53018), B(53019) /     0.35,   -8.21,    0.00 /
      DATA B(53164), B(53165), B(53166) /     0.37,   -8.38,    0.00 /
      DATA B(53311), B(53312), B(53313) /     0.43,   -8.48,    0.00 /
      DATA B(53458), B(53459), B(53460) /     0.50,   -8.45,    0.00 /
      DATA B(53605), B(53606), B(53607) /     0.58,   -8.25,    0.00 /
      DATA B(53752), B(53753), B(53754) /     0.69,   -7.89,    0.00 /
      DATA B(53899), B(53900), B(53901) /     0.85,   -7.42,    0.00 /
      DATA B(54046), B(54047), B(54048) /     1.03,   -6.90,    0.00 /
      DATA B(54193), B(54194), B(54195) /     1.20,   -6.35,    0.00 /
      DATA B(54340), B(54341), B(54342) /     1.31,   -5.80,    0.00 /
      DATA B(54487), B(54488), B(54489) /     1.37,   -5.29,    0.00 /
      DATA B(54634), B(54635), B(54636) /     1.41,   -4.85,    0.00 /
      DATA B(54781), B(54782), B(54783) /     1.44,   -4.49,    0.00 /
      DATA B(54928), B(54929), B(54930) /     1.47,   -4.20,    0.00 /
      DATA B(55075), B(55076), B(55077) /     1.50,   -3.96,    0.00 /
      DATA B(55222), B(55223), B(55224) /     1.52,   -3.73,    0.00 /
      DATA B(55369), B(55370), B(55371) /     1.56,   -3.52,    0.00 /
      DATA B(55516), B(55517), B(55518) /     1.63,   -3.32,    0.00 /
      DATA B(55663), B(55664), B(55665) /     1.74,   -3.12,    0.00 /
      DATA B(55810), B(55811), B(55812) /     1.86,   -2.91,    0.00 /
      DATA B(55957), B(55958), B(55959) /     1.97,   -2.69,    0.00 /
      DATA B(56104), B(56105), B(56106) /     2.09,   -2.45,    0.00 /
      DATA B(56251), B(56252), B(56253) /     2.21,   -2.22,    0.00 /
      DATA B(56398), B(56399), B(56400) /     2.34,   -2.01,    0.00 /
      DATA B(56545), B(56546), B(56547) /     2.46,   -1.80,    0.00 /
      DATA B(56692), B(56693), B(56694) /     2.58,   -1.60,    0.00 /
      DATA B(56839), B(56840), B(56841) /     2.68,   -1.42,    0.00 /
      DATA B(56986), B(56987), B(56988) /     2.78,   -1.24,    0.00 /
      DATA B(57133), B(57134), B(57135) /     2.87,   -1.07,    0.00 /
      DATA B(57280), B(57281), B(57282) /     2.94,   -0.92,    0.00 /
      DATA B(57427), B(57428), B(57429) /     3.00,   -0.77,    0.00 /
      DATA B(57574), B(57575), B(57576) /     3.03,   -0.63,    0.00 /
      DATA B(57721), B(57722), B(57723) /     3.04,   -0.49,    0.00 /
      DATA B(57868), B(57869), B(57870) /     3.04,   -0.35,    0.00 /
      DATA B(58015), B(58016), B(58017) /     3.02,   -0.23,    0.00 /
      DATA B(58162), B(58163), B(58164) /     3.01,   -0.14,    0.00 /
      DATA B(58309), B(58310), B(58311) /     2.98,   -0.10,    0.00 /
      DATA B(58456), B(58457), B(58458) /     2.93,   -0.14,    0.00 /
      DATA B(58603), B(58604), B(58605) /     2.84,   -0.24,    0.00 /
      DATA B(58750), B(58751), B(58752) /     2.72,   -0.39,    0.00 /
      DATA B(58897), B(58898), B(58899) /     2.57,   -0.57,    0.00 /
      DATA B(59044), B(59045), B(59046) /     2.43,   -0.76,    0.00 /
      DATA B(59191), B(59192), B(59193) /     2.27,   -0.94,    0.00 /
      DATA B(59338), B(59339), B(59340) /     2.12,   -1.08,    0.00 /
      DATA B(59485), B(59486), B(59487) /     1.97,   -1.15,    0.00 /
      DATA B(59632), B(59633), B(59634) /     1.86,   -1.16,    0.00 /
      DATA B(59779), B(59780), B(59781) /     1.80,   -1.11,    0.00 /
      DATA B(59926), B(59927), B(59928) /     1.79,   -1.03,    0.00 /
      DATA B(60073), B(60074), B(60075) /     1.83,   -0.93,    0.00 /
      DATA B(60220), B(60221), B(60222) /     1.93,   -0.81,    0.00 /
      DATA B(60367), B(60368), B(60369) /     2.06,   -0.66,    0.00 /
      DATA B(60514), B(60515), B(60516) /     2.20,   -0.49,    0.00 /
      DATA B(60661), B(60662), B(60663) /     2.36,   -0.29,    0.00 /
      DATA B(60808), B(60809), B(60810) /     2.53,   -0.05,    0.00 /
      DATA B(60955), B(60956), B(60957) /     2.72,    0.20,    0.00 /
      DATA B(61102), B(61103), B(61104) /     2.92,    0.46,    0.00 /
      DATA B(61249), B(61250), B(61251) /     3.12,    0.74,    0.00 /
      DATA B(61396), B(61397), B(61398) /     3.31,    1.02,    0.00 /
      DATA B(61543), B(61544), B(61545) /     3.49,    1.30,    0.00 /
      DATA B(61690), B(61691), B(61692) /     3.63,    1.58,    0.00 /
      DATA B(61837), B(61838), B(61839) /     3.74,    1.86,    0.00 /
      DATA B(61984), B(61985), B(61986) /     3.81,    2.12,    0.00 /
      DATA B(62131), B(62132), B(62133) /     3.86,    2.36,    0.00 /
      DATA B(62278), B(62279), B(62280) /     3.88,    2.62,    0.00 /
      DATA B(62425), B(62426), B(62427) /     3.83,    2.82,    0.00 /
      DATA B(62572), B(62573), B(62574) /     3.74,    2.96,    0.00 /
      DATA B(62719), B(62720), B(62721) /     3.61,    3.07,    0.00 /
      DATA B(62866), B(62867), B(62868) /     3.44,    3.15,    0.00 /
      DATA B(63013), B(63014), B(63015) /     3.23,    3.21,    0.00 /
      DATA B(63160), B(63161), B(63162) /     2.96,    3.24,    0.00 /
      DATA B(63307), B(63308), B(63309) /     2.63,    3.22,    0.00 /
      DATA B(63454), B(63455), B(63456) /     2.27,    3.08,    0.00 /
      DATA B(63601), B(63602), B(63603) /     1.66,    2.74,    0.00 /
      DATA B(63748), B(63749), B(63750) /     1.48,    2.37,    0.00 /
      DATA B(63895), B(63896), B(63897) /     1.15,    2.04,    0.00 /
      DATA B(64042), B(64043), B(64044) /     0.74,    1.77,    0.00 /
      DATA B(64189), B(64190), B(64191) /     0.34,    1.53,    0.00 /
      DATA B(64336), B(64337), B(64338) /    -0.04,    1.30,    0.00 /
      DATA B(64483), B(64484), B(64485) /    -0.40,    1.06,    0.00 /
      DATA B(64630), B(64631), B(64632) /    -0.76,    0.79,    0.00 /
      DATA B(64777), B(64778), B(64779) /    -1.13,    0.47,    0.00 /
      DATA B(64924), B(64925), B(64926) /    -1.51,    0.11,    0.00 /
      DATA B(65071), B(65072), B(65073) /    -1.89,   -0.31,    0.00 /
      DATA B(65218), B(65219), B(65220) /    -2.27,   -0.76,    0.00 /
      DATA B(65365), B(65366), B(65367) /    -2.65,   -1.23,    0.00 /
      DATA B(65512), B(65513), B(65514) /    -3.00,   -1.70,    0.00 /
      DATA B(65659), B(65660), B(65661) /    -3.34,   -2.17,    0.00 /
      DATA B(65806), B(65807), B(65808) /    -3.67,   -2.65,    0.00 /
      DATA B(65953), B(65954), B(65955) /    -3.99,   -3.15,    0.00 /
      DATA B(66100), B(66101), B(66102) /    -4.29,   -3.70,    0.00 /
      DATA B(66247), B(66248), B(66249) /    -4.52,   -4.22,    0.00 /
      DATA B(66394), B(66395), B(66396) /    -4.65,   -4.74,    0.00 /
      DATA B(66541), B(66542), B(66543) /    -4.75,   -5.25,    0.00 /
      DATA B(66688), B(66689), B(66690) /    -4.94,   -5.71,    0.00 /
      DATA B(66835), B(66836), B(66837) /    -5.18,   -6.09,    0.00 /
      DATA B(66982), B(66983), B(66984) /    -5.41,   -6.42,    0.00 /
      DATA B(67129), B(67130), B(67131) /    -5.63,   -6.70,    0.00 /
      DATA B(67276), B(67277), B(67278) /    -5.82,   -6.95,    0.00 /
      DATA B(67423), B(67424), B(67425) /    -6.01,   -7.17,    0.00 /
      DATA B(67570), B(67571), B(67572) /    -6.18,   -7.38,    0.00 /
      DATA B(46405), B(46406), B(46407) /    24.03,  -35.23,    0.00 /
      DATA B(46552), B(46553), B(46554) /    23.76,  -34.65,    0.00 /
      DATA B(46699), B(46700), B(46701) /    23.47,  -33.73,    0.00 /
      DATA B(46846), B(46847), B(46848) /    23.09,  -32.18,    0.00 /
      DATA B(46993), B(46994), B(46995) /    22.10,  -29.33,    0.00 /
      DATA B(47140), B(47141), B(47142) /    18.63,  -22.99,    0.00 /
      DATA B(47287), B(47288), B(47289) /    16.84,  -20.37,    0.00 /
      DATA B(47434), B(47435), B(47436) /    16.92,  -17.53,    0.00 /
      DATA B(47581), B(47582), B(47583) /    17.27,  -15.25,    0.00 /
      DATA B(47728), B(47729), B(47730) /    17.53,  -13.34,    0.00 /
      DATA B(47875), B(47876), B(47877) /    13.62,   -7.77,    0.00 /
      DATA B(48022), B(48023), B(48024) /    13.47,   -6.70,    0.00 /
      DATA B(48169), B(48170), B(48171) /    13.18,   -5.86,    0.00 /
      DATA B(48316), B(48317), B(48318) /    12.75,   -5.28,    0.00 /
      DATA B(48463), B(48464), B(48465) /    11.55,   -4.71,    0.00 /
      DATA B(48610), B(48611), B(48612) /    10.47,   -4.80,    0.00 /
      DATA B(48757), B(48758), B(48759) /     9.27,   -5.28,    0.00 /
      DATA B(48904), B(48905), B(48906) /     7.89,   -6.24,    0.00 /
      DATA B(49051), B(49052), B(49053) /     6.50,   -7.72,    0.00 /
      DATA B(49198), B(49199), B(49200) /     5.13,   -9.66,    0.00 /
      DATA B(49345), B(49346), B(49347) /     3.86,  -11.83,    0.00 /
      DATA B(49492), B(49493), B(49494) /     2.50,  -14.03,    0.00 /
      DATA B(49639), B(49640), B(49641) /     5.88,   -4.93,    0.00 /
      DATA B(49786), B(49787), B(49788) /     5.11,   -6.00,    0.00 /
      DATA B(49933), B(49934), B(49935) /     4.37,   -6.87,    0.00 /
      DATA B(50080), B(50081), B(50082) /     3.67,   -7.48,    0.00 /
      DATA B(50227), B(50228), B(50229) /     3.00,   -7.84,    0.00 /
      DATA B(50374), B(50375), B(50376) /     2.42,   -8.03,    0.00 /
      DATA B(50521), B(50522), B(50523) /     1.95,   -8.14,    0.00 /
      DATA B(50668), B(50669), B(50670) /     1.57,   -8.22,    0.00 /
      DATA B(50815), B(50816), B(50817) /     1.27,   -8.29,    0.00 /
      DATA B(50962), B(50963), B(50964) /     1.04,   -8.33,    0.00 /
      DATA B(51109), B(51110), B(51111) /     0.85,   -8.34,    0.00 /
      DATA B(51256), B(51257), B(51258) /     0.68,   -8.32,    0.00 /
      DATA B(51403), B(51404), B(51405) /     0.53,   -8.27,    0.00 /
      DATA B(51550), B(51551), B(51552) /     0.40,   -8.22,    0.00 /
      DATA B(51697), B(51698), B(51699) /     0.29,   -8.17,    0.00 /
      DATA B(51844), B(51845), B(51846) /     0.19,   -8.14,    0.00 /
      DATA B(51991), B(51992), B(51993) /     0.10,   -8.11,    0.00 /
      DATA B(52138), B(52139), B(52140) /     0.03,   -8.11,    0.00 /
      DATA B(52285), B(52286), B(52287) /    -0.03,   -8.15,    0.00 /
      DATA B(52432), B(52433), B(52434) /    -0.08,   -8.23,    0.00 /
      DATA B(52579), B(52580), B(52581) /    -0.12,   -8.36,    0.00 /
      DATA B(52726), B(52727), B(52728) /    -0.16,   -8.51,    0.00 /
      DATA B(52873), B(52874), B(52875) /    -0.18,   -8.68,    0.00 /
      DATA B(53020), B(53021), B(53022) /    -0.18,   -8.84,    0.00 /
      DATA B(53167), B(53168), B(53169) /    -0.14,   -8.98,    0.00 /
      DATA B(53314), B(53315), B(53316) /    -0.08,   -9.05,    0.00 /
      DATA B(53461), B(53462), B(53463) /    -0.03,   -9.00,    0.00 /
      DATA B(53608), B(53609), B(53610) /     0.04,   -8.80,    0.00 /
      DATA B(53755), B(53756), B(53757) /     0.12,   -8.45,    0.00 /
      DATA B(53902), B(53903), B(53904) /     0.24,   -8.00,    0.00 /
      DATA B(54049), B(54050), B(54051) /     0.38,   -7.49,    0.00 /
      DATA B(54196), B(54197), B(54198) /     0.50,   -6.96,    0.00 /
      DATA B(54343), B(54344), B(54345) /     0.59,   -6.42,    0.00 /
      DATA B(54490), B(54491), B(54492) /     0.63,   -5.92,    0.00 /
      DATA B(54637), B(54638), B(54639) /     0.66,   -5.49,    0.00 /
      DATA B(54784), B(54785), B(54786) /     0.69,   -5.15,    0.00 /
      DATA B(54931), B(54932), B(54933) /     0.72,   -4.88,    0.00 /
      DATA B(55078), B(55079), B(55080) /     0.73,   -4.68,    0.00 /
      DATA B(55225), B(55226), B(55227) /     0.74,   -4.51,    0.00 /
      DATA B(55372), B(55373), B(55374) /     0.75,   -4.35,    0.00 /
      DATA B(55519), B(55520), B(55521) /     0.79,   -4.21,    0.00 /
      DATA B(55666), B(55667), B(55668) /     0.84,   -4.06,    0.00 /
      DATA B(55813), B(55814), B(55815) /     0.90,   -3.90,    0.00 /
      DATA B(55960), B(55961), B(55962) /     0.96,   -3.72,    0.00 /
      DATA B(56107), B(56108), B(56109) /     1.03,   -3.50,    0.00 /
      DATA B(56254), B(56255), B(56256) /     1.10,   -3.28,    0.00 /
      DATA B(56401), B(56402), B(56403) /     1.19,   -3.05,    0.00 /
      DATA B(56548), B(56549), B(56550) /     1.29,   -2.84,    0.00 /
      DATA B(56695), B(56696), B(56697) /     1.38,   -2.62,    0.00 /
      DATA B(56842), B(56843), B(56844) /     1.48,   -2.42,    0.00 /
      DATA B(56989), B(56990), B(56991) /     1.56,   -2.22,    0.00 /
      DATA B(57136), B(57137), B(57138) /     1.64,   -2.04,    0.00 /
      DATA B(57283), B(57284), B(57285) /     1.71,   -1.87,    0.00 /
      DATA B(57430), B(57431), B(57432) /     1.76,   -1.70,    0.00 /
      DATA B(57577), B(57578), B(57579) /     1.80,   -1.54,    0.00 /
      DATA B(57724), B(57725), B(57726) /     1.82,   -1.39,    0.00 /
      DATA B(57871), B(57872), B(57873) /     1.83,   -1.24,    0.00 /
      DATA B(58018), B(58019), B(58020) /     1.84,   -1.10,    0.00 /
      DATA B(58165), B(58166), B(58167) /     1.85,   -1.01,    0.00 /
      DATA B(58312), B(58313), B(58314) /     1.86,   -0.97,    0.00 /
      DATA B(58459), B(58460), B(58461) /     1.84,   -1.00,    0.00 /
      DATA B(58606), B(58607), B(58608) /     1.79,   -1.09,    0.00 /
      DATA B(58753), B(58754), B(58755) /     1.71,   -1.22,    0.00 /
      DATA B(58900), B(58901), B(58902) /     1.61,   -1.39,    0.00 /
      DATA B(59047), B(59048), B(59049) /     1.49,   -1.57,    0.00 /
      DATA B(59194), B(59195), B(59196) /     1.36,   -1.74,    0.00 /
      DATA B(59341), B(59342), B(59343) /     1.22,   -1.87,    0.00 /
      DATA B(59488), B(59489), B(59490) /     1.09,   -1.95,    0.00 /
      DATA B(59635), B(59636), B(59637) /     0.98,   -1.97,    0.00 /
      DATA B(59782), B(59783), B(59784) /     0.92,   -1.94,    0.00 /
      DATA B(59929), B(59930), B(59931) /     0.91,   -1.87,    0.00 /
      DATA B(60076), B(60077), B(60078) /     0.94,   -1.78,    0.00 /
      DATA B(60223), B(60224), B(60225) /     1.01,   -1.67,    0.00 /
      DATA B(60370), B(60371), B(60372) /     1.11,   -1.54,    0.00 /
      DATA B(60517), B(60518), B(60519) /     1.23,   -1.38,    0.00 /
      DATA B(60664), B(60665), B(60666) /     1.36,   -1.19,    0.00 /
      DATA B(60811), B(60812), B(60813) /     1.51,   -0.96,    0.00 /
      DATA B(60958), B(60959), B(60960) /     1.68,   -0.71,    0.00 /
      DATA B(61105), B(61106), B(61107) /     1.86,   -0.44,    0.00 /
      DATA B(61252), B(61253), B(61254) /     2.04,   -0.16,    0.00 /
      DATA B(61399), B(61400), B(61401) /     2.22,    0.13,    0.00 /
      DATA B(61546), B(61547), B(61548) /     2.39,    0.42,    0.00 /
      DATA B(61693), B(61694), B(61695) /     2.53,    0.71,    0.00 /
      DATA B(61840), B(61841), B(61842) /     2.64,    1.01,    0.00 /
      DATA B(61987), B(61988), B(61989) /     2.73,    1.28,    0.00 /
      DATA B(62134), B(62135), B(62136) /     2.79,    1.55,    0.00 /
      DATA B(62281), B(62282), B(62283) /     2.82,    1.81,    0.00 /
      DATA B(62428), B(62429), B(62430) /     2.80,    2.00,    0.00 /
      DATA B(62575), B(62576), B(62577) /     2.73,    2.14,    0.00 /
      DATA B(62722), B(62723), B(62724) /     2.63,    2.24,    0.00 /
      DATA B(62869), B(62870), B(62871) /     2.49,    2.33,    0.00 /
      DATA B(63016), B(63017), B(63018) /     2.31,    2.39,    0.00 /
      DATA B(63163), B(63164), B(63165) /     2.08,    2.43,    0.00 /
      DATA B(63310), B(63311), B(63312) /     1.80,    2.43,    0.00 /
      DATA B(63457), B(63458), B(63459) /     1.47,    2.34,    0.00 /
      DATA B(63604), B(63605), B(63606) /     0.93,    2.05,    0.00 /
      DATA B(63751), B(63752), B(63753) /     0.76,    1.72,    0.00 /
      DATA B(63898), B(63899), B(63900) /     0.51,    1.39,    0.00 /
      DATA B(64045), B(64046), B(64047) /     0.13,    1.14,    0.00 /
      DATA B(64192), B(64193), B(64194) /    -0.24,    0.93,    0.00 /
      DATA B(64339), B(64340), B(64341) /    -0.59,    0.72,    0.00 /
      DATA B(64486), B(64487), B(64488) /    -0.92,    0.51,    0.00 /
      DATA B(64633), B(64634), B(64635) /    -1.25,    0.28,    0.00 /
      DATA B(64780), B(64781), B(64782) /    -1.58,    0.00,    0.00 /
      DATA B(64927), B(64928), B(64929) /    -1.93,   -0.34,    0.00 /
      DATA B(65074), B(65075), B(65076) /    -2.28,   -0.73,    0.00 /
      DATA B(65221), B(65222), B(65223) /    -2.63,   -1.16,    0.00 /
      DATA B(65368), B(65369), B(65370) /    -2.98,   -1.61,    0.00 /
      DATA B(65515), B(65516), B(65517) /    -3.30,   -2.06,    0.00 /
      DATA B(65662), B(65663), B(65664) /    -3.62,   -2.51,    0.00 /
      DATA B(65809), B(65810), B(65811) /    -3.93,   -2.98,    0.00 /
      DATA B(65956), B(65957), B(65958) /    -4.22,   -3.48,    0.00 /
      DATA B(66103), B(66104), B(66105) /    -4.47,   -4.02,    0.00 /
      DATA B(66250), B(66251), B(66252) /    -4.69,   -4.53,    0.00 /
      DATA B(66397), B(66398), B(66399) /    -4.79,   -5.04,    0.00 /
      DATA B(66544), B(66545), B(66546) /    -4.90,   -5.53,    0.00 /
      DATA B(66691), B(66692), B(66693) /    -5.11,   -5.96,    0.00 /
      DATA B(66838), B(66839), B(66840) /    -5.34,   -6.32,    0.00 /
      DATA B(66985), B(66986), B(66987) /    -5.57,   -6.63,    0.00 /
      DATA B(67132), B(67133), B(67134) /    -5.77,   -6.89,    0.00 /
      DATA B(67279), B(67280), B(67281) /    -5.96,   -7.12,    0.00 /
      DATA B(67426), B(67427), B(67428) /    -6.14,   -7.33,    0.00 /
      DATA B(67573), B(67574), B(67575) /    -6.30,   -7.53,    0.00 /
      DATA B(46408), B(46409), B(46410) /    23.06,  -34.80,    0.00 /
      DATA B(46555), B(46556), B(46557) /    22.58,  -34.11,    0.00 /
      DATA B(46702), B(46703), B(46704) /    22.00,  -33.03,    0.00 /
      DATA B(46849), B(46850), B(46851) /    21.21,  -31.18,    0.00 /
      DATA B(46996), B(46997), B(46998) /    19.60,  -28.07,    0.00 /
      DATA B(47143), B(47144), B(47145) /    18.13,  -23.63,    0.00 /
      DATA B(47290), B(47291), B(47292) /    17.40,  -20.95,    0.00 /
      DATA B(47437), B(47438), B(47439) /    17.03,  -18.65,    0.00 /
      DATA B(47584), B(47585), B(47586) /    16.94,  -16.51,    0.00 /
      DATA B(47731), B(47732), B(47733) /    12.88,  -10.71,    0.00 /
      DATA B(47878), B(47879), B(47880) /    12.62,   -9.35,    0.00 /
      DATA B(48025), B(48026), B(48027) /    12.37,   -8.17,    0.00 /
      DATA B(48172), B(48173), B(48174) /    11.98,   -7.24,    0.00 /
      DATA B(48319), B(48320), B(48321) /    10.92,   -6.31,    0.00 /
      DATA B(48466), B(48467), B(48468) /    10.02,   -6.05,    0.00 /
      DATA B(48613), B(48614), B(48615) /     9.01,   -6.12,    0.00 /
      DATA B(48760), B(48761), B(48762) /     7.85,   -6.57,    0.00 /
      DATA B(48907), B(48908), B(48909) /     6.52,   -7.50,    0.00 /
      DATA B(49054), B(49055), B(49056) /     5.13,   -9.01,    0.00 /
      DATA B(49201), B(49202), B(49203) /     3.79,  -11.05,    0.00 /
      DATA B(49348), B(49349), B(49350) /     2.58,  -13.27,    0.00 /
      DATA B(49495), B(49496), B(49497) /     1.26,  -15.39,    0.00 /
      DATA B(49642), B(49643), B(49644) /     5.23,   -5.60,    0.00 /
      DATA B(49789), B(49790), B(49791) /     4.49,   -6.60,    0.00 /
      DATA B(49936), B(49937), B(49938) /     3.79,   -7.42,    0.00 /
      DATA B(50083), B(50084), B(50085) /     3.10,   -8.03,    0.00 /
      DATA B(50230), B(50231), B(50232) /     2.44,   -8.42,    0.00 /
      DATA B(50377), B(50378), B(50379) /     1.85,   -8.63,    0.00 /
      DATA B(50524), B(50525), B(50526) /     1.37,   -8.76,    0.00 /
      DATA B(50671), B(50672), B(50673) /     0.98,   -8.86,    0.00 /
      DATA B(50818), B(50819), B(50820) /     0.67,   -8.93,    0.00 /
      DATA B(50965), B(50966), B(50967) /     0.43,   -8.99,    0.00 /
      DATA B(51112), B(51113), B(51114) /     0.23,   -9.01,    0.00 /
      DATA B(51259), B(51260), B(51261) /     0.05,   -9.00,    0.00 /
      DATA B(51406), B(51407), B(51408) /    -0.11,   -8.97,    0.00 /
      DATA B(51553), B(51554), B(51555) /    -0.24,   -8.93,    0.00 /
      DATA B(51700), B(51701), B(51702) /    -0.34,   -8.89,    0.00 /
      DATA B(51847), B(51848), B(51849) /    -0.43,   -8.86,    0.00 /
      DATA B(51994), B(51995), B(51996) /    -0.50,   -8.84,    0.00 /
      DATA B(52141), B(52142), B(52143) /    -0.55,   -8.83,    0.00 /
      DATA B(52288), B(52289), B(52290) /    -0.59,   -8.86,    0.00 /
      DATA B(52435), B(52436), B(52437) /    -0.62,   -8.93,    0.00 /
      DATA B(52582), B(52583), B(52584) /    -0.64,   -9.03,    0.00 /
      DATA B(52729), B(52730), B(52731) /    -0.65,   -9.15,    0.00 /
      DATA B(52876), B(52877), B(52878) /    -0.65,   -9.28,    0.00 /
      DATA B(53023), B(53024), B(53025) /    -0.63,   -9.41,    0.00 /
      DATA B(53170), B(53171), B(53172) /    -0.59,   -9.51,    0.00 /
      DATA B(53317), B(53318), B(53319) /    -0.54,   -9.54,    0.00 /
      DATA B(53464), B(53465), B(53466) /    -0.49,   -9.47,    0.00 /
      DATA B(53611), B(53612), B(53613) /    -0.44,   -9.26,    0.00 /
      DATA B(53758), B(53759), B(53760) /    -0.38,   -8.93,    0.00 /
      DATA B(53905), B(53906), B(53907) /    -0.30,   -8.50,    0.00 /
      DATA B(54052), B(54053), B(54054) /    -0.20,   -8.01,    0.00 /
      DATA B(54199), B(54200), B(54201) /    -0.11,   -7.50,    0.00 /
      DATA B(54346), B(54347), B(54348) /    -0.05,   -6.98,    0.00 /
      DATA B(54493), B(54494), B(54495) /    -0.01,   -6.50,    0.00 /
      DATA B(54640), B(54641), B(54642) /     0.02,   -6.08,    0.00 /
      DATA B(54787), B(54788), B(54789) /     0.05,   -5.75,    0.00 /
      DATA B(54934), B(54935), B(54936) /     0.08,   -5.51,    0.00 /
      DATA B(55081), B(55082), B(55083) /     0.09,   -5.34,    0.00 /
      DATA B(55228), B(55229), B(55230) /     0.09,   -5.20,    0.00 /
      DATA B(55375), B(55376), B(55377) /     0.09,   -5.09,    0.00 /
      DATA B(55522), B(55523), B(55524) /     0.10,   -4.99,    0.00 /
      DATA B(55669), B(55670), B(55671) /     0.12,   -4.88,    0.00 /
      DATA B(55816), B(55817), B(55818) /     0.14,   -4.75,    0.00 /
      DATA B(55963), B(55964), B(55965) /     0.15,   -4.59,    0.00 /
      DATA B(56110), B(56111), B(56112) /     0.17,   -4.39,    0.00 /
      DATA B(56257), B(56258), B(56259) /     0.21,   -4.18,    0.00 /
      DATA B(56404), B(56405), B(56406) /     0.26,   -3.95,    0.00 /
      DATA B(56551), B(56552), B(56553) /     0.33,   -3.72,    0.00 /
      DATA B(56698), B(56699), B(56700) /     0.40,   -3.50,    0.00 /
      DATA B(56845), B(56846), B(56847) /     0.47,   -3.29,    0.00 /
      DATA B(56992), B(56993), B(56994) /     0.54,   -3.08,    0.00 /
      DATA B(57139), B(57140), B(57141) /     0.61,   -2.88,    0.00 /
      DATA B(57286), B(57287), B(57288) /     0.67,   -2.70,    0.00 /
      DATA B(57433), B(57434), B(57435) /     0.72,   -2.52,    0.00 /
      DATA B(57580), B(57581), B(57582) /     0.75,   -2.35,    0.00 /
      DATA B(57727), B(57728), B(57729) /     0.78,   -2.19,    0.00 /
      DATA B(57874), B(57875), B(57876) /     0.81,   -2.03,    0.00 /
      DATA B(58021), B(58022), B(58023) /     0.83,   -1.90,    0.00 /
      DATA B(58168), B(58169), B(58170) /     0.86,   -1.81,    0.00 /
      DATA B(58315), B(58316), B(58317) /     0.88,   -1.77,    0.00 /
      DATA B(58462), B(58463), B(58464) /     0.89,   -1.79,    0.00 /
      DATA B(58609), B(58610), B(58611) /     0.87,   -1.87,    0.00 /
      DATA B(58756), B(58757), B(58758) /     0.82,   -1.99,    0.00 /
      DATA B(58903), B(58904), B(58905) /     0.75,   -2.14,    0.00 /
      DATA B(59050), B(59051), B(59052) /     0.66,   -2.30,    0.00 /
      DATA B(59197), B(59198), B(59199) /     0.56,   -2.46,    0.00 /
      DATA B(59344), B(59345), B(59346) /     0.44,   -2.58,    0.00 /
      DATA B(59491), B(59492), B(59493) /     0.32,   -2.66,    0.00 /
      DATA B(59638), B(59639), B(59640) /     0.23,   -2.68,    0.00 /
      DATA B(59785), B(59786), B(59787) /     0.17,   -2.66,    0.00 /
      DATA B(59932), B(59933), B(59934) /     0.15,   -2.60,    0.00 /
      DATA B(60079), B(60080), B(60081) /     0.17,   -2.53,    0.00 /
      DATA B(60226), B(60227), B(60228) /     0.22,   -2.43,    0.00 /
      DATA B(60373), B(60374), B(60375) /     0.30,   -2.31,    0.00 /
      DATA B(60520), B(60521), B(60522) /     0.39,   -2.16,    0.00 /
      DATA B(60667), B(60668), B(60669) /     0.49,   -1.98,    0.00 /
      DATA B(60814), B(60815), B(60816) /     0.61,   -1.75,    0.00 /
      DATA B(60961), B(60962), B(60963) /     0.75,   -1.51,    0.00 /
      DATA B(61108), B(61109), B(61110) /     0.90,   -1.24,    0.00 /
      DATA B(61255), B(61256), B(61257) /     1.06,   -0.96,    0.00 /
      DATA B(61402), B(61403), B(61404) /     1.23,   -0.68,    0.00 /
      DATA B(61549), B(61550), B(61551) /     1.38,   -0.38,    0.00 /
      DATA B(61696), B(61697), B(61698) /     1.51,   -0.08,    0.00 /
      DATA B(61843), B(61844), B(61845) /     1.62,    0.22,    0.00 /
      DATA B(61990), B(61991), B(61992) /     1.71,    0.52,    0.00 /
      DATA B(62137), B(62138), B(62139) /     1.78,    0.80,    0.00 /
      DATA B(62284), B(62285), B(62286) /     1.83,    1.07,    0.00 /
      DATA B(62431), B(62432), B(62433) /     1.82,    1.23,    0.00 /
      DATA B(62578), B(62579), B(62580) /     1.77,    1.37,    0.00 /
      DATA B(62725), B(62726), B(62727) /     1.68,    1.47,    0.00 /
      DATA B(62872), B(62873), B(62874) /     1.57,    1.55,    0.00 /
      DATA B(63019), B(63020), B(63021) /     1.42,    1.62,    0.00 /
      DATA B(63166), B(63167), B(63168) /     1.23,    1.67,    0.00 /
      DATA B(63313), B(63314), B(63315) /     0.99,    1.69,    0.00 /
      DATA B(63460), B(63461), B(63462) /     0.71,    1.62,    0.00 /
      DATA B(63607), B(63608), B(63609) /    -3.32,    0.68,    0.00 /
      DATA B(63754), B(63755), B(63756) /     0.05,    1.09,    0.00 /
      DATA B(63901), B(63902), B(63903) /    -0.14,    0.79,    0.00 /
      DATA B(64048), B(64049), B(64050) /    -0.46,    0.55,    0.00 /
      DATA B(64195), B(64196), B(64197) /    -0.81,    0.36,    0.00 /
      DATA B(64342), B(64343), B(64344) /    -1.13,    0.18,    0.00 /
      DATA B(64489), B(64490), B(64491) /    -1.44,   -0.01,    0.00 /
      DATA B(64636), B(64637), B(64638) /    -1.73,   -0.22,    0.00 /
      DATA B(64783), B(64784), B(64785) /    -2.03,   -0.47,    0.00 /
      DATA B(64930), B(64931), B(64932) /    -2.34,   -0.78,    0.00 /
      DATA B(65077), B(65078), B(65079) /    -2.66,   -1.15,    0.00 /
      DATA B(65224), B(65225), B(65226) /    -2.98,   -1.55,    0.00 /
      DATA B(65371), B(65372), B(65373) /    -3.30,   -1.98,    0.00 /
      DATA B(65518), B(65519), B(65520) /    -3.60,   -2.41,    0.00 /
      DATA B(65665), B(65666), B(65667) /    -3.89,   -2.85,    0.00 /
      DATA B(65812), B(65813), B(65814) /    -4.18,   -3.31,    0.00 /
      DATA B(65959), B(65960), B(65961) /    -4.45,   -3.81,    0.00 /
      DATA B(66106), B(66107), B(66108) /    -4.70,   -4.33,    0.00 /
      DATA B(66253), B(66254), B(66255) /    -4.85,   -4.82,    0.00 /
      DATA B(66400), B(66401), B(66402) /    -4.92,   -5.32,    0.00 /
      DATA B(66547), B(66548), B(66549) /    -5.06,   -5.79,    0.00 /
      DATA B(66694), B(66695), B(66696) /    -5.27,   -6.20,    0.00 /
      DATA B(66841), B(66842), B(66843) /    -5.50,   -6.54,    0.00 /
      DATA B(66988), B(66989), B(66990) /    -5.72,   -6.82,    0.00 /
      DATA B(67135), B(67136), B(67137) /    -5.92,   -7.07,    0.00 /
      DATA B(67282), B(67283), B(67284) /    -6.10,   -7.28,    0.00 /
      DATA B(67429), B(67430), B(67431) /    -6.26,   -7.48,    0.00 /
      DATA B(67576), B(67577), B(67578) /    -6.42,   -7.67,    0.00 /
      DATA B(46411), B(46412), B(46413) /    21.87,  -34.22,    0.00 /
      DATA B(46558), B(46559), B(46560) /    21.23,  -33.36,    0.00 /
      DATA B(46705), B(46706), B(46707) /    20.44,  -32.07,    0.00 /
      DATA B(46852), B(46853), B(46854) /    19.40,  -30.24,    0.00 /
      DATA B(46999), B(47000), B(47001) /    18.13,  -27.44,    0.00 /
      DATA B(47146), B(47147), B(47148) /    17.27,  -24.14,    0.00 /
      DATA B(47293), B(47294), B(47295) /    16.86,  -21.58,    0.00 /
      DATA B(47440), B(47441), B(47442) /    16.52,  -19.43,    0.00 /
      DATA B(47587), B(47588), B(47589) /    12.24,  -13.64,    0.00 /
      DATA B(47734), B(47735), B(47736) /    11.87,  -12.09,    0.00 /
      DATA B(47881), B(47882), B(47883) /    11.51,  -10.65,    0.00 /
      DATA B(48028), B(48029), B(48030) /    11.12,   -9.42,    0.00 /
      DATA B(48175), B(48176), B(48177) /    10.17,   -8.15,    0.00 /
      DATA B(48322), B(48323), B(48324) /     9.34,   -7.59,    0.00 /
      DATA B(48469), B(48470), B(48471) /     8.52,   -7.33,    0.00 /
      DATA B(48616), B(48617), B(48618) /     7.61,   -7.40,    0.00 /
      DATA B(48763), B(48764), B(48765) /     6.53,   -7.82,    0.00 /
      DATA B(48910), B(48911), B(48912) /     5.28,   -8.68,    0.00 /
      DATA B(49057), B(49058), B(49059) /     3.88,  -10.20,    0.00 /
      DATA B(49204), B(49205), B(49206) /     2.54,  -12.45,    0.00 /
      DATA B(49351), B(49352), B(49353) /     1.39,  -14.78,    0.00 /
      DATA B(49498), B(49499), B(49500) /     5.35,   -5.27,    0.00 /
      DATA B(49645), B(49646), B(49647) /     4.65,   -6.25,    0.00 /
      DATA B(49792), B(49793), B(49794) /     3.94,   -7.16,    0.00 /
      DATA B(49939), B(49940), B(49941) /     3.26,   -7.94,    0.00 /
      DATA B(50086), B(50087), B(50088) /     2.60,   -8.53,    0.00 /
      DATA B(50233), B(50234), B(50235) /     1.95,   -8.93,    0.00 /
      DATA B(50380), B(50381), B(50382) /     1.38,   -9.17,    0.00 /
      DATA B(50527), B(50528), B(50529) /     0.89,   -9.32,    0.00 /
      DATA B(50674), B(50675), B(50676) /     0.51,   -9.44,    0.00 /
      DATA B(50821), B(50822), B(50823) /     0.20,   -9.53,    0.00 /
      DATA B(50968), B(50969), B(50970) /    -0.05,   -9.60,    0.00 /
      DATA B(51115), B(51116), B(51117) /    -0.27,   -9.64,    0.00 /
      DATA B(51262), B(51263), B(51264) /    -0.45,   -9.65,    0.00 /
      DATA B(51409), B(51410), B(51411) /    -0.62,   -9.64,    0.00 /
      DATA B(51556), B(51557), B(51558) /    -0.75,   -9.61,    0.00 /
      DATA B(51703), B(51704), B(51705) /    -0.85,   -9.57,    0.00 /
      DATA B(51850), B(51851), B(51852) /    -0.92,   -9.54,    0.00 /
      DATA B(51997), B(51998), B(51999) /    -0.98,   -9.51,    0.00 /
      DATA B(52144), B(52145), B(52146) /    -1.03,   -9.50,    0.00 /
      DATA B(52291), B(52292), B(52293) /    -1.05,   -9.52,    0.00 /
      DATA B(52438), B(52439), B(52440) /    -1.06,   -9.56,    0.00 /
      DATA B(52585), B(52586), B(52587) /    -1.07,   -9.63,    0.00 /
      DATA B(52732), B(52733), B(52734) /    -1.07,   -9.72,    0.00 /
      DATA B(52879), B(52880), B(52881) /    -1.06,   -9.82,    0.00 /
      DATA B(53026), B(53027), B(53028) /    -1.03,   -9.90,    0.00 /
      DATA B(53173), B(53174), B(53175) /    -0.99,   -9.96,    0.00 /
      DATA B(53320), B(53321), B(53322) /    -0.94,   -9.96,    0.00 /
      DATA B(53467), B(53468), B(53469) /    -0.90,   -9.87,    0.00 /
      DATA B(53614), B(53615), B(53616) /    -0.87,   -9.67,    0.00 /
      DATA B(53761), B(53762), B(53763) /    -0.83,   -9.35,    0.00 /
      DATA B(53908), B(53909), B(53910) /    -0.77,   -8.94,    0.00 /
      DATA B(54055), B(54056), B(54057) /    -0.70,   -8.47,    0.00 /
      DATA B(54202), B(54203), B(54204) /    -0.63,   -7.98,    0.00 /
      DATA B(54349), B(54350), B(54351) /    -0.59,   -7.48,    0.00 /
      DATA B(54496), B(54497), B(54498) /    -0.57,   -7.02,    0.00 /
      DATA B(54643), B(54644), B(54645) /    -0.54,   -6.61,    0.00 /
      DATA B(54790), B(54791), B(54792) /    -0.50,   -6.30,    0.00 /
      DATA B(54937), B(54938), B(54939) /    -0.46,   -6.08,    0.00 /
      DATA B(55084), B(55085), B(55086) /    -0.44,   -5.93,    0.00 /
      DATA B(55231), B(55232), B(55233) /    -0.45,   -5.82,    0.00 /
      DATA B(55378), B(55379), B(55380) /    -0.46,   -5.73,    0.00 /
      DATA B(55525), B(55526), B(55527) /    -0.46,   -5.66,    0.00 /
      DATA B(55672), B(55673), B(55674) /    -0.47,   -5.58,    0.00 /
      DATA B(55819), B(55820), B(55821) /    -0.49,   -5.47,    0.00 /
      DATA B(55966), B(55967), B(55968) /    -0.50,   -5.33,    0.00 /
      DATA B(56113), B(56114), B(56115) /    -0.52,   -5.15,    0.00 /
      DATA B(56260), B(56261), B(56262) /    -0.51,   -4.95,    0.00 /
      DATA B(56407), B(56408), B(56409) /    -0.48,   -4.73,    0.00 /
      DATA B(56554), B(56555), B(56556) /    -0.44,   -4.50,    0.00 /
      DATA B(56701), B(56702), B(56703) /    -0.39,   -4.28,    0.00 /
      DATA B(56848), B(56849), B(56850) /    -0.34,   -4.06,    0.00 /
      DATA B(56995), B(56996), B(56997) /    -0.28,   -3.85,    0.00 /
      DATA B(57142), B(57143), B(57144) /    -0.23,   -3.65,    0.00 /
      DATA B(57289), B(57290), B(57291) /    -0.18,   -3.46,    0.00 /
      DATA B(57436), B(57437), B(57438) /    -0.14,   -3.28,    0.00 /
      DATA B(57583), B(57584), B(57585) /    -0.11,   -3.11,    0.00 /
      DATA B(57730), B(57731), B(57732) /    -0.08,   -2.95,    0.00 /
      DATA B(57877), B(57878), B(57879) /    -0.05,   -2.80,    0.00 /
      DATA B(58024), B(58025), B(58026) /    -0.01,   -2.67,    0.00 /
      DATA B(58171), B(58172), B(58173) /     0.02,   -2.58,    0.00 /
      DATA B(58318), B(58319), B(58320) /     0.05,   -2.54,    0.00 /
      DATA B(58465), B(58466), B(58467) /     0.07,   -2.55,    0.00 /
      DATA B(58612), B(58613), B(58614) /     0.07,   -2.62,    0.00 /
      DATA B(58759), B(58760), B(58761) /     0.05,   -2.72,    0.00 /
      DATA B(58906), B(58907), B(58908) /     0.00,   -2.84,    0.00 /
      DATA B(59053), B(59054), B(59055) /    -0.06,   -2.98,    0.00 /
      DATA B(59200), B(59201), B(59202) /    -0.14,   -3.12,    0.00 /
      DATA B(59347), B(59348), B(59349) /    -0.24,   -3.22,    0.00 /
      DATA B(59494), B(59495), B(59496) /    -0.33,   -3.29,    0.00 /
      DATA B(59641), B(59642), B(59643) /    -0.42,   -3.31,    0.00 /
      DATA B(59788), B(59789), B(59790) /    -0.47,   -3.29,    0.00 /
      DATA B(59935), B(59936), B(59937) /    -0.49,   -3.25,    0.00 /
      DATA B(60082), B(60083), B(60084) /    -0.49,   -3.18,    0.00 /
      DATA B(60229), B(60230), B(60231) /    -0.45,   -3.09,    0.00 /
      DATA B(60376), B(60377), B(60378) /    -0.40,   -2.98,    0.00 /
      DATA B(60523), B(60524), B(60525) /    -0.34,   -2.84,    0.00 /
      DATA B(60670), B(60671), B(60672) /    -0.27,   -2.66,    0.00 /
      DATA B(60817), B(60818), B(60819) /    -0.18,   -2.45,    0.00 /
      DATA B(60964), B(60965), B(60966) /    -0.07,   -2.21,    0.00 /
      DATA B(61111), B(61112), B(61113) /     0.06,   -1.95,    0.00 /
      DATA B(61258), B(61259), B(61260) /     0.19,   -1.67,    0.00 /
      DATA B(61405), B(61406), B(61407) /     0.32,   -1.39,    0.00 /
      DATA B(61552), B(61553), B(61554) /     0.45,   -1.09,    0.00 /
      DATA B(61699), B(61700), B(61701) /     0.57,   -0.79,    0.00 /
      DATA B(61846), B(61847), B(61848) /     0.67,   -0.48,    0.00 /
      DATA B(61993), B(61994), B(61995) /     0.76,   -0.18,    0.00 /
      DATA B(62140), B(62141), B(62142) /     0.83,    0.12,    0.00 /
      DATA B(62287), B(62288), B(62289) /     0.89,    0.35,    0.00 /
      DATA B(62434), B(62435), B(62436) /     0.89,    0.52,    0.00 /
      DATA B(62581), B(62582), B(62583) /     0.85,    0.64,    0.00 /
      DATA B(62728), B(62729), B(62730) /     0.79,    0.75,    0.00 /
      DATA B(62875), B(62876), B(62877) /     0.69,    0.83,    0.00 /
      DATA B(63022), B(63023), B(63024) /     0.57,    0.91,    0.00 /
      DATA B(63169), B(63170), B(63171) /     0.42,    0.96,    0.00 /
      DATA B(63316), B(63317), B(63318) /     0.22,    0.98,    0.00 /
      DATA B(63463), B(63464), B(63465) /    -0.03,    0.95,    0.00 /
      DATA B(63610), B(63611), B(63612) /    -0.30,    0.80,    0.00 /
      DATA B(63757), B(63758), B(63759) /    -0.63,    0.50,    0.00 /
      DATA B(63904), B(63905), B(63906) /    -0.77,    0.21,    0.00 /
      DATA B(64051), B(64052), B(64053) /    -1.05,   -0.01,    0.00 /
      DATA B(64198), B(64199), B(64200) /    -1.37,   -0.19,    0.00 /
      DATA B(64345), B(64346), B(64347) /    -1.66,   -0.36,    0.00 /
      DATA B(64492), B(64493), B(64494) /    -1.94,   -0.52,    0.00 /
      DATA B(64639), B(64640), B(64641) /    -2.21,   -0.71,    0.00 /
      DATA B(64786), B(64787), B(64788) /    -2.48,   -0.94,    0.00 /
      DATA B(64933), B(64934), B(64935) /    -2.75,   -1.22,    0.00 /
      DATA B(65080), B(65081), B(65082) /    -3.04,   -1.56,    0.00 /
      DATA B(65227), B(65228), B(65229) /    -3.33,   -1.94,    0.00 /
      DATA B(65374), B(65375), B(65376) /    -3.61,   -2.34,    0.00 /
      DATA B(65521), B(65522), B(65523) /    -3.88,   -2.75,    0.00 /
      DATA B(65668), B(65669), B(65670) /    -4.15,   -3.18,    0.00 /
      DATA B(65815), B(65816), B(65817) /    -4.41,   -3.63,    0.00 /
      DATA B(65962), B(65963), B(65964) /    -4.66,   -4.12,    0.00 /
      DATA B(66109), B(66110), B(66111) /    -4.87,   -4.63,    0.00 /
      DATA B(66256), B(66257), B(66258) /    -4.99,   -5.11,    0.00 /
      DATA B(66403), B(66404), B(66405) /    -5.06,   -5.60,    0.00 /
      DATA B(66550), B(66551), B(66552) /    -5.22,   -6.05,    0.00 /
      DATA B(66697), B(66698), B(66699) /    -5.43,   -6.43,    0.00 /
      DATA B(66844), B(66845), B(66846) /    -5.66,   -6.74,    0.00 /
      DATA B(66991), B(66992), B(66993) /    -5.86,   -7.00,    0.00 /
      DATA B(67138), B(67139), B(67140) /    -6.05,   -7.23,    0.00 /
      DATA B(67285), B(67286), B(67287) /    -6.22,   -7.44,    0.00 /
      DATA B(67432), B(67433), B(67434) /    -6.38,   -7.62,    0.00 /
      DATA B(67579), B(67580), B(67581) /    -6.53,   -7.80,    0.00 /
      DATA B(46414), B(46415), B(46416) /    20.47,  -33.47,    0.00 /
      DATA B(46561), B(46562), B(46563) /    19.71,  -32.52,    0.00 /
      DATA B(46708), B(46709), B(46710) /    18.82,  -31.21,    0.00 /
      DATA B(46855), B(46856), B(46857) /    17.86,  -29.46,    0.00 /
      DATA B(47002), B(47003), B(47004) /    16.90,  -27.12,    0.00 /
      DATA B(47149), B(47150), B(47151) /    16.28,  -24.46,    0.00 /
      DATA B(47296), B(47297), B(47298) /    15.92,  -22.09,    0.00 /
      DATA B(47443), B(47444), B(47445) /    11.59,  -16.36,    0.00 /
      DATA B(47590), B(47591), B(47592) /    11.12,  -14.76,    0.00 /
      DATA B(47737), B(47738), B(47739) /    10.68,  -13.20,    0.00 /
      DATA B(47884), B(47885), B(47886) /    10.25,  -11.73,    0.00 /
      DATA B(48031), B(48032), B(48033) /     9.35,  -10.20,    0.00 /
      DATA B(48178), B(48179), B(48180) /     8.52,   -9.37,    0.00 /
      DATA B(48325), B(48326), B(48327) /     7.80,   -8.83,    0.00 /
      DATA B(48472), B(48473), B(48474) /     7.08,   -8.61,    0.00 /
      DATA B(48619), B(48620), B(48621) /     6.26,   -8.68,    0.00 /
      DATA B(48766), B(48767), B(48768) /     5.30,   -9.05,    0.00 /
      DATA B(48913), B(48914), B(48915) /     4.22,   -9.79,    0.00 /
      DATA B(49060), B(49061), B(49062) /     2.92,  -11.17,    0.00 /
      DATA B(49207), B(49208), B(49209) /     1.39,  -13.85,    0.00 /
      DATA B(49354), B(49355), B(49356) /     0.33,  -16.44,    0.00 /
      DATA B(49501), B(49502), B(49503) /     4.80,   -6.07,    0.00 /
      DATA B(49648), B(49649), B(49650) /     4.09,   -6.90,    0.00 /
      DATA B(49795), B(49796), B(49797) /     3.42,   -7.72,    0.00 /
      DATA B(49942), B(49943), B(49944) /     2.78,   -8.45,    0.00 /
      DATA B(50089), B(50090), B(50091) /     2.15,   -9.02,    0.00 /
      DATA B(50236), B(50237), B(50238) /     1.53,   -9.42,    0.00 /
      DATA B(50383), B(50384), B(50385) /     0.98,   -9.68,    0.00 /
      DATA B(50530), B(50531), B(50532) /     0.51,   -9.86,    0.00 /
      DATA B(50677), B(50678), B(50679) /     0.13,   -9.99,    0.00 /
      DATA B(50824), B(50825), B(50826) /    -0.18,  -10.09,    0.00 /
      DATA B(50971), B(50972), B(50973) /    -0.44,  -10.18,    0.00 /
      DATA B(51118), B(51119), B(51120) /    -0.66,  -10.24,    0.00 /
      DATA B(51265), B(51266), B(51267) /    -0.85,  -10.26,    0.00 /
      DATA B(51412), B(51413), B(51414) /    -1.02,  -10.25,    0.00 /
      DATA B(51559), B(51560), B(51561) /    -1.15,  -10.22,    0.00 /
      DATA B(51706), B(51707), B(51708) /    -1.25,  -10.19,    0.00 /
      DATA B(51853), B(51854), B(51855) /    -1.32,  -10.15,    0.00 /
      DATA B(52000), B(52001), B(52002) /    -1.37,  -10.12,    0.00 /
      DATA B(52147), B(52148), B(52149) /    -1.41,  -10.10,    0.00 /
      DATA B(52294), B(52295), B(52296) /    -1.43,  -10.09,    0.00 /
      DATA B(52441), B(52442), B(52443) /    -1.43,  -10.11,    0.00 /
      DATA B(52588), B(52589), B(52590) /    -1.43,  -10.16,    0.00 /
      DATA B(52735), B(52736), B(52737) /    -1.42,  -10.21,    0.00 /
      DATA B(52882), B(52883), B(52884) /    -1.40,  -10.27,    0.00 /
      DATA B(53029), B(53030), B(53031) /    -1.38,  -10.33,    0.00 /
      DATA B(53176), B(53177), B(53178) /    -1.34,  -10.35,    0.00 /
      DATA B(53323), B(53324), B(53325) /    -1.30,  -10.33,    0.00 /
      DATA B(53470), B(53471), B(53472) /    -1.27,  -10.22,    0.00 /
      DATA B(53617), B(53618), B(53619) /    -1.25,  -10.01,    0.00 /
      DATA B(53764), B(53765), B(53766) /    -1.23,   -9.70,    0.00 /
      DATA B(53911), B(53912), B(53913) /    -1.19,   -9.31,    0.00 /
      DATA B(54058), B(54059), B(54060) /    -1.14,   -8.87,    0.00 /
      DATA B(54205), B(54206), B(54207) /    -1.10,   -8.40,    0.00 /
      DATA B(54352), B(54353), B(54354) /    -1.07,   -7.93,    0.00 /
      DATA B(54499), B(54500), B(54501) /    -1.05,   -7.49,    0.00 /
      DATA B(54646), B(54647), B(54648) /    -1.01,   -7.11,    0.00 /
      DATA B(54793), B(54794), B(54795) /    -0.97,   -6.81,    0.00 /
      DATA B(54940), B(54941), B(54942) /    -0.93,   -6.60,    0.00 /
      DATA B(55087), B(55088), B(55089) /    -0.90,   -6.46,    0.00 /
      DATA B(55234), B(55235), B(55236) /    -0.90,   -6.37,    0.00 /
      DATA B(55381), B(55382), B(55383) /    -0.92,   -6.30,    0.00 /
      DATA B(55528), B(55529), B(55530) /    -0.93,   -6.25,    0.00 /
      DATA B(55675), B(55676), B(55677) /    -0.96,   -6.19,    0.00 /
      DATA B(55822), B(55823), B(55824) /    -0.99,   -6.10,    0.00 /
      DATA B(55969), B(55970), B(55971) /    -1.03,   -5.98,    0.00 /
      DATA B(56116), B(56117), B(56118) /    -1.06,   -5.82,    0.00 /
      DATA B(56263), B(56264), B(56265) /    -1.08,   -5.63,    0.00 /
      DATA B(56410), B(56411), B(56412) /    -1.08,   -5.42,    0.00 /
      DATA B(56557), B(56558), B(56559) /    -1.06,   -5.21,    0.00 /
      DATA B(56704), B(56705), B(56706) /    -1.03,   -4.99,    0.00 /
      DATA B(56851), B(56852), B(56853) /    -0.99,   -4.78,    0.00 /
      DATA B(56998), B(56999), B(57000) /    -0.95,   -4.57,    0.00 /
      DATA B(57145), B(57146), B(57147) /    -0.91,   -4.38,    0.00 /
      DATA B(57292), B(57293), B(57294) /    -0.87,   -4.19,    0.00 /
      DATA B(57439), B(57440), B(57441) /    -0.83,   -4.02,    0.00 /
      DATA B(57586), B(57587), B(57588) /    -0.80,   -3.85,    0.00 /
      DATA B(57733), B(57734), B(57735) /    -0.77,   -3.69,    0.00 /
      DATA B(57880), B(57881), B(57882) /    -0.74,   -3.55,    0.00 /
      DATA B(58027), B(58028), B(58029) /    -0.70,   -3.44,    0.00 /
      DATA B(58174), B(58175), B(58176) /    -0.67,   -3.35,    0.00 /
      DATA B(58321), B(58322), B(58323) /    -0.64,   -3.31,    0.00 /
      DATA B(58468), B(58469), B(58470) /    -0.61,   -3.31,    0.00 /
      DATA B(58615), B(58616), B(58617) /    -0.60,   -3.35,    0.00 /
      DATA B(58762), B(58763), B(58764) /    -0.61,   -3.42,    0.00 /
      DATA B(58909), B(58910), B(58911) /    -0.63,   -3.52,    0.00 /
      DATA B(59056), B(59057), B(59058) /    -0.68,   -3.63,    0.00 /
      DATA B(59203), B(59204), B(59205) /    -0.74,   -3.74,    0.00 /
      DATA B(59350), B(59351), B(59352) /    -0.82,   -3.82,    0.00 /
      DATA B(59497), B(59498), B(59499) /    -0.90,   -3.87,    0.00 /
      DATA B(59644), B(59645), B(59646) /    -0.97,   -3.89,    0.00 /
      DATA B(59791), B(59792), B(59793) /    -1.02,   -3.87,    0.00 /
      DATA B(59938), B(59939), B(59940) /    -1.04,   -3.82,    0.00 /
      DATA B(60085), B(60086), B(60087) /    -1.05,   -3.76,    0.00 /
      DATA B(60232), B(60233), B(60234) /    -1.03,   -3.68,    0.00 /
      DATA B(60379), B(60380), B(60381) /    -1.00,   -3.57,    0.00 /
      DATA B(60526), B(60527), B(60528) /    -0.97,   -3.43,    0.00 /
      DATA B(60673), B(60674), B(60675) /    -0.92,   -3.26,    0.00 /
      DATA B(60820), B(60821), B(60822) /    -0.86,   -3.06,    0.00 /
      DATA B(60967), B(60968), B(60969) /    -0.78,   -2.83,    0.00 /
      DATA B(61114), B(61115), B(61116) /    -0.69,   -2.57,    0.00 /
      DATA B(61261), B(61262), B(61263) /    -0.58,   -2.31,    0.00 /
      DATA B(61408), B(61409), B(61410) /    -0.48,   -2.03,    0.00 /
      DATA B(61555), B(61556), B(61557) /    -0.37,   -1.74,    0.00 /
      DATA B(61702), B(61703), B(61704) /    -0.28,   -1.45,    0.00 /
      DATA B(61849), B(61850), B(61851) /    -0.19,   -1.13,    0.00 /
      DATA B(61996), B(61997), B(61998) /    -0.10,   -0.82,    0.00 /
      DATA B(62143), B(62144), B(62145) /    -0.02,   -0.51,    0.00 /
      DATA B(62290), B(62291), B(62292) /     0.03,   -0.32,    0.00 /
      DATA B(62437), B(62438), B(62439) /     0.04,   -0.16,    0.00 /
      DATA B(62584), B(62585), B(62586) /     0.01,   -0.03,    0.00 /
      DATA B(62731), B(62732), B(62733) /    -0.05,    0.07,    0.00 /
      DATA B(62878), B(62879), B(62880) /    -0.12,    0.16,    0.00 /
      DATA B(63025), B(63026), B(63027) /    -0.22,    0.23,    0.00 /
      DATA B(63172), B(63173), B(63174) /    -0.35,    0.29,    0.00 /
      DATA B(63319), B(63320), B(63321) /    -0.52,    0.32,    0.00 /
      DATA B(63466), B(63467), B(63468) /    -0.73,    0.31,    0.00 /
      DATA B(63613), B(63614), B(63615) /    -0.93,    0.19,    0.00 /
      DATA B(63760), B(63761), B(63762) /    -1.31,   -0.07,    0.00 /
      DATA B(63907), B(63908), B(63909) /    -1.38,   -0.34,    0.00 /
      DATA B(64054), B(64055), B(64056) /    -1.62,   -0.56,    0.00 /
      DATA B(64201), B(64202), B(64203) /    -1.91,   -0.73,    0.00 /
      DATA B(64348), B(64349), B(64350) /    -2.18,   -0.88,    0.00 /
      DATA B(64495), B(64496), B(64497) /    -2.44,   -1.03,    0.00 /
      DATA B(64642), B(64643), B(64644) /    -2.68,   -1.20,    0.00 /
      DATA B(64789), B(64790), B(64791) /    -2.92,   -1.40,    0.00 /
      DATA B(64936), B(64937), B(64938) /    -3.16,   -1.66,    0.00 /
      DATA B(65083), B(65084), B(65085) /    -3.41,   -1.97,    0.00 /
      DATA B(65230), B(65231), B(65232) /    -3.66,   -2.32,    0.00 /
      DATA B(65377), B(65378), B(65379) /    -3.91,   -2.69,    0.00 /
      DATA B(65524), B(65525), B(65526) /    -4.15,   -3.09,    0.00 /
      DATA B(65671), B(65672), B(65673) /    -4.40,   -3.50,    0.00 /
      DATA B(65818), B(65819), B(65820) /    -4.65,   -3.95,    0.00 /
      DATA B(65965), B(65966), B(65967) /    -5.63,   -7.33,    0.00 /
      DATA B(66112), B(66113), B(66114) /    -5.05,   -4.91,    0.00 /
      DATA B(66259), B(66260), B(66261) /    -5.12,   -5.39,    0.00 /
      DATA B(66406), B(66407), B(66408) /    -5.20,   -5.86,    0.00 /
      DATA B(66553), B(66554), B(66555) /    -5.38,   -6.28,    0.00 /
      DATA B(66700), B(66701), B(66702) /    -5.59,   -6.64,    0.00 /
      DATA B(66847), B(66848), B(66849) /    -5.81,   -6.93,    0.00 /
      DATA B(66994), B(66995), B(66996) /    -6.00,   -7.18,    0.00 /
      DATA B(67141), B(67142), B(67143) /    -6.18,   -7.39,    0.00 /
      DATA B(67288), B(67289), B(67290) /    -6.35,   -7.58,    0.00 /
      DATA B(67435), B(67436), B(67437) /    -6.50,   -7.76,    0.00 /
      DATA B(67582), B(67583), B(67584) /    -6.64,   -7.93,    0.00 /
      DATA B(46417), B(46418), B(46419) /    18.88,  -32.77,    0.00 /
      DATA B(46564), B(46565), B(46566) /    18.09,  -31.72,    0.00 /
      DATA B(46711), B(46712), B(46713) /    17.30,  -30.49,    0.00 /
      DATA B(46858), B(46859), B(46860) /    16.49,  -28.92,    0.00 /
      DATA B(47005), B(47006), B(47007) /    15.73,  -26.90,    0.00 /
      DATA B(47152), B(47153), B(47154) /    15.18,  -24.64,    0.00 /
      DATA B(47299), B(47300), B(47301) /    10.78,  -18.95,    0.00 /
      DATA B(47446), B(47447), B(47448) /    10.28,  -17.31,    0.00 /
      DATA B(47593), B(47594), B(47595) /     9.82,  -15.72,    0.00 /
      DATA B(47740), B(47741), B(47742) /     9.32,  -14.16,    0.00 /
      DATA B(47887), B(47888), B(47889) /     8.50,  -12.37,    0.00 /
      DATA B(48034), B(48035), B(48036) /     7.64,  -11.35,    0.00 /
      DATA B(48181), B(48182), B(48183) /     6.93,  -10.55,    0.00 /
      DATA B(48328), B(48329), B(48330) /     6.30,  -10.07,    0.00 /
      DATA B(48475), B(48476), B(48477) /     5.65,   -9.89,    0.00 /
      DATA B(48622), B(48623), B(48624) /     4.92,   -9.98,    0.00 /
      DATA B(48769), B(48770), B(48771) /     4.12,  -10.32,    0.00 /
      DATA B(48916), B(48917), B(48918) /     3.33,  -10.96,    0.00 /
      DATA B(49063), B(49064), B(49065) /     2.55,  -11.93,    0.00 /
      DATA B(49210), B(49211), B(49212) /     0.73,  -14.63,    0.00 /
      DATA B(49357), B(49358), B(49359) /     4.86,   -6.39,    0.00 /
      DATA B(49504), B(49505), B(49506) /     4.13,   -6.87,    0.00 /
      DATA B(49651), B(49652), B(49653) /     3.49,   -7.55,    0.00 /
      DATA B(49798), B(49799), B(49800) /     2.89,   -8.28,    0.00 /
      DATA B(49945), B(49946), B(49947) /     2.32,   -8.96,    0.00 /
      DATA B(50092), B(50093), B(50094) /     1.73,   -9.50,    0.00 /
      DATA B(50239), B(50240), B(50241) /     1.16,   -9.90,    0.00 /
      DATA B(50386), B(50387), B(50388) /     0.63,  -10.16,    0.00 /
      DATA B(50533), B(50534), B(50535) /     0.18,  -10.35,    0.00 /
      DATA B(50680), B(50681), B(50682) /    -0.19,  -10.49,    0.00 /
      DATA B(50827), B(50828), B(50829) /    -0.50,  -10.61,    0.00 /
      DATA B(50974), B(50975), B(50976) /    -0.75,  -10.70,    0.00 /
      DATA B(51121), B(51122), B(51123) /    -0.98,  -10.77,    0.00 /
      DATA B(51268), B(51269), B(51270) /    -1.17,  -10.79,    0.00 /
      DATA B(51415), B(51416), B(51417) /    -1.34,  -10.79,    0.00 /
      DATA B(51562), B(51563), B(51564) /    -1.47,  -10.76,    0.00 /
      DATA B(51709), B(51710), B(51711) /    -1.57,  -10.72,    0.00 /
      DATA B(51856), B(51857), B(51858) /    -1.64,  -10.67,    0.00 /
      DATA B(52003), B(52004), B(52005) /    -1.69,  -10.63,    0.00 /
      DATA B(52150), B(52151), B(52152) /    -1.72,  -10.60,    0.00 /
      DATA B(52297), B(52298), B(52299) /    -1.74,  -10.58,    0.00 /
      DATA B(52444), B(52445), B(52446) /    -1.74,  -10.58,    0.00 /
      DATA B(52591), B(52592), B(52593) /    -1.74,  -10.60,    0.00 /
      DATA B(52738), B(52739), B(52740) /    -1.73,  -10.63,    0.00 /
      DATA B(52885), B(52886), B(52887) /    -1.71,  -10.67,    0.00 /
      DATA B(53032), B(53033), B(53034) /    -1.68,  -10.69,    0.00 /
      DATA B(53179), B(53180), B(53181) /    -1.65,  -10.69,    0.00 /
      DATA B(53326), B(53327), B(53328) /    -1.62,  -10.64,    0.00 /
      DATA B(53473), B(53474), B(53475) /    -1.60,  -10.52,    0.00 /
      DATA B(53620), B(53621), B(53622) /    -1.60,  -10.31,    0.00 /
      DATA B(53767), B(53768), B(53769) /    -1.59,  -10.02,    0.00 /
      DATA B(53914), B(53915), B(53916) /    -1.56,   -9.65,    0.00 /
      DATA B(54061), B(54062), B(54063) /    -1.54,   -9.23,    0.00 /
      DATA B(54208), B(54209), B(54210) /    -1.51,   -8.79,    0.00 /
      DATA B(54355), B(54356), B(54357) /    -1.49,   -8.34,    0.00 /
      DATA B(54502), B(54503), B(54504) /    -1.46,   -7.92,    0.00 /
      DATA B(54649), B(54650), B(54651) /    -1.43,   -7.56,    0.00 /
      DATA B(54796), B(54797), B(54798) /    -1.38,   -7.28,    0.00 /
      DATA B(54943), B(54944), B(54945) /    -1.33,   -7.08,    0.00 /
      DATA B(55090), B(55091), B(55092) /    -1.30,   -6.95,    0.00 /
      DATA B(55237), B(55238), B(55239) /    -1.30,   -6.87,    0.00 /
      DATA B(55384), B(55385), B(55386) /    -1.31,   -6.82,    0.00 /
      DATA B(55531), B(55532), B(55533) /    -1.33,   -6.78,    0.00 /
      DATA B(55678), B(55679), B(55680) /    -1.36,   -6.73,    0.00 /
      DATA B(55825), B(55826), B(55827) /    -1.40,   -6.66,    0.00 /
      DATA B(55972), B(55973), B(55974) /    -1.45,   -6.56,    0.00 /
      DATA B(56119), B(56120), B(56121) /    -1.50,   -6.42,    0.00 /
      DATA B(56266), B(56267), B(56268) /    -1.53,   -6.25,    0.00 /
      DATA B(56413), B(56414), B(56415) /    -1.55,   -6.06,    0.00 /
      DATA B(56560), B(56561), B(56562) /    -1.55,   -5.86,    0.00 /
      DATA B(56707), B(56708), B(56709) /    -1.53,   -5.65,    0.00 /
      DATA B(56854), B(56855), B(56856) /    -1.51,   -5.45,    0.00 /
      DATA B(57001), B(57002), B(57003) /    -1.48,   -5.26,    0.00 /
      DATA B(57148), B(57149), B(57150) /    -1.45,   -5.07,    0.00 /
      DATA B(57295), B(57296), B(57297) /    -1.41,   -4.89,    0.00 /
      DATA B(57442), B(57443), B(57444) /    -1.38,   -4.73,    0.00 /
      DATA B(57589), B(57590), B(57591) /    -1.36,   -4.57,    0.00 /
      DATA B(57736), B(57737), B(57738) /    -1.33,   -4.42,    0.00 /
      DATA B(57883), B(57884), B(57885) /    -1.30,   -4.29,    0.00 /
      DATA B(58030), B(58031), B(58032) /    -1.26,   -4.17,    0.00 /
      DATA B(58177), B(58178), B(58179) /    -1.23,   -4.09,    0.00 /
      DATA B(58324), B(58325), B(58326) /    -1.20,   -4.04,    0.00 /
      DATA B(58471), B(58472), B(58473) /    -1.17,   -4.03,    0.00 /
      DATA B(58618), B(58619), B(58620) /    -1.16,   -4.05,    0.00 /
      DATA B(58765), B(58766), B(58767) /    -1.16,   -4.10,    0.00 /
      DATA B(58912), B(58913), B(58914) /    -1.17,   -4.17,    0.00 /
      DATA B(59059), B(59060), B(59061) /    -1.20,   -4.25,    0.00 /
      DATA B(59206), B(59207), B(59208) /    -1.25,   -4.32,    0.00 /
      DATA B(59353), B(59354), B(59355) /    -1.31,   -4.39,    0.00 /
      DATA B(59500), B(59501), B(59502) /    -1.37,   -4.42,    0.00 /
      DATA B(59647), B(59648), B(59649) /    -1.43,   -4.42,    0.00 /
      DATA B(59794), B(59795), B(59796) /    -1.48,   -4.40,    0.00 /
      DATA B(59941), B(59942), B(59943) /    -1.51,   -4.36,    0.00 /
      DATA B(60088), B(60089), B(60090) /    -1.52,   -4.29,    0.00 /
      DATA B(60235), B(60236), B(60237) /    -1.52,   -4.21,    0.00 /
      DATA B(60382), B(60383), B(60384) /    -1.51,   -4.11,    0.00 /
      DATA B(60529), B(60530), B(60531) /    -1.50,   -3.97,    0.00 /
      DATA B(60676), B(60677), B(60678) /    -1.47,   -3.81,    0.00 /
      DATA B(60823), B(60824), B(60825) /    -1.44,   -3.61,    0.00 /
      DATA B(60970), B(60971), B(60972) /    -1.39,   -3.39,    0.00 /
      DATA B(61117), B(61118), B(61119) /    -1.32,   -3.15,    0.00 /
      DATA B(61264), B(61265), B(61266) /    -1.25,   -2.89,    0.00 /
      DATA B(61411), B(61412), B(61413) /    -1.18,   -2.62,    0.00 /
      DATA B(61558), B(61559), B(61560) /    -1.11,   -2.35,    0.00 /
      DATA B(61705), B(61706), B(61707) /    -1.03,   -2.06,    0.00 /
      DATA B(61852), B(61853), B(61854) /    -0.95,   -1.75,    0.00 /
      DATA B(61999), B(62000), B(62001) /    -0.88,   -1.42,    0.00 /
      DATA B(62146), B(62147), B(62148) /    -0.79,   -1.15,    0.00 /
      DATA B(62293), B(62294), B(62295) /    -0.74,   -0.96,    0.00 /
      DATA B(62440), B(62441), B(62442) /    -0.74,   -0.81,    0.00 /
      DATA B(62587), B(62588), B(62589) /    -0.77,   -0.68,    0.00 /
      DATA B(62734), B(62735), B(62736) /    -0.81,   -0.58,    0.00 /
      DATA B(62881), B(62882), B(62883) /    -0.88,   -0.49,    0.00 /
      DATA B(63028), B(63029), B(63030) /    -0.96,   -0.41,    0.00 /
      DATA B(63175), B(63176), B(63177) /    -1.06,   -0.35,    0.00 /
      DATA B(63322), B(63323), B(63324) /    -1.20,   -0.31,    0.00 /
      DATA B(63469), B(63470), B(63471) /    -1.38,   -0.31,    0.00 /
      DATA B(63616), B(63617), B(63618) /    -1.59,   -0.39,    0.00 /
      DATA B(63763), B(63764), B(63765) /    -1.93,   -0.63,    0.00 /
      DATA B(63910), B(63911), B(63912) /    -1.98,   -0.88,    0.00 /
      DATA B(64057), B(64058), B(64059) /    -2.16,   -1.10,    0.00 /
      DATA B(64204), B(64205), B(64206) /    -2.43,   -1.26,    0.00 /
      DATA B(64351), B(64352), B(64353) /    -2.68,   -1.40,    0.00 /
      DATA B(64498), B(64499), B(64500) /    -2.92,   -1.54,    0.00 /
      DATA B(64645), B(64646), B(64647) /    -3.13,   -1.69,    0.00 /
      DATA B(64792), B(64793), B(64794) /    -3.34,   -1.86,    0.00 /
      DATA B(64939), B(64940), B(64941) /    -3.55,   -2.09,    0.00 /
      DATA B(65086), B(65087), B(65088) /    -3.76,   -2.36,    0.00 /
      DATA B(65233), B(65234), B(65235) /    -3.98,   -2.68,    0.00 /
      DATA B(65380), B(65381), B(65382) /    -4.20,   -3.04,    0.00 /
      DATA B(65527), B(65528), B(65529) /    -4.42,   -3.41,    0.00 /
      DATA B(65674), B(65675), B(65676) /    -4.64,   -3.82,    0.00 /
      DATA B(65821), B(65822), B(65823) /    -4.86,   -4.26,    0.00 /
      DATA B(65968), B(65969), B(65970) /    -5.05,   -4.74,    0.00 /
      DATA B(66115), B(66116), B(66117) /    -5.20,   -5.20,    0.00 /
      DATA B(66262), B(66263), B(66264) /    -5.26,   -5.66,    0.00 /
      DATA B(66409), B(66410), B(66411) /    -5.35,   -6.11,    0.00 /
      DATA B(66556), B(66557), B(66558) /    -5.54,   -6.51,    0.00 /
      DATA B(66703), B(66704), B(66705) /    -5.75,   -6.84,    0.00 /
      DATA B(66850), B(66851), B(66852) /    -5.95,   -7.11,    0.00 /
      DATA B(66997), B(66998), B(66999) /    -6.13,   -7.34,    0.00 /
      DATA B(67144), B(67145), B(67146) /    -6.31,   -7.54,    0.00 /
      DATA B(67291), B(67292), B(67293) /    -6.46,   -7.73,    0.00 /
      DATA B(67438), B(67439), B(67440) /    -6.61,   -7.89,    0.00 /
      DATA B(67585), B(67586), B(67587) /    -6.75,   -8.05,    0.00 /
      DATA B(46420), B(46421), B(46422) /    17.27,  -32.07,    0.00 /
      DATA B(46567), B(46568), B(46569) /    16.59,  -31.11,    0.00 /
      DATA B(46714), B(46715), B(46716) /    15.92,  -29.98,    0.00 /
      DATA B(46861), B(46862), B(46863) /    15.23,  -28.54,    0.00 /
      DATA B(47008), B(47009), B(47010) /    14.56,  -26.73,    0.00 /
      DATA B(47155), B(47156), B(47157) /    10.00,  -21.36,    0.00 /
      DATA B(47302), B(47303), B(47304) /     9.40,  -19.73,    0.00 /
      DATA B(47449), B(47450), B(47451) /     8.88,  -18.13,    0.00 /
      DATA B(47596), B(47597), B(47598) /     8.36,  -16.57,    0.00 /
      DATA B(47743), B(47744), B(47745) /     7.71,  -14.46,    0.00 /
      DATA B(47890), B(47891), B(47892) /     6.80,  -13.40,    0.00 /
      DATA B(48037), B(48038), B(48039) /     6.04,  -12.45,    0.00 /
      DATA B(48184), B(48185), B(48186) /     5.42,  -11.72,    0.00 /
      DATA B(48331), B(48332), B(48333) /     4.85,  -11.31,    0.00 /
      DATA B(48478), B(48479), B(48480) /     4.24,  -11.18,    0.00 /
      DATA B(48625), B(48626), B(48627) /     3.56,  -11.31,    0.00 /
      DATA B(48772), B(48773), B(48774) /     2.88,  -11.65,    0.00 /
      DATA B(48919), B(48920), B(48921) /     1.12,  -11.62,    0.00 /
      DATA B(49066), B(49067), B(49068) /     1.53,  -11.68,    0.00 /
      DATA B(49213), B(49214), B(49215) /     1.83,  -11.14,    0.00 /
      DATA B(49360), B(49361), B(49362) /     3.23,   -7.65,    0.00 /
      DATA B(49507), B(49508), B(49509) /     3.17,   -7.71,    0.00 /
      DATA B(49654), B(49655), B(49656) /     2.79,   -8.22,    0.00 /
      DATA B(49801), B(49802), B(49803) /     2.34,   -8.85,    0.00 /
      DATA B(49948), B(49949), B(49950) /     1.85,   -9.45,    0.00 /
      DATA B(50095), B(50096), B(50097) /     1.33,   -9.96,    0.00 /
      DATA B(50242), B(50243), B(50244) /     0.80,  -10.34,    0.00 /
      DATA B(50389), B(50390), B(50391) /     0.30,  -10.60,    0.00 /
      DATA B(50536), B(50537), B(50538) /    -0.12,  -10.79,    0.00 /
      DATA B(50683), B(50684), B(50685) /    -0.48,  -10.94,    0.00 /
      DATA B(50830), B(50831), B(50832) /    -0.77,  -11.06,    0.00 /
      DATA B(50977), B(50978), B(50979) /    -1.02,  -11.15,    0.00 /
      DATA B(51124), B(51125), B(51126) /    -1.25,  -11.21,    0.00 /
      DATA B(51271), B(51272), B(51273) /    -1.44,  -11.24,    0.00 /
      DATA B(51418), B(51419), B(51420) /    -1.61,  -11.24,    0.00 /
      DATA B(51565), B(51566), B(51567) /    -1.74,  -11.20,    0.00 /
      DATA B(51712), B(51713), B(51714) /    -1.84,  -11.16,    0.00 /
      DATA B(51859), B(51860), B(51861) /    -1.91,  -11.11,    0.00 /
      DATA B(52006), B(52007), B(52008) /    -1.96,  -11.07,    0.00 /
      DATA B(52153), B(52154), B(52155) /    -1.99,  -11.03,    0.00 /
      DATA B(52300), B(52301), B(52302) /    -2.01,  -11.00,    0.00 /
      DATA B(52447), B(52448), B(52449) /    -2.01,  -10.98,    0.00 /
      DATA B(52594), B(52595), B(52596) /    -2.01,  -10.98,    0.00 /
      DATA B(52741), B(52742), B(52743) /    -2.00,  -10.99,    0.00 /
      DATA B(52888), B(52889), B(52890) /    -1.98,  -11.00,    0.00 /
      DATA B(53035), B(53036), B(53037) /    -1.96,  -11.00,    0.00 /
      DATA B(53182), B(53183), B(53184) /    -1.94,  -10.98,    0.00 /
      DATA B(53329), B(53330), B(53331) /    -1.92,  -10.92,    0.00 /
      DATA B(53476), B(53477), B(53478) /    -1.91,  -10.79,    0.00 /
      DATA B(53623), B(53624), B(53625) /    -1.91,  -10.58,    0.00 /
      DATA B(53770), B(53771), B(53772) /    -1.91,  -10.30,    0.00 /
      DATA B(53917), B(53918), B(53919) /    -1.90,   -9.95,    0.00 /
      DATA B(54064), B(54065), B(54066) /    -1.88,   -9.56,    0.00 /
      DATA B(54211), B(54212), B(54213) /    -1.87,   -9.14,    0.00 /
      DATA B(54358), B(54359), B(54360) /    -1.85,   -8.72,    0.00 /
      DATA B(54505), B(54506), B(54507) /    -1.83,   -8.33,    0.00 /
      DATA B(54652), B(54653), B(54654) /    -1.79,   -7.99,    0.00 /
      DATA B(54799), B(54800), B(54801) /    -1.74,   -7.72,    0.00 /
      DATA B(54946), B(54947), B(54948) /    -1.68,   -7.53,    0.00 /
      DATA B(55093), B(55094), B(55095) /    -1.65,   -7.41,    0.00 /
      DATA B(55240), B(55241), B(55242) /    -1.64,   -7.34,    0.00 /
      DATA B(55387), B(55388), B(55389) /    -1.64,   -7.29,    0.00 /
      DATA B(55534), B(55535), B(55536) /    -1.66,   -7.26,    0.00 /
      DATA B(55681), B(55682), B(55683) /    -1.70,   -7.22,    0.00 /
      DATA B(55828), B(55829), B(55830) /    -1.75,   -7.17,    0.00 /
      DATA B(55975), B(55976), B(55977) /    -1.81,   -7.08,    0.00 /
      DATA B(56122), B(56123), B(56124) /    -1.86,   -6.95,    0.00 /
      DATA B(56269), B(56270), B(56271) /    -1.90,   -6.80,    0.00 /
      DATA B(56416), B(56417), B(56418) /    -1.93,   -6.63,    0.00 /
      DATA B(56563), B(56564), B(56565) /    -1.94,   -6.44,    0.00 /
      DATA B(56710), B(56711), B(56712) /    -1.93,   -6.26,    0.00 /
      DATA B(56857), B(56858), B(56859) /    -1.92,   -6.07,    0.00 /
      DATA B(57004), B(57005), B(57006) /    -1.90,   -5.89,    0.00 /
      DATA B(57151), B(57152), B(57153) /    -1.88,   -5.71,    0.00 /
      DATA B(57298), B(57299), B(57300) /    -1.85,   -5.54,    0.00 /
      DATA B(57445), B(57446), B(57447) /    -1.83,   -5.38,    0.00 /
      DATA B(57592), B(57593), B(57594) /    -1.80,   -5.23,    0.00 /
      DATA B(57739), B(57740), B(57741) /    -1.78,   -5.09,    0.00 /
      DATA B(57886), B(57887), B(57888) /    -1.75,   -4.97,    0.00 /
      DATA B(58033), B(58034), B(58035) /    -1.72,   -4.86,    0.00 /
      DATA B(58180), B(58181), B(58182) /    -1.69,   -4.78,    0.00 /
      DATA B(58327), B(58328), B(58329) /    -1.66,   -4.72,    0.00 /
      DATA B(58474), B(58475), B(58476) /    -1.63,   -4.70,    0.00 /
      DATA B(58621), B(58622), B(58623) /    -1.62,   -4.70,    0.00 /
      DATA B(58768), B(58769), B(58770) /    -1.61,   -4.73,    0.00 /
      DATA B(58915), B(58916), B(58917) /    -1.62,   -4.77,    0.00 /
      DATA B(59062), B(59063), B(59064) /    -1.64,   -4.82,    0.00 /
      DATA B(59209), B(59210), B(59211) /    -1.68,   -4.87,    0.00 /
      DATA B(59356), B(59357), B(59358) /    -1.73,   -4.91,    0.00 /
      DATA B(59503), B(59504), B(59505) /    -1.78,   -4.93,    0.00 /
      DATA B(59650), B(59651), B(59652) /    -1.83,   -4.92,    0.00 /
      DATA B(59797), B(59798), B(59799) /    -1.87,   -4.89,    0.00 /
      DATA B(59944), B(59945), B(59946) /    -1.90,   -4.84,    0.00 /
      DATA B(60091), B(60092), B(60093) /    -1.92,   -4.78,    0.00 /
      DATA B(60238), B(60239), B(60240) /    -1.93,   -4.70,    0.00 /
      DATA B(60385), B(60386), B(60387) /    -1.94,   -4.59,    0.00 /
      DATA B(60532), B(60533), B(60534) /    -1.94,   -4.46,    0.00 /
      DATA B(60679), B(60680), B(60681) /    -1.94,   -4.31,    0.00 /
      DATA B(60826), B(60827), B(60828) /    -1.93,   -4.12,    0.00 /
      DATA B(60973), B(60974), B(60975) /    -1.90,   -3.90,    0.00 /
      DATA B(61120), B(61121), B(61122) /    -1.86,   -3.67,    0.00 /
      DATA B(61267), B(61268), B(61269) /    -1.82,   -3.43,    0.00 /
      DATA B(61414), B(61415), B(61416) /    -1.78,   -3.17,    0.00 /
      DATA B(61561), B(61562), B(61563) /    -1.75,   -2.91,    0.00 /
      DATA B(61708), B(61709), B(61710) /    -1.71,   -2.64,    0.00 /
      DATA B(61855), B(61856), B(61857) /    -1.64,   -2.34,    0.00 /
      DATA B(62002), B(62003), B(62004) /    -1.54,   -1.97,    0.00 /
      DATA B(62149), B(62150), B(62151) /    -1.44,   -1.77,    0.00 /
      DATA B(62296), B(62297), B(62298) /    -1.41,   -1.59,    0.00 /
      DATA B(62443), B(62444), B(62445) /    -1.42,   -1.44,    0.00 /
      DATA B(62590), B(62591), B(62592) /    -1.45,   -1.31,    0.00 /
      DATA B(62737), B(62738), B(62739) /    -1.50,   -1.21,    0.00 /
      DATA B(62884), B(62885), B(62886) /    -1.55,   -1.12,    0.00 /
      DATA B(63031), B(63032), B(63033) /    -1.62,   -1.04,    0.00 /
      DATA B(63178), B(63179), B(63180) /    -1.71,   -0.97,    0.00 /
      DATA B(63325), B(63326), B(63327) /    -1.83,   -0.93,    0.00 /
      DATA B(63472), B(63473), B(63474) /    -1.99,   -0.91,    0.00 /
      DATA B(63619), B(63620), B(63621) /    -2.16,   -0.97,    0.00 /
      DATA B(63766), B(63767), B(63768) /    -2.54,   -1.17,    0.00 /
      DATA B(63913), B(63914), B(63915) /    -2.54,   -1.41,    0.00 /
      DATA B(64060), B(64061), B(64062) /    -2.69,   -1.62,    0.00 /
      DATA B(64207), B(64208), B(64209) /    -2.92,   -1.78,    0.00 /
      DATA B(64354), B(64355), B(64356) /    -3.16,   -1.90,    0.00 /
      DATA B(64501), B(64502), B(64503) /    -3.37,   -2.03,    0.00 /
      DATA B(64648), B(64649), B(64650) /    -3.56,   -2.16,    0.00 /
      DATA B(64795), B(64796), B(64797) /    -3.75,   -2.31,    0.00 /
      DATA B(64942), B(64943), B(64944) /    -3.92,   -2.51,    0.00 /
      DATA B(65089), B(65090), B(65091) /    -4.10,   -2.75,    0.00 /
      DATA B(65236), B(65237), B(65238) /    -4.29,   -3.04,    0.00 /
      DATA B(65383), B(65384), B(65385) /    -4.48,   -3.37,    0.00 /
      DATA B(65530), B(65531), B(65532) /    -4.68,   -3.73,    0.00 /
      DATA B(65677), B(65678), B(65679) /    -4.88,   -4.13,    0.00 /
      DATA B(65824), B(65825), B(65826) /    -5.08,   -4.57,    0.00 /
      DATA B(65971), B(65972), B(65973) /    -5.25,   -5.03,    0.00 /
      DATA B(66118), B(66119), B(66120) /    -5.34,   -5.47,    0.00 /
      DATA B(66265), B(66266), B(66267) /    -5.39,   -5.92,    0.00 /
      DATA B(66412), B(66413), B(66414) /    -5.50,   -6.35,    0.00 /
      DATA B(66559), B(66560), B(66561) /    -5.69,   -6.72,    0.00 /
      DATA B(66706), B(66707), B(66708) /    -5.89,   -7.02,    0.00 /
      DATA B(66853), B(66854), B(66855) /    -6.09,   -7.28,    0.00 /
      DATA B(67000), B(67001), B(67002) /    -6.26,   -7.50,    0.00 /
      DATA B(67147), B(67148), B(67149) /    -6.42,   -7.69,    0.00 /
      DATA B(67294), B(67295), B(67296) /    -6.58,   -7.86,    0.00 /
      DATA B(67441), B(67442), B(67443) /    -6.72,   -8.02,    0.00 /
      DATA B(67588), B(67589), B(67590) /    -6.85,   -8.17,    0.00 /
      DATA B(46423), B(46424), B(46425) /    15.88,  -31.55,    0.00 /
      DATA B(46570), B(46571), B(46572) /    15.27,  -30.65,    0.00 /
      DATA B(46717), B(46718), B(46719) /    14.66,  -29.57,    0.00 /
      DATA B(46864), B(46865), B(46866) /    14.00,  -28.21,    0.00 /
      DATA B(47011), B(47012), B(47013) /     9.34,  -23.32,    0.00 /
      DATA B(47158), B(47159), B(47160) /     8.60,  -21.89,    0.00 /
      DATA B(47305), B(47306), B(47307) /     7.98,  -20.37,    0.00 /
      DATA B(47452), B(47453), B(47454) /     7.39,  -18.83,    0.00 /
      DATA B(47599), B(47600), B(47601) /     0.66,   -8.15,    0.00 /
      DATA B(47746), B(47747), B(47748) /     6.04,  -15.37,    0.00 /
      DATA B(47893), B(47894), B(47895) /     5.18,  -14.41,    0.00 /
      DATA B(48040), B(48041), B(48042) /     4.54,  -13.54,    0.00 /
      DATA B(48187), B(48188), B(48189) /     3.97,  -12.87,    0.00 /
      DATA B(48334), B(48335), B(48336) /     3.41,  -12.53,    0.00 /
      DATA B(48481), B(48482), B(48483) /     2.83,  -12.47,    0.00 /
      DATA B(48628), B(48629), B(48630) /     2.18,  -12.63,    0.00 /
      DATA B(48775), B(48776), B(48777) /     0.48,  -12.38,    0.00 /
      DATA B(48922), B(48923), B(48924) /     0.61,  -12.13,    0.00 /
      DATA B(49069), B(49070), B(49071) /     0.82,  -12.04,    0.00 /
      DATA B(49216), B(49217), B(49218) /     0.83,  -11.01,    0.00 /
      DATA B(49363), B(49364), B(49365) /     1.56,   -9.12,    0.00 /
      DATA B(49510), B(49511), B(49512) /     2.09,   -8.69,    0.00 /
      DATA B(49657), B(49658), B(49659) /     2.03,   -8.94,    0.00 /
      DATA B(49804), B(49805), B(49806) /     1.75,   -9.42,    0.00 /
      DATA B(49951), B(49952), B(49953) /     1.37,   -9.94,    0.00 /
      DATA B(50098), B(50099), B(50100) /     0.92,  -10.39,    0.00 /
      DATA B(50245), B(50246), B(50247) /     0.45,  -10.74,    0.00 /
      DATA B(50392), B(50393), B(50394) /    -0.01,  -10.99,    0.00 /
      DATA B(50539), B(50540), B(50541) /    -0.40,  -11.18,    0.00 /
      DATA B(50686), B(50687), B(50688) /    -0.74,  -11.32,    0.00 /
      DATA B(50833), B(50834), B(50835) /    -1.02,  -11.44,    0.00 /
      DATA B(50980), B(50981), B(50982) /    -1.27,  -11.53,    0.00 /
      DATA B(51127), B(51128), B(51129) /    -1.48,  -11.59,    0.00 /
      DATA B(51274), B(51275), B(51276) /    -1.68,  -11.62,    0.00 /
      DATA B(51421), B(51422), B(51423) /    -1.84,  -11.61,    0.00 /
      DATA B(51568), B(51569), B(51570) /    -1.97,  -11.58,    0.00 /
      DATA B(51715), B(51716), B(51717) /    -2.07,  -11.53,    0.00 /
      DATA B(51862), B(51863), B(51864) /    -2.14,  -11.48,    0.00 /
      DATA B(52009), B(52010), B(52011) /    -2.19,  -11.43,    0.00 /
      DATA B(52156), B(52157), B(52158) /    -2.22,  -11.39,    0.00 /
      DATA B(52303), B(52304), B(52305) /    -2.24,  -11.35,    0.00 /
      DATA B(52450), B(52451), B(52452) /    -2.25,  -11.33,    0.00 /
      DATA B(52597), B(52598), B(52599) /    -2.25,  -11.31,    0.00 /
      DATA B(52744), B(52745), B(52746) /    -2.24,  -11.30,    0.00 /
      DATA B(52891), B(52892), B(52893) /    -2.23,  -11.29,    0.00 /
      DATA B(53038), B(53039), B(53040) /    -2.21,  -11.28,    0.00 /
      DATA B(53185), B(53186), B(53187) /    -2.20,  -11.23,    0.00 /
      DATA B(53332), B(53333), B(53334) /    -2.18,  -11.16,    0.00 /
      DATA B(53479), B(53480), B(53481) /    -2.18,  -11.02,    0.00 /
      DATA B(53626), B(53627), B(53628) /    -2.19,  -10.82,    0.00 /
      DATA B(53773), B(53774), B(53775) /    -2.20,  -10.55,    0.00 /
      DATA B(53920), B(53921), B(53922) /    -2.20,  -10.22,    0.00 /
      DATA B(54067), B(54068), B(54069) /    -2.20,   -9.86,    0.00 /
      DATA B(54214), B(54215), B(54216) /    -2.19,   -9.47,    0.00 /
      DATA B(54361), B(54362), B(54363) /    -2.17,   -9.07,    0.00 /
      DATA B(54508), B(54509), B(54510) /    -2.15,   -8.70,    0.00 /
      DATA B(54655), B(54656), B(54657) /    -2.11,   -8.38,    0.00 /
      DATA B(54802), B(54803), B(54804) /    -2.05,   -8.13,    0.00 /
      DATA B(54949), B(54950), B(54951) /    -2.00,   -7.95,    0.00 /
      DATA B(55096), B(55097), B(55098) /    -1.96,   -7.84,    0.00 /
      DATA B(55243), B(55244), B(55245) /    -1.94,   -7.77,    0.00 /
      DATA B(55390), B(55391), B(55392) /    -1.94,   -7.72,    0.00 /
      DATA B(55537), B(55538), B(55539) /    -1.96,   -7.69,    0.00 /
      DATA B(55684), B(55685), B(55686) /    -2.00,   -7.66,    0.00 /
      DATA B(55831), B(55832), B(55833) /    -2.05,   -7.61,    0.00 /
      DATA B(55978), B(55979), B(55980) /    -2.11,   -7.54,    0.00 /
      DATA B(56125), B(56126), B(56127) /    -2.16,   -7.43,    0.00 /
      DATA B(56272), B(56273), B(56274) /    -2.21,   -7.29,    0.00 /
      DATA B(56419), B(56420), B(56421) /    -2.24,   -7.14,    0.00 /
      DATA B(56566), B(56567), B(56568) /    -2.26,   -6.97,    0.00 /
      DATA B(56713), B(56714), B(56715) /    -2.26,   -6.80,    0.00 /
      DATA B(56860), B(56861), B(56862) /    -2.26,   -6.62,    0.00 /
      DATA B(57007), B(57008), B(57009) /    -2.25,   -6.45,    0.00 /
      DATA B(57154), B(57155), B(57156) /    -2.23,   -6.29,    0.00 /
      DATA B(57301), B(57302), B(57303) /    -2.21,   -6.13,    0.00 /
      DATA B(57448), B(57449), B(57450) /    -2.19,   -5.98,    0.00 /
      DATA B(57595), B(57596), B(57597) /    -2.17,   -5.83,    0.00 /
      DATA B(57742), B(57743), B(57744) /    -2.15,   -5.70,    0.00 /
      DATA B(57889), B(57890), B(57891) /    -2.12,   -5.58,    0.00 /
      DATA B(58036), B(58037), B(58038) /    -2.09,   -5.48,    0.00 /
      DATA B(58183), B(58184), B(58185) /    -2.07,   -5.40,    0.00 /
      DATA B(58330), B(58331), B(58332) /    -2.04,   -5.34,    0.00 /
      DATA B(58477), B(58478), B(58479) /    -2.02,   -5.30,    0.00 /
      DATA B(58624), B(58625), B(58626) /    -2.00,   -5.29,    0.00 /
      DATA B(58771), B(58772), B(58773) /    -2.00,   -5.29,    0.00 /
      DATA B(58918), B(58919), B(58920) /    -2.00,   -5.31,    0.00 /
      DATA B(59065), B(59066), B(59067) /    -2.02,   -5.34,    0.00 /
      DATA B(59212), B(59213), B(59214) /    -2.05,   -5.37,    0.00 /
      DATA B(59359), B(59360), B(59361) /    -2.08,   -5.38,    0.00 /
      DATA B(59506), B(59507), B(59508) /    -2.13,   -5.39,    0.00 /
      DATA B(59653), B(59654), B(59655) /    -2.17,   -5.37,    0.00 /
      DATA B(59800), B(59801), B(59802) /    -2.21,   -5.34,    0.00 /
      DATA B(59947), B(59948), B(59949) /    -2.24,   -5.28,    0.00 /
      DATA B(60094), B(60095), B(60096) /    -2.26,   -5.22,    0.00 /
      DATA B(60241), B(60242), B(60243) /    -2.28,   -5.13,    0.00 /
      DATA B(60388), B(60389), B(60390) /    -2.30,   -5.03,    0.00 /
      DATA B(60535), B(60536), B(60537) /    -2.32,   -4.91,    0.00 /
      DATA B(60682), B(60683), B(60684) /    -2.33,   -4.75,    0.00 /
      DATA B(60829), B(60830), B(60831) /    -2.34,   -4.57,    0.00 /
      DATA B(60976), B(60977), B(60978) /    -2.33,   -4.37,    0.00 /
      DATA B(61123), B(61124), B(61125) /    -2.32,   -4.15,    0.00 /
      DATA B(61270), B(61271), B(61272) /    -2.31,   -3.91,    0.00 /
      DATA B(61417), B(61418), B(61419) /    -2.30,   -3.67,    0.00 /
      DATA B(61564), B(61565), B(61566) /    -2.31,   -3.43,    0.00 /
      DATA B(61711), B(61712), B(61713) /    -2.32,   -3.18,    0.00 /
      DATA B(61858), B(61859), B(61860) /    -2.32,   -2.90,    0.00 /
      DATA B(62005), B(62006), B(62007) /    -1.99,   -2.55,    0.00 /
      DATA B(62152), B(62153), B(62154) /    -1.96,   -2.37,    0.00 /
      DATA B(62299), B(62300), B(62301) /    -1.98,   -2.19,    0.00 /
      DATA B(62446), B(62447), B(62448) /    -2.02,   -2.04,    0.00 /
      DATA B(62593), B(62594), B(62595) /    -2.06,   -1.92,    0.00 /
      DATA B(62740), B(62741), B(62742) /    -2.11,   -1.81,    0.00 /
      DATA B(62887), B(62888), B(62889) /    -2.16,   -1.72,    0.00 /
      DATA B(63034), B(63035), B(63036) /    -2.22,   -1.64,    0.00 /
      DATA B(63181), B(63182), B(63183) /    -2.29,   -1.58,    0.00 /
      DATA B(63328), B(63329), B(63330) /    -2.39,   -1.53,    0.00 /
      DATA B(63475), B(63476), B(63477) /    -2.53,   -1.50,    0.00 /
      DATA B(63622), B(63623), B(63624) /    -2.70,   -1.54,    0.00 /
      DATA B(63769), B(63770), B(63771) /    -3.07,   -1.71,    0.00 /
      DATA B(63916), B(63917), B(63918) /    -3.07,   -1.93,    0.00 /
      DATA B(64063), B(64064), B(64065) /    -3.18,   -2.13,    0.00 /
      DATA B(64210), B(64211), B(64212) /    -3.39,   -2.28,    0.00 /
      DATA B(64357), B(64358), B(64359) /    -3.60,   -2.39,    0.00 /
      DATA B(64504), B(64505), B(64506) /    -3.80,   -2.50,    0.00 /
      DATA B(64651), B(64652), B(64653) /    -3.97,   -2.61,    0.00 /
      DATA B(64798), B(64799), B(64800) /    -4.13,   -2.74,    0.00 /
      DATA B(64945), B(64946), B(64947) /    -4.28,   -2.91,    0.00 /
      DATA B(65092), B(65093), B(65094) /    -4.43,   -3.13,    0.00 /
      DATA B(65239), B(65240), B(65241) /    -4.59,   -3.40,    0.00 /
      DATA B(65386), B(65387), B(65388) /    -4.75,   -3.71,    0.00 /
      DATA B(65533), B(65534), B(65535) /    -4.93,   -4.05,    0.00 /
      DATA B(65680), B(65681), B(65682) /    -5.10,   -4.43,    0.00 /
      DATA B(65827), B(65828), B(65829) /    -5.26,   -4.87,    0.00 /
      DATA B(65974), B(65975), B(65976) /    -5.42,   -5.31,    0.00 /
      DATA B(66121), B(66122), B(66123) /    -5.48,   -5.74,    0.00 /
      DATA B(66268), B(66269), B(66270) /    -5.52,   -6.18,    0.00 /
      DATA B(66415), B(66416), B(66417) /    -5.66,   -6.58,    0.00 /
      DATA B(66562), B(66563), B(66564) /    -5.84,   -6.92,    0.00 /
      DATA B(66709), B(66710), B(66711) /    -6.04,   -7.20,    0.00 /
      DATA B(66856), B(66857), B(66858) /    -6.22,   -7.44,    0.00 /
      DATA B(67003), B(67004), B(67005) /    -6.39,   -7.65,    0.00 /
      DATA B(67150), B(67151), B(67152) /    -6.54,   -7.83,    0.00 /
      DATA B(67297), B(67298), B(67299) /    -6.68,   -7.99,    0.00 /
      DATA B(67444), B(67445), B(67446) /    -6.82,   -8.15,    0.00 /
      DATA B(67591), B(67592), B(67593) /    -6.94,   -8.29,    0.00 /
      DATA B(46426), B(46427), B(46428) /    14.65,  -31.10,    0.00 /
      DATA B(46573), B(46574), B(46575) /    14.07,  -30.24,    0.00 /
      DATA B(46720), B(46721), B(46722) /    13.45,  -29.19,    0.00 /
      DATA B(46867), B(46868), B(46869) /     8.77,  -24.75,    0.00 /
      DATA B(47014), B(47015), B(47016) /     7.95,  -23.63,    0.00 /
      DATA B(47161), B(47162), B(47163) /     7.21,  -22.32,    0.00 /
      DATA B(47308), B(47309), B(47310) /     6.51,  -20.88,    0.00 /
      DATA B(47455), B(47456), B(47457) /     5.78,  -19.41,    0.00 /
      DATA B(47602), B(47603), B(47604) /     5.36,  -17.17,    0.00 /
      DATA B(47749), B(47750), B(47751) /     4.38,  -16.25,    0.00 /
      DATA B(47896), B(47897), B(47898) /     3.64,  -15.43,    0.00 /
      DATA B(48043), B(48044), B(48045) /     3.11,  -14.63,    0.00 /
      DATA B(48190), B(48191), B(48192) /     2.56,  -13.96,    0.00 /
      DATA B(48337), B(48338), B(48339) /     1.99,  -13.72,    0.00 /
      DATA B(48484), B(48485), B(48486) /    -0.20,  -14.11,    0.00 /
      DATA B(48631), B(48632), B(48633) /    -0.15,  -13.37,    0.00 /
      DATA B(48778), B(48779), B(48780) /    -0.14,  -12.84,    0.00 /
      DATA B(48925), B(48926), B(48927) /    -0.10,  -12.53,    0.00 /
      DATA B(49072), B(49073), B(49074) /    -0.07,  -12.25,    0.00 /
      DATA B(49219), B(49220), B(49221) /     0.02,  -11.38,    0.00 /
      DATA B(49366), B(49367), B(49368) /     0.58,  -10.22,    0.00 /
      DATA B(49513), B(49514), B(49515) /     1.12,   -9.72,    0.00 /
      DATA B(49660), B(49661), B(49662) /     1.27,   -9.70,    0.00 /
      DATA B(49807), B(49808), B(49809) /     1.16,  -10.02,    0.00 /
      DATA B(49954), B(49955), B(49956) /     0.89,  -10.42,    0.00 /
      DATA B(50101), B(50102), B(50103) /     0.51,  -10.81,    0.00 /
      DATA B(50248), B(50249), B(50250) /     0.10,  -11.12,    0.00 /
      DATA B(50395), B(50396), B(50397) /    -0.31,  -11.35,    0.00 /
      DATA B(50542), B(50543), B(50544) /    -0.68,  -11.53,    0.00 /
      DATA B(50689), B(50690), B(50691) /    -0.99,  -11.66,    0.00 /
      DATA B(50836), B(50837), B(50838) /    -1.26,  -11.77,    0.00 /
      DATA B(50983), B(50984), B(50985) /    -1.49,  -11.86,    0.00 /
      DATA B(51130), B(51131), B(51132) /    -1.70,  -11.91,    0.00 /
      DATA B(51277), B(51278), B(51279) /    -1.89,  -11.94,    0.00 /
      DATA B(51424), B(51425), B(51426) /    -2.05,  -11.93,    0.00 /
      DATA B(51571), B(51572), B(51573) /    -2.17,  -11.90,    0.00 /
      DATA B(51718), B(51719), B(51720) /    -2.27,  -11.85,    0.00 /
      DATA B(51865), B(51866), B(51867) /    -2.34,  -11.80,    0.00 /
      DATA B(52012), B(52013), B(52014) /    -2.39,  -11.75,    0.00 /
      DATA B(52159), B(52160), B(52161) /    -2.43,  -11.70,    0.00 /
      DATA B(52306), B(52307), B(52308) /    -2.45,  -11.66,    0.00 /
      DATA B(52453), B(52454), B(52455) /    -2.46,  -11.63,    0.00 /
      DATA B(52600), B(52601), B(52602) /    -2.46,  -11.60,    0.00 /
      DATA B(52747), B(52748), B(52749) /    -2.46,  -11.58,    0.00 /
      DATA B(52894), B(52895), B(52896) /    -2.45,  -11.55,    0.00 /
      DATA B(53041), B(53042), B(53043) /    -2.44,  -11.52,    0.00 /
      DATA B(53188), B(53189), B(53190) /    -2.43,  -11.46,    0.00 /
      DATA B(53335), B(53336), B(53337) /    -2.43,  -11.37,    0.00 /
      DATA B(53482), B(53483), B(53484) /    -2.44,  -11.23,    0.00 /
      DATA B(53629), B(53630), B(53631) /    -2.45,  -11.03,    0.00 /
      DATA B(53776), B(53777), B(53778) /    -2.47,  -10.78,    0.00 /
      DATA B(53923), B(53924), B(53925) /    -2.48,  -10.47,    0.00 /
      DATA B(54070), B(54071), B(54072) /    -2.48,  -10.13,    0.00 /
      DATA B(54217), B(54218), B(54219) /    -2.47,   -9.76,    0.00 /
      DATA B(54364), B(54365), B(54366) /    -2.46,   -9.40,    0.00 /
      DATA B(54511), B(54512), B(54513) /    -2.44,   -9.05,    0.00 /
      DATA B(54658), B(54659), B(54660) /    -2.39,   -8.75,    0.00 /
      DATA B(54805), B(54806), B(54807) /    -2.34,   -8.51,    0.00 /
      DATA B(54952), B(54953), B(54954) /    -2.28,   -8.34,    0.00 /
      DATA B(55099), B(55100), B(55101) /    -2.23,   -8.23,    0.00 /
      DATA B(55246), B(55247), B(55248) /    -2.21,   -8.16,    0.00 /
      DATA B(55393), B(55394), B(55395) /    -2.21,   -8.11,    0.00 /
      DATA B(55540), B(55541), B(55542) /    -2.23,   -8.09,    0.00 /
      DATA B(55687), B(55688), B(55689) /    -2.26,   -8.06,    0.00 /
      DATA B(55834), B(55835), B(55836) /    -2.31,   -8.01,    0.00 /
      DATA B(55981), B(55982), B(55983) /    -2.37,   -7.94,    0.00 /
      DATA B(56128), B(56129), B(56130) /    -2.42,   -7.85,    0.00 /
      DATA B(56275), B(56276), B(56277) /    -2.47,   -7.72,    0.00 /
      DATA B(56422), B(56423), B(56424) /    -2.51,   -7.58,    0.00 /
      DATA B(56569), B(56570), B(56571) /    -2.53,   -7.43,    0.00 /
      DATA B(56716), B(56717), B(56718) /    -2.54,   -7.27,    0.00 /
      DATA B(56863), B(56864), B(56865) /    -2.54,   -7.11,    0.00 /
      DATA B(57010), B(57011), B(57012) /    -2.54,   -6.95,    0.00 /
      DATA B(57157), B(57158), B(57159) /    -2.53,   -6.80,    0.00 /
      DATA B(57304), B(57305), B(57306) /    -2.52,   -6.65,    0.00 /
      DATA B(57451), B(57452), B(57453) /    -2.50,   -6.50,    0.00 /
      DATA B(57598), B(57599), B(57600) /    -2.48,   -6.37,    0.00 /
      DATA B(57745), B(57746), B(57747) /    -2.46,   -6.24,    0.00 /
      DATA B(57892), B(57893), B(57894) /    -2.44,   -6.13,    0.00 /
      DATA B(58039), B(58040), B(58041) /    -2.41,   -6.03,    0.00 /
      DATA B(58186), B(58187), B(58188) /    -2.39,   -5.94,    0.00 /
      DATA B(58333), B(58334), B(58335) /    -2.37,   -5.88,    0.00 /
      DATA B(58480), B(58481), B(58482) /    -2.35,   -5.83,    0.00 /
      DATA B(58627), B(58628), B(58629) /    -2.33,   -5.81,    0.00 /
      DATA B(58774), B(58775), B(58776) /    -2.33,   -5.80,    0.00 /
      DATA B(58921), B(58922), B(58923) /    -2.33,   -5.80,    0.00 /
      DATA B(59068), B(59069), B(59070) /    -2.34,   -5.80,    0.00 /
      DATA B(59215), B(59216), B(59217) /    -2.36,   -5.81,    0.00 /
      DATA B(59362), B(59363), B(59364) /    -2.39,   -5.81,    0.00 /
      DATA B(59509), B(59510), B(59511) /    -2.43,   -5.80,    0.00 /
      DATA B(59656), B(59657), B(59658) /    -2.47,   -5.77,    0.00 /
      DATA B(59803), B(59804), B(59805) /    -2.50,   -5.73,    0.00 /
      DATA B(59950), B(59951), B(59952) /    -2.53,   -5.68,    0.00 /
      DATA B(60097), B(60098), B(60099) /    -2.56,   -5.61,    0.00 /
      DATA B(60244), B(60245), B(60246) /    -2.59,   -5.53,    0.00 /
      DATA B(60391), B(60392), B(60393) /    -2.61,   -5.42,    0.00 /
      DATA B(60538), B(60539), B(60540) /    -2.64,   -5.30,    0.00 /
      DATA B(60685), B(60686), B(60687) /    -2.66,   -5.15,    0.00 /
      DATA B(60832), B(60833), B(60834) /    -2.68,   -4.98,    0.00 /
      DATA B(60979), B(60980), B(60981) /    -2.70,   -4.78,    0.00 /
      DATA B(61126), B(61127), B(61128) /    -2.71,   -4.57,    0.00 /
      DATA B(61273), B(61274), B(61275) /    -2.72,   -4.35,    0.00 /
      DATA B(61420), B(61421), B(61422) /    -2.74,   -4.12,    0.00 /
      DATA B(61567), B(61568), B(61569) /    -2.78,   -3.89,    0.00 /
      DATA B(61714), B(61715), B(61716) /    -2.84,   -3.65,    0.00 /
      DATA B(61861), B(61862), B(61863) /    -2.92,   -3.37,    0.00 /
      DATA B(62008), B(62009), B(62010) /    -2.29,   -3.05,    0.00 /
      DATA B(62155), B(62156), B(62157) /    -2.38,   -2.90,    0.00 /
      DATA B(62302), B(62303), B(62304) /    -2.47,   -2.74,    0.00 /
      DATA B(62449), B(62450), B(62451) /    -2.54,   -2.60,    0.00 /
      DATA B(62596), B(62597), B(62598) /    -2.59,   -2.49,    0.00 /
      DATA B(62743), B(62744), B(62745) /    -2.64,   -2.39,    0.00 /
      DATA B(62890), B(62891), B(62892) /    -2.69,   -2.30,    0.00 /
      DATA B(63037), B(63038), B(63039) /    -2.74,   -2.22,    0.00 /
      DATA B(63184), B(63185), B(63186) /    -2.81,   -2.15,    0.00 /
      DATA B(63331), B(63332), B(63333) /    -2.90,   -2.10,    0.00 /
      DATA B(63478), B(63479), B(63480) /    -3.02,   -2.07,    0.00 /
      DATA B(63625), B(63626), B(63627) /    -3.18,   -2.09,    0.00 /
      DATA B(63772), B(63773), B(63774) /    -3.23,   -2.25,    0.00 /
      DATA B(63919), B(63920), B(63921) /    -3.56,   -2.42,    0.00 /
      DATA B(64066), B(64067), B(64068) /    -3.63,   -2.62,    0.00 /
      DATA B(64213), B(64214), B(64215) /    -3.81,   -2.76,    0.00 /
      DATA B(64360), B(64361), B(64362) /    -4.02,   -2.86,    0.00 /
      DATA B(64507), B(64508), B(64509) /    -4.19,   -2.95,    0.00 /
      DATA B(64654), B(64655), B(64656) /    -4.35,   -3.05,    0.00 /
      DATA B(64801), B(64802), B(64803) /    -4.48,   -3.16,    0.00 /
      DATA B(64948), B(64949), B(64950) /    -4.61,   -3.31,    0.00 /
      DATA B(65095), B(65096), B(65097) /    -4.74,   -3.50,    0.00 /
      DATA B(65242), B(65243), B(65244) /    -4.87,   -3.74,    0.00 /
      DATA B(65389), B(65390), B(65391) /    -5.01,   -4.03,    0.00 /
      DATA B(65536), B(65537), B(65538) /    -5.16,   -4.36,    0.00 /
      DATA B(65683), B(65684), B(65685) /    -5.32,   -4.74,    0.00 /
      DATA B(65830), B(65831), B(65832) /    -5.47,   -5.19,    0.00 /
      DATA B(65977), B(65978), B(65979) /    -5.58,   -5.58,    0.00 /
      DATA B(66124), B(66125), B(66126) /    -5.61,   -6.00,    0.00 /
      DATA B(66271), B(66272), B(66273) /    -5.66,   -6.42,    0.00 /
      DATA B(66418), B(66419), B(66420) /    -5.81,   -6.79,    0.00 /
      DATA B(66565), B(66566), B(66567) /    -5.99,   -7.11,    0.00 /
      DATA B(66712), B(66713), B(66714) /    -6.18,   -7.37,    0.00 /
      DATA B(66859), B(66860), B(66861) /    -6.35,   -7.60,    0.00 /
      DATA B(67006), B(67007), B(67008) /    -6.50,   -7.79,    0.00 /
      DATA B(67153), B(67154), B(67155) /    -6.65,   -7.97,    0.00 /
      DATA B(67300), B(67301), B(67302) /    -6.79,   -8.12,    0.00 /
      DATA B(67447), B(67448), B(67449) /    -6.92,   -8.27,    0.00 /
      DATA B(67594), B(67595), B(67596) /    -7.04,   -8.40,    0.00 /
      DATA B(46429), B(46430), B(46431) /    13.51,  -30.66,    0.00 /
      DATA B(46576), B(46577), B(46578) /    12.90,  -29.83,    0.00 /
      DATA B(46723), B(46724), B(46725) /     8.23,  -25.75,    0.00 /
      DATA B(46870), B(46871), B(46872) /     7.39,  -24.93,    0.00 /
      DATA B(47017), B(47018), B(47019) /     6.57,  -23.88,    0.00 /
      DATA B(47164), B(47165), B(47166) /     5.77,  -22.64,    0.00 /
      DATA B(47311), B(47312), B(47313) /     4.94,  -21.30,    0.00 /
      DATA B(47458), B(47459), B(47460) /     4.78,  -18.77,    0.00 /
      DATA B(47605), B(47606), B(47607) /     3.69,  -17.88,    0.00 /
      DATA B(47752), B(47753), B(47754) /     2.80,  -17.13,    0.00 /
      DATA B(47899), B(47900), B(47901) /     2.13,  -16.50,    0.00 /
      DATA B(48046), B(48047), B(48048) /     1.71,  -15.74,    0.00 /
      DATA B(48193), B(48194), B(48195) /     1.14,  -14.96,    0.00 /
      DATA B(48340), B(48341), B(48342) /    -0.91,  -15.35,    0.00 /
      DATA B(48487), B(48488), B(48489) /    -0.77,  -14.51,    0.00 /
      DATA B(48634), B(48635), B(48636) /    -0.74,  -13.80,    0.00 /
      DATA B(48781), B(48782), B(48783) /    -0.76,  -13.25,    0.00 /
      DATA B(48928), B(48929), B(48930) /    -0.79,  -12.88,    0.00 /
      DATA B(49075), B(49076), B(49077) /    -0.80,  -12.52,    0.00 /
      DATA B(49222), B(49223), B(49224) /    -0.68,  -11.89,    0.00 /
      DATA B(49369), B(49370), B(49371) /    -0.26,  -11.13,    0.00 /
      DATA B(49516), B(49517), B(49518) /     0.24,  -10.64,    0.00 /
      DATA B(49663), B(49664), B(49665) /     0.56,  -10.50,    0.00 /
      DATA B(49810), B(49811), B(49812) /     0.57,  -10.63,    0.00 /
      DATA B(49957), B(49958), B(49959) /     0.40,  -10.92,    0.00 /
      DATA B(50104), B(50105), B(50106) /     0.11,  -11.22,    0.00 /
      DATA B(50251), B(50252), B(50253) /    -0.25,  -11.49,    0.00 /
      DATA B(50398), B(50399), B(50400) /    -0.61,  -11.69,    0.00 /
      DATA B(50545), B(50546), B(50547) /    -0.95,  -11.85,    0.00 /
      DATA B(50692), B(50693), B(50694) /    -1.24,  -11.97,    0.00 /
      DATA B(50839), B(50840), B(50841) /    -1.49,  -12.07,    0.00 /
      DATA B(50986), B(50987), B(50988) /    -1.71,  -12.14,    0.00 /
      DATA B(51133), B(51134), B(51135) /    -1.91,  -12.19,    0.00 /
      DATA B(51280), B(51281), B(51282) /    -2.09,  -12.21,    0.00 /
      DATA B(51427), B(51428), B(51429) /    -2.24,  -12.20,    0.00 /
      DATA B(51574), B(51575), B(51576) /    -2.36,  -12.17,    0.00 /
      DATA B(51721), B(51722), B(51723) /    -2.45,  -12.13,    0.00 /
      DATA B(51868), B(51869), B(51870) /    -2.53,  -12.08,    0.00 /
      DATA B(52015), B(52016), B(52017) /    -2.58,  -12.03,    0.00 /
      DATA B(52162), B(52163), B(52164) /    -2.62,  -11.97,    0.00 /
      DATA B(52309), B(52310), B(52311) /    -2.64,  -11.93,    0.00 /
      DATA B(52456), B(52457), B(52458) /    -2.66,  -11.89,    0.00 /
      DATA B(52603), B(52604), B(52605) /    -2.66,  -11.85,    0.00 /
      DATA B(52750), B(52751), B(52752) /    -2.66,  -11.81,    0.00 /
      DATA B(52897), B(52898), B(52899) /    -2.66,  -11.78,    0.00 /
      DATA B(53044), B(53045), B(53046) /    -2.66,  -11.73,    0.00 /
      DATA B(53191), B(53192), B(53193) /    -2.66,  -11.66,    0.00 /
      DATA B(53338), B(53339), B(53340) /    -2.66,  -11.56,    0.00 /
      DATA B(53485), B(53486), B(53487) /    -2.67,  -11.42,    0.00 /
      DATA B(53632), B(53633), B(53634) /    -2.69,  -11.23,    0.00 /
      DATA B(53779), B(53780), B(53781) /    -2.71,  -10.99,    0.00 /
      DATA B(53926), B(53927), B(53928) /    -2.73,  -10.70,    0.00 /
      DATA B(54073), B(54074), B(54075) /    -2.73,  -10.37,    0.00 /
      DATA B(54220), B(54221), B(54222) /    -2.73,  -10.03,    0.00 /
      DATA B(54367), B(54368), B(54369) /    -2.72,   -9.69,    0.00 /
      DATA B(54514), B(54515), B(54516) /    -2.69,   -9.37,    0.00 /
      DATA B(54661), B(54662), B(54663) /    -2.65,   -9.09,    0.00 /
      DATA B(54808), B(54809), B(54810) /    -2.59,   -8.86,    0.00 /
      DATA B(54955), B(54956), B(54957) /    -2.53,   -8.70,    0.00 /
      DATA B(55102), B(55103), B(55104) /    -2.49,   -8.58,    0.00 /
      DATA B(55249), B(55250), B(55251) /    -2.46,   -8.51,    0.00 /
      DATA B(55396), B(55397), B(55398) /    -2.46,   -8.47,    0.00 /
      DATA B(55543), B(55544), B(55545) /    -2.47,   -8.44,    0.00 /
      DATA B(55690), B(55691), B(55692) /    -2.50,   -8.41,    0.00 /
      DATA B(55837), B(55838), B(55839) /    -2.54,   -8.37,    0.00 /
      DATA B(55984), B(55985), B(55986) /    -2.60,   -8.30,    0.00 /
      DATA B(56131), B(56132), B(56133) /    -2.65,   -8.22,    0.00 /
      DATA B(56278), B(56279), B(56280) /    -2.70,   -8.10,    0.00 /
      DATA B(56425), B(56426), B(56427) /    -2.74,   -7.98,    0.00 /
      DATA B(56572), B(56573), B(56574) /    -2.77,   -7.83,    0.00 /
      DATA B(56719), B(56720), B(56721) /    -2.78,   -7.69,    0.00 /
      DATA B(56866), B(56867), B(56868) /    -2.79,   -7.54,    0.00 /
      DATA B(57013), B(57014), B(57015) /    -2.79,   -7.39,    0.00 /
      DATA B(57160), B(57161), B(57162) /    -2.78,   -7.24,    0.00 /
      DATA B(57307), B(57308), B(57309) /    -2.77,   -7.10,    0.00 /
      DATA B(57454), B(57455), B(57456) /    -2.76,   -6.96,    0.00 /
      DATA B(57601), B(57602), B(57603) /    -2.75,   -6.84,    0.00 /
      DATA B(57748), B(57749), B(57750) /    -2.73,   -6.71,    0.00 /
      DATA B(57895), B(57896), B(57897) /    -2.71,   -6.60,    0.00 /
      DATA B(58042), B(58043), B(58044) /    -2.69,   -6.51,    0.00 /
      DATA B(58189), B(58190), B(58191) /    -2.67,   -6.42,    0.00 /
      DATA B(58336), B(58337), B(58338) /    -2.65,   -6.36,    0.00 /
      DATA B(58483), B(58484), B(58485) /    -2.63,   -6.30,    0.00 /
      DATA B(58630), B(58631), B(58632) /    -2.62,   -6.27,    0.00 /
      DATA B(58777), B(58778), B(58779) /    -2.61,   -6.24,    0.00 /
      DATA B(58924), B(58925), B(58926) /    -2.61,   -6.23,    0.00 /
      DATA B(59071), B(59072), B(59073) /    -2.62,   -6.22,    0.00 /
      DATA B(59218), B(59219), B(59220) /    -2.64,   -6.21,    0.00 /
      DATA B(59365), B(59366), B(59367) /    -2.67,   -6.19,    0.00 /
      DATA B(59512), B(59513), B(59514) /    -2.70,   -6.17,    0.00 /
      DATA B(59659), B(59660), B(59661) /    -2.73,   -6.14,    0.00 /
      DATA B(59806), B(59807), B(59808) /    -2.76,   -6.09,    0.00 /
      DATA B(59953), B(59954), B(59955) /    -2.79,   -6.03,    0.00 /
      DATA B(60100), B(60101), B(60102) /    -2.82,   -5.96,    0.00 /
      DATA B(60247), B(60248), B(60249) /    -2.85,   -5.88,    0.00 /
      DATA B(60394), B(60395), B(60396) /    -2.88,   -5.77,    0.00 /
      DATA B(60541), B(60542), B(60543) /    -2.92,   -5.65,    0.00 /
      DATA B(60688), B(60689), B(60690) /    -2.95,   -5.51,    0.00 /
      DATA B(60835), B(60836), B(60837) /    -2.98,   -5.34,    0.00 /
      DATA B(60982), B(60983), B(60984) /    -3.00,   -5.16,    0.00 /
      DATA B(61129), B(61130), B(61131) /    -3.03,   -4.96,    0.00 /
      DATA B(61276), B(61277), B(61278) /    -3.06,   -4.75,    0.00 /
      DATA B(61423), B(61424), B(61425) /    -3.11,   -4.53,    0.00 /
      DATA B(61570), B(61571), B(61572) /    -3.17,   -4.31,    0.00 /
      DATA B(61717), B(61718), B(61719) /    -3.25,   -4.07,    0.00 /
      DATA B(61864), B(61865), B(61866) /    -2.47,   -3.57,    0.00 /
      DATA B(62011), B(62012), B(62013) /    -2.77,   -3.57,    0.00 /
      DATA B(62158), B(62159), B(62160) /    -2.82,   -3.38,    0.00 /
      DATA B(62305), B(62306), B(62307) /    -2.91,   -3.25,    0.00 /
      DATA B(62452), B(62453), B(62454) /    -2.99,   -3.13,    0.00 /
      DATA B(62599), B(62600), B(62601) /    -3.05,   -3.02,    0.00 /
      DATA B(62746), B(62747), B(62748) /    -3.10,   -2.93,    0.00 /
      DATA B(62893), B(62894), B(62895) /    -3.15,   -2.84,    0.00 /
      DATA B(63040), B(63041), B(63042) /    -3.20,   -2.76,    0.00 /
      DATA B(63187), B(63188), B(63189) /    -3.27,   -2.69,    0.00 /
      DATA B(63334), B(63335), B(63336) /    -3.35,   -2.64,    0.00 /
      DATA B(63481), B(63482), B(63483) /    -3.46,   -2.61,    0.00 /
      DATA B(63628), B(63629), B(63630) /    -3.60,   -2.61,    0.00 /
      DATA B(63775), B(63776), B(63777) /    -3.76,   -2.69,    0.00 /
      DATA B(63922), B(63923), B(63924) /    -4.01,   -2.89,    0.00 /
      DATA B(64069), B(64070), B(64071) /    -4.05,   -3.07,    0.00 /
      DATA B(64216), B(64217), B(64218) /    -4.20,   -3.21,    0.00 /
      DATA B(64363), B(64364), B(64365) /    -4.39,   -3.31,    0.00 /
      DATA B(64510), B(64511), B(64512) /    -4.56,   -3.38,    0.00 /
      DATA B(64657), B(64658), B(64659) /    -4.70,   -3.46,    0.00 /
      DATA B(64804), B(64805), B(64806) /    -4.82,   -3.56,    0.00 /
      DATA B(64951), B(64952), B(64953) /    -4.93,   -3.69,    0.00 /
      DATA B(65098), B(65099), B(65100) /    -5.03,   -3.86,    0.00 /
      DATA B(65245), B(65246), B(65247) /    -5.14,   -4.08,    0.00 /
      DATA B(65392), B(65393), B(65394) /    -5.26,   -4.35,    0.00 /
      DATA B(65539), B(65540), B(65541) /    -5.39,   -4.66,    0.00 /
      DATA B(65686), B(65687), B(65688) /    -5.52,   -5.03,    0.00 /
      DATA B(65833), B(65834), B(65835) /    -5.64,   -5.45,    0.00 /
      DATA B(65980), B(65981), B(65982) /    -5.72,   -5.85,    0.00 /
      DATA B(66127), B(66128), B(66129) /    -5.74,   -6.25,    0.00 /
      DATA B(66274), B(66275), B(66276) /    -5.81,   -6.65,    0.00 /
      DATA B(66421), B(66422), B(66423) /    -5.96,   -7.00,    0.00 /
      DATA B(66568), B(66569), B(66570) /    -6.14,   -7.29,    0.00 /
      DATA B(66715), B(66716), B(66717) /    -6.31,   -7.54,    0.00 /
      DATA B(66862), B(66863), B(66864) /    -6.47,   -7.75,    0.00 /
      DATA B(67009), B(67010), B(67011) /    -6.62,   -7.93,    0.00 /
      DATA B(67156), B(67157), B(67158) /    -6.76,   -8.10,    0.00 /
      DATA B(67303), B(67304), B(67305) /    -6.89,   -8.24,    0.00 /
      DATA B(67450), B(67451), B(67452) /    -7.01,   -8.38,    0.00 /
      DATA B(67597), B(67598), B(67599) /    -7.13,   -8.51,    0.00 /
      DATA B(46432), B(46433), B(46434) /    12.37,  -30.18,    0.00 /
      DATA B(46579), B(46580), B(46581) /     7.72,  -26.45,    0.00 /
      DATA B(46726), B(46727), B(46728) /     6.88,  -25.86,    0.00 /
      DATA B(46873), B(46874), B(46875) /     6.03,  -25.07,    0.00 /
      DATA B(47020), B(47021), B(47022) /     5.16,  -24.07,    0.00 /
      DATA B(47167), B(47168), B(47169) /     4.27,  -22.89,    0.00 /
      DATA B(47314), B(47315), B(47316) /     4.34,  -20.13,    0.00 /
      DATA B(47461), B(47462), B(47463) /     3.16,  -19.31,    0.00 /
      DATA B(47608), B(47609), B(47610) /     2.16,  -18.60,    0.00 /
      DATA B(47755), B(47756), B(47757) /     1.34,  -18.02,    0.00 /
      DATA B(47902), B(47903), B(47904) /     0.63,  -17.56,    0.00 /
      DATA B(48049), B(48050), B(48051) /     0.03,  -17.14,    0.00 /
      DATA B(48196), B(48197), B(48198) /    -1.58,  -16.53,    0.00 /
      DATA B(48343), B(48344), B(48345) /    -1.37,  -15.70,    0.00 /
      DATA B(48490), B(48491), B(48492) /    -1.27,  -14.91,    0.00 /
      DATA B(48637), B(48638), B(48639) /    -1.28,  -14.21,    0.00 /
      DATA B(48784), B(48785), B(48786) /    -1.34,  -13.65,    0.00 /
      DATA B(48931), B(48932), B(48933) /    -1.39,  -13.24,    0.00 /
      DATA B(49078), B(49079), B(49080) /    -1.40,  -12.89,    0.00 /
      DATA B(49225), B(49226), B(49227) /    -1.29,  -12.45,    0.00 /
      DATA B(49372), B(49373), B(49374) /    -0.98,  -11.93,    0.00 /
      DATA B(49519), B(49520), B(49521) /    -0.51,  -11.53,    0.00 /
      DATA B(49666), B(49667), B(49668) /    -0.19,  -11.28,    0.00 /
      DATA B(49813), B(49814), B(49815) /     0.00,  -11.27,    0.00 /
      DATA B(49960), B(49961), B(49962) /    -0.07,  -11.43,    0.00 /
      DATA B(50107), B(50108), B(50109) /    -0.29,  -11.64,    0.00 /
      DATA B(50254), B(50255), B(50256) /    -0.59,  -11.85,    0.00 /
      DATA B(50401), B(50402), B(50403) /    -0.91,  -12.02,    0.00 /
      DATA B(50548), B(50549), B(50550) /    -1.21,  -12.15,    0.00 /
      DATA B(50695), B(50696), B(50697) /    -1.47,  -12.25,    0.00 /
      DATA B(50842), B(50843), B(50844) /    -1.71,  -12.34,    0.00 /
      DATA B(50989), B(50990), B(50991) /    -1.92,  -12.40,    0.00 /
      DATA B(51136), B(51137), B(51138) /    -2.10,  -12.44,    0.00 /
      DATA B(51283), B(51284), B(51285) /    -2.27,  -12.45,    0.00 /
      DATA B(51430), B(51431), B(51432) /    -2.41,  -12.44,    0.00 /
      DATA B(51577), B(51578), B(51579) /    -2.53,  -12.41,    0.00 /
      DATA B(51724), B(51725), B(51726) /    -2.62,  -12.37,    0.00 /
      DATA B(51871), B(51872), B(51873) /    -2.70,  -12.32,    0.00 /
      DATA B(52018), B(52019), B(52020) /    -2.75,  -12.27,    0.00 /
      DATA B(52165), B(52166), B(52167) /    -2.79,  -12.21,    0.00 /
      DATA B(52312), B(52313), B(52314) /    -2.82,  -12.16,    0.00 /
      DATA B(52459), B(52460), B(52461) /    -2.83,  -12.12,    0.00 /
      DATA B(52606), B(52607), B(52608) /    -2.85,  -12.07,    0.00 /
      DATA B(52753), B(52754), B(52755) /    -2.85,  -12.03,    0.00 /
      DATA B(52900), B(52901), B(52902) /    -2.86,  -11.98,    0.00 /
      DATA B(53047), B(53048), B(53049) /    -2.86,  -11.92,    0.00 /
      DATA B(53194), B(53195), B(53196) /    -2.86,  -11.84,    0.00 /
      DATA B(53341), B(53342), B(53343) /    -2.87,  -11.74,    0.00 /
      DATA B(53488), B(53489), B(53490) /    -2.89,  -11.60,    0.00 /
      DATA B(53635), B(53636), B(53637) /    -2.91,  -11.41,    0.00 /
      DATA B(53782), B(53783), B(53784) /    -2.94,  -11.18,    0.00 /
      DATA B(53929), B(53930), B(53931) /    -2.95,  -10.90,    0.00 /
      DATA B(54076), B(54077), B(54078) /    -2.96,  -10.60,    0.00 /
      DATA B(54223), B(54224), B(54225) /    -2.97,  -10.29,    0.00 /
      DATA B(54370), B(54371), B(54372) /    -2.95,   -9.97,    0.00 /
      DATA B(54517), B(54518), B(54519) /    -2.93,   -9.67,    0.00 /
      DATA B(54664), B(54665), B(54666) /    -2.88,   -9.40,    0.00 /
      DATA B(54811), B(54812), B(54813) /    -2.82,   -9.19,    0.00 /
      DATA B(54958), B(54959), B(54960) /    -2.77,   -9.03,    0.00 /
      DATA B(55105), B(55106), B(55107) /    -2.72,   -8.92,    0.00 /
      DATA B(55252), B(55253), B(55254) /    -2.69,   -8.84,    0.00 /
      DATA B(55399), B(55400), B(55401) /    -2.68,   -8.80,    0.00 /
      DATA B(55546), B(55547), B(55548) /    -2.69,   -8.76,    0.00 /
      DATA B(55693), B(55694), B(55695) /    -2.72,   -8.73,    0.00 /
      DATA B(55840), B(55841), B(55842) /    -2.76,   -8.69,    0.00 /
      DATA B(55987), B(55988), B(55989) /    -2.81,   -8.63,    0.00 /
      DATA B(56134), B(56135), B(56136) /    -2.86,   -8.54,    0.00 /
      DATA B(56281), B(56282), B(56283) /    -2.91,   -8.44,    0.00 /
      DATA B(56428), B(56429), B(56430) /    -2.95,   -8.32,    0.00 /
      DATA B(56575), B(56576), B(56577) /    -2.98,   -8.19,    0.00 /
      DATA B(56722), B(56723), B(56724) /    -3.00,   -8.05,    0.00 /
      DATA B(56869), B(56870), B(56871) /    -3.01,   -7.92,    0.00 /
      DATA B(57016), B(57017), B(57018) /    -3.01,   -7.77,    0.00 /
      DATA B(57163), B(57164), B(57165) /    -3.01,   -7.64,    0.00 /
      DATA B(57310), B(57311), B(57312) /    -3.00,   -7.50,    0.00 /
      DATA B(57457), B(57458), B(57459) /    -2.99,   -7.37,    0.00 /
      DATA B(57604), B(57605), B(57606) /    -2.98,   -7.25,    0.00 /
      DATA B(57751), B(57752), B(57753) /    -2.96,   -7.13,    0.00 /
      DATA B(57898), B(57899), B(57900) /    -2.95,   -7.03,    0.00 /
      DATA B(58045), B(58046), B(58047) /    -2.93,   -6.93,    0.00 /
      DATA B(58192), B(58193), B(58194) /    -2.91,   -6.85,    0.00 /
      DATA B(58339), B(58340), B(58341) /    -2.90,   -6.78,    0.00 /
      DATA B(58486), B(58487), B(58488) /    -2.88,   -6.72,    0.00 /
      DATA B(58633), B(58634), B(58635) /    -2.87,   -6.67,    0.00 /
      DATA B(58780), B(58781), B(58782) /    -2.87,   -6.64,    0.00 /
      DATA B(58927), B(58928), B(58929) /    -2.87,   -6.61,    0.00 /
      DATA B(59074), B(59075), B(59076) /    -2.88,   -6.59,    0.00 /
      DATA B(59221), B(59222), B(59223) /    -2.89,   -6.56,    0.00 /
      DATA B(59368), B(59369), B(59370) /    -2.91,   -6.54,    0.00 /
      DATA B(59515), B(59516), B(59517) /    -2.94,   -6.50,    0.00 /
      DATA B(59662), B(59663), B(59664) /    -2.97,   -6.46,    0.00 /
      DATA B(59809), B(59810), B(59811) /    -3.00,   -6.41,    0.00 /
      DATA B(59956), B(59957), B(59958) /    -3.03,   -6.35,    0.00 /
      DATA B(60103), B(60104), B(60105) /    -3.06,   -6.28,    0.00 /
      DATA B(60250), B(60251), B(60252) /    -3.09,   -6.19,    0.00 /
      DATA B(60397), B(60398), B(60399) /    -3.12,   -6.09,    0.00 /
      DATA B(60544), B(60545), B(60546) /    -3.16,   -5.97,    0.00 /
      DATA B(60691), B(60692), B(60693) /    -3.20,   -5.83,    0.00 /
      DATA B(60838), B(60839), B(60840) /    -3.23,   -5.67,    0.00 /
      DATA B(60985), B(60986), B(60987) /    -3.27,   -5.49,    0.00 /
      DATA B(61132), B(61133), B(61134) /    -3.31,   -5.30,    0.00 /
      DATA B(61279), B(61280), B(61281) /    -3.35,   -5.10,    0.00 /
      DATA B(61426), B(61427), B(61428) /    -3.41,   -4.90,    0.00 /
      DATA B(61573), B(61574), B(61575) /    -3.49,   -4.69,    0.00 /
      DATA B(61720), B(61721), B(61722) /    -3.59,   -4.46,    0.00 /
      DATA B(61867), B(61868), B(61869) /    -2.92,   -4.01,    0.00 /
      DATA B(62014), B(62015), B(62016) /    -2.90,   -3.74,    0.00 /
      DATA B(62161), B(62162), B(62163) /    -3.23,   -3.86,    0.00 /
      DATA B(62308), B(62309), B(62310) /    -3.31,   -3.74,    0.00 /
      DATA B(62455), B(62456), B(62457) /    -3.39,   -3.63,    0.00 /
      DATA B(62602), B(62603), B(62604) /    -3.46,   -3.53,    0.00 /
      DATA B(62749), B(62750), B(62751) /    -3.51,   -3.44,    0.00 /
      DATA B(62896), B(62897), B(62898) /    -3.56,   -3.35,    0.00 /
      DATA B(63043), B(63044), B(63045) /    -3.61,   -3.28,    0.00 /
      DATA B(63190), B(63191), B(63192) /    -3.66,   -3.21,    0.00 /
      DATA B(63337), B(63338), B(63339) /    -3.74,   -3.16,    0.00 /
      DATA B(63484), B(63485), B(63486) /    -3.84,   -3.12,    0.00 /
      DATA B(63631), B(63632), B(63633) /    -3.98,   -3.11,    0.00 /
      DATA B(63778), B(63779), B(63780) /    -4.13,   -3.15,    0.00 /
      DATA B(63925), B(63926), B(63927) /    -4.42,   -3.32,    0.00 /
      DATA B(64072), B(64073), B(64074) /    -4.43,   -3.51,    0.00 /
      DATA B(64219), B(64220), B(64221) /    -4.56,   -3.65,    0.00 /
      DATA B(64366), B(64367), B(64368) /    -4.73,   -3.73,    0.00 /
      DATA B(64513), B(64514), B(64515) /    -4.89,   -3.80,    0.00 /
      DATA B(64660), B(64661), B(64662) /    -5.01,   -3.87,    0.00 /
      DATA B(64807), B(64808), B(64809) /    -5.12,   -3.95,    0.00 /
      DATA B(64954), B(64955), B(64956) /    -5.22,   -4.06,    0.00 /
      DATA B(65101), B(65102), B(65103) /    -5.30,   -4.21,    0.00 /
      DATA B(65248), B(65249), B(65250) /    -5.39,   -4.41,    0.00 /
      DATA B(65395), B(65396), B(65397) /    -5.49,   -4.66,    0.00 /
      DATA B(65542), B(65543), B(65544) /    -5.60,   -4.96,    0.00 /
      DATA B(65689), B(65690), B(65691) /    -5.72,   -5.34,    0.00 /
      DATA B(65836), B(65837), B(65838) /    -5.82,   -5.72,    0.00 /
      DATA B(65983), B(65984), B(65985) /    -5.86,   -6.10,    0.00 /
      DATA B(66130), B(66131), B(66132) /    -5.87,   -6.50,    0.00 /
      DATA B(66277), B(66278), B(66279) /    -5.96,   -6.87,    0.00 /
      DATA B(66424), B(66425), B(66426) /    -6.11,   -7.20,    0.00 /
      DATA B(66571), B(66572), B(66573) /    -6.28,   -7.47,    0.00 /
      DATA B(66718), B(66719), B(66720) /    -6.44,   -7.70,    0.00 /
      DATA B(66865), B(66866), B(66867) /    -6.59,   -7.89,    0.00 /
      DATA B(67012), B(67013), B(67014) /    -6.73,   -8.07,    0.00 /
      DATA B(67159), B(67160), B(67161) /    -6.86,   -8.22,    0.00 /
      DATA B(67306), B(67307), B(67308) /    -6.99,   -8.36,    0.00 /
      DATA B(67453), B(67454), B(67455) /    -7.10,   -8.50,    0.00 /
      DATA B(67600), B(67601), B(67602) /    -7.21,   -8.62,    0.00 /
      DATA B(46435), B(46436), B(46437) /     7.23,  -26.94,    0.00 /
      DATA B(46582), B(46583), B(46584) /     6.38,  -26.52,    0.00 /
      DATA B(46729), B(46730), B(46731) /     5.54,  -25.94,    0.00 /
      DATA B(46876), B(46877), B(46878) /     4.65,  -25.16,    0.00 /
      DATA B(47023), B(47024), B(47025) /     3.70,  -24.17,    0.00 /
      DATA B(47170), B(47171), B(47172) /     4.07,  -21.24,    0.00 /
      DATA B(47317), B(47318), B(47319) /     2.75,  -20.52,    0.00 /
      DATA B(47464), B(47465), B(47466) /     1.64,  -19.87,    0.00 /
      DATA B(47611), B(47612), B(47613) /     0.75,  -19.34,    0.00 /
      DATA B(47758), B(47759), B(47760) /     0.00,  -18.91,    0.00 /
      DATA B(47905), B(47906), B(47907) /    -1.36,  -17.38,    0.00 /
      DATA B(48052), B(48053), B(48054) /    -1.35,  -16.53,    0.00 /
      DATA B(48199), B(48200), B(48201) /    -1.57,  -16.59,    0.00 /
      DATA B(48346), B(48347), B(48348) /    -1.65,  -15.99,    0.00 /
      DATA B(48493), B(48494), B(48495) /    -1.69,  -15.29,    0.00 /
      DATA B(48640), B(48641), B(48642) /    -1.76,  -14.63,    0.00 /
      DATA B(48787), B(48788), B(48789) /    -1.85,  -14.07,    0.00 /
      DATA B(48934), B(48935), B(48936) /    -1.91,  -13.65,    0.00 /
      DATA B(49081), B(49082), B(49083) /    -1.91,  -13.33,    0.00 /
      DATA B(49228), B(49229), B(49230) /    -1.82,  -13.02,    0.00 /
      DATA B(49375), B(49376), B(49377) /    -1.60,  -12.67,    0.00 /
      DATA B(49522), B(49523), B(49524) /    -1.23,  -12.33,    0.00 /
      DATA B(49669), B(49670), B(49671) /    -0.81,  -12.12,    0.00 /
      DATA B(49816), B(49817), B(49818) /    -0.56,  -11.94,    0.00 /
      DATA B(49963), B(49964), B(49965) /    -0.54,  -11.95,    0.00 /
      DATA B(50110), B(50111), B(50112) /    -0.69,  -12.07,    0.00 /
      DATA B(50257), B(50258), B(50259) /    -0.93,  -12.20,    0.00 /
      DATA B(50404), B(50405), B(50406) /    -1.20,  -12.33,    0.00 /
      DATA B(50551), B(50552), B(50553) /    -1.47,  -12.43,    0.00 /
      DATA B(50698), B(50699), B(50700) /    -1.71,  -12.51,    0.00 /
      DATA B(50845), B(50846), B(50847) /    -1.92,  -12.58,    0.00 /
      DATA B(50992), B(50993), B(50994) /    -2.12,  -12.63,    0.00 /
      DATA B(51139), B(51140), B(51141) /    -2.29,  -12.66,    0.00 /
      DATA B(51286), B(51287), B(51288) /    -2.45,  -12.67,    0.00 /
      DATA B(51433), B(51434), B(51435) /    -2.58,  -12.65,    0.00 /
      DATA B(51580), B(51581), B(51582) /    -2.69,  -12.62,    0.00 /
      DATA B(51727), B(51728), B(51729) /    -2.78,  -12.58,    0.00 /
      DATA B(51874), B(51875), B(51876) /    -2.86,  -12.53,    0.00 /
      DATA B(52021), B(52022), B(52023) /    -2.91,  -12.48,    0.00 /
      DATA B(52168), B(52169), B(52170) /    -2.95,  -12.43,    0.00 /
      DATA B(52315), B(52316), B(52317) /    -2.98,  -12.37,    0.00 /
      DATA B(52462), B(52463), B(52464) /    -3.00,  -12.32,    0.00 /
      DATA B(52609), B(52610), B(52611) /    -3.02,  -12.27,    0.00 /
      DATA B(52756), B(52757), B(52758) /    -3.03,  -12.22,    0.00 /
      DATA B(52903), B(52904), B(52905) /    -3.04,  -12.16,    0.00 /
      DATA B(53050), B(53051), B(53052) /    -3.04,  -12.09,    0.00 /
      DATA B(53197), B(53198), B(53199) /    -3.05,  -12.01,    0.00 /
      DATA B(53344), B(53345), B(53346) /    -3.07,  -11.90,    0.00 /
      DATA B(53491), B(53492), B(53493) /    -3.09,  -11.76,    0.00 /
      DATA B(53638), B(53639), B(53640) /    -3.12,  -11.58,    0.00 /
      DATA B(53785), B(53786), B(53787) /    -3.14,  -11.35,    0.00 /
      DATA B(53932), B(53933), B(53934) /    -3.16,  -11.10,    0.00 /
      DATA B(54079), B(54080), B(54081) /    -3.18,  -10.82,    0.00 /
      DATA B(54226), B(54227), B(54228) /    -3.18,  -10.52,    0.00 /
      DATA B(54373), B(54374), B(54375) /    -3.17,  -10.22,    0.00 /
      DATA B(54520), B(54521), B(54522) /    -3.14,   -9.94,    0.00 /
      DATA B(54667), B(54668), B(54669) /    -3.09,   -9.69,    0.00 /
      DATA B(54814), B(54815), B(54816) /    -3.04,   -9.49,    0.00 /
      DATA B(54961), B(54962), B(54963) /    -2.98,   -9.33,    0.00 /
      DATA B(55108), B(55109), B(55110) /    -2.94,   -9.22,    0.00 /
      DATA B(55255), B(55256), B(55257) /    -2.91,   -9.15,    0.00 /
      DATA B(55402), B(55403), B(55404) /    -2.90,   -9.09,    0.00 /
      DATA B(55549), B(55550), B(55551) /    -2.90,   -9.06,    0.00 /
      DATA B(55696), B(55697), B(55698) /    -2.92,   -9.02,    0.00 /
      DATA B(55843), B(55844), B(55845) /    -2.96,   -8.97,    0.00 /
      DATA B(55990), B(55991), B(55992) /    -3.01,   -8.91,    0.00 /
      DATA B(56137), B(56138), B(56139) /    -3.06,   -8.84,    0.00 /
      DATA B(56284), B(56285), B(56286) /    -3.10,   -8.74,    0.00 /
      DATA B(56431), B(56432), B(56433) /    -3.14,   -8.63,    0.00 /
      DATA B(56578), B(56579), B(56580) /    -3.17,   -8.51,    0.00 /
      DATA B(56725), B(56726), B(56727) /    -3.19,   -8.38,    0.00 /
      DATA B(56872), B(56873), B(56874) /    -3.20,   -8.25,    0.00 /
      DATA B(57019), B(57020), B(57021) /    -3.21,   -8.12,    0.00 /
      DATA B(57166), B(57167), B(57168) /    -3.21,   -7.99,    0.00 /
      DATA B(57313), B(57314), B(57315) /    -3.20,   -7.86,    0.00 /
      DATA B(57460), B(57461), B(57462) /    -3.20,   -7.73,    0.00 /
      DATA B(57607), B(57608), B(57609) /    -3.19,   -7.61,    0.00 /
      DATA B(57754), B(57755), B(57756) /    -3.17,   -7.50,    0.00 /
      DATA B(57901), B(57902), B(57903) /    -3.16,   -7.40,    0.00 /
      DATA B(58048), B(58049), B(58050) /    -3.15,   -7.30,    0.00 /
      DATA B(58195), B(58196), B(58197) /    -3.13,   -7.22,    0.00 /
      DATA B(58342), B(58343), B(58344) /    -3.12,   -7.15,    0.00 /
      DATA B(58489), B(58490), B(58491) /    -3.11,   -7.08,    0.00 /
      DATA B(58636), B(58637), B(58638) /    -3.10,   -7.03,    0.00 /
      DATA B(58783), B(58784), B(58785) /    -3.09,   -6.99,    0.00 /
      DATA B(58930), B(58931), B(58932) /    -3.09,   -6.95,    0.00 /
      DATA B(59077), B(59078), B(59079) /    -3.10,   -6.92,    0.00 /
      DATA B(59224), B(59225), B(59226) /    -3.11,   -6.88,    0.00 /
      DATA B(59371), B(59372), B(59373) /    -3.13,   -6.85,    0.00 /
      DATA B(59518), B(59519), B(59520) /    -3.16,   -6.81,    0.00 /
      DATA B(59665), B(59666), B(59667) /    -3.18,   -6.76,    0.00 /
      DATA B(59812), B(59813), B(59814) /    -3.21,   -6.70,    0.00 /
      DATA B(59959), B(59960), B(59961) /    -3.24,   -6.64,    0.00 /
      DATA B(60106), B(60107), B(60108) /    -3.27,   -6.56,    0.00 /
      DATA B(60253), B(60254), B(60255) /    -3.30,   -6.47,    0.00 /
      DATA B(60400), B(60401), B(60402) /    -3.34,   -6.37,    0.00 /
      DATA B(60547), B(60548), B(60549) /    -3.38,   -6.25,    0.00 /
      DATA B(60694), B(60695), B(60696) /    -3.41,   -6.11,    0.00 /
      DATA B(60841), B(60842), B(60843) /    -3.45,   -5.96,    0.00 /
      DATA B(60988), B(60989), B(60990) /    -3.49,   -5.80,    0.00 /
      DATA B(61135), B(61136), B(61137) /    -3.54,   -5.62,    0.00 /
      DATA B(61282), B(61283), B(61284) /    -3.59,   -5.43,    0.00 /
      DATA B(61429), B(61430), B(61431) /    -3.66,   -5.24,    0.00 /
      DATA B(61576), B(61577), B(61578) /    -3.74,   -5.04,    0.00 /
      DATA B(61723), B(61724), B(61725) /    -3.26,   -4.67,    0.00 /
      DATA B(61870), B(61871), B(61872) /    -3.29,   -4.42,    0.00 /
      DATA B(62017), B(62018), B(62019) /    -3.27,   -4.17,    0.00 /
      DATA B(62164), B(62165), B(62166) /    -3.59,   -4.31,    0.00 /
      DATA B(62311), B(62312), B(62313) /    -3.66,   -4.20,    0.00 /
      DATA B(62458), B(62459), B(62460) /    -3.74,   -4.11,    0.00 /
      DATA B(62605), B(62606), B(62607) /    -3.81,   -4.01,    0.00 /
      DATA B(62752), B(62753), B(62754) /    -3.86,   -3.92,    0.00 /
      DATA B(62899), B(62900), B(62901) /    -3.91,   -3.84,    0.00 /
      DATA B(63046), B(63047), B(63048) /    -3.96,   -3.77,    0.00 /
      DATA B(63193), B(63194), B(63195) /    -4.01,   -3.70,    0.00 /
      DATA B(63340), B(63341), B(63342) /    -4.08,   -3.65,    0.00 /
      DATA B(63487), B(63488), B(63489) /    -4.18,   -3.60,    0.00 /
      DATA B(63634), B(63635), B(63636) /    -4.31,   -3.58,    0.00 /
      DATA B(63781), B(63782), B(63783) /    -4.46,   -3.61,    0.00 /
      DATA B(63928), B(63929), B(63930) /    -4.77,   -3.75,    0.00 /
      DATA B(64075), B(64076), B(64077) /    -4.77,   -3.93,    0.00 /
      DATA B(64222), B(64223), B(64224) /    -4.87,   -4.06,    0.00 /
      DATA B(64369), B(64370), B(64371) /    -5.03,   -4.14,    0.00 /
      DATA B(64516), B(64517), B(64518) /    -5.18,   -4.20,    0.00 /
      DATA B(64663), B(64664), B(64665) /    -5.30,   -4.26,    0.00 /
      DATA B(64810), B(64811), B(64812) /    -5.40,   -4.33,    0.00 /
      DATA B(64957), B(64958), B(64959) /    -5.48,   -4.42,    0.00 /
      DATA B(65104), B(65105), B(65106) /    -5.56,   -4.55,    0.00 /
      DATA B(65251), B(65252), B(65253) /    -5.63,   -4.73,    0.00 /
      DATA B(65398), B(65399), B(65400) /    -5.71,   -4.96,    0.00 /
      DATA B(65545), B(65546), B(65547) /    -5.81,   -5.25,    0.00 /
      DATA B(65692), B(65693), B(65694) /    -5.87,   -5.61,    0.00 /
      DATA B(65839), B(65840), B(65841) /    -5.97,   -5.98,    0.00 /
      DATA B(65986), B(65987), B(65988) /    -5.99,   -6.35,    0.00 /
      DATA B(66133), B(66134), B(66135) /    -6.00,   -6.73,    0.00 /
      DATA B(66280), B(66281), B(66282) /    -6.11,   -7.08,    0.00 /
      DATA B(66427), B(66428), B(66429) /    -6.26,   -7.38,    0.00 /
      DATA B(66574), B(66575), B(66576) /    -6.41,   -7.64,    0.00 /
      DATA B(66721), B(66722), B(66723) /    -6.56,   -7.85,    0.00 /
      DATA B(66868), B(66869), B(66870) /    -6.71,   -8.03,    0.00 /
      DATA B(67015), B(67016), B(67017) /    -6.84,   -8.20,    0.00 /
      DATA B(67162), B(67163), B(67164) /    -6.96,   -8.35,    0.00 /
      DATA B(67309), B(67310), B(67311) /    -7.08,   -8.48,    0.00 /
      DATA B(67456), B(67457), B(67458) /    -7.19,   -8.60,    0.00 /
      DATA B(67603), B(67604), B(67605) /    -7.29,   -8.72,    0.00 /
      DATA B(46438), B(46439), B(46440) /     5.94,  -26.99,    0.00 /
      DATA B(46585), B(46586), B(46587) /     5.09,  -26.57,    0.00 /
      DATA B(46732), B(46733), B(46734) /     4.19,  -25.98,    0.00 /
      DATA B(46879), B(46880), B(46881) /     3.22,  -25.16,    0.00 /
      DATA B(47026), B(47027), B(47028) /     3.94,  -22.07,    0.00 /
      DATA B(47173), B(47174), B(47175) /     2.48,  -21.48,    0.00 /
      DATA B(47320), B(47321), B(47322) /     1.25,  -20.93,    0.00 /
      DATA B(47467), B(47468), B(47469) /     0.26,  -20.47,    0.00 /
      DATA B(47614), B(47615), B(47616) /    -0.54,  -20.10,    0.00 /
      DATA B(47761), B(47762), B(47763) /    -1.88,  -18.73,    0.00 /
      DATA B(47908), B(47909), B(47910) /    -1.83,  -17.73,    0.00 /
      DATA B(48055), B(48056), B(48057) /    -1.74,  -16.99,    0.00 /
      DATA B(48202), B(48203), B(48204) /    -1.78,  -16.69,    0.00 /
      DATA B(48349), B(48350), B(48351) /    -1.95,  -16.22,    0.00 /
      DATA B(48496), B(48497), B(48498) /    -2.07,  -15.64,    0.00 /
      DATA B(48643), B(48644), B(48645) /    -2.19,  -15.04,    0.00 /
      DATA B(48790), B(48791), B(48792) /    -2.30,  -14.50,    0.00 /
      DATA B(48937), B(48938), B(48939) /    -2.35,  -14.09,    0.00 /
      DATA B(49084), B(49085), B(49086) /    -2.34,  -13.80,    0.00 /
      DATA B(49231), B(49232), B(49233) /    -2.27,  -13.57,    0.00 /
      DATA B(49378), B(49379), B(49380) /    -2.11,  -13.34,    0.00 /
      DATA B(49525), B(49526), B(49527) /    -1.83,  -13.08,    0.00 /
      DATA B(49672), B(49673), B(49674) /    -1.46,  -12.83,    0.00 /
      DATA B(49819), B(49820), B(49821) /    -1.10,  -12.61,    0.00 /
      DATA B(49966), B(49967), B(49968) /    -1.01,  -12.50,    0.00 /
      DATA B(50113), B(50114), B(50115) /    -1.08,  -12.50,    0.00 /
      DATA B(50260), B(50261), B(50262) /    -1.26,  -12.56,    0.00 /
      DATA B(50407), B(50408), B(50409) /    -1.49,  -12.63,    0.00 /
      DATA B(50554), B(50555), B(50556) /    -1.72,  -12.70,    0.00 /
      DATA B(50701), B(50702), B(50703) /    -1.94,  -12.76,    0.00 /
      DATA B(50848), B(50849), B(50850) /    -2.13,  -12.80,    0.00 /
      DATA B(50995), B(50996), B(50997) /    -2.31,  -12.84,    0.00 /
      DATA B(51142), B(51143), B(51144) /    -2.48,  -12.86,    0.00 /
      DATA B(51289), B(51290), B(51291) /    -2.62,  -12.86,    0.00 /
      DATA B(51436), B(51437), B(51438) /    -2.75,  -12.85,    0.00 /
      DATA B(51583), B(51584), B(51585) /    -2.85,  -12.82,    0.00 /
      DATA B(51730), B(51731), B(51732) /    -2.94,  -12.77,    0.00 /
      DATA B(51877), B(51878), B(51879) /    -3.01,  -12.72,    0.00 /
      DATA B(52024), B(52025), B(52026) /    -3.06,  -12.67,    0.00 /
      DATA B(52171), B(52172), B(52173) /    -3.10,  -12.62,    0.00 /
      DATA B(52318), B(52319), B(52320) /    -3.14,  -12.56,    0.00 /
      DATA B(52465), B(52466), B(52467) /    -3.16,  -12.50,    0.00 /
      DATA B(52612), B(52613), B(52614) /    -3.18,  -12.45,    0.00 /
      DATA B(52759), B(52760), B(52761) /    -3.20,  -12.39,    0.00 /
      DATA B(52906), B(52907), B(52908) /    -3.21,  -12.32,    0.00 /
      DATA B(53053), B(53054), B(53055) /    -3.22,  -12.25,    0.00 /
      DATA B(53200), B(53201), B(53202) /    -3.23,  -12.16,    0.00 /
      DATA B(53347), B(53348), B(53349) /    -3.25,  -12.05,    0.00 /
      DATA B(53494), B(53495), B(53496) /    -3.28,  -11.91,    0.00 /
      DATA B(53641), B(53642), B(53643) /    -3.30,  -11.73,    0.00 /
      DATA B(53788), B(53789), B(53790) /    -3.33,  -11.52,    0.00 /
      DATA B(53935), B(53936), B(53937) /    -3.36,  -11.28,    0.00 /
      DATA B(54082), B(54083), B(54084) /    -3.37,  -11.01,    0.00 /
      DATA B(54229), B(54230), B(54231) /    -3.37,  -10.74,    0.00 /
      DATA B(54376), B(54377), B(54378) /    -3.36,  -10.46,    0.00 /
      DATA B(54523), B(54524), B(54525) /    -3.33,  -10.20,    0.00 /
      DATA B(54670), B(54671), B(54672) /    -3.29,   -9.96,    0.00 /
      DATA B(54817), B(54818), B(54819) /    -3.24,   -9.77,    0.00 /
      DATA B(54964), B(54965), B(54966) /    -3.18,   -9.62,    0.00 /
      DATA B(55111), B(55112), B(55113) /    -3.14,   -9.50,    0.00 /
      DATA B(55258), B(55259), B(55260) /    -3.11,   -9.43,    0.00 /
      DATA B(55405), B(55406), B(55407) /    -3.10,   -9.37,    0.00 /
      DATA B(55552), B(55553), B(55554) /    -3.10,   -9.33,    0.00 /
      DATA B(55699), B(55700), B(55701) /    -3.12,   -9.28,    0.00 /
      DATA B(55846), B(55847), B(55848) /    -3.15,   -9.24,    0.00 /
      DATA B(55993), B(55994), B(55995) /    -3.19,   -9.18,    0.00 /
      DATA B(56140), B(56141), B(56142) /    -3.24,   -9.10,    0.00 /
      DATA B(56287), B(56288), B(56289) /    -3.28,   -9.01,    0.00 /
      DATA B(56434), B(56435), B(56436) /    -3.31,   -8.91,    0.00 /
      DATA B(56581), B(56582), B(56583) /    -3.34,   -8.79,    0.00 /
      DATA B(56728), B(56729), B(56730) /    -3.36,   -8.67,    0.00 /
      DATA B(56875), B(56876), B(56877) /    -3.38,   -8.55,    0.00 /
      DATA B(57022), B(57023), B(57024) /    -3.38,   -8.42,    0.00 /
      DATA B(57169), B(57170), B(57171) /    -3.39,   -8.30,    0.00 /
      DATA B(57316), B(57317), B(57318) /    -3.39,   -8.17,    0.00 /
      DATA B(57463), B(57464), B(57465) /    -3.38,   -8.05,    0.00 /
      DATA B(57610), B(57611), B(57612) /    -3.37,   -7.94,    0.00 /
      DATA B(57757), B(57758), B(57759) /    -3.37,   -7.83,    0.00 /
      DATA B(57904), B(57905), B(57906) /    -3.35,   -7.73,    0.00 /
      DATA B(58051), B(58052), B(58053) /    -3.34,   -7.64,    0.00 /
      DATA B(58198), B(58199), B(58200) /    -3.33,   -7.55,    0.00 /
      DATA B(58345), B(58346), B(58347) /    -3.32,   -7.48,    0.00 /
      DATA B(58492), B(58493), B(58494) /    -3.31,   -7.41,    0.00 /
      DATA B(58639), B(58640), B(58641) /    -3.30,   -7.35,    0.00 /
      DATA B(58786), B(58787), B(58788) /    -3.30,   -7.30,    0.00 /
      DATA B(58933), B(58934), B(58935) /    -3.30,   -7.26,    0.00 /
      DATA B(59080), B(59081), B(59082) /    -3.31,   -7.21,    0.00 /
      DATA B(59227), B(59228), B(59229) /    -3.32,   -7.17,    0.00 /
      DATA B(59374), B(59375), B(59376) /    -3.34,   -7.13,    0.00 /
      DATA B(59521), B(59522), B(59523) /    -3.36,   -7.08,    0.00 /
      DATA B(59668), B(59669), B(59670) /    -3.38,   -7.03,    0.00 /
      DATA B(59815), B(59816), B(59817) /    -3.41,   -6.96,    0.00 /
      DATA B(59962), B(59963), B(59964) /    -3.43,   -6.90,    0.00 /
      DATA B(60109), B(60110), B(60111) /    -3.46,   -6.82,    0.00 /
      DATA B(60256), B(60257), B(60258) /    -3.50,   -6.73,    0.00 /
      DATA B(60403), B(60404), B(60405) /    -3.53,   -6.63,    0.00 /
      DATA B(60550), B(60551), B(60552) /    -3.57,   -6.51,    0.00 /
      DATA B(60697), B(60698), B(60699) /    -3.61,   -6.38,    0.00 /
      DATA B(60844), B(60845), B(60846) /    -3.65,   -6.23,    0.00 /
      DATA B(60991), B(60992), B(60993) /    -3.69,   -6.07,    0.00 /
      DATA B(61138), B(61139), B(61140) /    -3.74,   -5.91,    0.00 /
      DATA B(61285), B(61286), B(61287) /    -3.80,   -5.73,    0.00 /
      DATA B(61432), B(61433), B(61434) /    -3.87,   -5.55,    0.00 /
      DATA B(61579), B(61580), B(61581) /    -3.95,   -5.36,    0.00 /
      DATA B(61726), B(61727), B(61728) /    -3.59,   -5.05,    0.00 /
      DATA B(61873), B(61874), B(61875) /    -3.62,   -4.81,    0.00 /
      DATA B(62020), B(62021), B(62022) /    -3.60,   -4.63,    0.00 /
      DATA B(62167), B(62168), B(62169) /    -3.90,   -4.75,    0.00 /
      DATA B(62314), B(62315), B(62316) /    -3.97,   -4.65,    0.00 /
      DATA B(62461), B(62462), B(62463) /    -4.05,   -4.56,    0.00 /
      DATA B(62608), B(62609), B(62610) /    -4.11,   -4.47,    0.00 /
      DATA B(62755), B(62756), B(62757) /    -4.16,   -4.38,    0.00 /
      DATA B(62902), B(62903), B(62904) /    -4.21,   -4.31,    0.00 /
      DATA B(63049), B(63050), B(63051) /    -4.26,   -4.23,    0.00 /
      DATA B(63196), B(63197), B(63198) /    -4.32,   -4.17,    0.00 /
      DATA B(63343), B(63344), B(63345) /    -4.38,   -4.11,    0.00 /
      DATA B(63490), B(63491), B(63492) /    -4.47,   -4.07,    0.00 /
      DATA B(63637), B(63638), B(63639) /    -4.60,   -4.04,    0.00 /
      DATA B(63784), B(63785), B(63786) /    -4.76,   -4.05,    0.00 /
      DATA B(63931), B(63932), B(63933) /    -5.04,   -4.16,    0.00 /
      DATA B(64078), B(64079), B(64080) /    -5.08,   -4.31,    0.00 /
      DATA B(64225), B(64226), B(64227) /    -5.16,   -4.46,    0.00 /
      DATA B(64372), B(64373), B(64374) /    -5.30,   -4.53,    0.00 /
      DATA B(64519), B(64520), B(64521) /    -5.45,   -4.58,    0.00 /
      DATA B(64666), B(64667), B(64668) /    -5.56,   -4.63,    0.00 /
      DATA B(64813), B(64814), B(64815) /    -5.65,   -4.69,    0.00 /
      DATA B(64960), B(64961), B(64962) /    -5.72,   -4.77,    0.00 /
      DATA B(65107), B(65108), B(65109) /    -5.79,   -4.88,    0.00 /
      DATA B(65254), B(65255), B(65256) /    -5.85,   -5.04,    0.00 /
      DATA B(65401), B(65402), B(65403) /    -5.92,   -5.25,    0.00 /
      DATA B(65548), B(65549), B(65550) /    -6.00,   -5.54,    0.00 /
      DATA B(65695), B(65696), B(65697) /    -6.08,   -5.91,    0.00 /
      DATA B(65842), B(65843), B(65844) /    -6.12,   -6.23,    0.00 /
      DATA B(65989), B(65990), B(65991) /    -6.11,   -6.60,    0.00 /
      DATA B(66136), B(66137), B(66138) /    -6.14,   -6.96,    0.00 /
      DATA B(66283), B(66284), B(66285) /    -6.25,   -7.29,    0.00 /
      DATA B(66430), B(66431), B(66432) /    -6.40,   -7.56,    0.00 /
      DATA B(66577), B(66578), B(66579) /    -6.54,   -7.80,    0.00 /
      DATA B(66724), B(66725), B(66726) /    -6.68,   -8.00,    0.00 /
      DATA B(66871), B(66872), B(66873) /    -6.82,   -8.17,    0.00 /
      DATA B(67018), B(67019), B(67020) /    -6.94,   -8.32,    0.00 /
      DATA B(67165), B(67166), B(67167) /    -7.06,   -8.46,    0.00 /
      DATA B(67312), B(67313), B(67314) /    -7.17,   -8.59,    0.00 /
      DATA B(67459), B(67460), B(67461) /    -7.28,   -8.71,    0.00 /
      DATA B(67606), B(67607), B(67608) /    -7.37,   -8.82,    0.00 /
      DATA B(46441), B(46442), B(46443) /     4.68,  -27.02,    0.00 /
      DATA B(46588), B(46589), B(46590) /     3.78,  -26.58,    0.00 /
      DATA B(46735), B(46736), B(46737) /     2.80,  -25.93,    0.00 /
      DATA B(46882), B(46883), B(46884) /    -4.17,  -14.83,    0.00 /
      DATA B(47029), B(47030), B(47031) /     2.31,  -22.20,    0.00 /
      DATA B(47176), B(47177), B(47178) /     0.98,  -21.75,    0.00 /
      DATA B(47323), B(47324), B(47325) /    -0.12,  -21.38,    0.00 /
      DATA B(47470), B(47471), B(47472) /    -2.32,  -20.96,    0.00 /
      DATA B(47617), B(47618), B(47619) /    -2.38,  -19.92,    0.00 /
      DATA B(47764), B(47765), B(47766) /    -2.35,  -18.95,    0.00 /
      DATA B(47911), B(47912), B(47913) /    -2.27,  -18.06,    0.00 /
      DATA B(48058), B(48059), B(48060) /    -2.18,  -17.36,    0.00 /
      DATA B(48205), B(48206), B(48207) /    -2.22,  -16.85,    0.00 /
      DATA B(48352), B(48353), B(48354) /    -2.32,  -16.47,    0.00 /
      DATA B(48499), B(48500), B(48501) /    -2.46,  -15.96,    0.00 /
      DATA B(48646), B(48647), B(48648) /    -2.60,  -15.42,    0.00 /
      DATA B(48793), B(48794), B(48795) /    -2.70,  -14.91,    0.00 /
      DATA B(48940), B(48941), B(48942) /    -2.74,  -14.52,    0.00 /
      DATA B(49087), B(49088), B(49089) /    -2.72,  -14.26,    0.00 /
      DATA B(49234), B(49235), B(49236) /    -2.65,  -14.08,    0.00 /
      DATA B(49381), B(49382), B(49383) /    -2.54,  -13.93,    0.00 /
      DATA B(49528), B(49529), B(49530) /    -2.34,  -13.74,    0.00 /
      DATA B(49675), B(49676), B(49677) /    -2.03,  -13.50,    0.00 /
      DATA B(49822), B(49823), B(49824) /    -1.68,  -13.31,    0.00 /
      DATA B(49969), B(49970), B(49971) /    -1.49,  -13.05,    0.00 /
      DATA B(50116), B(50117), B(50118) /    -1.46,  -12.94,    0.00 /
      DATA B(50263), B(50264), B(50265) /    -1.58,  -12.91,    0.00 /
      DATA B(50410), B(50411), B(50412) /    -1.77,  -12.92,    0.00 /
      DATA B(50557), B(50558), B(50559) /    -1.97,  -12.95,    0.00 /
      DATA B(50704), B(50705), B(50706) /    -2.16,  -12.98,    0.00 /
      DATA B(50851), B(50852), B(50853) /    -2.34,  -13.01,    0.00 /
      DATA B(50998), B(50999), B(51000) /    -2.51,  -13.03,    0.00 /
      DATA B(51145), B(51146), B(51147) /    -2.66,  -13.04,    0.00 /
      DATA B(51292), B(51293), B(51294) /    -2.79,  -13.04,    0.00 /
      DATA B(51439), B(51440), B(51441) /    -2.91,  -13.02,    0.00 /
      DATA B(51586), B(51587), B(51588) /    -3.01,  -12.99,    0.00 /
      DATA B(51733), B(51734), B(51735) /    -3.09,  -12.95,    0.00 /
      DATA B(51880), B(51881), B(51882) /    -3.16,  -12.90,    0.00 /
      DATA B(52027), B(52028), B(52029) /    -3.21,  -12.84,    0.00 /
      DATA B(52174), B(52175), B(52176) /    -3.25,  -12.79,    0.00 /
      DATA B(52321), B(52322), B(52323) /    -3.29,  -12.73,    0.00 /
      DATA B(52468), B(52469), B(52470) /    -3.31,  -12.67,    0.00 /
      DATA B(52615), B(52616), B(52617) /    -3.33,  -12.61,    0.00 /
      DATA B(52762), B(52763), B(52764) /    -3.35,  -12.54,    0.00 /
      DATA B(52909), B(52910), B(52911) /    -3.37,  -12.47,    0.00 /
      DATA B(53056), B(53057), B(53058) /    -3.38,  -12.40,    0.00 /
      DATA B(53203), B(53204), B(53205) /    -3.40,  -12.30,    0.00 /
      DATA B(53350), B(53351), B(53352) /    -3.42,  -12.19,    0.00 /
      DATA B(53497), B(53498), B(53499) /    -3.45,  -12.05,    0.00 /
      DATA B(53644), B(53645), B(53646) /    -3.48,  -11.88,    0.00 /
      DATA B(53791), B(53792), B(53793) /    -3.51,  -11.68,    0.00 /
      DATA B(53938), B(53939), B(53940) /    -3.53,  -11.45,    0.00 /
      DATA B(54085), B(54086), B(54087) /    -3.55,  -11.20,    0.00 /
      DATA B(54232), B(54233), B(54234) /    -3.55,  -10.94,    0.00 /
      DATA B(54379), B(54380), B(54381) /    -3.54,  -10.68,    0.00 /
      DATA B(54526), B(54527), B(54528) /    -3.51,  -10.44,    0.00 /
      DATA B(54673), B(54674), B(54675) /    -3.47,  -10.21,    0.00 /
      DATA B(54820), B(54821), B(54822) /    -3.42,  -10.03,    0.00 /
      DATA B(54967), B(54968), B(54969) /    -3.37,   -9.88,    0.00 /
      DATA B(55114), B(55115), B(55116) /    -3.33,   -9.77,    0.00 /
      DATA B(55261), B(55262), B(55263) /    -3.30,   -9.69,    0.00 /
      DATA B(55408), B(55409), B(55410) /    -3.28,   -9.62,    0.00 /
      DATA B(55555), B(55556), B(55557) /    -3.28,   -9.57,    0.00 /
      DATA B(55702), B(55703), B(55704) /    -3.30,   -9.53,    0.00 /
      DATA B(55849), B(55850), B(55851) /    -3.33,   -9.48,    0.00 /
      DATA B(55996), B(55997), B(55998) /    -3.37,   -9.42,    0.00 /
      DATA B(56143), B(56144), B(56145) /    -3.41,   -9.34,    0.00 /
      DATA B(56290), B(56291), B(56292) /    -3.44,   -9.25,    0.00 /
      DATA B(56437), B(56438), B(56439) /    -3.48,   -9.16,    0.00 /
      DATA B(56584), B(56585), B(56586) /    -3.51,   -9.05,    0.00 /
      DATA B(56731), B(56732), B(56733) /    -3.53,   -8.93,    0.00 /
      DATA B(56878), B(56879), B(56880) /    -3.54,   -8.81,    0.00 /
      DATA B(57025), B(57026), B(57027) /    -3.55,   -8.69,    0.00 /
      DATA B(57172), B(57173), B(57174) /    -3.56,   -8.58,    0.00 /
      DATA B(57319), B(57320), B(57321) /    -3.56,   -8.46,    0.00 /
      DATA B(57466), B(57467), B(57468) /    -3.55,   -8.34,    0.00 /
      DATA B(57613), B(57614), B(57615) /    -3.55,   -8.23,    0.00 /
      DATA B(57760), B(57761), B(57762) /    -3.54,   -8.13,    0.00 /
      DATA B(57907), B(57908), B(57909) /    -3.53,   -8.03,    0.00 /
      DATA B(58054), B(58055), B(58056) /    -3.52,   -7.94,    0.00 /
      DATA B(58201), B(58202), B(58203) /    -3.51,   -7.85,    0.00 /
      DATA B(58348), B(58349), B(58350) /    -3.51,   -7.78,    0.00 /
      DATA B(58495), B(58496), B(58497) /    -3.50,   -7.71,    0.00 /
      DATA B(58642), B(58643), B(58644) /    -3.49,   -7.64,    0.00 /
      DATA B(58789), B(58790), B(58791) /    -3.49,   -7.59,    0.00 /
      DATA B(58936), B(58937), B(58938) /    -3.49,   -7.53,    0.00 /
      DATA B(59083), B(59084), B(59085) /    -3.50,   -7.48,    0.00 /
      DATA B(59230), B(59231), B(59232) /    -3.51,   -7.44,    0.00 /
      DATA B(59377), B(59378), B(59379) /    -3.52,   -7.38,    0.00 /
      DATA B(59524), B(59525), B(59526) /    -3.54,   -7.33,    0.00 /
      DATA B(59671), B(59672), B(59673) /    -3.56,   -7.27,    0.00 /
      DATA B(59818), B(59819), B(59820) /    -3.59,   -7.21,    0.00 /
      DATA B(59965), B(59966), B(59967) /    -3.62,   -7.14,    0.00 /
      DATA B(60112), B(60113), B(60114) /    -3.65,   -7.05,    0.00 /
      DATA B(60259), B(60260), B(60261) /    -3.68,   -6.96,    0.00 /
      DATA B(60406), B(60407), B(60408) /    -3.71,   -6.86,    0.00 /
      DATA B(60553), B(60554), B(60555) /    -3.75,   -6.75,    0.00 /
      DATA B(60700), B(60701), B(60702) /    -3.79,   -6.62,    0.00 /
      DATA B(60847), B(60848), B(60849) /    -3.83,   -6.48,    0.00 /
      DATA B(60994), B(60995), B(60996) /    -3.87,   -6.33,    0.00 /
      DATA B(61141), B(61142), B(61143) /    -3.92,   -6.17,    0.00 /
      DATA B(61288), B(61289), B(61290) /    -3.97,   -6.00,    0.00 /
      DATA B(61435), B(61436), B(61437) /    -4.02,   -5.83,    0.00 /
      DATA B(61582), B(61583), B(61584) /    -3.83,   -5.59,    0.00 /
      DATA B(61729), B(61730), B(61731) /    -3.87,   -5.39,    0.00 /
      DATA B(61876), B(61877), B(61878) /    -3.90,   -5.19,    0.00 /
      DATA B(62023), B(62024), B(62025) /    -3.89,   -5.02,    0.00 /
      DATA B(62170), B(62171), B(62172) /    -4.17,   -5.16,    0.00 /
      DATA B(62317), B(62318), B(62319) /    -4.24,   -5.07,    0.00 /
      DATA B(62464), B(62465), B(62466) /    -4.32,   -4.98,    0.00 /
      DATA B(62611), B(62612), B(62613) /    -4.38,   -4.90,    0.00 /
      DATA B(62758), B(62759), B(62760) /    -4.43,   -4.82,    0.00 /
      DATA B(62905), B(62906), B(62907) /    -4.48,   -4.75,    0.00 /
      DATA B(63052), B(63053), B(63054) /    -4.53,   -4.68,    0.00 /
      DATA B(63199), B(63200), B(63201) /    -4.58,   -4.61,    0.00 /
      DATA B(63346), B(63347), B(63348) /    -4.65,   -4.56,    0.00 /
      DATA B(63493), B(63494), B(63495) /    -4.74,   -4.51,    0.00 /
      DATA B(63640), B(63641), B(63642) /    -4.85,   -4.48,    0.00 /
      DATA B(63787), B(63788), B(63789) /    -5.00,   -4.47,    0.00 /
      DATA B(63934), B(63935), B(63936) /    -5.13,   -4.52,    0.00 /
      DATA B(64081), B(64082), B(64083) /    -5.37,   -4.68,    0.00 /
      DATA B(64228), B(64229), B(64230) /    -5.41,   -4.82,    0.00 /
      DATA B(64375), B(64376), B(64377) /    -5.54,   -4.90,    0.00 /
      DATA B(64522), B(64523), B(64524) /    -5.68,   -4.94,    0.00 /
      DATA B(64669), B(64670), B(64671) /    -5.79,   -4.98,    0.00 /
      DATA B(64816), B(64817), B(64818) /    -5.88,   -5.03,    0.00 /
      DATA B(64963), B(64964), B(64965) /    -5.94,   -5.10,    0.00 /
      DATA B(65110), B(65111), B(65112) /    -6.00,   -5.20,    0.00 /
      DATA B(65257), B(65258), B(65259) /    -6.05,   -5.34,    0.00 /
      DATA B(65404), B(65405), B(65406) /    -6.10,   -5.54,    0.00 /
      DATA B(65551), B(65552), B(65553) /    -6.17,   -5.81,    0.00 /
      DATA B(65698), B(65699), B(65700) /    -6.22,   -6.15,    0.00 /
      DATA B(65845), B(65846), B(65847) /    -6.25,   -6.48,    0.00 /
      DATA B(65992), B(65993), B(65994) /    -6.23,   -6.83,    0.00 /
      DATA B(66139), B(66140), B(66141) /    -6.28,   -7.18,    0.00 /
      DATA B(66286), B(66287), B(66288) /    -6.40,   -7.48,    0.00 /
      DATA B(66433), B(66434), B(66435) /    -6.53,   -7.74,    0.00 /
      DATA B(66580), B(66581), B(66582) /    -6.67,   -7.95,    0.00 /
      DATA B(66727), B(66728), B(66729) /    -6.80,   -8.14,    0.00 /
      DATA B(66874), B(66875), B(66876) /    -6.92,   -8.30,    0.00 /
      DATA B(67021), B(67022), B(67023) /    -7.04,   -8.45,    0.00 /
      DATA B(67168), B(67169), B(67170) /    -7.15,   -8.58,    0.00 /
      DATA B(67315), B(67316), B(67317) /    -7.26,   -8.70,    0.00 /
      DATA B(67462), B(67463), B(67464) /    -7.36,   -8.81,    0.00 /
      DATA B(67609), B(67610), B(67611) /    -7.45,   -8.92,    0.00 /
      DATA B(46444), B(46445), B(46446) /     3.42,  -27.00,    0.00 /
      DATA B(46591), B(46592), B(46593) /     2.42,  -26.51,    0.00 /
      DATA B(46738), B(46739), B(46740) /     1.33,  -25.85,    0.00 /
      DATA B(46885), B(46886), B(46887) /     2.23,  -22.69,    0.00 /
      DATA B(47032), B(47033), B(47034) /     0.81,  -22.35,    0.00 /
      DATA B(47179), B(47180), B(47181) /    -0.39,  -22.08,    0.00 /
      DATA B(47326), B(47327), B(47328) /    -2.67,  -21.87,    0.00 /
      DATA B(47473), B(47474), B(47475) /    -2.81,  -20.92,    0.00 /
      DATA B(47620), B(47621), B(47622) /    -2.82,  -20.02,    0.00 /
      DATA B(47767), B(47768), B(47769) /    -2.77,  -19.16,    0.00 /
      DATA B(47914), B(47915), B(47916) /    -2.69,  -18.37,    0.00 /
      DATA B(48061), B(48062), B(48063) /    -2.62,  -17.69,    0.00 /
      DATA B(48208), B(48209), B(48210) /    -2.61,  -17.14,    0.00 /
      DATA B(48355), B(48356), B(48357) /    -2.73,  -16.71,    0.00 /
      DATA B(48502), B(48503), B(48504) /    -2.85,  -16.26,    0.00 /
      DATA B(48649), B(48650), B(48651) /    -2.97,  -15.77,    0.00 /
      DATA B(48796), B(48797), B(48798) /    -3.06,  -15.30,    0.00 /
      DATA B(48943), B(48944), B(48945) /    -3.08,  -14.93,    0.00 /
      DATA B(49090), B(49091), B(49092) /    -3.04,  -14.68,    0.00 /
      DATA B(49237), B(49238), B(49239) /    -2.97,  -14.53,    0.00 /
      DATA B(49384), B(49385), B(49386) /    -2.88,  -14.43,    0.00 /
      DATA B(49531), B(49532), B(49533) /    -2.75,  -14.31,    0.00 /
      DATA B(49678), B(49679), B(49680) /    -2.53,  -14.12,    0.00 /
      DATA B(49825), B(49826), B(49827) /    -2.24,  -13.87,    0.00 /
      DATA B(49972), B(49973), B(49974) /    -1.92,  -13.63,    0.00 /
      DATA B(50119), B(50120), B(50121) /    -1.85,  -13.38,    0.00 /
      DATA B(50266), B(50267), B(50268) /    -1.91,  -13.26,    0.00 /
      DATA B(50413), B(50414), B(50415) /    -2.04,  -13.21,    0.00 /
      DATA B(50560), B(50561), B(50562) /    -2.21,  -13.20,    0.00 /
      DATA B(50707), B(50708), B(50709) /    -2.38,  -13.20,    0.00 /
      DATA B(50854), B(50855), B(50856) /    -2.54,  -13.21,    0.00 /
      DATA B(51001), B(51002), B(51003) /    -2.69,  -13.21,    0.00 /
      DATA B(51148), B(51149), B(51150) /    -2.83,  -13.21,    0.00 /
      DATA B(51295), B(51296), B(51297) /    -2.95,  -13.20,    0.00 /
      DATA B(51442), B(51443), B(51444) /    -3.06,  -13.18,    0.00 /
      DATA B(51589), B(51590), B(51591) /    -3.16,  -13.15,    0.00 /
      DATA B(51736), B(51737), B(51738) /    -3.23,  -13.10,    0.00 /
      DATA B(51883), B(51884), B(51885) /    -3.30,  -13.06,    0.00 /
      DATA B(52030), B(52031), B(52032) /    -3.35,  -13.00,    0.00 /
      DATA B(52177), B(52178), B(52179) /    -3.39,  -12.94,    0.00 /
      DATA B(52324), B(52325), B(52326) /    -3.43,  -12.88,    0.00 /
      DATA B(52471), B(52472), B(52473) /    -3.46,  -12.82,    0.00 /
      DATA B(52618), B(52619), B(52620) /    -3.48,  -12.76,    0.00 /
      DATA B(52765), B(52766), B(52767) /    -3.50,  -12.69,    0.00 /
      DATA B(52912), B(52913), B(52914) /    -3.52,  -12.61,    0.00 /
      DATA B(53059), B(53060), B(53061) /    -3.54,  -12.53,    0.00 /
      DATA B(53206), B(53207), B(53208) /    -3.56,  -12.43,    0.00 /
      DATA B(53353), B(53354), B(53355) /    -3.59,  -12.32,    0.00 /
      DATA B(53500), B(53501), B(53502) /    -3.62,  -12.18,    0.00 /
      DATA B(53647), B(53648), B(53649) /    -3.65,  -12.02,    0.00 /
      DATA B(53794), B(53795), B(53796) /    -3.68,  -11.82,    0.00 /
      DATA B(53941), B(53942), B(53943) /    -3.70,  -11.61,    0.00 /
      DATA B(54088), B(54089), B(54090) /    -3.71,  -11.37,    0.00 /
      DATA B(54235), B(54236), B(54237) /    -3.71,  -11.13,    0.00 /
      DATA B(54382), B(54383), B(54384) /    -3.70,  -10.89,    0.00 /
      DATA B(54529), B(54530), B(54531) /    -3.68,  -10.66,    0.00 /
      DATA B(54676), B(54677), B(54678) /    -3.64,  -10.45,    0.00 /
      DATA B(54823), B(54824), B(54825) /    -3.60,  -10.27,    0.00 /
      DATA B(54970), B(54971), B(54972) /    -3.55,  -10.13,    0.00 /
      DATA B(55117), B(55118), B(55119) /    -3.51,  -10.01,    0.00 /
      DATA B(55264), B(55265), B(55266) /    -3.48,   -9.93,    0.00 /
      DATA B(55411), B(55412), B(55413) /    -3.46,   -9.86,    0.00 /
      DATA B(55558), B(55559), B(55560) /    -3.46,   -9.81,    0.00 /
      DATA B(55705), B(55706), B(55707) /    -3.47,   -9.76,    0.00 /
      DATA B(55852), B(55853), B(55854) /    -3.50,   -9.70,    0.00 /
      DATA B(55999), B(56000), B(56001) /    -3.53,   -9.64,    0.00 /
      DATA B(56146), B(56147), B(56148) /    -3.57,   -9.56,    0.00 /
      DATA B(56293), B(56294), B(56295) /    -3.60,   -9.48,    0.00 /
      DATA B(56440), B(56441), B(56442) /    -3.63,   -9.38,    0.00 /
      DATA B(56587), B(56588), B(56589) /    -3.66,   -9.28,    0.00 /
      DATA B(56734), B(56735), B(56736) /    -3.68,   -9.17,    0.00 /
      DATA B(56881), B(56882), B(56883) /    -3.70,   -9.06,    0.00 /
      DATA B(57028), B(57029), B(57030) /    -3.71,   -8.94,    0.00 /
      DATA B(57175), B(57176), B(57177) /    -3.71,   -8.83,    0.00 /
      DATA B(57322), B(57323), B(57324) /    -3.71,   -8.72,    0.00 /
      DATA B(57469), B(57470), B(57471) /    -3.71,   -8.60,    0.00 /
      DATA B(57616), B(57617), B(57618) /    -3.71,   -8.50,    0.00 /
      DATA B(57763), B(57764), B(57765) /    -3.71,   -8.40,    0.00 /
      DATA B(57910), B(57911), B(57912) /    -3.70,   -8.30,    0.00 /
      DATA B(58057), B(58058), B(58059) /    -3.69,   -8.21,    0.00 /
      DATA B(58204), B(58205), B(58206) /    -3.69,   -8.12,    0.00 /
      DATA B(58351), B(58352), B(58353) /    -3.68,   -8.05,    0.00 /
      DATA B(58498), B(58499), B(58500) /    -3.67,   -7.97,    0.00 /
      DATA B(58645), B(58646), B(58647) /    -3.67,   -7.91,    0.00 /
      DATA B(58792), B(58793), B(58794) /    -3.67,   -7.85,    0.00 /
      DATA B(58939), B(58940), B(58941) /    -3.67,   -7.79,    0.00 /
      DATA B(59086), B(59087), B(59088) /    -3.68,   -7.73,    0.00 /
      DATA B(59233), B(59234), B(59235) /    -3.69,   -7.68,    0.00 /
      DATA B(59380), B(59381), B(59382) /    -3.70,   -7.62,    0.00 /
      DATA B(59527), B(59528), B(59529) /    -3.72,   -7.56,    0.00 /
      DATA B(59674), B(59675), B(59676) /    -3.74,   -7.50,    0.00 /
      DATA B(59821), B(59822), B(59823) /    -3.76,   -7.43,    0.00 /
      DATA B(59968), B(59969), B(59970) /    -3.79,   -7.36,    0.00 /
      DATA B(60115), B(60116), B(60117) /    -3.82,   -7.28,    0.00 /
      DATA B(60262), B(60263), B(60264) /    -3.85,   -7.19,    0.00 /
      DATA B(60409), B(60410), B(60411) /    -3.88,   -7.08,    0.00 /
      DATA B(60556), B(60557), B(60558) /    -3.91,   -6.97,    0.00 /
      DATA B(60703), B(60704), B(60705) /    -3.95,   -6.85,    0.00 /
      DATA B(60850), B(60851), B(60852) /    -3.99,   -6.72,    0.00 /
      DATA B(60997), B(60998), B(60999) /    -4.03,   -6.57,    0.00 /
      DATA B(61144), B(61145), B(61146) /    -4.07,   -6.41,    0.00 /
      DATA B(61291), B(61292), B(61293) /    -4.12,   -6.26,    0.00 /
      DATA B(61438), B(61439), B(61440) /    -4.03,   -6.07,    0.00 /
      DATA B(61585), B(61586), B(61587) /    -4.08,   -5.91,    0.00 /
      DATA B(61732), B(61733), B(61734) /    -4.12,   -5.71,    0.00 /
      DATA B(61879), B(61880), B(61881) /    -4.16,   -5.54,    0.00 /
      DATA B(62026), B(62027), B(62028) /    -4.17,   -5.40,    0.00 /
      DATA B(62173), B(62174), B(62175) /    -4.41,   -5.54,    0.00 /
      DATA B(62320), B(62321), B(62322) /    -4.48,   -5.46,    0.00 /
      DATA B(62467), B(62468), B(62469) /    -4.55,   -5.38,    0.00 /
      DATA B(62614), B(62615), B(62616) /    -4.62,   -5.31,    0.00 /
      DATA B(62761), B(62762), B(62763) /    -4.67,   -5.23,    0.00 /
      DATA B(62908), B(62909), B(62910) /    -4.72,   -5.16,    0.00 /
      DATA B(63055), B(63056), B(63057) /    -4.77,   -5.09,    0.00 /
      DATA B(63202), B(63203), B(63204) /    -4.82,   -5.03,    0.00 /
      DATA B(63349), B(63350), B(63351) /    -4.89,   -4.98,    0.00 /
      DATA B(63496), B(63497), B(63498) /    -4.97,   -4.93,    0.00 /
      DATA B(63643), B(63644), B(63645) /    -5.08,   -4.89,    0.00 /
      DATA B(63790), B(63791), B(63792) /    -5.22,   -4.87,    0.00 /
      DATA B(63937), B(63938), B(63939) /    -5.39,   -4.90,    0.00 /
      DATA B(64084), B(64085), B(64086) /    -5.60,   -5.03,    0.00 /
      DATA B(64231), B(64232), B(64233) /    -5.64,   -5.16,    0.00 /
      DATA B(64378), B(64379), B(64380) /    -5.75,   -5.24,    0.00 /
      DATA B(64525), B(64526), B(64527) /    -5.89,   -5.28,    0.00 /
      DATA B(64672), B(64673), B(64674) /    -6.00,   -5.31,    0.00 /
      DATA B(64819), B(64820), B(64821) /    -6.08,   -5.35,    0.00 /
      DATA B(64966), B(64967), B(64968) /    -6.14,   -5.41,    0.00 /
      DATA B(65113), B(65114), B(65115) /    -6.19,   -5.50,    0.00 /
      DATA B(65260), B(65261), B(65262) /    -6.23,   -5.63,    0.00 /
      DATA B(65407), B(65408), B(65409) /    -6.28,   -5.81,    0.00 /
      DATA B(65554), B(65555), B(65556) /    -6.34,   -6.09,    0.00 /
      DATA B(65701), B(65702), B(65703) /    -6.38,   -6.40,    0.00 /
      DATA B(65848), B(65849), B(65850) /    -6.38,   -6.72,    0.00 /
      DATA B(65995), B(65996), B(65997) /    -6.36,   -7.06,    0.00 /
      DATA B(66142), B(66143), B(66144) /    -6.42,   -7.39,    0.00 /
      DATA B(66289), B(66290), B(66291) /    -6.53,   -7.67,    0.00 /
      DATA B(66436), B(66437), B(66438) /    -6.66,   -7.90,    0.00 /
      DATA B(66583), B(66584), B(66585) /    -6.79,   -8.10,    0.00 /
      DATA B(66730), B(66731), B(66732) /    -6.91,   -8.28,    0.00 /
      DATA B(66877), B(66878), B(66879) /    -7.03,   -8.43,    0.00 /
      DATA B(67024), B(67025), B(67026) /    -7.14,   -8.57,    0.00 /
      DATA B(67171), B(67172), B(67173) /    -7.24,   -8.69,    0.00 /
      DATA B(67318), B(67319), B(67320) /    -7.34,   -8.81,    0.00 /
      DATA B(67465), B(67466), B(67467) /    -7.44,   -8.91,    0.00 /
      DATA B(67612), B(67613), B(67614) /    -7.53,   -9.01,    0.00 /
      DATA B(46447), B(46448), B(46449) /     2.08,  -26.92,    0.00 /
      DATA B(46594), B(46595), B(46596) /     0.99,  -26.35,    0.00 /
      DATA B(46741), B(46742), B(46743) /     2.23,  -23.00,    0.00 /
      DATA B(46888), B(46889), B(46890) /     0.73,  -22.76,    0.00 /
      DATA B(47035), B(47036), B(47037) /    -2.52,  -23.49,    0.00 /
      DATA B(47182), B(47183), B(47184) /    -2.92,  -22.58,    0.00 /
      DATA B(47329), B(47330), B(47331) /    -3.14,  -21.73,    0.00 /
      DATA B(47476), B(47477), B(47478) /    -3.23,  -20.91,    0.00 /
      DATA B(47623), B(47624), B(47625) /    -3.22,  -20.12,    0.00 /
      DATA B(47770), B(47771), B(47772) /    -3.17,  -19.36,    0.00 /
      DATA B(47917), B(47918), B(47919) /    -3.10,  -18.64,    0.00 /
      DATA B(48064), B(48065), B(48066) /    -3.04,  -17.99,    0.00 /
      DATA B(48211), B(48212), B(48213) /    -3.04,  -17.43,    0.00 /
      DATA B(48358), B(48359), B(48360) /    -3.14,  -16.98,    0.00 /
      DATA B(48505), B(48506), B(48507) /    -3.22,  -16.54,    0.00 /
      DATA B(48652), B(48653), B(48654) /    -3.32,  -16.09,    0.00 /
      DATA B(48799), B(48800), B(48801) /    -3.38,  -15.66,    0.00 /
      DATA B(48946), B(48947), B(48948) /    -3.38,  -15.31,    0.00 /
      DATA B(49093), B(49094), B(49095) /    -3.32,  -15.07,    0.00 /
      DATA B(49240), B(49241), B(49242) /    -3.25,  -14.94,    0.00 /
      DATA B(49387), B(49388), B(49389) /    -3.17,  -14.87,    0.00 /
      DATA B(49534), B(49535), B(49536) /    -3.09,  -14.79,    0.00 /
      DATA B(49681), B(49682), B(49683) /    -2.94,  -14.65,    0.00 /
      DATA B(49828), B(49829), B(49830) /    -2.70,  -14.42,    0.00 /
      DATA B(49975), B(49976), B(49977) /    -2.45,  -14.17,    0.00 /
      DATA B(50122), B(50123), B(50124) /    -2.25,  -13.86,    0.00 /
      DATA B(50269), B(50270), B(50271) /    -2.23,  -13.63,    0.00 /
      DATA B(50416), B(50417), B(50418) /    -2.32,  -13.50,    0.00 /
      DATA B(50563), B(50564), B(50565) /    -2.45,  -13.44,    0.00 /
      DATA B(50710), B(50711), B(50712) /    -2.59,  -13.41,    0.00 /
      DATA B(50857), B(50858), B(50859) /    -2.74,  -13.39,    0.00 /
      DATA B(51004), B(51005), B(51006) /    -2.88,  -13.38,    0.00 /
      DATA B(51151), B(51152), B(51153) /    -3.00,  -13.37,    0.00 /
      DATA B(51298), B(51299), B(51300) /    -3.12,  -13.35,    0.00 /
      DATA B(51445), B(51446), B(51447) /    -3.22,  -13.33,    0.00 /
      DATA B(51592), B(51593), B(51594) /    -3.30,  -13.29,    0.00 /
      DATA B(51739), B(51740), B(51741) /    -3.38,  -13.25,    0.00 /
      DATA B(51886), B(51887), B(51888) /    -3.44,  -13.20,    0.00 /
      DATA B(52033), B(52034), B(52035) /    -3.49,  -13.15,    0.00 /
      DATA B(52180), B(52181), B(52182) /    -3.53,  -13.09,    0.00 /
      DATA B(52327), B(52328), B(52329) /    -3.57,  -13.03,    0.00 /
      DATA B(52474), B(52475), B(52476) /    -3.60,  -12.96,    0.00 /
      DATA B(52621), B(52622), B(52623) /    -3.62,  -12.89,    0.00 /
      DATA B(52768), B(52769), B(52770) /    -3.65,  -12.82,    0.00 /
      DATA B(52915), B(52916), B(52917) /    -3.67,  -12.74,    0.00 /
      DATA B(53062), B(53063), B(53064) /    -3.69,  -12.66,    0.00 /
      DATA B(53209), B(53210), B(53211) /    -3.71,  -12.56,    0.00 /
      DATA B(53356), B(53357), B(53358) /    -3.74,  -12.44,    0.00 /
      DATA B(53503), B(53504), B(53505) /    -3.77,  -12.31,    0.00 /
      DATA B(53650), B(53651), B(53652) /    -3.80,  -12.15,    0.00 /
      DATA B(53797), B(53798), B(53799) /    -3.83,  -11.96,    0.00 /
      DATA B(53944), B(53945), B(53946) /    -3.85,  -11.76,    0.00 /
      DATA B(54091), B(54092), B(54093) /    -3.87,  -11.54,    0.00 /
      DATA B(54238), B(54239), B(54240) /    -3.87,  -11.31,    0.00 /
      DATA B(54385), B(54386), B(54387) /    -3.86,  -11.08,    0.00 /
      DATA B(54532), B(54533), B(54534) /    -3.84,  -10.87,    0.00 /
      DATA B(54679), B(54680), B(54681) /    -3.80,  -10.67,    0.00 /
      DATA B(54826), B(54827), B(54828) /    -3.76,  -10.50,    0.00 /
      DATA B(54973), B(54974), B(54975) /    -3.72,  -10.36,    0.00 /
      DATA B(55120), B(55121), B(55122) /    -3.68,  -10.24,    0.00 /
      DATA B(55267), B(55268), B(55269) /    -3.65,  -10.16,    0.00 /
      DATA B(55414), B(55415), B(55416) /    -3.63,  -10.08,    0.00 /
      DATA B(55561), B(55562), B(55563) /    -3.63,  -10.02,    0.00 /
      DATA B(55708), B(55709), B(55710) /    -3.64,   -9.97,    0.00 /
      DATA B(55855), B(55856), B(55857) /    -3.66,   -9.91,    0.00 /
      DATA B(56002), B(56003), B(56004) /    -3.69,   -9.84,    0.00 /
      DATA B(56149), B(56150), B(56151) /    -3.72,   -9.77,    0.00 /
      DATA B(56296), B(56297), B(56298) /    -3.75,   -9.69,    0.00 /
      DATA B(56443), B(56444), B(56445) /    -3.78,   -9.59,    0.00 /
      DATA B(56590), B(56591), B(56592) /    -3.81,   -9.49,    0.00 /
      DATA B(56737), B(56738), B(56739) /    -3.83,   -9.39,    0.00 /
      DATA B(56884), B(56885), B(56886) /    -3.84,   -9.28,    0.00 /
      DATA B(57031), B(57032), B(57033) /    -3.85,   -9.17,    0.00 /
      DATA B(57178), B(57179), B(57180) /    -3.86,   -9.06,    0.00 /
      DATA B(57325), B(57326), B(57327) /    -3.86,   -8.95,    0.00 /
      DATA B(57472), B(57473), B(57474) /    -3.86,   -8.84,    0.00 /
      DATA B(57619), B(57620), B(57621) /    -3.86,   -8.74,    0.00 /
      DATA B(57766), B(57767), B(57768) /    -3.86,   -8.64,    0.00 /
      DATA B(57913), B(57914), B(57915) /    -3.86,   -8.54,    0.00 /
      DATA B(58060), B(58061), B(58062) /    -3.85,   -8.46,    0.00 /
      DATA B(58207), B(58208), B(58209) /    -3.85,   -8.37,    0.00 /
      DATA B(58354), B(58355), B(58356) /    -3.84,   -8.29,    0.00 /
      DATA B(58501), B(58502), B(58503) /    -3.84,   -8.22,    0.00 /
      DATA B(58648), B(58649), B(58650) /    -3.84,   -8.15,    0.00 /
      DATA B(58795), B(58796), B(58797) /    -3.84,   -8.08,    0.00 /
      DATA B(58942), B(58943), B(58944) /    -3.84,   -8.02,    0.00 /
      DATA B(59089), B(59090), B(59091) /    -3.84,   -7.96,    0.00 /
      DATA B(59236), B(59237), B(59238) /    -3.85,   -7.90,    0.00 /
      DATA B(59383), B(59384), B(59385) /    -3.87,   -7.84,    0.00 /
      DATA B(59530), B(59531), B(59532) /    -3.88,   -7.78,    0.00 /
      DATA B(59677), B(59678), B(59679) /    -3.90,   -7.71,    0.00 /
      DATA B(59824), B(59825), B(59826) /    -3.93,   -7.64,    0.00 /
      DATA B(59971), B(59972), B(59973) /    -3.95,   -7.57,    0.00 /
      DATA B(60118), B(60119), B(60120) /    -3.98,   -7.48,    0.00 /
      DATA B(60265), B(60266), B(60267) /    -4.01,   -7.39,    0.00 /
      DATA B(60412), B(60413), B(60414) /    -4.04,   -7.29,    0.00 /
      DATA B(60559), B(60560), B(60561) /    -4.07,   -7.18,    0.00 /
      DATA B(60706), B(60707), B(60708) /    -4.11,   -7.07,    0.00 /
      DATA B(60853), B(60854), B(60855) /    -4.14,   -6.94,    0.00 /
      DATA B(61000), B(61001), B(61002) /    -4.18,   -6.79,    0.00 /
      DATA B(61147), B(61148), B(61149) /    -4.22,   -6.64,    0.00 /
      DATA B(61294), B(61295), B(61296) /    -4.26,   -6.49,    0.00 /
      DATA B(61441), B(61442), B(61443) /    -4.24,   -6.34,    0.00 /
      DATA B(61588), B(61589), B(61590) /    -4.29,   -6.19,    0.00 /
      DATA B(61735), B(61736), B(61737) /    -4.34,   -6.02,    0.00 /
      DATA B(61882), B(61883), B(61884) /    -4.39,   -5.88,    0.00 /
      DATA B(62029), B(62030), B(62031) /    -4.38,   -5.76,    0.00 /
      DATA B(62176), B(62177), B(62178) /    -4.62,   -5.90,    0.00 /
      DATA B(62323), B(62324), B(62325) /    -4.69,   -5.83,    0.00 /
      DATA B(62470), B(62471), B(62472) /    -4.77,   -5.76,    0.00 /
      DATA B(62617), B(62618), B(62619) /    -4.83,   -5.68,    0.00 /
      DATA B(62764), B(62765), B(62766) /    -4.89,   -5.61,    0.00 /
      DATA B(62911), B(62912), B(62913) /    -4.94,   -5.55,    0.00 /
      DATA B(63058), B(63059), B(63060) /    -4.99,   -5.48,    0.00 /
      DATA B(63205), B(63206), B(63207) /    -5.04,   -5.42,    0.00 /
      DATA B(63352), B(63353), B(63354) /    -5.10,   -5.37,    0.00 /
      DATA B(63499), B(63500), B(63501) /    -5.18,   -5.32,    0.00 /
      DATA B(63646), B(63647), B(63648) /    -5.28,   -5.27,    0.00 /
      DATA B(63793), B(63794), B(63795) /    -5.42,   -5.24,    0.00 /
      DATA B(63940), B(63941), B(63942) /    -5.57,   -5.25,    0.00 /
      DATA B(64087), B(64088), B(64089) /    -5.85,   -5.35,    0.00 /
      DATA B(64234), B(64235), B(64236) /    -5.86,   -5.48,    0.00 /
      DATA B(64381), B(64382), B(64383) /    -5.94,   -5.56,    0.00 /
      DATA B(64528), B(64529), B(64530) /    -6.07,   -5.60,    0.00 /
      DATA B(64675), B(64676), B(64677) /    -6.18,   -5.63,    0.00 /
      DATA B(64822), B(64823), B(64824) /    -6.26,   -5.66,    0.00 /
      DATA B(64969), B(64970), B(64971) /    -6.32,   -5.71,    0.00 /
      DATA B(65116), B(65117), B(65118) /    -6.37,   -5.79,    0.00 /
      DATA B(65263), B(65264), B(65265) /    -6.40,   -5.91,    0.00 /
      DATA B(65410), B(65411), B(65412) /    -6.44,   -6.08,    0.00 /
      DATA B(65557), B(65558), B(65559) /    -6.52,   -6.73,    0.00 /
      DATA B(65704), B(65705), B(65706) /    -6.52,   -6.63,    0.00 /
      DATA B(65851), B(65852), B(65853) /    -6.50,   -6.95,    0.00 /
      DATA B(65998), B(65999), B(66000) /    -6.49,   -7.28,    0.00 /
      DATA B(66145), B(66146), B(66147) /    -6.56,   -7.59,    0.00 /
      DATA B(66292), B(66293), B(66294) /    -6.67,   -7.85,    0.00 /
      DATA B(66439), B(66440), B(66441) /    -6.79,   -8.06,    0.00 /
      DATA B(66586), B(66587), B(66588) /    -6.90,   -8.25,    0.00 /
      DATA B(66733), B(66734), B(66735) /    -7.02,   -8.41,    0.00 /
      DATA B(66880), B(66881), B(66882) /    -7.13,   -8.55,    0.00 /
      DATA B(67027), B(67028), B(67029) /    -7.23,   -8.68,    0.00 /
      DATA B(67174), B(67175), B(67176) /    -7.33,   -8.80,    0.00 /
      DATA B(67321), B(67322), B(67323) /    -7.42,   -8.91,    0.00 /
      DATA B(67468), B(67469), B(67470) /    -7.51,   -9.01,    0.00 /
      DATA B(67615), B(67616), B(67617) /    -7.60,   -9.11,    0.00 /
      DATA B(46450), B(46451), B(46452) /     0.66,  -26.75,    0.00 /
      DATA B(46597), B(46598), B(46599) /     2.26,  -23.17,    0.00 /
      DATA B(46744), B(46745), B(46746) /    -1.91,  -24.84,    0.00 /
      DATA B(46891), B(46892), B(46893) /    -2.59,  -23.94,    0.00 /
      DATA B(47038), B(47039), B(47040) /    -3.07,  -23.12,    0.00 /
      DATA B(47185), B(47186), B(47187) /    -3.37,  -22.36,    0.00 /
      DATA B(47332), B(47333), B(47334) /    -3.53,  -21.63,    0.00 /
      DATA B(47479), B(47480), B(47481) /    -3.59,  -20.92,    0.00 /
      DATA B(47626), B(47627), B(47628) /    -3.58,  -20.22,    0.00 /
      DATA B(47773), B(47774), B(47775) /    -3.54,  -19.54,    0.00 /
      DATA B(47920), B(47921), B(47922) /    -3.48,  -18.88,    0.00 /
      DATA B(48067), B(48068), B(48069) /    -3.44,  -18.27,    0.00 /
      DATA B(48214), B(48215), B(48216) /    -3.43,  -17.72,    0.00 /
      DATA B(48361), B(48362), B(48363) /    -3.48,  -17.20,    0.00 /
      DATA B(48508), B(48509), B(48510) /    -3.59,  -16.81,    0.00 /
      DATA B(48655), B(48656), B(48657) /    -3.64,  -16.39,    0.00 /
      DATA B(48802), B(48803), B(48804) /    -3.67,  -15.98,    0.00 /
      DATA B(48949), B(48950), B(48951) /    -3.64,  -15.65,    0.00 /
      DATA B(49096), B(49097), B(49098) /    -3.57,  -15.42,    0.00 /
      DATA B(49243), B(49244), B(49245) /    -3.49,  -15.30,    0.00 /
      DATA B(49390), B(49391), B(49392) /    -3.42,  -15.24,    0.00 /
      DATA B(49537), B(49538), B(49539) /    -3.36,  -15.19,    0.00 /
      DATA B(49684), B(49685), B(49686) /    -3.27,  -15.10,    0.00 /
      DATA B(49831), B(49832), B(49833) /    -3.12,  -14.91,    0.00 /
      DATA B(49978), B(49979), B(49980) /    -2.88,  -14.62,    0.00 /
      DATA B(50125), B(50126), B(50127) /    -2.67,  -14.39,    0.00 /
      DATA B(50272), B(50273), B(50274) /    -2.57,  -14.00,    0.00 /
      DATA B(50419), B(50420), B(50421) /    -2.59,  -13.79,    0.00 /
      DATA B(50566), B(50567), B(50568) /    -2.69,  -13.67,    0.00 /
      DATA B(50713), B(50714), B(50715) /    -2.81,  -13.60,    0.00 /
      DATA B(50860), B(50861), B(50862) /    -2.93,  -13.56,    0.00 /
      DATA B(51007), B(51008), B(51009) /    -3.06,  -13.54,    0.00 /
      DATA B(51154), B(51155), B(51156) /    -3.17,  -13.52,    0.00 /
      DATA B(51301), B(51302), B(51303) /    -3.28,  -13.50,    0.00 /
      DATA B(51448), B(51449), B(51450) /    -3.37,  -13.47,    0.00 /
      DATA B(51595), B(51596), B(51597) /    -3.45,  -13.43,    0.00 /
      DATA B(51742), B(51743), B(51744) /    -3.52,  -13.39,    0.00 /
      DATA B(51889), B(51890), B(51891) /    -3.57,  -13.34,    0.00 /
      DATA B(52036), B(52037), B(52038) /    -3.62,  -13.28,    0.00 /
      DATA B(52183), B(52184), B(52185) /    -3.67,  -13.22,    0.00 /
      DATA B(52330), B(52331), B(52332) /    -3.70,  -13.16,    0.00 /
      DATA B(52477), B(52478), B(52479) /    -3.73,  -13.09,    0.00 /
      DATA B(52624), B(52625), B(52626) /    -3.76,  -13.02,    0.00 /
      DATA B(52771), B(52772), B(52773) /    -3.79,  -12.95,    0.00 /
      DATA B(52918), B(52919), B(52920) /    -3.81,  -12.87,    0.00 /
      DATA B(53065), B(53066), B(53067) /    -3.83,  -12.78,    0.00 /
      DATA B(53212), B(53213), B(53214) /    -3.86,  -12.68,    0.00 /
      DATA B(53359), B(53360), B(53361) /    -3.89,  -12.56,    0.00 /
      DATA B(53506), B(53507), B(53508) /    -3.92,  -12.43,    0.00 /
      DATA B(53653), B(53654), B(53655) /    -3.95,  -12.27,    0.00 /
      DATA B(53800), B(53801), B(53802) /    -3.98,  -12.09,    0.00 /
      DATA B(53947), B(53948), B(53949) /    -4.00,  -11.90,    0.00 /
      DATA B(54094), B(54095), B(54096) /    -4.01,  -11.69,    0.00 /
      DATA B(54241), B(54242), B(54243) /    -4.01,  -11.48,    0.00 /
      DATA B(54388), B(54389), B(54390) /    -4.00,  -11.27,    0.00 /
      DATA B(54535), B(54536), B(54537) /    -3.98,  -11.06,    0.00 /
      DATA B(54682), B(54683), B(54684) /    -3.95,  -10.88,    0.00 /
      DATA B(54829), B(54830), B(54831) /    -3.91,  -10.71,    0.00 /
      DATA B(54976), B(54977), B(54978) /    -3.87,  -10.57,    0.00 /
      DATA B(55123), B(55124), B(55125) /    -3.84,  -10.46,    0.00 /
      DATA B(55270), B(55271), B(55272) /    -3.81,  -10.37,    0.00 /
      DATA B(55417), B(55418), B(55419) /    -3.80,  -10.29,    0.00 /
      DATA B(55564), B(55565), B(55566) /    -3.79,  -10.23,    0.00 /
      DATA B(55711), B(55712), B(55713) /    -3.80,  -10.17,    0.00 /
      DATA B(55858), B(55859), B(55860) /    -3.82,  -10.10,    0.00 /
      DATA B(56005), B(56006), B(56007) /    -3.84,  -10.04,    0.00 /
      DATA B(56152), B(56153), B(56154) /    -3.87,   -9.96,    0.00 /
      DATA B(56299), B(56300), B(56301) /    -3.90,   -9.88,    0.00 /
      DATA B(56446), B(56447), B(56448) /    -3.92,   -9.79,    0.00 /
      DATA B(56593), B(56594), B(56595) /    -3.95,   -9.69,    0.00 /
      DATA B(56740), B(56741), B(56742) /    -3.97,   -9.59,    0.00 /
      DATA B(56887), B(56888), B(56889) /    -3.98,   -9.48,    0.00 /
      DATA B(57034), B(57035), B(57036) /    -3.99,   -9.38,    0.00 /
      DATA B(57181), B(57182), B(57183) /    -4.00,   -9.27,    0.00 /
      DATA B(57328), B(57329), B(57330) /    -4.01,   -9.17,    0.00 /
      DATA B(57475), B(57476), B(57477) /    -4.01,   -9.06,    0.00 /
      DATA B(57622), B(57623), B(57624) /    -4.01,   -8.96,    0.00 /
      DATA B(57769), B(57770), B(57771) /    -4.01,   -8.86,    0.00 /
      DATA B(57916), B(57917), B(57918) /    -4.01,   -8.77,    0.00 /
      DATA B(58063), B(58064), B(58065) /    -4.00,   -8.68,    0.00 /
      DATA B(58210), B(58211), B(58212) /    -4.00,   -8.60,    0.00 /
      DATA B(58357), B(58358), B(58359) /    -4.00,   -8.52,    0.00 /
      DATA B(58504), B(58505), B(58506) /    -3.99,   -8.44,    0.00 /
      DATA B(58651), B(58652), B(58653) /    -3.99,   -8.37,    0.00 /
      DATA B(58798), B(58799), B(58800) /    -3.99,   -8.31,    0.00 /
      DATA B(58945), B(58946), B(58947) /    -4.00,   -8.24,    0.00 /
      DATA B(59092), B(59093), B(59094) /    -4.00,   -8.18,    0.00 /
      DATA B(59239), B(59240), B(59241) /    -4.01,   -8.11,    0.00 /
      DATA B(59386), B(59387), B(59388) /    -4.03,   -8.05,    0.00 /
      DATA B(59533), B(59534), B(59535) /    -4.04,   -7.98,    0.00 /
      DATA B(59680), B(59681), B(59682) /    -4.06,   -7.91,    0.00 /
      DATA B(59827), B(59828), B(59829) /    -4.08,   -7.84,    0.00 /
      DATA B(59974), B(59975), B(59976) /    -4.11,   -7.76,    0.00 /
      DATA B(60121), B(60122), B(60123) /    -4.13,   -7.68,    0.00 /
      DATA B(60268), B(60269), B(60270) /    -4.16,   -7.59,    0.00 /
      DATA B(60415), B(60416), B(60417) /    -4.19,   -7.49,    0.00 /
      DATA B(60562), B(60563), B(60564) /    -4.22,   -7.38,    0.00 /
      DATA B(60709), B(60710), B(60711) /    -4.26,   -7.27,    0.00 /
      DATA B(60856), B(60857), B(60858) /    -4.29,   -7.14,    0.00 /
      DATA B(61003), B(61004), B(61005) /    -4.33,   -7.00,    0.00 /
      DATA B(61150), B(61151), B(61152) /    -4.35,   -6.82,    0.00 /
      DATA B(61297), B(61298), B(61299) /    -4.40,   -6.73,    0.00 /
      DATA B(61444), B(61445), B(61446) /    -4.43,   -6.60,    0.00 /
      DATA B(61591), B(61592), B(61593) /    -4.48,   -6.46,    0.00 /
      DATA B(61738), B(61739), B(61740) /    -4.54,   -6.32,    0.00 /
      DATA B(61885), B(61886), B(61887) /    -4.59,   -6.19,    0.00 /
      DATA B(62032), B(62033), B(62034) /    -4.60,   -6.09,    0.00 /
      DATA B(62179), B(62180), B(62181) /    -4.82,   -6.22,    0.00 /
      DATA B(62326), B(62327), B(62328) /    -4.89,   -6.17,    0.00 /
      DATA B(62473), B(62474), B(62475) /    -4.96,   -6.10,    0.00 /
      DATA B(62620), B(62621), B(62622) /    -5.03,   -6.04,    0.00 /
      DATA B(62767), B(62768), B(62769) /    -5.08,   -5.97,    0.00 /
      DATA B(62914), B(62915), B(62916) /    -5.13,   -5.91,    0.00 /
      DATA B(63061), B(63062), B(63063) /    -5.18,   -5.84,    0.00 /
      DATA B(63208), B(63209), B(63210) /    -5.24,   -5.79,    0.00 /
      DATA B(63355), B(63356), B(63357) /    -5.30,   -5.73,    0.00 /
      DATA B(63502), B(63503), B(63504) /    -5.37,   -5.68,    0.00 /
      DATA B(63649), B(63650), B(63651) /    -5.47,   -5.63,    0.00 /
      DATA B(63796), B(63797), B(63798) /    -5.60,   -5.60,    0.00 /
      DATA B(63943), B(63944), B(63945) /    -5.75,   -5.59,    0.00 /
      DATA B(64090), B(64091), B(64092) /    -6.02,   -5.66,    0.00 /
      DATA B(64237), B(64238), B(64239) /    -6.05,   -5.77,    0.00 /
      DATA B(64384), B(64385), B(64386) /    -6.11,   -5.86,    0.00 /
      DATA B(64531), B(64532), B(64533) /    -6.23,   -5.90,    0.00 /
      DATA B(64678), B(64679), B(64680) /    -6.34,   -5.92,    0.00 /
      DATA B(64825), B(64826), B(64827) /    -6.42,   -5.95,    0.00 /
      DATA B(64972), B(64973), B(64974) /    -6.48,   -5.99,    0.00 /
      DATA B(65119), B(65120), B(65121) /    -6.52,   -6.06,    0.00 /
      DATA B(65266), B(65267), B(65268) /    -6.56,   -6.17,    0.00 /
      DATA B(65413), B(65414), B(65415) /    -6.60,   -6.34,    0.00 /
      DATA B(65560), B(65561), B(65562) /    -6.63,   -6.63,    0.00 /
      DATA B(65707), B(65708), B(65709) /    -6.67,   -6.87,    0.00 /
      DATA B(65854), B(65855), B(65856) /    -6.63,   -7.18,    0.00 /
      DATA B(66001), B(66002), B(66003) /    -6.63,   -7.50,    0.00 /
      DATA B(66148), B(66149), B(66150) /    -6.70,   -7.78,    0.00 /
      DATA B(66295), B(66296), B(66297) /    -6.80,   -8.02,    0.00 /
      DATA B(66442), B(66443), B(66444) /    -6.91,   -8.22,    0.00 /
      DATA B(66589), B(66590), B(66591) /    -7.02,   -8.39,    0.00 /
      DATA B(66736), B(66737), B(66738) /    -7.12,   -8.54,    0.00 /
      DATA B(66883), B(66884), B(66885) /    -7.22,   -8.67,    0.00 /
      DATA B(67030), B(67031), B(67032) /    -7.32,   -8.80,    0.00 /
      DATA B(67177), B(67178), B(67179) /    -7.41,   -8.91,    0.00 /
      DATA B(67324), B(67325), B(67326) /    -7.50,   -9.01,    0.00 /
      DATA B(67471), B(67472), B(67473) /    -7.59,   -9.11,    0.00 /
      DATA B(67618), B(67619), B(67620) /    -7.67,   -9.20,    0.00 /
      DATA B(46453), B(46454), B(46455) /    -1.11,  -26.07,    0.00 /
      DATA B(46600), B(46601), B(46602) /    -1.96,  -25.10,    0.00 /
      DATA B(46747), B(46748), B(46749) /    -2.65,  -24.26,    0.00 /
      DATA B(46894), B(46895), B(46896) /    -3.17,  -23.52,    0.00 /
      DATA B(47041), B(47042), B(47043) /    -3.53,  -22.84,    0.00 /
      DATA B(47188), B(47189), B(47190) /    -3.75,  -22.19,    0.00 /
      DATA B(47335), B(47336), B(47337) /    -3.86,  -21.56,    0.00 /
      DATA B(47482), B(47483), B(47484) /    -3.91,  -20.94,    0.00 /
      DATA B(47629), B(47630), B(47631) /    -3.90,  -20.32,    0.00 /
      DATA B(47776), B(47777), B(47778) /    -3.87,  -19.71,    0.00 /
      DATA B(47923), B(47924), B(47925) /    -3.84,  -19.11,    0.00 /
      DATA B(48070), B(48071), B(48072) /    -3.81,  -18.53,    0.00 /
      DATA B(48217), B(48218), B(48219) /    -3.81,  -17.99,    0.00 /
      DATA B(48364), B(48365), B(48366) /    -3.85,  -17.49,    0.00 /
      DATA B(48511), B(48512), B(48513) /    -3.89,  -17.09,    0.00 /
      DATA B(48658), B(48659), B(48660) /    -3.93,  -16.67,    0.00 /
      DATA B(48805), B(48806), B(48807) /    -3.93,  -16.29,    0.00 /
      DATA B(48952), B(48953), B(48954) /    -3.88,  -15.96,    0.00 /
      DATA B(49099), B(49100), B(49101) /    -3.79,  -15.74,    0.00 /
      DATA B(49246), B(49247), B(49248) /    -3.70,  -15.62,    0.00 /
      DATA B(49393), B(49394), B(49395) /    -3.63,  -15.56,    0.00 /
      DATA B(49540), B(49541), B(49542) /    -3.58,  -15.53,    0.00 /
      DATA B(49687), B(49688), B(49689) /    -3.54,  -15.47,    0.00 /
      DATA B(49834), B(49835), B(49836) /    -3.45,  -15.32,    0.00 /
      DATA B(49981), B(49982), B(49983) /    -3.29,  -15.07,    0.00 /
      DATA B(50128), B(50129), B(50130) /    -3.10,  -14.73,    0.00 /
      DATA B(50275), B(50276), B(50277) /    -2.89,  -14.41,    0.00 /
      DATA B(50422), B(50423), B(50424) /    -2.87,  -14.09,    0.00 /
      DATA B(50569), B(50570), B(50571) /    -2.92,  -13.91,    0.00 /
      DATA B(50716), B(50717), B(50718) /    -3.02,  -13.79,    0.00 /
      DATA B(50863), B(50864), B(50865) /    -3.13,  -13.73,    0.00 /
      DATA B(51010), B(51011), B(51012) /    -3.24,  -13.69,    0.00 /
      DATA B(51157), B(51158), B(51159) /    -3.34,  -13.66,    0.00 /
      DATA B(51304), B(51305), B(51306) /    -3.43,  -13.63,    0.00 /
      DATA B(51451), B(51452), B(51453) /    -3.52,  -13.60,    0.00 /
      DATA B(51598), B(51599), B(51600) /    -3.59,  -13.56,    0.00 /
      DATA B(51745), B(51746), B(51747) /    -3.65,  -13.51,    0.00 /
      DATA B(51892), B(51893), B(51894) /    -3.71,  -13.46,    0.00 /
      DATA B(52039), B(52040), B(52041) /    -3.76,  -13.41,    0.00 /
      DATA B(52186), B(52187), B(52188) /    -3.80,  -13.35,    0.00 /
      DATA B(52333), B(52334), B(52335) /    -3.83,  -13.28,    0.00 /
      DATA B(52480), B(52481), B(52482) /    -3.87,  -13.21,    0.00 /
      DATA B(52627), B(52628), B(52629) /    -3.89,  -13.14,    0.00 /
      DATA B(52774), B(52775), B(52776) /    -3.92,  -13.06,    0.00 /
      DATA B(52921), B(52922), B(52923) /    -3.95,  -12.98,    0.00 /
      DATA B(53068), B(53069), B(53070) /    -3.97,  -12.89,    0.00 /
      DATA B(53215), B(53216), B(53217) /    -4.00,  -12.79,    0.00 /
      DATA B(53362), B(53363), B(53364) /    -4.03,  -12.67,    0.00 /
      DATA B(53509), B(53510), B(53511) /    -4.06,  -12.54,    0.00 /
      DATA B(53656), B(53657), B(53658) /    -4.09,  -12.39,    0.00 /
      DATA B(53803), B(53804), B(53805) /    -4.11,  -12.22,    0.00 /
      DATA B(53950), B(53951), B(53952) /    -4.13,  -12.04,    0.00 /
      DATA B(54097), B(54098), B(54099) /    -4.15,  -11.84,    0.00 /
      DATA B(54244), B(54245), B(54246) /    -4.15,  -11.64,    0.00 /
      DATA B(54391), B(54392), B(54393) /    -4.14,  -11.44,    0.00 /
      DATA B(54538), B(54539), B(54540) /    -4.12,  -11.25,    0.00 /
      DATA B(54685), B(54686), B(54687) /    -4.09,  -11.07,    0.00 /
      DATA B(54832), B(54833), B(54834) /    -4.06,  -10.91,    0.00 /
      DATA B(54979), B(54980), B(54981) /    -4.02,  -10.78,    0.00 /
      DATA B(55126), B(55127), B(55128) /    -3.99,  -10.66,    0.00 /
      DATA B(55273), B(55274), B(55275) /    -3.97,  -10.57,    0.00 /
      DATA B(55420), B(55421), B(55422) /    -3.95,  -10.49,    0.00 /
      DATA B(55567), B(55568), B(55569) /    -3.95,  -10.42,    0.00 /
      DATA B(55714), B(55715), B(55716) /    -3.95,  -10.35,    0.00 /
      DATA B(55861), B(55862), B(55863) /    -3.97,  -10.29,    0.00 /
      DATA B(56008), B(56009), B(56010) /    -3.99,  -10.22,    0.00 /
      DATA B(56155), B(56156), B(56157) /    -4.01,  -10.14,    0.00 /
      DATA B(56302), B(56303), B(56304) /    -4.04,  -10.06,    0.00 /
      DATA B(56449), B(56450), B(56451) /    -4.06,   -9.97,    0.00 /
      DATA B(56596), B(56597), B(56598) /    -4.08,   -9.88,    0.00 /
      DATA B(56743), B(56744), B(56745) /    -4.10,   -9.78,    0.00 /
      DATA B(56890), B(56891), B(56892) /    -4.12,   -9.68,    0.00 /
      DATA B(57037), B(57038), B(57039) /    -4.13,   -9.57,    0.00 /
      DATA B(57184), B(57185), B(57186) /    -4.14,   -9.47,    0.00 /
      DATA B(57331), B(57332), B(57333) /    -4.14,   -9.37,    0.00 /
      DATA B(57478), B(57479), B(57480) /    -4.15,   -9.26,    0.00 /
      DATA B(57625), B(57626), B(57627) /    -4.15,   -9.17,    0.00 /
      DATA B(57772), B(57773), B(57774) /    -4.15,   -9.07,    0.00 /
      DATA B(57919), B(57920), B(57921) /    -4.15,   -8.98,    0.00 /
      DATA B(58066), B(58067), B(58068) /    -4.15,   -8.89,    0.00 /
      DATA B(58213), B(58214), B(58215) /    -4.14,   -8.81,    0.00 /
      DATA B(58360), B(58361), B(58362) /    -4.14,   -8.73,    0.00 /
      DATA B(58507), B(58508), B(58509) /    -4.14,   -8.65,    0.00 /
      DATA B(58654), B(58655), B(58656) /    -4.14,   -8.58,    0.00 /
      DATA B(58801), B(58802), B(58803) /    -4.14,   -8.51,    0.00 /
      DATA B(58948), B(58949), B(58950) /    -4.15,   -8.44,    0.00 /
      DATA B(59095), B(59096), B(59097) /    -4.16,   -8.38,    0.00 /
      DATA B(59242), B(59243), B(59244) /    -4.16,   -8.31,    0.00 /
      DATA B(59389), B(59390), B(59391) /    -4.18,   -8.24,    0.00 /
      DATA B(59536), B(59537), B(59538) /    -4.19,   -8.18,    0.00 /
      DATA B(59683), B(59684), B(59685) /    -4.21,   -8.10,    0.00 /
      DATA B(59830), B(59831), B(59832) /    -4.23,   -8.03,    0.00 /
      DATA B(59977), B(59978), B(59979) /    -4.26,   -7.95,    0.00 /
      DATA B(60124), B(60125), B(60126) /    -4.28,   -7.87,    0.00 /
      DATA B(60271), B(60272), B(60273) /    -4.31,   -7.78,    0.00 /
      DATA B(60418), B(60419), B(60420) /    -4.34,   -7.68,    0.00 /
      DATA B(60565), B(60566), B(60567) /    -4.37,   -7.57,    0.00 /
      DATA B(60712), B(60713), B(60714) /    -4.41,   -7.46,    0.00 /
      DATA B(60859), B(60860), B(60861) /    -4.44,   -7.34,    0.00 /
      DATA B(61006), B(61007), B(61008) /    -4.47,   -7.20,    0.00 /
      DATA B(61153), B(61154), B(61155) /    -4.50,   -7.08,    0.00 /
      DATA B(61300), B(61301), B(61302) /    -4.55,   -6.97,    0.00 /
      DATA B(61447), B(61448), B(61449) /    -4.60,   -6.85,    0.00 /
      DATA B(61594), B(61595), B(61596) /    -4.66,   -6.71,    0.00 /
      DATA B(61741), B(61742), B(61743) /    -4.73,   -6.59,    0.00 /
      DATA B(61888), B(61889), B(61890) /    -4.78,   -6.48,    0.00 /
      DATA B(62035), B(62036), B(62037) /    -4.78,   -6.40,    0.00 /
      DATA B(62182), B(62183), B(62184) /    -5.00,   -6.53,    0.00 /
      DATA B(62329), B(62330), B(62331) /    -5.07,   -6.48,    0.00 /
      DATA B(62476), B(62477), B(62478) /    -5.14,   -6.43,    0.00 /
      DATA B(62623), B(62624), B(62625) /    -5.21,   -6.37,    0.00 /
      DATA B(62770), B(62771), B(62772) /    -5.27,   -6.30,    0.00 /
      DATA B(62917), B(62918), B(62919) /    -5.32,   -6.24,    0.00 /
      DATA B(63064), B(63065), B(63066) /    -5.37,   -6.18,    0.00 /
      DATA B(63211), B(63212), B(63213) /    -5.42,   -6.13,    0.00 /
      DATA B(63358), B(63359), B(63360) /    -5.48,   -6.07,    0.00 /
      DATA B(63505), B(63506), B(63507) /    -5.55,   -6.02,    0.00 /
      DATA B(63652), B(63653), B(63654) /    -5.64,   -5.97,    0.00 /
      DATA B(63799), B(63800), B(63801) /    -5.76,   -5.93,    0.00 /
      DATA B(63946), B(63947), B(63948) /    -5.91,   -5.90,    0.00 /
      DATA B(64093), B(64094), B(64095) /    -6.02,   -5.94,    0.00 /
      DATA B(64240), B(64241), B(64242) /    -6.23,   -6.04,    0.00 /
      DATA B(64387), B(64388), B(64389) /    -6.27,   -6.14,    0.00 /
      DATA B(64534), B(64535), B(64536) /    -6.38,   -6.18,    0.00 /
      DATA B(64681), B(64682), B(64683) /    -6.49,   -6.20,    0.00 /
      DATA B(64828), B(64829), B(64830) /    -6.57,   -6.22,    0.00 /
      DATA B(64975), B(64976), B(64977) /    -6.63,   -6.26,    0.00 /
      DATA B(65122), B(65123), B(65124) /    -6.67,   -6.32,    0.00 /
      DATA B(65269), B(65270), B(65271) /    -6.70,   -6.43,    0.00 /
      DATA B(65416), B(65417), B(65418) /    -6.74,   -6.59,    0.00 /
      DATA B(65563), B(65564), B(65565) /    -6.75,   -6.84,    0.00 /
      DATA B(65710), B(65711), B(65712) /    -6.77,   -7.11,    0.00 /
      DATA B(65857), B(65858), B(65859) /    -6.74,   -7.41,    0.00 /
      DATA B(66004), B(66005), B(66006) /    -6.75,   -7.71,    0.00 /
      DATA B(66151), B(66152), B(66153) /    -6.82,   -7.97,    0.00 /
      DATA B(66298), B(66299), B(66300) /    -6.92,   -8.19,    0.00 /
      DATA B(66445), B(66446), B(66447) /    -7.02,   -8.37,    0.00 /
      DATA B(66592), B(66593), B(66594) /    -7.12,   -8.53,    0.00 /
      DATA B(66739), B(66740), B(66741) /    -7.22,   -8.67,    0.00 /
      DATA B(66886), B(66887), B(66888) /    -7.31,   -8.79,    0.00 /
      DATA B(67033), B(67034), B(67035) /    -7.40,   -8.91,    0.00 /
      DATA B(67180), B(67181), B(67182) /    -7.49,   -9.01,    0.00 /
      DATA B(67327), B(67328), B(67329) /    -7.58,   -9.11,    0.00 /
      DATA B(67474), B(67475), B(67476) /    -7.66,   -9.20,    0.00 /
      DATA B(67621), B(67622), B(67623) /    -7.73,   -9.29,    0.00 /
      DATA B(46456), B(46457), B(46458) /    -2.06,  -25.35,    0.00 /
      DATA B(46603), B(46604), B(46605) /    -2.75,  -24.54,    0.00 /
      DATA B(46750), B(46751), B(46752) /    -3.26,  -23.83,    0.00 /
      DATA B(46897), B(46898), B(46899) /    -3.63,  -23.20,    0.00 /
      DATA B(47044), B(47045), B(47046) /    -3.89,  -22.62,    0.00 /
      DATA B(47191), B(47192), B(47193) /    -4.06,  -22.06,    0.00 /
      DATA B(47338), B(47339), B(47340) /    -4.15,  -21.51,    0.00 /
      DATA B(47485), B(47486), B(47487) /    -4.19,  -20.97,    0.00 /
      DATA B(47632), B(47633), B(47634) /    -4.19,  -20.42,    0.00 /
      DATA B(47779), B(47780), B(47781) /    -4.18,  -19.87,    0.00 /
      DATA B(47926), B(47927), B(47928) /    -4.16,  -19.32,    0.00 /
      DATA B(48073), B(48074), B(48075) /    -4.15,  -18.77,    0.00 /
      DATA B(48220), B(48221), B(48222) /    -4.14,  -18.25,    0.00 /
      DATA B(48367), B(48368), B(48369) /    -4.15,  -17.76,    0.00 /
      DATA B(48514), B(48515), B(48516) /    -4.23,  -17.34,    0.00 /
      DATA B(48661), B(48662), B(48663) /    -4.20,  -16.93,    0.00 /
      DATA B(48808), B(48809), B(48810) /    -4.16,  -16.56,    0.00 /
      DATA B(48955), B(48956), B(48957) /    -4.08,  -16.25,    0.00 /
      DATA B(49102), B(49103), B(49104) /    -3.98,  -16.03,    0.00 /
      DATA B(49249), B(49250), B(49251) /    -3.89,  -15.90,    0.00 /
      DATA B(49396), B(49397), B(49398) /    -3.82,  -15.84,    0.00 /
      DATA B(49543), B(49544), B(49545) /    -3.78,  -15.82,    0.00 /
      DATA B(49690), B(49691), B(49692) /    -3.75,  -15.77,    0.00 /
      DATA B(49837), B(49838), B(49839) /    -3.72,  -15.66,    0.00 /
      DATA B(49984), B(49985), B(49986) /    -3.63,  -15.44,    0.00 /
      DATA B(50131), B(50132), B(50133) /    -3.44,  -15.13,    0.00 /
      DATA B(50278), B(50279), B(50280) /    -3.25,  -14.79,    0.00 /
      DATA B(50425), B(50426), B(50427) /    -3.15,  -14.41,    0.00 /
      DATA B(50572), B(50573), B(50574) /    -3.16,  -14.14,    0.00 /
      DATA B(50719), B(50720), B(50721) /    -3.23,  -13.98,    0.00 /
      DATA B(50866), B(50867), B(50868) /    -3.32,  -13.89,    0.00 /
      DATA B(51013), B(51014), B(51015) /    -3.41,  -13.83,    0.00 /
      DATA B(51160), B(51161), B(51162) /    -3.50,  -13.79,    0.00 /
      DATA B(51307), B(51308), B(51309) /    -3.59,  -13.76,    0.00 /
      DATA B(51454), B(51455), B(51456) /    -3.66,  -13.72,    0.00 /
      DATA B(51601), B(51602), B(51603) /    -3.73,  -13.68,    0.00 /
      DATA B(51748), B(51749), B(51750) /    -3.79,  -13.64,    0.00 /
      DATA B(51895), B(51896), B(51897) /    -3.84,  -13.58,    0.00 /
      DATA B(52042), B(52043), B(52044) /    -3.89,  -13.53,    0.00 /
      DATA B(52189), B(52190), B(52191) /    -3.93,  -13.46,    0.00 /
      DATA B(52336), B(52337), B(52338) /    -3.96,  -13.40,    0.00 /
      DATA B(52483), B(52484), B(52485) /    -3.99,  -13.33,    0.00 /
      DATA B(52630), B(52631), B(52632) /    -4.02,  -13.25,    0.00 /
      DATA B(52777), B(52778), B(52779) /    -4.05,  -13.18,    0.00 /
      DATA B(52924), B(52925), B(52926) /    -4.08,  -13.09,    0.00 /
      DATA B(53071), B(53072), B(53073) /    -4.10,  -13.00,    0.00 /
      DATA B(53218), B(53219), B(53220) /    -4.13,  -12.89,    0.00 /
      DATA B(53365), B(53366), B(53367) /    -4.16,  -12.78,    0.00 /
      DATA B(53512), B(53513), B(53514) /    -4.19,  -12.65,    0.00 /
      DATA B(53659), B(53660), B(53661) /    -4.22,  -12.50,    0.00 /
      DATA B(53806), B(53807), B(53808) /    -4.24,  -12.34,    0.00 /
      DATA B(53953), B(53954), B(53955) /    -4.26,  -12.17,    0.00 /
      DATA B(54100), B(54101), B(54102) /    -4.28,  -11.98,    0.00 /
      DATA B(54247), B(54248), B(54249) /    -4.28,  -11.79,    0.00 /
      DATA B(54394), B(54395), B(54396) /    -4.27,  -11.60,    0.00 /
      DATA B(54541), B(54542), B(54543) /    -4.25,  -11.42,    0.00 /
      DATA B(54688), B(54689), B(54690) /    -4.23,  -11.25,    0.00 /
      DATA B(54835), B(54836), B(54837) /    -4.20,  -11.10,    0.00 /
      DATA B(54982), B(54983), B(54984) /    -4.17,  -10.97,    0.00 /
      DATA B(55129), B(55130), B(55131) /    -4.14,  -10.86,    0.00 /
      DATA B(55276), B(55277), B(55278) /    -4.11,  -10.76,    0.00 /
      DATA B(55423), B(55424), B(55425) /    -4.10,  -10.68,    0.00 /
      DATA B(55570), B(55571), B(55572) /    -4.09,  -10.60,    0.00 /
      DATA B(55717), B(55718), B(55719) /    -4.10,  -10.53,    0.00 /
      DATA B(55864), B(55865), B(55866) /    -4.11,  -10.46,    0.00 /
      DATA B(56011), B(56012), B(56013) /    -4.13,  -10.39,    0.00 /
      DATA B(56158), B(56159), B(56160) /    -4.15,  -10.31,    0.00 /
      DATA B(56305), B(56306), B(56307) /    -4.17,  -10.23,    0.00 /
      DATA B(56452), B(56453), B(56454) /    -4.19,  -10.14,    0.00 /
      DATA B(56599), B(56600), B(56601) /    -4.21,  -10.05,    0.00 /
      DATA B(56746), B(56747), B(56748) /    -4.23,   -9.95,    0.00 /
      DATA B(56893), B(56894), B(56895) /    -4.25,   -9.85,    0.00 /
      DATA B(57040), B(57041), B(57042) /    -4.26,   -9.75,    0.00 /
      DATA B(57187), B(57188), B(57189) /    -4.27,   -9.65,    0.00 /
      DATA B(57334), B(57335), B(57336) /    -4.27,   -9.55,    0.00 /
      DATA B(57481), B(57482), B(57483) /    -4.28,   -9.45,    0.00 /
      DATA B(57628), B(57629), B(57630) /    -4.28,   -9.36,    0.00 /
      DATA B(57775), B(57776), B(57777) /    -4.28,   -9.26,    0.00 /
      DATA B(57922), B(57923), B(57924) /    -4.29,   -9.17,    0.00 /
      DATA B(58069), B(58070), B(58071) /    -4.29,   -9.09,    0.00 /
      DATA B(58216), B(58217), B(58218) /    -4.29,   -9.00,    0.00 /
      DATA B(58363), B(58364), B(58365) /    -4.29,   -8.93,    0.00 /
      DATA B(58510), B(58511), B(58512) /    -4.29,   -8.85,    0.00 /
      DATA B(58657), B(58658), B(58659) /    -4.29,   -8.78,    0.00 /
      DATA B(58804), B(58805), B(58806) /    -4.29,   -8.71,    0.00 /
      DATA B(58951), B(58952), B(58953) /    -4.29,   -8.64,    0.00 /
      DATA B(59098), B(59099), B(59100) /    -4.30,   -8.57,    0.00 /
      DATA B(59245), B(59246), B(59247) /    -4.31,   -8.50,    0.00 /
      DATA B(59392), B(59393), B(59394) /    -4.32,   -8.43,    0.00 /
      DATA B(59539), B(59540), B(59541) /    -4.34,   -8.36,    0.00 /
      DATA B(59686), B(59687), B(59688) /    -4.36,   -8.29,    0.00 /
      DATA B(59833), B(59834), B(59835) /    -4.38,   -8.21,    0.00 /
      DATA B(59980), B(59981), B(59982) /    -4.40,   -8.13,    0.00 /
      DATA B(60127), B(60128), B(60129) /    -4.43,   -8.05,    0.00 /
      DATA B(60274), B(60275), B(60276) /    -4.46,   -7.96,    0.00 /
      DATA B(60421), B(60422), B(60423) /    -4.49,   -7.86,    0.00 /
      DATA B(60568), B(60569), B(60570) /    -4.52,   -7.76,    0.00 /
      DATA B(60715), B(60716), B(60717) /    -4.54,   -7.62,    0.00 /
      DATA B(60862), B(60863), B(60864) /    -4.58,   -7.51,    0.00 /
      DATA B(61009), B(61010), B(61011) /    -4.62,   -7.41,    0.00 /
      DATA B(61156), B(61157), B(61158) /    -4.66,   -7.30,    0.00 /
      DATA B(61303), B(61304), B(61305) /    -4.71,   -7.19,    0.00 /
      DATA B(61450), B(61451), B(61452) /    -4.76,   -7.07,    0.00 /
      DATA B(61597), B(61598), B(61599) /    -4.83,   -6.96,    0.00 /
      DATA B(61744), B(61745), B(61746) /    -4.90,   -6.84,    0.00 /
      DATA B(61891), B(61892), B(61893) /    -4.96,   -6.75,    0.00 /
      DATA B(62038), B(62039), B(62040) /    -4.97,   -6.68,    0.00 /
      DATA B(62185), B(62186), B(62187) /    -5.16,   -6.81,    0.00 /
      DATA B(62332), B(62333), B(62334) /    -5.23,   -6.78,    0.00 /
      DATA B(62479), B(62480), B(62481) /    -5.31,   -6.73,    0.00 /
      DATA B(62626), B(62627), B(62628) /    -5.38,   -6.67,    0.00 /
      DATA B(62773), B(62774), B(62775) /    -5.44,   -6.61,    0.00 /
      DATA B(62920), B(62921), B(62922) /    -5.49,   -6.56,    0.00 /
      DATA B(63067), B(63068), B(63069) /    -5.54,   -6.50,    0.00 /
      DATA B(63214), B(63215), B(63216) /    -5.59,   -6.45,    0.00 /
      DATA B(63361), B(63362), B(63363) /    -5.65,   -6.39,    0.00 /
      DATA B(63508), B(63509), B(63510) /    -5.72,   -6.34,    0.00 /
      DATA B(63655), B(63656), B(63657) /    -5.81,   -6.29,    0.00 /
      DATA B(63802), B(63803), B(63804) /    -5.92,   -6.24,    0.00 /
      DATA B(63949), B(63950), B(63951) /    -6.05,   -6.20,    0.00 /
      DATA B(64096), B(64097), B(64098) /    -6.20,   -6.21,    0.00 /
      DATA B(64243), B(64244), B(64245) /    -6.39,   -6.31,    0.00 /
      DATA B(64390), B(64391), B(64392) /    -6.41,   -6.39,    0.00 /
      DATA B(64537), B(64538), B(64539) /    -6.50,   -6.44,    0.00 /
      DATA B(64684), B(64685), B(64686) /    -6.61,   -6.46,    0.00 /
      DATA B(64831), B(64832), B(64833) /    -6.70,   -6.48,    0.00 /
      DATA B(64978), B(64979), B(64980) /    -6.76,   -6.51,    0.00 /
      DATA B(65125), B(65126), B(65127) /    -6.80,   -6.57,    0.00 /
      DATA B(65272), B(65273), B(65274) /    -6.83,   -6.68,    0.00 /
      DATA B(65419), B(65420), B(65421) /    -6.86,   -6.84,    0.00 /
      DATA B(65566), B(65567), B(65568) /    -6.85,   -6.99,    0.00 /
      DATA B(65713), B(65714), B(65715) /    -6.86,   -7.32,    0.00 /
      DATA B(65860), B(65861), B(65862) /    -6.84,   -7.63,    0.00 /
      DATA B(66007), B(66008), B(66009) /    -6.87,   -7.91,    0.00 /
      DATA B(66154), B(66155), B(66156) /    -6.94,   -8.15,    0.00 /
      DATA B(66301), B(66302), B(66303) /    -7.03,   -8.35,    0.00 /
      DATA B(66448), B(66449), B(66450) /    -7.13,   -8.51,    0.00 /
      DATA B(66595), B(66596), B(66597) /    -7.22,   -8.66,    0.00 /
      DATA B(66742), B(66743), B(66744) /    -7.31,   -8.79,    0.00 /
      DATA B(66889), B(66890), B(66891) /    -7.40,   -8.90,    0.00 /
      DATA B(67036), B(67037), B(67038) /    -7.49,   -9.01,    0.00 /
      DATA B(67183), B(67184), B(67185) /    -7.57,   -9.11,    0.00 /
      DATA B(67330), B(67331), B(67332) /    -7.65,   -9.20,    0.00 /
      DATA B(67477), B(67478), B(67479) /    -7.72,   -9.29,    0.00 /
      DATA B(67624), B(67625), B(67626) /    -7.80,   -9.37,    0.00 /
      DATA B(46459), B(46460), B(46461) /    -2.83,  -24.78,    0.00 /
      DATA B(46606), B(46607), B(46608) /    -3.34,  -24.10,    0.00 /
      DATA B(46753), B(46754), B(46755) /    -3.72,  -23.50,    0.00 /
      DATA B(46900), B(46901), B(46902) /    -3.99,  -22.96,    0.00 /
      DATA B(47047), B(47048), B(47049) /    -4.19,  -22.46,    0.00 /
      DATA B(47194), B(47195), B(47196) /    -4.32,  -21.97,    0.00 /
      DATA B(47341), B(47342), B(47343) /    -4.39,  -21.49,    0.00 /
      DATA B(47488), B(47489), B(47490) /    -4.43,  -21.01,    0.00 /
      DATA B(47635), B(47636), B(47637) /    -4.45,  -20.51,    0.00 /
      DATA B(47782), B(47783), B(47784) /    -4.45,  -20.01,    0.00 /
      DATA B(47929), B(47930), B(47931) /    -4.45,  -19.50,    0.00 /
      DATA B(48076), B(48077), B(48078) /    -4.44,  -18.99,    0.00 /
      DATA B(48223), B(48224), B(48225) /    -4.44,  -18.49,    0.00 /
      DATA B(48370), B(48371), B(48372) /    -4.44,  -18.00,    0.00 /
      DATA B(48517), B(48518), B(48519) /    -4.47,  -17.58,    0.00 /
      DATA B(48664), B(48665), B(48666) /    -4.42,  -17.18,    0.00 /
      DATA B(48811), B(48812), B(48813) /    -4.36,  -16.82,    0.00 /
      DATA B(48958), B(48959), B(48960) /    -4.27,  -16.52,    0.00 /
      DATA B(49105), B(49106), B(49107) /    -4.16,  -16.29,    0.00 /
      DATA B(49252), B(49253), B(49254) /    -4.06,  -16.16,    0.00 /
      DATA B(49399), B(49400), B(49401) /    -3.98,  -16.09,    0.00 /
      DATA B(49546), B(49547), B(49548) /    -3.94,  -16.06,    0.00 /
      DATA B(49693), B(49694), B(49695) /    -3.93,  -16.02,    0.00 /
      DATA B(49840), B(49841), B(49842) /    -3.93,  -15.94,    0.00 /
      DATA B(49987), B(49988), B(49989) /    -3.89,  -15.76,    0.00 /
      DATA B(50134), B(50135), B(50136) /    -3.79,  -15.46,    0.00 /
      DATA B(50281), B(50282), B(50283) /    -3.59,  -15.11,    0.00 /
      DATA B(50428), B(50429), B(50430) /    -3.43,  -14.74,    0.00 /
      DATA B(50575), B(50576), B(50577) /    -3.40,  -14.38,    0.00 /
      DATA B(50722), B(50723), B(50724) /    -3.43,  -14.16,    0.00 /
      DATA B(50869), B(50870), B(50871) /    -3.51,  -14.03,    0.00 /
      DATA B(51016), B(51017), B(51018) /    -3.59,  -13.96,    0.00 /
      DATA B(51163), B(51164), B(51165) /    -3.67,  -13.92,    0.00 /
      DATA B(51310), B(51311), B(51312) /    -3.74,  -13.88,    0.00 /
      DATA B(51457), B(51458), B(51459) /    -3.81,  -13.84,    0.00 /
      DATA B(51604), B(51605), B(51606) /    -3.87,  -13.80,    0.00 /
      DATA B(51751), B(51752), B(51753) /    -3.92,  -13.75,    0.00 /
      DATA B(51898), B(51899), B(51900) /    -3.97,  -13.70,    0.00 /
      DATA B(52045), B(52046), B(52047) /    -4.01,  -13.64,    0.00 /
      DATA B(52192), B(52193), B(52194) /    -4.05,  -13.58,    0.00 /
      DATA B(52339), B(52340), B(52341) /    -4.09,  -13.51,    0.00 /
      DATA B(52486), B(52487), B(52488) /    -4.12,  -13.44,    0.00 /
      DATA B(52633), B(52634), B(52635) /    -4.15,  -13.36,    0.00 /
      DATA B(52780), B(52781), B(52782) /    -4.18,  -13.28,    0.00 /
      DATA B(52927), B(52928), B(52929) /    -4.20,  -13.19,    0.00 /
      DATA B(53074), B(53075), B(53076) /    -4.23,  -13.10,    0.00 /
      DATA B(53221), B(53222), B(53223) /    -4.26,  -13.00,    0.00 /
      DATA B(53368), B(53369), B(53370) /    -4.29,  -12.88,    0.00 /
      DATA B(53515), B(53516), B(53517) /    -4.32,  -12.76,    0.00 /
      DATA B(53662), B(53663), B(53664) /    -4.34,  -12.61,    0.00 /
      DATA B(53809), B(53810), B(53811) /    -4.37,  -12.46,    0.00 /
      DATA B(53956), B(53957), B(53958) /    -4.39,  -12.29,    0.00 /
      DATA B(54103), B(54104), B(54105) /    -4.40,  -12.12,    0.00 /
      DATA B(54250), B(54251), B(54252) /    -4.40,  -11.94,    0.00 /
      DATA B(54397), B(54398), B(54399) /    -4.40,  -11.76,    0.00 /
      DATA B(54544), B(54545), B(54546) /    -4.38,  -11.59,    0.00 /
      DATA B(54691), B(54692), B(54693) /    -4.36,  -11.43,    0.00 /
      DATA B(54838), B(54839), B(54840) /    -4.33,  -11.28,    0.00 /
      DATA B(54985), B(54986), B(54987) /    -4.30,  -11.15,    0.00 /
      DATA B(55132), B(55133), B(55134) /    -4.28,  -11.04,    0.00 /
      DATA B(55279), B(55280), B(55281) /    -4.26,  -10.94,    0.00 /
      DATA B(55426), B(55427), B(55428) /    -4.24,  -10.85,    0.00 /
      DATA B(55573), B(55574), B(55575) /    -4.24,  -10.77,    0.00 /
      DATA B(55720), B(55721), B(55722) /    -4.24,  -10.70,    0.00 /
      DATA B(55867), B(55868), B(55869) /    -4.25,  -10.63,    0.00 /
      DATA B(56014), B(56015), B(56016) /    -4.27,  -10.55,    0.00 /
      DATA B(56161), B(56162), B(56163) /    -4.28,  -10.47,    0.00 /
      DATA B(56308), B(56309), B(56310) /    -4.30,  -10.39,    0.00 /
      DATA B(56455), B(56456), B(56457) /    -4.32,  -10.30,    0.00 /
      DATA B(56602), B(56603), B(56604) /    -4.34,  -10.21,    0.00 /
      DATA B(56749), B(56750), B(56751) /    -4.36,  -10.12,    0.00 /
      DATA B(56896), B(56897), B(56898) /    -4.37,  -10.02,    0.00 /
      DATA B(57043), B(57044), B(57045) /    -4.38,   -9.92,    0.00 /
      DATA B(57190), B(57191), B(57192) /    -4.39,   -9.82,    0.00 /
      DATA B(57337), B(57338), B(57339) /    -4.40,   -9.73,    0.00 /
      DATA B(57484), B(57485), B(57486) /    -4.41,   -9.63,    0.00 /
      DATA B(57631), B(57632), B(57633) /    -4.41,   -9.54,    0.00 /
      DATA B(57778), B(57779), B(57780) /    -4.42,   -9.44,    0.00 /
      DATA B(57925), B(57926), B(57927) /    -4.42,   -9.36,    0.00 /
      DATA B(58072), B(58073), B(58074) /    -4.42,   -9.27,    0.00 /
      DATA B(58219), B(58220), B(58221) /    -4.42,   -9.19,    0.00 /
      DATA B(58366), B(58367), B(58368) /    -4.42,   -9.11,    0.00 /
      DATA B(58513), B(58514), B(58515) /    -4.42,   -9.04,    0.00 /
      DATA B(58660), B(58661), B(58662) /    -4.43,   -8.96,    0.00 /
      DATA B(58807), B(58808), B(58809) /    -4.43,   -8.89,    0.00 /
      DATA B(58954), B(58955), B(58956) /    -4.44,   -8.82,    0.00 /
      DATA B(59101), B(59102), B(59103) /    -4.44,   -8.75,    0.00 /
      DATA B(59248), B(59249), B(59250) /    -4.45,   -8.68,    0.00 /
      DATA B(59395), B(59396), B(59397) /    -4.47,   -8.61,    0.00 /
      DATA B(59542), B(59543), B(59544) /    -4.48,   -8.54,    0.00 /
      DATA B(59689), B(59690), B(59691) /    -4.50,   -8.46,    0.00 /
      DATA B(59836), B(59837), B(59838) /    -4.52,   -8.39,    0.00 /
      DATA B(59983), B(59984), B(59985) /    -4.55,   -8.31,    0.00 /
      DATA B(60130), B(60131), B(60132) /    -4.58,   -8.22,    0.00 /
      DATA B(60277), B(60278), B(60279) /    -4.61,   -8.13,    0.00 /
      DATA B(60424), B(60425), B(60426) /    -4.63,   -8.04,    0.00 /
      DATA B(60571), B(60572), B(60573) /    -4.67,   -7.92,    0.00 /
      DATA B(60718), B(60719), B(60720) /    -4.69,   -7.82,    0.00 /
      DATA B(60865), B(60866), B(60867) /    -4.73,   -7.71,    0.00 /
      DATA B(61012), B(61013), B(61014) /    -4.77,   -7.61,    0.00 /
      DATA B(61159), B(61160), B(61161) /    -4.81,   -7.51,    0.00 /
      DATA B(61306), B(61307), B(61308) /    -4.86,   -7.40,    0.00 /
      DATA B(61453), B(61454), B(61455) /    -4.92,   -7.30,    0.00 /
      DATA B(61600), B(61601), B(61602) /    -4.99,   -7.19,    0.00 /
      DATA B(61747), B(61748), B(61749) /    -5.06,   -7.08,    0.00 /
      DATA B(61894), B(61895), B(61896) /    -5.13,   -7.00,    0.00 /
      DATA B(62041), B(62042), B(62043) /    -5.14,   -6.95,    0.00 /
      DATA B(62188), B(62189), B(62190) /    -5.32,   -7.07,    0.00 /
      DATA B(62335), B(62336), B(62337) /    -5.39,   -7.05,    0.00 /
      DATA B(62482), B(62483), B(62484) /    -5.47,   -7.01,    0.00 /
      DATA B(62629), B(62630), B(62631) /    -5.54,   -6.96,    0.00 /
      DATA B(62776), B(62777), B(62778) /    -5.60,   -6.91,    0.00 /
      DATA B(62923), B(62924), B(62925) /    -5.65,   -6.85,    0.00 /
      DATA B(63070), B(63071), B(63072) /    -5.70,   -6.80,    0.00 /
      DATA B(63217), B(63218), B(63219) /    -5.76,   -6.74,    0.00 /
      DATA B(63364), B(63365), B(63366) /    -5.81,   -6.69,    0.00 /
      DATA B(63511), B(63512), B(63513) /    -5.88,   -6.64,    0.00 /
      DATA B(63658), B(63659), B(63660) /    -5.96,   -6.59,    0.00 /
      DATA B(63805), B(63806), B(63807) /    -6.06,   -6.54,    0.00 /
      DATA B(63952), B(63953), B(63954) /    -6.19,   -6.49,    0.00 /
      DATA B(64099), B(64100), B(64101) /    -6.33,   -6.47,    0.00 /
      DATA B(64246), B(64247), B(64248) /    -6.54,   -6.54,    0.00 /
      DATA B(64393), B(64394), B(64395) /    -6.55,   -6.64,    0.00 /
      DATA B(64540), B(64541), B(64542) /    -6.62,   -6.69,    0.00 /
      DATA B(64687), B(64688), B(64689) /    -6.73,   -6.71,    0.00 /
      DATA B(64834), B(64835), B(64836) /    -6.82,   -6.72,    0.00 /
      DATA B(64981), B(64982), B(64983) /    -6.88,   -6.75,    0.00 /
      DATA B(65128), B(65129), B(65130) /    -6.92,   -6.81,    0.00 /
      DATA B(65275), B(65276), B(65277) /    -6.95,   -6.91,    0.00 /
      DATA B(65422), B(65423), B(65424) /    -6.98,   -7.07,    0.00 /
      DATA B(65569), B(65570), B(65571) /    -6.97,   -7.26,    0.00 /
      DATA B(65716), B(65717), B(65718) /    -6.97,   -7.53,    0.00 /
      DATA B(65863), B(65864), B(65865) /    -6.95,   -7.83,    0.00 /
      DATA B(66010), B(66011), B(66012) /    -6.98,   -8.10,    0.00 /
      DATA B(66157), B(66158), B(66159) /    -7.05,   -8.32,    0.00 /
      DATA B(66304), B(66305), B(66306) /    -7.14,   -8.50,    0.00 /
      DATA B(66451), B(66452), B(66453) /    -7.23,   -8.65,    0.00 /
      DATA B(66598), B(66599), B(66600) /    -7.32,   -8.79,    0.00 /
      DATA B(66745), B(66746), B(66747) /    -7.40,   -8.91,    0.00 /
      DATA B(66892), B(66893), B(66894) /    -7.48,   -9.01,    0.00 /
      DATA B(67039), B(67040), B(67041) /    -7.56,   -9.12,    0.00 /
      DATA B(67186), B(67187), B(67188) /    -7.64,   -9.21,    0.00 /
      DATA B(67333), B(67334), B(67335) /    -7.72,   -9.30,    0.00 /
      DATA B(67480), B(67481), B(67482) /    -7.79,   -9.38,    0.00 /
      DATA B(67627), B(67628), B(67629) /    -7.86,   -9.46,    0.00 /
      DATA B(46462), B(46463), B(46464) /    -3.40,  -24.32,    0.00 /
      DATA B(46609), B(46610), B(46611) /    -3.78,  -23.75,    0.00 /
      DATA B(46756), B(46757), B(46758) /    -4.06,  -23.24,    0.00 /
      DATA B(46903), B(46904), B(46905) /    -4.27,  -22.77,    0.00 /
      DATA B(47050), B(47051), B(47052) /    -4.42,  -22.34,    0.00 /
      DATA B(47197), B(47198), B(47199) /    -4.53,  -21.91,    0.00 /
      DATA B(47344), B(47345), B(47346) /    -4.60,  -21.48,    0.00 /
      DATA B(47491), B(47492), B(47493) /    -4.64,  -21.05,    0.00 /
      DATA B(47638), B(47639), B(47640) /    -4.67,  -20.60,    0.00 /
      DATA B(47785), B(47786), B(47787) /    -4.69,  -20.15,    0.00 /
      DATA B(47932), B(47933), B(47934) /    -4.70,  -19.67,    0.00 /
      DATA B(48079), B(48080), B(48081) /    -4.70,  -19.19,    0.00 /
      DATA B(48226), B(48227), B(48228) /    -4.70,  -18.71,    0.00 /
      DATA B(48373), B(48374), B(48375) /    -4.69,  -18.24,    0.00 /
      DATA B(48520), B(48521), B(48522) /    -4.68,  -17.80,    0.00 /
      DATA B(48667), B(48668), B(48669) /    -4.65,  -17.42,    0.00 /
      DATA B(48814), B(48815), B(48816) /    -4.54,  -17.07,    0.00 /
      DATA B(48961), B(48962), B(48963) /    -4.42,  -16.76,    0.00 /
      DATA B(49108), B(49109), B(49110) /    -4.31,  -16.53,    0.00 /
      DATA B(49255), B(49256), B(49257) /    -4.20,  -16.39,    0.00 /
      DATA B(49402), B(49403), B(49404) /    -4.13,  -16.31,    0.00 /
      DATA B(49549), B(49550), B(49551) /    -4.08,  -16.27,    0.00 /
      DATA B(49696), B(49697), B(49698) /    -4.08,  -16.23,    0.00 /
      DATA B(49843), B(49844), B(49845) /    -4.09,  -16.16,    0.00 /
      DATA B(49990), B(49991), B(49992) /    -4.10,  -16.01,    0.00 /
      DATA B(50137), B(50138), B(50139) /    -4.05,  -15.75,    0.00 /
      DATA B(50284), B(50285), B(50286) /    -3.91,  -15.41,    0.00 /
      DATA B(50431), B(50432), B(50433) /    -3.79,  -15.01,    0.00 /
      DATA B(50578), B(50579), B(50580) /    -3.63,  -14.62,    0.00 /
      DATA B(50725), B(50726), B(50727) /    -3.64,  -14.32,    0.00 /
      DATA B(50872), B(50873), B(50874) /    -3.70,  -14.17,    0.00 /
      DATA B(51019), B(51020), B(51021) /    -3.76,  -14.09,    0.00 /
      DATA B(51166), B(51167), B(51168) /    -3.83,  -14.04,    0.00 /
      DATA B(51313), B(51314), B(51315) /    -3.89,  -14.00,    0.00 /
      DATA B(51460), B(51461), B(51462) /    -3.95,  -13.96,    0.00 /
      DATA B(51607), B(51608), B(51609) /    -4.00,  -13.91,    0.00 /
      DATA B(51754), B(51755), B(51756) /    -4.05,  -13.86,    0.00 /
      DATA B(51901), B(51902), B(51903) /    -4.10,  -13.81,    0.00 /
      DATA B(52048), B(52049), B(52050) /    -4.14,  -13.75,    0.00 /
      DATA B(52195), B(52196), B(52197) /    -4.17,  -13.68,    0.00 /
      DATA B(52342), B(52343), B(52344) /    -4.21,  -13.62,    0.00 /
      DATA B(52489), B(52490), B(52491) /    -4.24,  -13.54,    0.00 /
      DATA B(52636), B(52637), B(52638) /    -4.27,  -13.47,    0.00 /
      DATA B(52783), B(52784), B(52785) /    -4.30,  -13.38,    0.00 /
      DATA B(52930), B(52931), B(52932) /    -4.33,  -13.30,    0.00 /
      DATA B(53077), B(53078), B(53079) /    -4.35,  -13.20,    0.00 /
      DATA B(53224), B(53225), B(53226) /    -4.38,  -13.10,    0.00 /
      DATA B(53371), B(53372), B(53373) /    -4.41,  -12.98,    0.00 /
      DATA B(53518), B(53519), B(53520) /    -4.44,  -12.86,    0.00 /
      DATA B(53665), B(53666), B(53667) /    -4.46,  -12.72,    0.00 /
      DATA B(53812), B(53813), B(53814) /    -4.49,  -12.57,    0.00 /
      DATA B(53959), B(53960), B(53961) /    -4.51,  -12.41,    0.00 /
      DATA B(54106), B(54107), B(54108) /    -4.52,  -12.25,    0.00 /
      DATA B(54253), B(54254), B(54255) /    -4.52,  -12.08,    0.00 /
      DATA B(54400), B(54401), B(54402) /    -4.51,  -11.91,    0.00 /
      DATA B(54547), B(54548), B(54549) /    -4.50,  -11.74,    0.00 /
      DATA B(54694), B(54695), B(54696) /    -4.48,  -11.59,    0.00 /
      DATA B(54841), B(54842), B(54843) /    -4.46,  -11.45,    0.00 /
      DATA B(54988), B(54989), B(54990) /    -4.43,  -11.32,    0.00 /
      DATA B(55135), B(55136), B(55137) /    -4.41,  -11.21,    0.00 /
      DATA B(55282), B(55283), B(55284) /    -4.39,  -11.11,    0.00 /
      DATA B(55429), B(55430), B(55431) /    -4.38,  -11.02,    0.00 /
      DATA B(55576), B(55577), B(55578) /    -4.37,  -10.94,    0.00 /
      DATA B(55723), B(55724), B(55725) /    -4.38,  -10.86,    0.00 /
      DATA B(55870), B(55871), B(55872) /    -4.38,  -10.78,    0.00 /
      DATA B(56017), B(56018), B(56019) /    -4.40,  -10.71,    0.00 /
      DATA B(56164), B(56165), B(56166) /    -4.41,  -10.63,    0.00 /
      DATA B(56311), B(56312), B(56313) /    -4.43,  -10.54,    0.00 /
      DATA B(56458), B(56459), B(56460) /    -4.45,  -10.46,    0.00 /
      DATA B(56605), B(56606), B(56607) /    -4.47,  -10.37,    0.00 /
      DATA B(56752), B(56753), B(56754) /    -4.48,  -10.27,    0.00 /
      DATA B(56899), B(56900), B(56901) /    -4.50,  -10.18,    0.00 /
      DATA B(57046), B(57047), B(57048) /    -4.51,  -10.08,    0.00 /
      DATA B(57193), B(57194), B(57195) /    -4.52,   -9.98,    0.00 /
      DATA B(57340), B(57341), B(57342) /    -4.53,   -9.89,    0.00 /
      DATA B(57487), B(57488), B(57489) /    -4.53,   -9.80,    0.00 /
      DATA B(57634), B(57635), B(57636) /    -4.54,   -9.70,    0.00 /
      DATA B(57781), B(57782), B(57783) /    -4.54,   -9.61,    0.00 /
      DATA B(57928), B(57929), B(57930) /    -4.55,   -9.53,    0.00 /
      DATA B(58075), B(58076), B(58077) /    -4.55,   -9.44,    0.00 /
      DATA B(58222), B(58223), B(58224) /    -4.55,   -9.36,    0.00 /
      DATA B(58369), B(58370), B(58371) /    -4.56,   -9.29,    0.00 /
      DATA B(58516), B(58517), B(58518) /    -4.56,   -9.21,    0.00 /
      DATA B(58663), B(58664), B(58665) /    -4.56,   -9.14,    0.00 /
      DATA B(58810), B(58811), B(58812) /    -4.57,   -9.07,    0.00 /
      DATA B(58957), B(58958), B(58959) /    -4.57,   -9.00,    0.00 /
      DATA B(59104), B(59105), B(59106) /    -4.58,   -8.93,    0.00 /
      DATA B(59251), B(59252), B(59253) /    -4.59,   -8.85,    0.00 /
      DATA B(59398), B(59399), B(59400) /    -4.61,   -8.78,    0.00 /
      DATA B(59545), B(59546), B(59547) /    -4.62,   -8.71,    0.00 /
      DATA B(59692), B(59693), B(59694) /    -4.64,   -8.64,    0.00 /
      DATA B(59839), B(59840), B(59841) /    -4.67,   -8.56,    0.00 /
      DATA B(59986), B(59987), B(59988) /    -4.69,   -8.48,    0.00 /
      DATA B(60133), B(60134), B(60135) /    -4.72,   -8.40,    0.00 /
      DATA B(60280), B(60281), B(60282) /    -4.75,   -8.30,    0.00 /
      DATA B(60427), B(60428), B(60429) /    -4.78,   -8.20,    0.00 /
      DATA B(60574), B(60575), B(60576) /    -4.81,   -8.10,    0.00 /
      DATA B(60721), B(60722), B(60723) /    -4.84,   -8.00,    0.00 /
      DATA B(60868), B(60869), B(60870) /    -4.87,   -7.91,    0.00 /
      DATA B(61015), B(61016), B(61017) /    -4.92,   -7.81,    0.00 /
      DATA B(61162), B(61163), B(61164) /    -4.97,   -7.71,    0.00 /
      DATA B(61309), B(61310), B(61311) /    -5.02,   -7.61,    0.00 /
      DATA B(61456), B(61457), B(61458) /    -5.08,   -7.51,    0.00 /
      DATA B(61603), B(61604), B(61605) /    -5.14,   -7.41,    0.00 /
      DATA B(61750), B(61751), B(61752) /    -5.22,   -7.31,    0.00 /
      DATA B(61897), B(61898), B(61899) /    -5.28,   -7.24,    0.00 /
      DATA B(62044), B(62045), B(62046) /    -5.30,   -7.20,    0.00 /
      DATA B(62191), B(62192), B(62193) /    -5.46,   -7.32,    0.00 /
      DATA B(62338), B(62339), B(62340) /    -5.54,   -7.31,    0.00 /
      DATA B(62485), B(62486), B(62487) /    -5.62,   -7.28,    0.00 /
      DATA B(62632), B(62633), B(62634) /    -5.69,   -7.23,    0.00 /
      DATA B(62779), B(62780), B(62781) /    -5.75,   -7.18,    0.00 /
      DATA B(62926), B(62927), B(62928) /    -5.81,   -7.13,    0.00 /
      DATA B(63073), B(63074), B(63075) /    -5.86,   -7.08,    0.00 /
      DATA B(63220), B(63221), B(63222) /    -5.91,   -7.03,    0.00 /
      DATA B(63367), B(63368), B(63369) /    -5.97,   -6.98,    0.00 /
      DATA B(63514), B(63515), B(63516) /    -6.04,   -6.93,    0.00 /
      DATA B(63661), B(63662), B(63663) /    -6.12,   -6.88,    0.00 /
      DATA B(63808), B(63809), B(63810) /    -6.21,   -6.82,    0.00 /
      DATA B(63955), B(63956), B(63957) /    -6.32,   -6.77,    0.00 /
      DATA B(64102), B(64103), B(64104) /    -6.44,   -6.74,    0.00 /
      DATA B(64249), B(64250), B(64251) /    -6.69,   -6.78,    0.00 /
      DATA B(64396), B(64397), B(64398) /    -6.68,   -6.87,    0.00 /
      DATA B(64543), B(64544), B(64545) /    -6.73,   -6.93,    0.00 /
      DATA B(64690), B(64691), B(64692) /    -6.83,   -6.94,    0.00 /
      DATA B(64837), B(64838), B(64839) /    -6.92,   -6.95,    0.00 /
      DATA B(64984), B(64985), B(64986) /    -6.99,   -6.98,    0.00 /
      DATA B(65131), B(65132), B(65133) /    -7.03,   -7.04,    0.00 /
      DATA B(65278), B(65279), B(65280) /    -7.06,   -7.14,    0.00 /
      DATA B(65425), B(65426), B(65427) /    -7.08,   -7.29,    0.00 /
      DATA B(65572), B(65573), B(65574) /    -7.07,   -7.48,    0.00 /
      DATA B(65719), B(65720), B(65721) /    -7.05,   -7.74,    0.00 /
      DATA B(65866), B(65867), B(65868) /    -7.04,   -8.03,    0.00 /
      DATA B(66013), B(66014), B(66015) /    -7.08,   -8.28,    0.00 /
      DATA B(66160), B(66161), B(66162) /    -7.16,   -8.48,    0.00 /
      DATA B(66307), B(66308), B(66309) /    -7.24,   -8.65,    0.00 /
      DATA B(66454), B(66455), B(66456) /    -7.32,   -8.79,    0.00 /
      DATA B(66601), B(66602), B(66603) /    -7.41,   -8.91,    0.00 /
      DATA B(66748), B(66749), B(66750) /    -7.49,   -9.02,    0.00 /
      DATA B(66895), B(66896), B(66897) /    -7.56,   -9.12,    0.00 /
      DATA B(67042), B(67043), B(67044) /    -7.64,   -9.22,    0.00 /
      DATA B(67189), B(67190), B(67191) /    -7.71,   -9.30,    0.00 /
      DATA B(67336), B(67337), B(67338) /    -7.78,   -9.39,    0.00 /
      DATA B(67483), B(67484), B(67485) /    -7.85,   -9.46,    0.00 /
      DATA B(67630), B(67631), B(67632) /    -7.92,   -9.54,    0.00 /
      DATA B(46465), B(46466), B(46467) /    -3.82,  -23.94,    0.00 /
      DATA B(46612), B(46613), B(46614) /    -4.10,  -23.47,    0.00 /
      DATA B(46759), B(46760), B(46761) /    -4.32,  -23.03,    0.00 /
      DATA B(46906), B(46907), B(46908) /    -4.49,  -22.63,    0.00 /
      DATA B(47053), B(47054), B(47055) /    -4.62,  -22.24,    0.00 /
      DATA B(47200), B(47201), B(47202) /    -4.71,  -21.86,    0.00 /
      DATA B(47347), B(47348), B(47349) /    -4.78,  -21.48,    0.00 /
      DATA B(47494), B(47495), B(47496) /    -4.83,  -21.08,    0.00 /
      DATA B(47641), B(47642), B(47643) /    -4.87,  -20.68,    0.00 /
      DATA B(47788), B(47789), B(47790) /    -4.90,  -20.26,    0.00 /
      DATA B(47935), B(47936), B(47937) /    -4.92,  -19.82,    0.00 /
      DATA B(48082), B(48083), B(48084) /    -4.93,  -19.37,    0.00 /
      DATA B(48229), B(48230), B(48231) /    -4.92,  -18.91,    0.00 /
      DATA B(48376), B(48377), B(48378) /    -4.90,  -18.45,    0.00 /
      DATA B(48523), B(48524), B(48525) /    -4.86,  -18.02,    0.00 /
      DATA B(48670), B(48671), B(48672) /    -4.77,  -17.66,    0.00 /
      DATA B(48817), B(48818), B(48819) /    -4.69,  -17.29,    0.00 /
      DATA B(48964), B(48965), B(48966) /    -4.56,  -16.99,    0.00 /
      DATA B(49111), B(49112), B(49113) /    -4.44,  -16.75,    0.00 /
      DATA B(49258), B(49259), B(49260) /    -4.33,  -16.59,    0.00 /
      DATA B(49405), B(49406), B(49407) /    -4.25,  -16.50,    0.00 /
      DATA B(49552), B(49553), B(49554) /    -4.21,  -16.45,    0.00 /
      DATA B(49699), B(49700), B(49701) /    -4.20,  -16.41,    0.00 /
      DATA B(49846), B(49847), B(49848) /    -4.22,  -16.35,    0.00 /
      DATA B(49993), B(49994), B(49995) /    -4.25,  -16.22,    0.00 /
      DATA B(50140), B(50141), B(50142) /    -4.24,  -15.99,    0.00 /
      DATA B(50287), B(50288), B(50289) /    -4.16,  -15.65,    0.00 /
      DATA B(50434), B(50435), B(50436) /    -3.99,  -15.28,    0.00 /
      DATA B(50581), B(50582), B(50583) /    -3.89,  -14.84,    0.00 /
      DATA B(50728), B(50729), B(50730) /    -3.85,  -14.48,    0.00 /
      DATA B(50875), B(50876), B(50877) /    -3.89,  -14.30,    0.00 /
      DATA B(51022), B(51023), B(51024) /    -3.93,  -14.21,    0.00 /
      DATA B(51169), B(51170), B(51171) /    -3.98,  -14.16,    0.00 /
      DATA B(51316), B(51317), B(51318) /    -4.04,  -14.11,    0.00 /
      DATA B(51463), B(51464), B(51465) /    -4.09,  -14.07,    0.00 /
      DATA B(51610), B(51611), B(51612) /    -4.13,  -14.02,    0.00 /
      DATA B(51757), B(51758), B(51759) /    -4.18,  -13.97,    0.00 /
      DATA B(51904), B(51905), B(51906) /    -4.22,  -13.91,    0.00 /
      DATA B(52051), B(52052), B(52053) /    -4.26,  -13.85,    0.00 /
      DATA B(52198), B(52199), B(52200) /    -4.30,  -13.79,    0.00 /
      DATA B(52345), B(52346), B(52347) /    -4.33,  -13.72,    0.00 /
      DATA B(52492), B(52493), B(52494) /    -4.36,  -13.64,    0.00 /
      DATA B(52639), B(52640), B(52641) /    -4.39,  -13.57,    0.00 /
      DATA B(52786), B(52787), B(52788) /    -4.42,  -13.48,    0.00 /
      DATA B(52933), B(52934), B(52935) /    -4.45,  -13.39,    0.00 /
      DATA B(53080), B(53081), B(53082) /    -4.47,  -13.30,    0.00 /
      DATA B(53227), B(53228), B(53229) /    -4.50,  -13.19,    0.00 /
      DATA B(53374), B(53375), B(53376) /    -4.53,  -13.08,    0.00 /
      DATA B(53521), B(53522), B(53523) /    -4.56,  -12.96,    0.00 /
      DATA B(53668), B(53669), B(53670) /    -4.58,  -12.82,    0.00 /
      DATA B(53815), B(53816), B(53817) /    -4.60,  -12.68,    0.00 /
      DATA B(53962), B(53963), B(53964) /    -4.62,  -12.53,    0.00 /
      DATA B(54109), B(54110), B(54111) /    -4.63,  -12.37,    0.00 /
      DATA B(54256), B(54257), B(54258) /    -4.63,  -12.21,    0.00 /
      DATA B(54403), B(54404), B(54405) /    -4.63,  -12.05,    0.00 /
      DATA B(54550), B(54551), B(54552) /    -4.62,  -11.89,    0.00 /
      DATA B(54697), B(54698), B(54699) /    -4.60,  -11.74,    0.00 /
      DATA B(54844), B(54845), B(54846) /    -4.58,  -11.61,    0.00 /
      DATA B(54991), B(54992), B(54993) /    -4.56,  -11.48,    0.00 /
      DATA B(55138), B(55139), B(55140) /    -4.54,  -11.37,    0.00 /
      DATA B(55285), B(55286), B(55287) /    -4.52,  -11.27,    0.00 /
      DATA B(55432), B(55433), B(55434) /    -4.51,  -11.18,    0.00 /
      DATA B(55579), B(55580), B(55581) /    -4.51,  -11.09,    0.00 /
      DATA B(55726), B(55727), B(55728) /    -4.51,  -11.01,    0.00 /
      DATA B(55873), B(55874), B(55875) /    -4.52,  -10.94,    0.00 /
      DATA B(56020), B(56021), B(56022) /    -4.53,  -10.86,    0.00 /
      DATA B(56167), B(56168), B(56169) /    -4.54,  -10.77,    0.00 /
      DATA B(56314), B(56315), B(56316) /    -4.56,  -10.69,    0.00 /
      DATA B(56461), B(56462), B(56463) /    -4.57,  -10.60,    0.00 /
      DATA B(56608), B(56609), B(56610) /    -4.59,  -10.51,    0.00 /
      DATA B(56755), B(56756), B(56757) /    -4.60,  -10.42,    0.00 /
      DATA B(56902), B(56903), B(56904) /    -4.62,  -10.33,    0.00 /
      DATA B(57049), B(57050), B(57051) /    -4.63,  -10.23,    0.00 /
      DATA B(57196), B(57197), B(57198) /    -4.64,  -10.14,    0.00 /
      DATA B(57343), B(57344), B(57345) /    -4.65,  -10.04,    0.00 /
      DATA B(57490), B(57491), B(57492) /    -4.66,   -9.95,    0.00 /
      DATA B(57637), B(57638), B(57639) /    -4.66,   -9.86,    0.00 /
      DATA B(57784), B(57785), B(57786) /    -4.67,   -9.77,    0.00 /
      DATA B(57931), B(57932), B(57933) /    -4.68,   -9.69,    0.00 /
      DATA B(58078), B(58079), B(58080) /    -4.68,   -9.61,    0.00 /
      DATA B(58225), B(58226), B(58227) /    -4.68,   -9.53,    0.00 /
      DATA B(58372), B(58373), B(58374) /    -4.69,   -9.46,    0.00 /
      DATA B(58519), B(58520), B(58521) /    -4.69,   -9.38,    0.00 /
      DATA B(58666), B(58667), B(58668) /    -4.70,   -9.31,    0.00 /
      DATA B(58813), B(58814), B(58815) /    -4.70,   -9.24,    0.00 /
      DATA B(58960), B(58961), B(58962) /    -4.71,   -9.17,    0.00 /
      DATA B(59107), B(59108), B(59109) /    -4.72,   -9.10,    0.00 /
      DATA B(59254), B(59255), B(59256) /    -4.73,   -9.02,    0.00 /
      DATA B(59401), B(59402), B(59403) /    -4.74,   -8.95,    0.00 /
      DATA B(59548), B(59549), B(59550) /    -4.76,   -8.88,    0.00 /
      DATA B(59695), B(59696), B(59697) /    -4.78,   -8.80,    0.00 /
      DATA B(59842), B(59843), B(59844) /    -4.81,   -8.73,    0.00 /
      DATA B(59989), B(59990), B(59991) /    -4.84,   -8.65,    0.00 /
      DATA B(60136), B(60137), B(60138) /    -4.87,   -8.56,    0.00 /
      DATA B(60283), B(60284), B(60285) /    -4.89,   -8.45,    0.00 /
      DATA B(60430), B(60431), B(60432) /    -4.92,   -8.35,    0.00 /
      DATA B(60577), B(60578), B(60579) /    -4.95,   -8.28,    0.00 /
      DATA B(60724), B(60725), B(60726) /    -4.98,   -8.18,    0.00 /
      DATA B(60871), B(60872), B(60873) /    -5.02,   -8.09,    0.00 /
      DATA B(61018), B(61019), B(61020) /    -5.07,   -8.00,    0.00 /
      DATA B(61165), B(61166), B(61167) /    -5.12,   -7.91,    0.00 /
      DATA B(61312), B(61313), B(61314) /    -5.17,   -7.81,    0.00 /
      DATA B(61459), B(61460), B(61461) /    -5.23,   -7.71,    0.00 /
      DATA B(61606), B(61607), B(61608) /    -5.29,   -7.61,    0.00 /
      DATA B(61753), B(61754), B(61755) /    -5.37,   -7.53,    0.00 /
      DATA B(61900), B(61901), B(61902) /    -5.44,   -7.46,    0.00 /
      DATA B(62047), B(62048), B(62049) /    -5.47,   -7.44,    0.00 /
      DATA B(62194), B(62195), B(62196) /    -5.61,   -7.56,    0.00 /
      DATA B(62341), B(62342), B(62343) /    -5.68,   -7.56,    0.00 /
      DATA B(62488), B(62489), B(62490) /    -5.76,   -7.53,    0.00 /
      DATA B(62635), B(62636), B(62637) /    -5.84,   -7.49,    0.00 /
      DATA B(62782), B(62783), B(62784) /    -5.90,   -7.45,    0.00 /
      DATA B(62929), B(62930), B(62931) /    -5.96,   -7.40,    0.00 /
      DATA B(63076), B(63077), B(63078) /    -6.01,   -7.35,    0.00 /
      DATA B(63223), B(63224), B(63225) /    -6.07,   -7.30,    0.00 /
      DATA B(63370), B(63371), B(63372) /    -6.13,   -7.25,    0.00 /
      DATA B(63517), B(63518), B(63519) /    -6.19,   -7.20,    0.00 /
      DATA B(63664), B(63665), B(63666) /    -6.27,   -7.15,    0.00 /
      DATA B(63811), B(63812), B(63813) /    -6.35,   -7.10,    0.00 /
      DATA B(63958), B(63959), B(63960) /    -6.44,   -7.04,    0.00 /
      DATA B(64105), B(64106), B(64107) /    -6.56,   -6.99,    0.00 /
      DATA B(64252), B(64253), B(64254) /    -6.77,   -7.00,    0.00 /
      DATA B(64399), B(64400), B(64401) /    -6.80,   -7.10,    0.00 /
      DATA B(64546), B(64547), B(64548) /    -6.83,   -7.15,    0.00 /
      DATA B(64693), B(64694), B(64695) /    -6.93,   -7.15,    0.00 /
      DATA B(64840), B(64841), B(64842) /    -7.03,   -7.16,    0.00 /
      DATA B(64987), B(64988), B(64989) /    -7.09,   -7.19,    0.00 /
      DATA B(65134), B(65135), B(65136) /    -7.13,   -7.25,    0.00 /
      DATA B(65281), B(65282), B(65283) /    -7.16,   -7.35,    0.00 /
      DATA B(65428), B(65429), B(65430) /    -7.18,   -7.51,    0.00 /
      DATA B(65575), B(65576), B(65577) /    -7.17,   -7.68,    0.00 /
      DATA B(65722), B(65723), B(65724) /    -7.15,   -7.94,    0.00 /
      DATA B(65869), B(65870), B(65871) /    -7.14,   -8.22,    0.00 /
      DATA B(66016), B(66017), B(66018) /    -7.18,   -8.45,    0.00 /
      DATA B(66163), B(66164), B(66165) /    -7.25,   -8.64,    0.00 /
      DATA B(66310), B(66311), B(66312) /    -7.33,   -8.79,    0.00 /
      DATA B(66457), B(66458), B(66459) /    -7.41,   -8.91,    0.00 /
      DATA B(66604), B(66605), B(66606) /    -7.49,   -9.03,    0.00 /
      DATA B(66751), B(66752), B(66753) /    -7.57,   -9.13,    0.00 /
      DATA B(66898), B(66899), B(66900) /    -7.64,   -9.23,    0.00 /
      DATA B(67045), B(67046), B(67047) /    -7.71,   -9.31,    0.00 /
      DATA B(67192), B(67193), B(67194) /    -7.78,   -9.40,    0.00 /
      DATA B(67339), B(67340), B(67341) /    -7.85,   -9.48,    0.00 /
      DATA B(67486), B(67487), B(67488) /    -7.92,   -9.55,    0.00 /
      DATA B(67633), B(67634), B(67635) /    -7.98,   -9.62,    0.00 /
      DATA B(46468), B(46469), B(46470) /    -4.13,  -23.64,    0.00 /
      DATA B(46615), B(46616), B(46617) /    -4.35,  -23.24,    0.00 /
      DATA B(46762), B(46763), B(46764) /    -4.52,  -22.87,    0.00 /
      DATA B(46909), B(46910), B(46911) /    -4.66,  -22.51,    0.00 /
      DATA B(47056), B(47057), B(47058) /    -4.77,  -22.16,    0.00 /
      DATA B(47203), B(47204), B(47205) /    -4.86,  -21.82,    0.00 /
      DATA B(47350), B(47351), B(47352) /    -4.93,  -21.47,    0.00 /
      DATA B(47497), B(47498), B(47499) /    -4.99,  -21.11,    0.00 /
      DATA B(47644), B(47645), B(47646) /    -5.03,  -20.74,    0.00 /
      DATA B(47791), B(47792), B(47793) /    -5.07,  -20.35,    0.00 /
      DATA B(47938), B(47939), B(47940) /    -5.10,  -19.94,    0.00 /
      DATA B(48085), B(48086), B(48087) /    -5.11,  -19.51,    0.00 /
      DATA B(48232), B(48233), B(48234) /    -5.11,  -19.08,    0.00 /
      DATA B(48379), B(48380), B(48381) /    -5.08,  -18.64,    0.00 /
      DATA B(48526), B(48527), B(48528) /    -5.02,  -18.23,    0.00 /
      DATA B(48673), B(48674), B(48675) /    -4.96,  -17.83,    0.00 /
      DATA B(48820), B(48821), B(48822) /    -4.82,  -17.50,    0.00 /
      DATA B(48967), B(48968), B(48969) /    -4.68,  -17.19,    0.00 /
      DATA B(49114), B(49115), B(49116) /    -4.55,  -16.95,    0.00 /
      DATA B(49261), B(49262), B(49263) /    -4.44,  -16.78,    0.00 /
      DATA B(49408), B(49409), B(49410) /    -4.36,  -16.67,    0.00 /
      DATA B(49555), B(49556), B(49557) /    -4.32,  -16.61,    0.00 /
      DATA B(49702), B(49703), B(49704) /    -4.31,  -16.56,    0.00 /
      DATA B(49849), B(49850), B(49851) /    -4.33,  -16.50,    0.00 /
      DATA B(49996), B(49997), B(49998) /    -4.36,  -16.38,    0.00 /
      DATA B(50143), B(50144), B(50145) /    -4.38,  -16.18,    0.00 /
      DATA B(50290), B(50291), B(50292) /    -4.34,  -15.86,    0.00 /
      DATA B(50437), B(50438), B(50439) /    -4.24,  -15.45,    0.00 /
      DATA B(50584), B(50585), B(50586) /    -4.13,  -15.10,    0.00 /
      DATA B(50731), B(50732), B(50733) /    -4.06,  -14.59,    0.00 /
      DATA B(50878), B(50879), B(50880) /    -4.07,  -14.42,    0.00 /
      DATA B(51025), B(51026), B(51027) /    -4.10,  -14.34,    0.00 /
      DATA B(51172), B(51173), B(51174) /    -4.13,  -14.27,    0.00 /
      DATA B(51319), B(51320), B(51321) /    -4.18,  -14.23,    0.00 /
      DATA B(51466), B(51467), B(51468) /    -4.22,  -14.18,    0.00 /
      DATA B(51613), B(51614), B(51615) /    -4.26,  -14.13,    0.00 /
      DATA B(51760), B(51761), B(51762) /    -4.30,  -14.07,    0.00 /
      DATA B(51907), B(51908), B(51909) /    -4.34,  -14.02,    0.00 /
      DATA B(52054), B(52055), B(52056) /    -4.38,  -13.95,    0.00 /
      DATA B(52201), B(52202), B(52203) /    -4.41,  -13.89,    0.00 /
      DATA B(52348), B(52349), B(52350) /    -4.45,  -13.82,    0.00 /
      DATA B(52495), B(52496), B(52497) /    -4.48,  -13.74,    0.00 /
      DATA B(52642), B(52643), B(52644) /    -4.51,  -13.66,    0.00 /
      DATA B(52789), B(52790), B(52791) /    -4.53,  -13.58,    0.00 /
      DATA B(52936), B(52937), B(52938) /    -4.56,  -13.49,    0.00 /
      DATA B(53083), B(53084), B(53085) /    -4.59,  -13.39,    0.00 /
      DATA B(53230), B(53231), B(53232) /    -4.62,  -13.29,    0.00 /
      DATA B(53377), B(53378), B(53379) /    -4.64,  -13.18,    0.00 /
      DATA B(53524), B(53525), B(53526) /    -4.67,  -13.06,    0.00 /
      DATA B(53671), B(53672), B(53673) /    -4.69,  -12.93,    0.00 /
      DATA B(53818), B(53819), B(53820) /    -4.71,  -12.79,    0.00 /
      DATA B(53965), B(53966), B(53967) /    -4.73,  -12.64,    0.00 /
      DATA B(54112), B(54113), B(54114) /    -4.74,  -12.49,    0.00 /
      DATA B(54259), B(54260), B(54261) /    -4.74,  -12.34,    0.00 /
      DATA B(54406), B(54407), B(54408) /    -4.74,  -12.18,    0.00 /
      DATA B(54553), B(54554), B(54555) /    -4.73,  -12.03,    0.00 /
      DATA B(54700), B(54701), B(54702) /    -4.72,  -11.89,    0.00 /
      DATA B(54847), B(54848), B(54849) /    -4.70,  -11.76,    0.00 /
      DATA B(54994), B(54995), B(54996) /    -4.68,  -11.64,    0.00 /
      DATA B(55141), B(55142), B(55143) /    -4.66,  -11.53,    0.00 /
      DATA B(55288), B(55289), B(55290) /    -4.65,  -11.42,    0.00 /
      DATA B(55435), B(55436), B(55437) /    -4.64,  -11.33,    0.00 /
      DATA B(55582), B(55583), B(55584) /    -4.63,  -11.24,    0.00 /
      DATA B(55729), B(55730), B(55731) /    -4.64,  -11.16,    0.00 /
      DATA B(55876), B(55877), B(55878) /    -4.64,  -11.08,    0.00 /
      DATA B(56023), B(56024), B(56025) /    -4.65,  -11.00,    0.00 /
      DATA B(56170), B(56171), B(56172) /    -4.66,  -10.91,    0.00 /
      DATA B(56317), B(56318), B(56319) /    -4.68,  -10.83,    0.00 /
      DATA B(56464), B(56465), B(56466) /    -4.69,  -10.74,    0.00 /
      DATA B(56611), B(56612), B(56613) /    -4.71,  -10.65,    0.00 /
      DATA B(56758), B(56759), B(56760) /    -4.72,  -10.56,    0.00 /
      DATA B(56905), B(56906), B(56907) /    -4.73,  -10.47,    0.00 /
      DATA B(57052), B(57053), B(57054) /    -4.75,  -10.38,    0.00 /
      DATA B(57199), B(57200), B(57201) /    -4.76,  -10.28,    0.00 /
      DATA B(57346), B(57347), B(57348) /    -4.77,  -10.19,    0.00 /
      DATA B(57493), B(57494), B(57495) /    -4.78,  -10.10,    0.00 /
      DATA B(57640), B(57641), B(57642) /    -4.78,  -10.01,    0.00 /
      DATA B(57787), B(57788), B(57789) /    -4.79,   -9.93,    0.00 /
      DATA B(57934), B(57935), B(57936) /    -4.80,   -9.84,    0.00 /
      DATA B(58081), B(58082), B(58083) /    -4.81,   -9.77,    0.00 /
      DATA B(58228), B(58229), B(58230) /    -4.81,   -9.69,    0.00 /
      DATA B(58375), B(58376), B(58377) /    -4.82,   -9.62,    0.00 /
      DATA B(58522), B(58523), B(58524) /    -4.83,   -9.55,    0.00 /
      DATA B(58669), B(58670), B(58671) /    -4.83,   -9.48,    0.00 /
      DATA B(58816), B(58817), B(58818) /    -4.84,   -9.41,    0.00 /
      DATA B(58963), B(58964), B(58965) /    -4.84,   -9.34,    0.00 /
      DATA B(59110), B(59111), B(59112) /    -4.85,   -9.26,    0.00 /
      DATA B(59257), B(59258), B(59259) /    -4.87,   -9.19,    0.00 /
      DATA B(59404), B(59405), B(59406) /    -4.88,   -9.12,    0.00 /
      DATA B(59551), B(59552), B(59553) /    -4.90,   -9.05,    0.00 /
      DATA B(59698), B(59699), B(59700) /    -4.92,   -8.97,    0.00 /
      DATA B(59845), B(59846), B(59847) /    -4.95,   -8.89,    0.00 /
      DATA B(59992), B(59993), B(59994) /    -4.98,   -8.81,    0.00 /
      DATA B(60139), B(60140), B(60141) /    -5.01,   -8.71,    0.00 /
      DATA B(60286), B(60287), B(60288) /    -5.02,   -8.60,    0.00 /
      DATA B(60433), B(60434), B(60435) /    -5.06,   -8.53,    0.00 /
      DATA B(60580), B(60581), B(60582) /    -5.09,   -8.45,    0.00 /
      DATA B(60727), B(60728), B(60729) /    -5.13,   -8.37,    0.00 /
      DATA B(60874), B(60875), B(60876) /    -5.17,   -8.28,    0.00 /
      DATA B(61021), B(61022), B(61023) /    -5.22,   -8.19,    0.00 /
      DATA B(61168), B(61169), B(61170) /    -5.27,   -8.10,    0.00 /
      DATA B(61315), B(61316), B(61317) /    -5.32,   -8.00,    0.00 /
      DATA B(61462), B(61463), B(61464) /    -5.37,   -7.91,    0.00 /
      DATA B(61609), B(61610), B(61611) /    -5.44,   -7.81,    0.00 /
      DATA B(61756), B(61757), B(61758) /    -5.51,   -7.73,    0.00 /
      DATA B(61903), B(61904), B(61905) /    -5.58,   -7.68,    0.00 /
      DATA B(62050), B(62051), B(62052) /    -5.61,   -7.67,    0.00 /
      DATA B(62197), B(62198), B(62199) /    -5.74,   -7.78,    0.00 /
      DATA B(62344), B(62345), B(62346) /    -5.82,   -7.80,    0.00 /
      DATA B(62491), B(62492), B(62493) /    -5.90,   -7.78,    0.00 /
      DATA B(62638), B(62639), B(62640) /    -5.98,   -7.74,    0.00 /
      DATA B(62785), B(62786), B(62787) /    -6.04,   -7.70,    0.00 /
      DATA B(62932), B(62933), B(62934) /    -6.10,   -7.65,    0.00 /
      DATA B(63079), B(63080), B(63081) /    -6.16,   -7.60,    0.00 /
      DATA B(63226), B(63227), B(63228) /    -6.22,   -7.55,    0.00 /
      DATA B(63373), B(63374), B(63375) /    -6.28,   -7.50,    0.00 /
      DATA B(63520), B(63521), B(63522) /    -6.35,   -7.46,    0.00 /
      DATA B(63667), B(63668), B(63669) /    -6.42,   -7.42,    0.00 /
      DATA B(63814), B(63815), B(63816) /    -6.51,   -7.37,    0.00 /
      DATA B(63961), B(63962), B(63963) /    -6.59,   -7.32,    0.00 /
      DATA B(64108), B(64109), B(64110) /    -6.66,   -7.24,    0.00 /
      DATA B(64255), B(64256), B(64257) /    -6.75,   -7.21,    0.00 /
      DATA B(64402), B(64403), B(64404) /    -6.92,   -7.33,    0.00 /
      DATA B(64549), B(64550), B(64551) /    -6.93,   -7.35,    0.00 /
      DATA B(64696), B(64697), B(64698) /    -7.04,   -7.35,    0.00 /
      DATA B(64843), B(64844), B(64845) /    -7.13,   -7.36,    0.00 /
      DATA B(64990), B(64991), B(64992) /    -7.19,   -7.40,    0.00 /
      DATA B(65137), B(65138), B(65139) /    -7.23,   -7.46,    0.00 /
      DATA B(65284), B(65285), B(65286) /    -7.25,   -7.56,    0.00 /
      DATA B(65431), B(65432), B(65433) /    -7.27,   -7.72,    0.00 /
      DATA B(65578), B(65579), B(65580) /    -7.25,   -7.90,    0.00 /
      DATA B(65725), B(65726), B(65727) /    -7.23,   -8.15,    0.00 /
      DATA B(65872), B(65873), B(65874) /    -7.22,   -8.41,    0.00 /
      DATA B(66019), B(66020), B(66021) /    -7.27,   -8.62,    0.00 /
      DATA B(66166), B(66167), B(66168) /    -7.34,   -8.79,    0.00 /
      DATA B(66313), B(66314), B(66315) /    -7.42,   -8.92,    0.00 /
      DATA B(66460), B(66461), B(66462) /    -7.50,   -9.04,    0.00 /
      DATA B(66607), B(66608), B(66609) /    -7.57,   -9.14,    0.00 /
      DATA B(66754), B(66755), B(66756) /    -7.64,   -9.24,    0.00 /
      DATA B(66901), B(66902), B(66903) /    -7.71,   -9.33,    0.00 /
      DATA B(67048), B(67049), B(67050) /    -7.78,   -9.41,    0.00 /
      DATA B(67195), B(67196), B(67197) /    -7.85,   -9.49,    0.00 /
      DATA B(67342), B(67343), B(67344) /    -7.91,   -9.56,    0.00 /
      DATA B(67489), B(67490), B(67491) /    -7.98,   -9.63,    0.00 /
      DATA B(67636), B(67637), B(67638) /    -8.04,   -9.70,    0.00 /
      DATA B(46471), B(46472), B(46473) /    -4.36,  -23.40,    0.00 /
      DATA B(46618), B(46619), B(46620) /    -4.54,  -23.05,    0.00 /
      DATA B(46765), B(46766), B(46767) /    -4.68,  -22.72,    0.00 /
      DATA B(46912), B(46913), B(46914) /    -4.80,  -22.40,    0.00 /
      DATA B(47059), B(47060), B(47061) /    -4.90,  -22.09,    0.00 /
      DATA B(47206), B(47207), B(47208) /    -4.99,  -21.78,    0.00 /
      DATA B(47353), B(47354), B(47355) /    -5.06,  -21.46,    0.00 /
      DATA B(47500), B(47501), B(47502) /    -5.12,  -21.13,    0.00 /
      DATA B(47647), B(47648), B(47649) /    -5.17,  -20.79,    0.00 /
      DATA B(47794), B(47795), B(47796) /    -5.22,  -20.42,    0.00 /
      DATA B(47941), B(47942), B(47943) /    -5.25,  -20.04,    0.00 /
      DATA B(48088), B(48089), B(48090) /    -5.26,  -19.63,    0.00 /
      DATA B(48235), B(48236), B(48237) /    -5.25,  -19.22,    0.00 /
      DATA B(48382), B(48383), B(48384) /    -5.22,  -18.81,    0.00 /
      DATA B(48529), B(48530), B(48531) /    -5.15,  -18.41,    0.00 /
      DATA B(48676), B(48677), B(48678) /    -5.05,  -18.04,    0.00 /
      DATA B(48823), B(48824), B(48825) /    -4.93,  -17.68,    0.00 /
      DATA B(48970), B(48971), B(48972) /    -4.78,  -17.38,    0.00 /
      DATA B(49117), B(49118), B(49119) /    -4.65,  -17.13,    0.00 /
      DATA B(49264), B(49265), B(49266) /    -4.53,  -16.94,    0.00 /
      DATA B(49411), B(49412), B(49413) /    -4.45,  -16.82,    0.00 /
      DATA B(49558), B(49559), B(49560) /    -4.41,  -16.74,    0.00 /
      DATA B(49705), B(49706), B(49707) /    -4.40,  -16.69,    0.00 /
      DATA B(49852), B(49853), B(49854) /    -4.41,  -16.62,    0.00 /
      DATA B(49999), B(50000), B(50001) /    -4.45,  -16.51,    0.00 /
      DATA B(50146), B(50147), B(50148) /    -4.47,  -16.32,    0.00 /
      DATA B(50293), B(50294), B(50295) /    -4.46,  -16.03,    0.00 /
      DATA B(50440), B(50441), B(50442) /    -4.38,  -15.61,    0.00 /
      DATA B(50587), B(50588), B(50589) /    -4.33,  -15.17,    0.00 /
      DATA B(50734), B(50735), B(50736) /    -4.11,  -14.66,    0.00 /
      DATA B(50881), B(50882), B(50883) /    -4.22,  -14.55,    0.00 /
      DATA B(51028), B(51029), B(51030) /    -4.25,  -14.45,    0.00 /
      DATA B(51175), B(51176), B(51177) /    -4.28,  -14.39,    0.00 /
      DATA B(51322), B(51323), B(51324) /    -4.31,  -14.33,    0.00 /
      DATA B(51469), B(51470), B(51471) /    -4.35,  -14.28,    0.00 /
      DATA B(51616), B(51617), B(51618) /    -4.39,  -14.23,    0.00 /
      DATA B(51763), B(51764), B(51765) /    -4.43,  -14.18,    0.00 /
      DATA B(51910), B(51911), B(51912) /    -4.46,  -14.12,    0.00 /
      DATA B(52057), B(52058), B(52059) /    -4.50,  -14.05,    0.00 /
      DATA B(52204), B(52205), B(52206) /    -4.53,  -13.99,    0.00 /
      DATA B(52351), B(52352), B(52353) /    -4.56,  -13.91,    0.00 /
      DATA B(52498), B(52499), B(52500) /    -4.59,  -13.84,    0.00 /
      DATA B(52645), B(52646), B(52647) /    -4.62,  -13.76,    0.00 /
      DATA B(52792), B(52793), B(52794) /    -4.65,  -13.67,    0.00 /
      DATA B(52939), B(52940), B(52941) /    -4.67,  -13.58,    0.00 /
      DATA B(53086), B(53087), B(53088) /    -4.70,  -13.48,    0.00 /
      DATA B(53233), B(53234), B(53235) /    -4.73,  -13.38,    0.00 /
      DATA B(53380), B(53381), B(53382) /    -4.75,  -13.27,    0.00 /
      DATA B(53527), B(53528), B(53529) /    -4.78,  -13.15,    0.00 /
      DATA B(53674), B(53675), B(53676) /    -4.80,  -13.03,    0.00 /
      DATA B(53821), B(53822), B(53823) /    -4.82,  -12.89,    0.00 /
      DATA B(53968), B(53969), B(53970) /    -4.84,  -12.75,    0.00 /
      DATA B(54115), B(54116), B(54117) /    -4.85,  -12.61,    0.00 /
      DATA B(54262), B(54263), B(54264) /    -4.85,  -12.46,    0.00 /
      DATA B(54409), B(54410), B(54411) /    -4.85,  -12.31,    0.00 /
      DATA B(54556), B(54557), B(54558) /    -4.84,  -12.17,    0.00 /
      DATA B(54703), B(54704), B(54705) /    -4.83,  -12.03,    0.00 /
      DATA B(54850), B(54851), B(54852) /    -4.81,  -11.90,    0.00 /
      DATA B(54997), B(54998), B(54999) /    -4.80,  -11.78,    0.00 /
      DATA B(55144), B(55145), B(55146) /    -4.78,  -11.67,    0.00 /
      DATA B(55291), B(55292), B(55293) /    -4.77,  -11.57,    0.00 /
      DATA B(55438), B(55439), B(55440) /    -4.76,  -11.48,    0.00 /
      DATA B(55585), B(55586), B(55587) /    -4.76,  -11.39,    0.00 /
      DATA B(55732), B(55733), B(55734) /    -4.76,  -11.30,    0.00 /
      DATA B(55879), B(55880), B(55881) /    -4.77,  -11.22,    0.00 /
      DATA B(56026), B(56027), B(56028) /    -4.77,  -11.13,    0.00 /
      DATA B(56173), B(56174), B(56175) /    -4.79,  -11.05,    0.00 /
      DATA B(56320), B(56321), B(56322) /    -4.80,  -10.96,    0.00 /
      DATA B(56467), B(56468), B(56469) /    -4.81,  -10.88,    0.00 /
      DATA B(56614), B(56615), B(56616) /    -4.82,  -10.79,    0.00 /
      DATA B(56761), B(56762), B(56763) /    -4.84,  -10.70,    0.00 /
      DATA B(56908), B(56909), B(56910) /    -4.85,  -10.60,    0.00 /
      DATA B(57055), B(57056), B(57057) /    -4.86,  -10.51,    0.00 /
      DATA B(57202), B(57203), B(57204) /    -4.87,  -10.42,    0.00 /
      DATA B(57349), B(57350), B(57351) /    -4.88,  -10.33,    0.00 /
      DATA B(57496), B(57497), B(57498) /    -4.89,  -10.24,    0.00 /
      DATA B(57643), B(57644), B(57645) /    -4.91,  -10.16,    0.00 /
      DATA B(57790), B(57791), B(57792) /    -4.91,  -10.07,    0.00 /
      DATA B(57937), B(57938), B(57939) /    -4.92,   -9.99,    0.00 /
      DATA B(58084), B(58085), B(58086) /    -4.93,   -9.92,    0.00 /
      DATA B(58231), B(58232), B(58233) /    -4.94,   -9.84,    0.00 /
      DATA B(58378), B(58379), B(58380) /    -4.95,   -9.77,    0.00 /
      DATA B(58525), B(58526), B(58527) /    -4.96,   -9.71,    0.00 /
      DATA B(58672), B(58673), B(58674) /    -4.96,   -9.64,    0.00 /
      DATA B(58819), B(58820), B(58821) /    -4.97,   -9.57,    0.00 /
      DATA B(58966), B(58967), B(58968) /    -4.98,   -9.50,    0.00 /
      DATA B(59113), B(59114), B(59115) /    -4.99,   -9.43,    0.00 /
      DATA B(59260), B(59261), B(59262) /    -5.00,   -9.36,    0.00 /
      DATA B(59407), B(59408), B(59409) /    -5.02,   -9.29,    0.00 /
      DATA B(59554), B(59555), B(59556) /    -5.04,   -9.21,    0.00 /
      DATA B(59701), B(59702), B(59703) /    -5.07,   -9.14,    0.00 /
      DATA B(59848), B(59849), B(59850) /    -5.10,   -9.06,    0.00 /
      DATA B(59995), B(59996), B(59997) /    -5.13,   -8.97,    0.00 /
      DATA B(60142), B(60143), B(60144) /    -5.16,   -8.87,    0.00 /
      DATA B(60289), B(60290), B(60291) /    -5.17,   -8.78,    0.00 /
      DATA B(60436), B(60437), B(60438) /    -5.20,   -8.70,    0.00 /
      DATA B(60583), B(60584), B(60585) /    -5.24,   -8.62,    0.00 /
      DATA B(60730), B(60731), B(60732) /    -5.28,   -8.55,    0.00 /
      DATA B(60877), B(60878), B(60879) /    -5.33,   -8.46,    0.00 /
      DATA B(61024), B(61025), B(61026) /    -5.37,   -8.38,    0.00 /
      DATA B(61171), B(61172), B(61173) /    -5.42,   -8.29,    0.00 /
      DATA B(61318), B(61319), B(61320) /    -5.46,   -8.19,    0.00 /
      DATA B(61465), B(61466), B(61467) /    -5.52,   -8.09,    0.00 /
      DATA B(61612), B(61613), B(61614) /    -5.58,   -8.00,    0.00 /
      DATA B(61759), B(61760), B(61761) /    -5.65,   -7.93,    0.00 /
      DATA B(61906), B(61907), B(61908) /    -5.72,   -7.88,    0.00 /
      DATA B(62053), B(62054), B(62055) /    -5.77,   -7.88,    0.00 /
      DATA B(62200), B(62201), B(62202) /    -5.88,   -8.00,    0.00 /
      DATA B(62347), B(62348), B(62349) /    -5.95,   -8.02,    0.00 /
      DATA B(62494), B(62495), B(62496) /    -6.04,   -8.01,    0.00 /
      DATA B(62641), B(62642), B(62643) /    -6.12,   -7.97,    0.00 /
      DATA B(62788), B(62789), B(62790) /    -6.18,   -7.93,    0.00 /
      DATA B(62935), B(62936), B(62937) /    -6.24,   -7.89,    0.00 /
      DATA B(63082), B(63083), B(63084) /    -6.30,   -7.84,    0.00 /
      DATA B(63229), B(63230), B(63231) /    -6.36,   -7.79,    0.00 /
      DATA B(63376), B(63377), B(63378) /    -6.42,   -7.75,    0.00 /
      DATA B(63523), B(63524), B(63525) /    -6.50,   -7.70,    0.00 /
      DATA B(63670), B(63671), B(63672) /    -6.58,   -7.67,    0.00 /
      DATA B(63817), B(63818), B(63819) /    -6.68,   -7.63,    0.00 /
      DATA B(63964), B(63965), B(63966) /    -6.76,   -7.59,    0.00 /
      DATA B(64111), B(64112), B(64113) /    -6.81,   -7.53,    0.00 /
      DATA B(64258), B(64259), B(64260) /    -6.86,   -7.41,    0.00 /
      DATA B(64405), B(64406), B(64407) /    -6.99,   -7.57,    0.00 /
      DATA B(64552), B(64553), B(64554) /    -7.07,   -7.52,    0.00 /
      DATA B(64699), B(64700), B(64701) /    -7.17,   -7.53,    0.00 /
      DATA B(64846), B(64847), B(64848) /    -7.24,   -7.56,    0.00 /
      DATA B(64993), B(64994), B(64995) /    -7.29,   -7.60,    0.00 /
      DATA B(65140), B(65141), B(65142) /    -7.32,   -7.66,    0.00 /
      DATA B(65287), B(65288), B(65289) /    -7.34,   -7.75,    0.00 /
      DATA B(65434), B(65435), B(65436) /    -7.35,   -7.92,    0.00 /
      DATA B(65581), B(65582), B(65583) /    -7.31,   -8.07,    0.00 /
      DATA B(65728), B(65729), B(65730) /    -7.31,   -8.34,    0.00 /
      DATA B(65875), B(65876), B(65877) /    -7.31,   -8.59,    0.00 /
      DATA B(66022), B(66023), B(66024) /    -7.36,   -8.78,    0.00 /
      DATA B(66169), B(66170), B(66171) /    -7.43,   -8.93,    0.00 /
      DATA B(66316), B(66317), B(66318) /    -7.51,   -9.05,    0.00 /
      DATA B(66463), B(66464), B(66465) /    -7.58,   -9.16,    0.00 /
      DATA B(66610), B(66611), B(66612) /    -7.65,   -9.25,    0.00 /
      DATA B(66757), B(66758), B(66759) /    -7.72,   -9.34,    0.00 /
      DATA B(66904), B(66905), B(66906) /    -7.78,   -9.43,    0.00 /
      DATA B(67051), B(67052), B(67053) /    -7.85,   -9.50,    0.00 /
      DATA B(67198), B(67199), B(67200) /    -7.91,   -9.58,    0.00 /
      DATA B(67345), B(67346), B(67347) /    -7.97,   -9.65,    0.00 /
      DATA B(67492), B(67493), B(67494) /    -8.03,   -9.71,    0.00 /
      DATA B(67639), B(67640), B(67641) /    -8.09,   -9.78,    0.00 /
      DATA B(46474), B(46475), B(46476) /    -4.53,  -23.20,    0.00 /
      DATA B(46621), B(46622), B(46623) /    -4.68,  -22.89,    0.00 /
      DATA B(46768), B(46769), B(46770) /    -4.81,  -22.60,    0.00 /
      DATA B(46915), B(46916), B(46917) /    -4.92,  -22.31,    0.00 /
      DATA B(47062), B(47063), B(47064) /    -5.01,  -22.03,    0.00 /
      DATA B(47209), B(47210), B(47211) /    -5.09,  -21.74,    0.00 /
      DATA B(47356), B(47357), B(47358) /    -5.16,  -21.45,    0.00 /
      DATA B(47503), B(47504), B(47505) /    -5.23,  -21.14,    0.00 /
      DATA B(47650), B(47651), B(47652) /    -5.28,  -20.82,    0.00 /
      DATA B(47797), B(47798), B(47799) /    -5.33,  -20.47,    0.00 /
      DATA B(47944), B(47945), B(47946) /    -5.36,  -20.11,    0.00 /
      DATA B(48091), B(48092), B(48093) /    -5.38,  -19.73,    0.00 /
      DATA B(48238), B(48239), B(48240) /    -5.37,  -19.34,    0.00 /
      DATA B(48385), B(48386), B(48387) /    -5.33,  -18.95,    0.00 /
      DATA B(48532), B(48533), B(48534) /    -5.26,  -18.57,    0.00 /
      DATA B(48679), B(48680), B(48681) /    -5.16,  -18.21,    0.00 /
      DATA B(48826), B(48827), B(48828) /    -5.03,  -17.86,    0.00 /
      DATA B(48973), B(48974), B(48975) /    -4.86,  -17.56,    0.00 /
      DATA B(49120), B(49121), B(49122) /    -4.73,  -17.29,    0.00 /
      DATA B(49267), B(49268), B(49269) /    -4.61,  -17.09,    0.00 /
      DATA B(49414), B(49415), B(49416) /    -4.53,  -16.96,    0.00 /
      DATA B(49561), B(49562), B(49563) /    -4.48,  -16.86,    0.00 /
      DATA B(49708), B(49709), B(49710) /    -4.47,  -16.79,    0.00 /
      DATA B(49855), B(49856), B(49857) /    -4.48,  -16.72,    0.00 /
      DATA B(50002), B(50003), B(50004) /    -4.51,  -16.61,    0.00 /
      DATA B(50149), B(50150), B(50151) /    -4.54,  -16.44,    0.00 /
      DATA B(50296), B(50297), B(50298) /    -4.53,  -16.17,    0.00 /
      DATA B(50443), B(50444), B(50445) /    -4.47,  -15.76,    0.00 /
      DATA B(50590), B(50591), B(50592) /    -4.36,  -15.28,    0.00 /
      DATA B(50737), B(50738), B(50739) /    -4.32,  -14.82,    0.00 /
      DATA B(50884), B(50885), B(50886) /    -4.37,  -14.66,    0.00 /
      DATA B(51031), B(51032), B(51033) /    -4.39,  -14.56,    0.00 /
      DATA B(51178), B(51179), B(51180) /    -4.42,  -14.50,    0.00 /
      DATA B(51325), B(51326), B(51327) /    -4.44,  -14.44,    0.00 /
      DATA B(51472), B(51473), B(51474) /    -4.48,  -14.39,    0.00 /
      DATA B(51619), B(51620), B(51621) /    -4.51,  -14.33,    0.00 /
      DATA B(51766), B(51767), B(51768) /    -4.55,  -14.28,    0.00 /
      DATA B(51913), B(51914), B(51915) /    -4.58,  -14.21,    0.00 /
      DATA B(52060), B(52061), B(52062) /    -4.61,  -14.15,    0.00 /
      DATA B(52207), B(52208), B(52209) /    -4.64,  -14.08,    0.00 /
      DATA B(52354), B(52355), B(52356) /    -4.67,  -14.01,    0.00 /
      DATA B(52501), B(52502), B(52503) /    -4.70,  -13.93,    0.00 /
      DATA B(52648), B(52649), B(52650) /    -4.73,  -13.85,    0.00 /
      DATA B(52795), B(52796), B(52797) /    -4.76,  -13.76,    0.00 /
      DATA B(52942), B(52943), B(52944) /    -4.79,  -13.67,    0.00 /
      DATA B(53089), B(53090), B(53091) /    -4.81,  -13.58,    0.00 /
      DATA B(53236), B(53237), B(53238) /    -4.84,  -13.47,    0.00 /
      DATA B(53383), B(53384), B(53385) /    -4.86,  -13.36,    0.00 /
      DATA B(53530), B(53531), B(53532) /    -4.89,  -13.25,    0.00 /
      DATA B(53677), B(53678), B(53679) /    -4.91,  -13.12,    0.00 /
      DATA B(53824), B(53825), B(53826) /    -4.93,  -12.99,    0.00 /
      DATA B(53971), B(53972), B(53973) /    -4.94,  -12.86,    0.00 /
      DATA B(54118), B(54119), B(54120) /    -4.95,  -12.72,    0.00 /
      DATA B(54265), B(54266), B(54267) /    -4.95,  -12.58,    0.00 /
      DATA B(54412), B(54413), B(54414) /    -4.95,  -12.44,    0.00 /
      DATA B(54559), B(54560), B(54561) /    -4.95,  -12.30,    0.00 /
      DATA B(54706), B(54707), B(54708) /    -4.94,  -12.17,    0.00 /
      DATA B(54853), B(54854), B(54855) /    -4.92,  -12.04,    0.00 /
      DATA B(55000), B(55001), B(55002) /    -4.91,  -11.92,    0.00 /
      DATA B(55147), B(55148), B(55149) /    -4.90,  -11.81,    0.00 /
      DATA B(55294), B(55295), B(55296) /    -4.89,  -11.71,    0.00 /
      DATA B(55441), B(55442), B(55443) /    -4.88,  -11.61,    0.00 /
      DATA B(55588), B(55589), B(55590) /    -4.88,  -11.52,    0.00 /
      DATA B(55735), B(55736), B(55737) /    -4.88,  -11.44,    0.00 /
      DATA B(55882), B(55883), B(55884) /    -4.89,  -11.35,    0.00 /
      DATA B(56029), B(56030), B(56031) /    -4.89,  -11.26,    0.00 /
      DATA B(56176), B(56177), B(56178) /    -4.90,  -11.18,    0.00 /
      DATA B(56323), B(56324), B(56325) /    -4.91,  -11.09,    0.00 /
      DATA B(56470), B(56471), B(56472) /    -4.93,  -11.00,    0.00 /
      DATA B(56617), B(56618), B(56619) /    -4.94,  -10.92,    0.00 /
      DATA B(56764), B(56765), B(56766) /    -4.95,  -10.83,    0.00 /
      DATA B(56911), B(56912), B(56913) /    -4.96,  -10.73,    0.00 /
      DATA B(57058), B(57059), B(57060) /    -4.98,  -10.64,    0.00 /
      DATA B(57205), B(57206), B(57207) /    -4.99,  -10.55,    0.00 /
      DATA B(57352), B(57353), B(57354) /    -5.00,  -10.46,    0.00 /
      DATA B(57499), B(57500), B(57501) /    -5.01,  -10.38,    0.00 /
      DATA B(57646), B(57647), B(57648) /    -5.02,  -10.29,    0.00 /
      DATA B(57793), B(57794), B(57795) /    -5.04,  -10.21,    0.00 /
      DATA B(57940), B(57941), B(57942) /    -5.05,  -10.14,    0.00 /
      DATA B(58087), B(58088), B(58089) /    -5.06,  -10.06,    0.00 /
      DATA B(58234), B(58235), B(58236) /    -5.07,   -9.99,    0.00 /
      DATA B(58381), B(58382), B(58383) /    -5.08,   -9.93,    0.00 /
      DATA B(58528), B(58529), B(58530) /    -5.09,   -9.87,    0.00 /
      DATA B(58675), B(58676), B(58677) /    -5.10,   -9.80,    0.00 /
      DATA B(58822), B(58823), B(58824) /    -5.11,   -9.74,    0.00 /
      DATA B(58969), B(58970), B(58971) /    -5.12,   -9.67,    0.00 /
      DATA B(59116), B(59117), B(59118) /    -5.13,   -9.60,    0.00 /
      DATA B(59263), B(59264), B(59265) /    -5.14,   -9.53,    0.00 /
      DATA B(59410), B(59411), B(59412) /    -5.16,   -9.45,    0.00 /
      DATA B(59557), B(59558), B(59559) /    -5.18,   -9.38,    0.00 /
      DATA B(59704), B(59705), B(59706) /    -5.21,   -9.29,    0.00 /
      DATA B(59851), B(59852), B(59853) /    -5.24,   -9.22,    0.00 /
      DATA B(59998), B(59999), B(60000) /    -5.26,   -9.10,    0.00 /
      DATA B(60145), B(60146), B(60147) /    -5.28,   -9.03,    0.00 /
      DATA B(60292), B(60293), B(60294) /    -5.31,   -8.95,    0.00 /
      DATA B(60439), B(60440), B(60441) /    -5.35,   -8.87,    0.00 /
      DATA B(60586), B(60587), B(60588) /    -5.39,   -8.80,    0.00 /
      DATA B(60733), B(60734), B(60735) /    -5.43,   -8.73,    0.00 /
      DATA B(60880), B(60881), B(60882) /    -5.48,   -8.65,    0.00 /
      DATA B(61027), B(61028), B(61029) /    -5.52,   -8.56,    0.00 /
      DATA B(61174), B(61175), B(61176) /    -5.56,   -8.47,    0.00 /
      DATA B(61321), B(61322), B(61323) /    -5.61,   -8.37,    0.00 /
      DATA B(61468), B(61469), B(61470) /    -5.66,   -8.28,    0.00 /
      DATA B(61615), B(61616), B(61617) /    -5.71,   -8.19,    0.00 /
      DATA B(61762), B(61763), B(61764) /    -5.78,   -8.11,    0.00 /
      DATA B(61909), B(61910), B(61911) /    -5.85,   -8.07,    0.00 /
      DATA B(62056), B(62057), B(62058) /    -5.89,   -8.08,    0.00 /
      DATA B(62203), B(62204), B(62205) /    -6.01,   -8.21,    0.00 /
      DATA B(62350), B(62351), B(62352) /    -6.09,   -8.24,    0.00 /
      DATA B(62497), B(62498), B(62499) /    -6.17,   -8.23,    0.00 /
      DATA B(62644), B(62645), B(62646) /    -6.25,   -8.20,    0.00 /
      DATA B(62791), B(62792), B(62793) /    -6.32,   -8.16,    0.00 /
      DATA B(62938), B(62939), B(62940) /    -6.38,   -8.12,    0.00 /
      DATA B(63085), B(63086), B(63087) /    -6.44,   -8.07,    0.00 /
      DATA B(63232), B(63233), B(63234) /    -6.50,   -8.03,    0.00 /
      DATA B(63379), B(63380), B(63381) /    -6.57,   -7.98,    0.00 /
      DATA B(63526), B(63527), B(63528) /    -6.65,   -7.94,    0.00 /
      DATA B(63673), B(63674), B(63675) /    -6.74,   -7.90,    0.00 /
      DATA B(63820), B(63821), B(63822) /    -6.85,   -7.87,    0.00 /
      DATA B(63967), B(63968), B(63969) /    -6.96,   -7.84,    0.00 /
      DATA B(64114), B(64115), B(64116) /    -7.04,   -7.78,    0.00 /
      DATA B(64261), B(64262), B(64263) /    -7.15,   -7.69,    0.00 /
      DATA B(64408), B(64409), B(64410) /    -7.30,   -7.75,    0.00 /
      DATA B(64555), B(64556), B(64557) /    -7.27,   -7.71,    0.00 /
      DATA B(64702), B(64703), B(64704) /    -7.31,   -7.73,    0.00 /
      DATA B(64849), B(64850), B(64851) /    -7.35,   -7.76,    0.00 /
      DATA B(64996), B(64997), B(64998) /    -7.38,   -7.79,    0.00 /
      DATA B(65143), B(65144), B(65145) /    -7.40,   -7.85,    0.00 /
      DATA B(65290), B(65291), B(65292) /    -7.41,   -7.94,    0.00 /
      DATA B(65437), B(65438), B(65439) /    -7.43,   -8.11,    0.00 /
      DATA B(65584), B(65585), B(65586) /    -7.42,   -8.30,    0.00 /
      DATA B(65731), B(65732), B(65733) /    -7.38,   -8.54,    0.00 /
      DATA B(65878), B(65879), B(65880) /    -7.38,   -8.76,    0.00 /
      DATA B(66025), B(66026), B(66027) /    -7.44,   -8.93,    0.00 /
      DATA B(66172), B(66173), B(66174) /    -7.51,   -9.07,    0.00 /
      DATA B(66319), B(66320), B(66321) /    -7.59,   -9.18,    0.00 /
      DATA B(66466), B(66467), B(66468) /    -7.66,   -9.27,    0.00 /
      DATA B(66613), B(66614), B(66615) /    -7.72,   -9.36,    0.00 /
      DATA B(66760), B(66761), B(66762) /    -7.79,   -9.44,    0.00 /
      DATA B(66907), B(66908), B(66909) /    -7.85,   -9.52,    0.00 /
      DATA B(67054), B(67055), B(67056) /    -7.91,   -9.59,    0.00 /
      DATA B(67201), B(67202), B(67203) /    -7.97,   -9.66,    0.00 /
      DATA B(67348), B(67349), B(67350) /    -8.03,   -9.73,    0.00 /
      DATA B(67495), B(67496), B(67497) /    -8.09,   -9.79,    0.00 /
      DATA B(67642), B(67643), B(67644) /    -8.15,   -9.86,    0.00 /
      DATA B(46477), B(46478), B(46479) /    -4.67,  -23.03,    0.00 /
      DATA B(46624), B(46625), B(46626) /    -4.80,  -22.75,    0.00 /
      DATA B(46771), B(46772), B(46773) /    -4.91,  -22.49,    0.00 /
      DATA B(46918), B(46919), B(46920) /    -5.01,  -22.23,    0.00 /
      DATA B(47065), B(47066), B(47067) /    -5.10,  -21.97,    0.00 /
      DATA B(47212), B(47213), B(47214) /    -5.18,  -21.70,    0.00 /
      DATA B(47359), B(47360), B(47361) /    -5.25,  -21.42,    0.00 /
      DATA B(47506), B(47507), B(47508) /    -5.31,  -21.14,    0.00 /
      DATA B(47653), B(47654), B(47655) /    -5.37,  -20.83,    0.00 /
      DATA B(47800), B(47801), B(47802) /    -5.42,  -20.51,    0.00 /
      DATA B(47947), B(47948), B(47949) /    -5.45,  -20.17,    0.00 /
      DATA B(48094), B(48095), B(48096) /    -5.47,  -19.81,    0.00 /
      DATA B(48241), B(48242), B(48243) /    -5.46,  -19.44,    0.00 /
      DATA B(48388), B(48389), B(48390) /    -5.41,  -19.07,    0.00 /
      DATA B(48535), B(48536), B(48537) /    -5.34,  -18.72,    0.00 /
      DATA B(48682), B(48683), B(48684) /    -5.24,  -18.38,    0.00 /
      DATA B(48829), B(48830), B(48831) /    -5.12,  -18.06,    0.00 /
      DATA B(48976), B(48977), B(48978) /    -4.95,  -17.72,    0.00 /
      DATA B(49123), B(49124), B(49125) /    -4.79,  -17.44,    0.00 /
      DATA B(49270), B(49271), B(49272) /    -4.68,  -17.23,    0.00 /
      DATA B(49417), B(49418), B(49419) /    -4.60,  -17.07,    0.00 /
      DATA B(49564), B(49565), B(49566) /    -4.55,  -16.97,    0.00 /
      DATA B(49711), B(49712), B(49713) /    -4.53,  -16.88,    0.00 /
      DATA B(49858), B(49859), B(49860) /    -4.54,  -16.80,    0.00 /
      DATA B(50005), B(50006), B(50007) /    -4.57,  -16.69,    0.00 /
      DATA B(50152), B(50153), B(50154) /    -4.59,  -16.53,    0.00 /
      DATA B(50299), B(50300), B(50301) /    -4.58,  -16.28,    0.00 /
      DATA B(50446), B(50447), B(50448) /    -4.55,  -15.91,    0.00 /
      DATA B(50593), B(50594), B(50595) /    -4.51,  -15.42,    0.00 /
      DATA B(50740), B(50741), B(50742) /    -4.58,  -14.98,    0.00 /
      DATA B(50887), B(50888), B(50889) /    -4.53,  -14.78,    0.00 /
      DATA B(51034), B(51035), B(51036) /    -4.53,  -14.68,    0.00 /
      DATA B(51181), B(51182), B(51183) /    -4.55,  -14.61,    0.00 /
      DATA B(51328), B(51329), B(51330) /    -4.57,  -14.55,    0.00 /
      DATA B(51475), B(51476), B(51477) /    -4.60,  -14.49,    0.00 /
      DATA B(51622), B(51623), B(51624) /    -4.63,  -14.43,    0.00 /
      DATA B(51769), B(51770), B(51771) /    -4.66,  -14.37,    0.00 /
      DATA B(51916), B(51917), B(51918) /    -4.70,  -14.31,    0.00 /
      DATA B(52063), B(52064), B(52065) /    -4.73,  -14.24,    0.00 /
      DATA B(52210), B(52211), B(52212) /    -4.76,  -14.17,    0.00 /
      DATA B(52357), B(52358), B(52359) /    -4.79,  -14.10,    0.00 /
      DATA B(52504), B(52505), B(52506) /    -4.81,  -14.02,    0.00 /
      DATA B(52651), B(52652), B(52653) /    -4.84,  -13.94,    0.00 /
      DATA B(52798), B(52799), B(52800) /    -4.87,  -13.85,    0.00 /
      DATA B(52945), B(52946), B(52947) /    -4.89,  -13.76,    0.00 /
      DATA B(53092), B(53093), B(53094) /    -4.92,  -13.66,    0.00 /
      DATA B(53239), B(53240), B(53241) /    -4.94,  -13.56,    0.00 /
      DATA B(53386), B(53387), B(53388) /    -4.97,  -13.45,    0.00 /
      DATA B(53533), B(53534), B(53535) /    -4.99,  -13.34,    0.00 /
      DATA B(53680), B(53681), B(53682) /    -5.01,  -13.22,    0.00 /
      DATA B(53827), B(53828), B(53829) /    -5.03,  -13.09,    0.00 /
      DATA B(53974), B(53975), B(53976) /    -5.04,  -12.96,    0.00 /
      DATA B(54121), B(54122), B(54123) /    -5.05,  -12.83,    0.00 /
      DATA B(54268), B(54269), B(54270) /    -5.05,  -12.69,    0.00 /
      DATA B(54415), B(54416), B(54417) /    -5.05,  -12.56,    0.00 /
      DATA B(54562), B(54563), B(54564) /    -5.05,  -12.42,    0.00 /
      DATA B(54709), B(54710), B(54711) /    -5.04,  -12.29,    0.00 /
      DATA B(54856), B(54857), B(54858) /    -5.03,  -12.17,    0.00 /
      DATA B(55003), B(55004), B(55005) /    -5.02,  -12.06,    0.00 /
      DATA B(55150), B(55151), B(55152) /    -5.01,  -11.95,    0.00 /
      DATA B(55297), B(55298), B(55299) /    -5.00,  -11.84,    0.00 /
      DATA B(55444), B(55445), B(55446) /    -5.00,  -11.75,    0.00 /
      DATA B(55591), B(55592), B(55593) /    -5.00,  -11.65,    0.00 /
      DATA B(55738), B(55739), B(55740) /    -5.00,  -11.57,    0.00 /
      DATA B(55885), B(55886), B(55887) /    -5.00,  -11.48,    0.00 /
      DATA B(56032), B(56033), B(56034) /    -5.01,  -11.39,    0.00 /
      DATA B(56179), B(56180), B(56181) /    -5.02,  -11.30,    0.00 /
      DATA B(56326), B(56327), B(56328) /    -5.03,  -11.22,    0.00 /
      DATA B(56473), B(56474), B(56475) /    -5.04,  -11.13,    0.00 /
      DATA B(56620), B(56621), B(56622) /    -5.05,  -11.04,    0.00 /
      DATA B(56767), B(56768), B(56769) /    -5.07,  -10.95,    0.00 /
      DATA B(56914), B(56915), B(56916) /    -5.08,  -10.86,    0.00 /
      DATA B(57061), B(57062), B(57063) /    -5.09,  -10.77,    0.00 /
      DATA B(57208), B(57209), B(57210) /    -5.10,  -10.68,    0.00 /
      DATA B(57355), B(57356), B(57357) /    -5.12,  -10.59,    0.00 /
      DATA B(57502), B(57503), B(57504) /    -5.13,  -10.51,    0.00 /
      DATA B(57649), B(57650), B(57651) /    -5.14,  -10.43,    0.00 /
      DATA B(57796), B(57797), B(57798) /    -5.16,  -10.35,    0.00 /
      DATA B(57943), B(57944), B(57945) /    -5.17,  -10.27,    0.00 /
      DATA B(58090), B(58091), B(58092) /    -5.19,  -10.21,    0.00 /
      DATA B(58237), B(58238), B(58239) /    -5.20,  -10.14,    0.00 /
      DATA B(58384), B(58385), B(58386) /    -5.21,  -10.08,    0.00 /
      DATA B(58531), B(58532), B(58533) /    -5.22,  -10.02,    0.00 /
      DATA B(58678), B(58679), B(58680) /    -5.23,   -9.97,    0.00 /
      DATA B(58825), B(58826), B(58827) /    -5.24,   -9.90,    0.00 /
      DATA B(58972), B(58973), B(58974) /    -5.26,   -9.84,    0.00 /
      DATA B(59119), B(59120), B(59121) /    -5.27,   -9.77,    0.00 /
      DATA B(59266), B(59267), B(59268) /    -5.29,   -9.69,    0.00 /
      DATA B(59413), B(59414), B(59415) /    -5.30,   -9.61,    0.00 /
      DATA B(59560), B(59561), B(59562) /    -5.33,   -9.53,    0.00 /
      DATA B(59707), B(59708), B(59709) /    -5.35,   -9.43,    0.00 /
      DATA B(59854), B(59855), B(59856) /    -5.37,   -9.33,    0.00 /
      DATA B(60001), B(60002), B(60003) /    -5.40,   -9.26,    0.00 /
      DATA B(60148), B(60149), B(60150) /    -5.43,   -9.18,    0.00 /
      DATA B(60295), B(60296), B(60297) /    -5.46,   -9.11,    0.00 /
      DATA B(60442), B(60443), B(60444) /    -5.50,   -9.05,    0.00 /
      DATA B(60589), B(60590), B(60591) /    -5.54,   -8.98,    0.00 /
      DATA B(60736), B(60737), B(60738) /    -5.59,   -8.90,    0.00 /
      DATA B(60883), B(60884), B(60885) /    -5.63,   -8.82,    0.00 /
      DATA B(61030), B(61031), B(61032) /    -5.67,   -8.73,    0.00 /
      DATA B(61177), B(61178), B(61179) /    -5.71,   -8.64,    0.00 /
      DATA B(61324), B(61325), B(61326) /    -5.75,   -8.55,    0.00 /
      DATA B(61471), B(61472), B(61473) /    -5.79,   -8.45,    0.00 /
      DATA B(61618), B(61619), B(61620) /    -5.85,   -8.37,    0.00 /
      DATA B(61765), B(61766), B(61767) /    -5.91,   -8.29,    0.00 /
      DATA B(61912), B(61913), B(61914) /    -5.98,   -8.25,    0.00 /
      DATA B(62059), B(62060), B(62061) /    -6.03,   -8.26,    0.00 /
      DATA B(62206), B(62207), B(62208) /    -6.14,   -8.41,    0.00 /
      DATA B(62353), B(62354), B(62355) /    -6.22,   -8.45,    0.00 /
      DATA B(62500), B(62501), B(62502) /    -6.31,   -8.44,    0.00 /
      DATA B(62647), B(62648), B(62649) /    -6.39,   -8.42,    0.00 /
      DATA B(62794), B(62795), B(62796) /    -6.45,   -8.38,    0.00 /
      DATA B(62941), B(62942), B(62943) /    -6.51,   -8.34,    0.00 /
      DATA B(63088), B(63089), B(63090) /    -6.58,   -8.30,    0.00 /
      DATA B(63235), B(63236), B(63237) /    -6.64,   -8.25,    0.00 /
      DATA B(63382), B(63383), B(63384) /    -6.71,   -8.20,    0.00 /
      DATA B(63529), B(63530), B(63531) /    -6.79,   -8.16,    0.00 /
      DATA B(63676), B(63677), B(63678) /    -6.90,   -8.12,    0.00 /
      DATA B(63823), B(63824), B(63825) /    -7.02,   -8.08,    0.00 /
      DATA B(63970), B(63971), B(63972) /    -7.15,   -8.04,    0.00 /
      DATA B(64117), B(64118), B(64119) /    -7.24,   -7.96,    0.00 /
      DATA B(64264), B(64265), B(64266) /    -7.32,   -7.90,    0.00 /
      DATA B(64411), B(64412), B(64413) /    -7.42,   -8.01,    0.00 /
      DATA B(64558), B(64559), B(64560) /    -7.44,   -7.94,    0.00 /
      DATA B(64705), B(64706), B(64707) /    -7.44,   -7.94,    0.00 /
      DATA B(64852), B(64853), B(64854) /    -7.46,   -7.95,    0.00 /
      DATA B(64999), B(65000), B(65001) /    -7.47,   -7.99,    0.00 /
      DATA B(65146), B(65147), B(65148) /    -7.47,   -8.03,    0.00 /
      DATA B(65293), B(65294), B(65295) /    -7.47,   -8.12,    0.00 /
      DATA B(65440), B(65441), B(65442) /    -7.49,   -8.28,    0.00 /
      DATA B(65587), B(65588), B(65589) /    -7.47,   -8.50,    0.00 /
      DATA B(65734), B(65735), B(65736) /    -7.44,   -8.74,    0.00 /
      DATA B(65881), B(65882), B(65883) /    -7.46,   -8.93,    0.00 /
      DATA B(66028), B(66029), B(66030) /    -7.52,   -9.08,    0.00 /
      DATA B(66175), B(66176), B(66177) /    -7.59,   -9.20,    0.00 /
      DATA B(66322), B(66323), B(66324) /    -7.66,   -9.30,    0.00 /
      DATA B(66469), B(66470), B(66471) /    -7.73,   -9.38,    0.00 /
      DATA B(66616), B(66617), B(66618) /    -7.79,   -9.47,    0.00 /
      DATA B(66763), B(66764), B(66765) /    -7.86,   -9.54,    0.00 /
      DATA B(66910), B(66911), B(66912) /    -7.92,   -9.61,    0.00 /
      DATA B(67057), B(67058), B(67059) /    -7.97,   -9.68,    0.00 /
      DATA B(67204), B(67205), B(67206) /    -8.03,   -9.75,    0.00 /
      DATA B(67351), B(67352), B(67353) /    -8.09,   -9.81,    0.00 /
      DATA B(67498), B(67499), B(67500) /    -8.14,   -9.87,    0.00 /
      DATA B(67645), B(67646), B(67647) /    -8.20,   -9.93,    0.00 /
      DATA B(46480), B(46481), B(46482) /    -4.77,  -22.88,    0.00 /
      DATA B(46627), B(46628), B(46629) /    -4.89,  -22.63,    0.00 /
      DATA B(46774), B(46775), B(46776) /    -4.99,  -22.39,    0.00 /
      DATA B(46921), B(46922), B(46923) /    -5.08,  -22.15,    0.00 /
      DATA B(47068), B(47069), B(47070) /    -5.17,  -21.91,    0.00 /
      DATA B(47215), B(47216), B(47217) /    -5.24,  -21.66,    0.00 /
      DATA B(47362), B(47363), B(47364) /    -5.31,  -21.40,    0.00 /
      DATA B(47509), B(47510), B(47511) /    -5.38,  -21.13,    0.00 /
      DATA B(47656), B(47657), B(47658) /    -5.44,  -20.84,    0.00 /
      DATA B(47803), B(47804), B(47805) /    -5.48,  -20.53,    0.00 /
      DATA B(47950), B(47951), B(47952) /    -5.52,  -20.21,    0.00 /
      DATA B(48097), B(48098), B(48099) /    -5.53,  -19.88,    0.00 /
      DATA B(48244), B(48245), B(48246) /    -5.52,  -19.53,    0.00 /
      DATA B(48391), B(48392), B(48393) /    -5.48,  -19.19,    0.00 /
      DATA B(48538), B(48539), B(48540) /    -5.40,  -18.85,    0.00 /
      DATA B(48685), B(48686), B(48687) /    -5.30,  -18.54,    0.00 /
      DATA B(48832), B(48833), B(48834) /    -5.21,  -18.26,    0.00 /
      DATA B(48979), B(48980), B(48981) /    -4.99,  -17.89,    0.00 /
      DATA B(49126), B(49127), B(49128) /    -4.84,  -17.58,    0.00 /
      DATA B(49273), B(49274), B(49275) /    -4.72,  -17.35,    0.00 /
      DATA B(49420), B(49421), B(49422) /    -4.64,  -17.18,    0.00 /
      DATA B(49567), B(49568), B(49569) /    -4.60,  -17.06,    0.00 /
      DATA B(49714), B(49715), B(49716) /    -4.58,  -16.96,    0.00 /
      DATA B(49861), B(49862), B(49863) /    -4.59,  -16.87,    0.00 /
      DATA B(50008), B(50009), B(50010) /    -4.61,  -16.76,    0.00 /
      DATA B(50155), B(50156), B(50157) /    -4.63,  -16.60,    0.00 /
      DATA B(50302), B(50303), B(50304) /    -4.64,  -16.37,    0.00 /
      DATA B(50449), B(50450), B(50451) /    -4.63,  -16.02,    0.00 /
      DATA B(50596), B(50597), B(50598) /    -4.62,  -15.50,    0.00 /
      DATA B(50743), B(50744), B(50745) /    -4.60,  -15.06,    0.00 /
      DATA B(50890), B(50891), B(50892) /    -4.66,  -14.90,    0.00 /
      DATA B(51037), B(51038), B(51039) /    -4.66,  -14.79,    0.00 /
      DATA B(51184), B(51185), B(51186) /    -4.67,  -14.71,    0.00 /
      DATA B(51331), B(51332), B(51333) /    -4.69,  -14.65,    0.00 /
      DATA B(51478), B(51479), B(51480) /    -4.72,  -14.59,    0.00 /
      DATA B(51625), B(51626), B(51627) /    -4.75,  -14.53,    0.00 /
      DATA B(51772), B(51773), B(51774) /    -4.78,  -14.47,    0.00 /
      DATA B(51919), B(51920), B(51921) /    -4.81,  -14.40,    0.00 /
      DATA B(52066), B(52067), B(52068) /    -4.84,  -14.34,    0.00 /
      DATA B(52213), B(52214), B(52215) /    -4.87,  -14.26,    0.00 /
      DATA B(52360), B(52361), B(52362) /    -4.90,  -14.19,    0.00 /
      DATA B(52507), B(52508), B(52509) /    -4.92,  -14.11,    0.00 /
      DATA B(52654), B(52655), B(52656) /    -4.95,  -14.03,    0.00 /
      DATA B(52801), B(52802), B(52803) /    -4.98,  -13.94,    0.00 /
      DATA B(52948), B(52949), B(52950) /    -5.00,  -13.85,    0.00 /
      DATA B(53095), B(53096), B(53097) /    -5.03,  -13.75,    0.00 /
      DATA B(53242), B(53243), B(53244) /    -5.05,  -13.65,    0.00 /
      DATA B(53389), B(53390), B(53391) /    -5.07,  -13.54,    0.00 /
      DATA B(53536), B(53537), B(53538) /    -5.09,  -13.43,    0.00 /
      DATA B(53683), B(53684), B(53685) /    -5.11,  -13.31,    0.00 /
      DATA B(53830), B(53831), B(53832) /    -5.13,  -13.19,    0.00 /
      DATA B(53977), B(53978), B(53979) /    -5.14,  -13.06,    0.00 /
      DATA B(54124), B(54125), B(54126) /    -5.15,  -12.93,    0.00 /
      DATA B(54271), B(54272), B(54273) /    -5.15,  -12.80,    0.00 /
      DATA B(54418), B(54419), B(54420) /    -5.16,  -12.67,    0.00 /
      DATA B(54565), B(54566), B(54567) /    -5.15,  -12.54,    0.00 /
      DATA B(54712), B(54713), B(54714) /    -5.15,  -12.42,    0.00 /
      DATA B(54859), B(54860), B(54861) /    -5.14,  -12.30,    0.00 /
      DATA B(55006), B(55007), B(55008) /    -5.13,  -12.18,    0.00 /
      DATA B(55153), B(55154), B(55155) /    -5.12,  -12.08,    0.00 /
      DATA B(55300), B(55301), B(55302) /    -5.12,  -11.97,    0.00 /
      DATA B(55447), B(55448), B(55449) /    -5.11,  -11.88,    0.00 /
      DATA B(55594), B(55595), B(55596) /    -5.11,  -11.78,    0.00 /
      DATA B(55741), B(55742), B(55743) /    -5.11,  -11.69,    0.00 /
      DATA B(55888), B(55889), B(55890) /    -5.12,  -11.60,    0.00 /
      DATA B(56035), B(56036), B(56037) /    -5.12,  -11.51,    0.00 /
      DATA B(56182), B(56183), B(56184) /    -5.13,  -11.42,    0.00 /
      DATA B(56329), B(56330), B(56331) /    -5.14,  -11.34,    0.00 /
      DATA B(56476), B(56477), B(56478) /    -5.15,  -11.25,    0.00 /
      DATA B(56623), B(56624), B(56625) /    -5.16,  -11.16,    0.00 /
      DATA B(56770), B(56771), B(56772) /    -5.18,  -11.07,    0.00 /
      DATA B(56917), B(56918), B(56919) /    -5.19,  -10.98,    0.00 /
      DATA B(57064), B(57065), B(57066) /    -5.20,  -10.89,    0.00 /
      DATA B(57211), B(57212), B(57213) /    -5.22,  -10.80,    0.00 /
      DATA B(57358), B(57359), B(57360) /    -5.23,  -10.72,    0.00 /
      DATA B(57505), B(57506), B(57507) /    -5.24,  -10.63,    0.00 /
      DATA B(57652), B(57653), B(57654) /    -5.26,  -10.55,    0.00 /
      DATA B(57799), B(57800), B(57801) /    -5.28,  -10.48,    0.00 /
      DATA B(57946), B(57947), B(57948) /    -5.30,  -10.41,    0.00 /
      DATA B(58093), B(58094), B(58095) /    -5.31,  -10.34,    0.00 /
      DATA B(58240), B(58241), B(58242) /    -5.33,  -10.29,    0.00 /
      DATA B(58387), B(58388), B(58389) /    -5.35,  -10.23,    0.00 /
      DATA B(58534), B(58535), B(58536) /    -5.36,  -10.18,    0.00 /
      DATA B(58681), B(58682), B(58683) /    -5.37,  -10.13,    0.00 /
      DATA B(58828), B(58829), B(58830) /    -5.38,  -10.07,    0.00 /
      DATA B(58975), B(58976), B(58977) /    -5.40,  -10.00,    0.00 /
      DATA B(59122), B(59123), B(59124) /    -5.41,   -9.93,    0.00 /
      DATA B(59269), B(59270), B(59271) /    -5.43,   -9.85,    0.00 /
      DATA B(59416), B(59417), B(59418) /    -5.45,   -9.76,    0.00 /
      DATA B(59563), B(59564), B(59565) /    -5.48,   -9.67,    0.00 /
      DATA B(59710), B(59711), B(59712) /    -5.50,   -9.58,    0.00 /
      DATA B(59857), B(59858), B(59859) /    -5.53,   -9.49,    0.00 /
      DATA B(60004), B(60005), B(60006) /    -5.55,   -9.41,    0.00 /
      DATA B(60151), B(60152), B(60153) /    -5.58,   -9.35,    0.00 /
      DATA B(60298), B(60299), B(60300) /    -5.62,   -9.29,    0.00 /
      DATA B(60445), B(60446), B(60447) /    -5.66,   -9.22,    0.00 /
      DATA B(60592), B(60593), B(60594) /    -5.70,   -9.15,    0.00 /
      DATA B(60739), B(60740), B(60741) /    -5.74,   -9.08,    0.00 /
      DATA B(60886), B(60887), B(60888) /    -5.77,   -8.99,    0.00 /
      DATA B(61033), B(61034), B(61035) /    -5.81,   -8.90,    0.00 /
      DATA B(61180), B(61181), B(61182) /    -5.85,   -8.81,    0.00 /
      DATA B(61327), B(61328), B(61329) /    -5.88,   -8.72,    0.00 /
      DATA B(61474), B(61475), B(61476) /    -5.93,   -8.62,    0.00 /
      DATA B(61621), B(61622), B(61623) /    -5.98,   -8.54,    0.00 /
      DATA B(61768), B(61769), B(61770) /    -6.04,   -8.47,    0.00 /
      DATA B(61915), B(61916), B(61917) /    -6.10,   -8.43,    0.00 /
      DATA B(62062), B(62063), B(62064) /    -6.15,   -8.45,    0.00 /
      DATA B(62209), B(62210), B(62211) /    -6.28,   -8.61,    0.00 /
      DATA B(62356), B(62357), B(62358) /    -6.35,   -8.65,    0.00 /
      DATA B(62503), B(62504), B(62505) /    -6.44,   -8.65,    0.00 /
      DATA B(62650), B(62651), B(62652) /    -6.52,   -8.63,    0.00 /
      DATA B(62797), B(62798), B(62799) /    -6.58,   -8.60,    0.00 /
      DATA B(62944), B(62945), B(62946) /    -6.65,   -8.56,    0.00 /
      DATA B(63091), B(63092), B(63093) /    -6.71,   -8.51,    0.00 /
      DATA B(63238), B(63239), B(63240) /    -6.77,   -8.47,    0.00 /
      DATA B(63385), B(63386), B(63387) /    -6.85,   -8.42,    0.00 /
      DATA B(63532), B(63533), B(63534) /    -6.93,   -8.37,    0.00 /
      DATA B(63679), B(63680), B(63681) /    -7.04,   -8.33,    0.00 /
      DATA B(63826), B(63827), B(63828) /    -7.17,   -8.28,    0.00 /
      DATA B(63973), B(63974), B(63975) /    -7.29,   -8.22,    0.00 /
      DATA B(64120), B(64121), B(64122) /    -7.36,   -8.15,    0.00 /
      DATA B(64267), B(64268), B(64269) /    -7.42,   -8.13,    0.00 /
      DATA B(64414), B(64415), B(64416) /    -7.48,   -8.18,    0.00 /
      DATA B(64561), B(64562), B(64563) /    -7.54,   -8.16,    0.00 /
      DATA B(64708), B(64709), B(64710) /    -7.55,   -8.14,    0.00 /
      DATA B(64855), B(64856), B(64857) /    -7.55,   -8.15,    0.00 /
      DATA B(65002), B(65003), B(65004) /    -7.55,   -8.18,    0.00 /
      DATA B(65149), B(65150), B(65151) /    -7.53,   -8.22,    0.00 /
      DATA B(65296), B(65297), B(65298) /    -7.52,   -8.28,    0.00 /
      DATA B(65443), B(65444), B(65445) /    -7.54,   -8.43,    0.00 /
      DATA B(65590), B(65591), B(65592) /    -7.54,   -8.70,    0.00 /
      DATA B(65737), B(65738), B(65739) /    -7.49,   -8.94,    0.00 /
      DATA B(65884), B(65885), B(65886) /    -7.52,   -9.09,    0.00 /
      DATA B(66031), B(66032), B(66033) /    -7.59,   -9.22,    0.00 /
      DATA B(66178), B(66179), B(66180) /    -7.67,   -9.32,    0.00 /
      DATA B(66325), B(66326), B(66327) /    -7.74,   -9.41,    0.00 /
      DATA B(66472), B(66473), B(66474) /    -7.80,   -9.49,    0.00 /
      DATA B(66619), B(66620), B(66621) /    -7.86,   -9.57,    0.00 /
      DATA B(66766), B(66767), B(66768) /    -7.92,   -9.64,    0.00 /
      DATA B(66913), B(66914), B(66915) /    -7.98,   -9.70,    0.00 /
      DATA B(67060), B(67061), B(67062) /    -8.03,   -9.77,    0.00 /
      DATA B(67207), B(67208), B(67209) /    -8.09,   -9.83,    0.00 /
      DATA B(67354), B(67355), B(67356) /    -8.14,   -9.89,    0.00 /
      DATA B(67501), B(67502), B(67503) /    -8.20,   -9.95,    0.00 /
      DATA B(67648), B(67649), B(67650) /    -8.25,  -10.01,    0.00 /
      DATA B(46483), B(46484), B(46485) /    -4.86,  -22.75,    0.00 /
      DATA B(46630), B(46631), B(46632) /    -4.96,  -22.52,    0.00 /
      DATA B(46777), B(46778), B(46779) /    -5.05,  -22.30,    0.00 /
      DATA B(46924), B(46925), B(46926) /    -5.14,  -22.07,    0.00 /
      DATA B(47071), B(47072), B(47073) /    -5.22,  -21.85,    0.00 /
      DATA B(47218), B(47219), B(47220) /    -5.29,  -21.61,    0.00 /
      DATA B(47365), B(47366), B(47367) /    -5.36,  -21.37,    0.00 /
      DATA B(47512), B(47513), B(47514) /    -5.43,  -21.11,    0.00 /
      DATA B(47659), B(47660), B(47661) /    -5.48,  -20.84,    0.00 /
      DATA B(47806), B(47807), B(47808) /    -5.53,  -20.55,    0.00 /
      DATA B(47953), B(47954), B(47955) /    -5.56,  -20.25,    0.00 /
      DATA B(48100), B(48101), B(48102) /    -5.57,  -19.93,    0.00 /
      DATA B(48247), B(48248), B(48249) /    -5.56,  -19.61,    0.00 /
      DATA B(48394), B(48395), B(48396) /    -5.52,  -19.29,    0.00 /
      DATA B(48541), B(48542), B(48543) /    -5.45,  -18.98,    0.00 /
      DATA B(48688), B(48689), B(48690) /    -5.35,  -18.68,    0.00 /
      DATA B(48835), B(48836), B(48837) /    -5.23,  -18.39,    0.00 /
      DATA B(48982), B(48983), B(48984) /    -5.03,  -18.03,    0.00 /
      DATA B(49129), B(49130), B(49131) /    -4.87,  -17.70,    0.00 /
      DATA B(49276), B(49277), B(49278) /    -4.76,  -17.45,    0.00 /
      DATA B(49423), B(49424), B(49425) /    -4.68,  -17.27,    0.00 /
      DATA B(49570), B(49571), B(49572) /    -4.64,  -17.13,    0.00 /
      DATA B(49717), B(49718), B(49719) /    -4.62,  -17.02,    0.00 /
      DATA B(49864), B(49865), B(49866) /    -4.63,  -16.91,    0.00 /
      DATA B(50011), B(50012), B(50013) /    -4.65,  -16.80,    0.00 /
      DATA B(50158), B(50159), B(50160) /    -4.68,  -16.65,    0.00 /
      DATA B(50305), B(50306), B(50307) /    -4.70,  -16.43,    0.00 /
      DATA B(50452), B(50453), B(50454) /    -4.71,  -16.10,    0.00 /
      DATA B(50599), B(50600), B(50601) /    -4.72,  -15.62,    0.00 /
      DATA B(50746), B(50747), B(50748) /    -4.79,  -15.20,    0.00 /
      DATA B(50893), B(50894), B(50895) /    -4.77,  -15.02,    0.00 /
      DATA B(51040), B(51041), B(51042) /    -4.77,  -14.90,    0.00 /
      DATA B(51187), B(51188), B(51189) /    -4.78,  -14.82,    0.00 /
      DATA B(51334), B(51335), B(51336) /    -4.80,  -14.75,    0.00 /
      DATA B(51481), B(51482), B(51483) /    -4.83,  -14.69,    0.00 /
      DATA B(51628), B(51629), B(51630) /    -4.86,  -14.62,    0.00 /
      DATA B(51775), B(51776), B(51777) /    -4.89,  -14.56,    0.00 /
      DATA B(51922), B(51923), B(51924) /    -4.92,  -14.50,    0.00 /
      DATA B(52069), B(52070), B(52071) /    -4.95,  -14.43,    0.00 /
      DATA B(52216), B(52217), B(52218) /    -4.98,  -14.35,    0.00 /
      DATA B(52363), B(52364), B(52365) /    -5.00,  -14.28,    0.00 /
      DATA B(52510), B(52511), B(52512) /    -5.03,  -14.20,    0.00 /
      DATA B(52657), B(52658), B(52659) /    -5.06,  -14.11,    0.00 /
      DATA B(52804), B(52805), B(52806) /    -5.08,  -14.03,    0.00 /
      DATA B(52951), B(52952), B(52953) /    -5.11,  -13.94,    0.00 /
      DATA B(53098), B(53099), B(53100) /    -5.13,  -13.84,    0.00 /
      DATA B(53245), B(53246), B(53247) /    -5.15,  -13.74,    0.00 /
      DATA B(53392), B(53393), B(53394) /    -5.17,  -13.63,    0.00 /
      DATA B(53539), B(53540), B(53541) /    -5.19,  -13.52,    0.00 /
      DATA B(53686), B(53687), B(53688) /    -5.21,  -13.41,    0.00 /
      DATA B(53833), B(53834), B(53835) /    -5.23,  -13.29,    0.00 /
      DATA B(53980), B(53981), B(53982) /    -5.24,  -13.16,    0.00 /
      DATA B(54127), B(54128), B(54129) /    -5.25,  -13.04,    0.00 /
      DATA B(54274), B(54275), B(54276) /    -5.25,  -12.91,    0.00 /
      DATA B(54421), B(54422), B(54423) /    -5.26,  -12.78,    0.00 /
      DATA B(54568), B(54569), B(54570) /    -5.25,  -12.66,    0.00 /
      DATA B(54715), B(54716), B(54717) /    -5.25,  -12.54,    0.00 /
      DATA B(54862), B(54863), B(54864) /    -5.24,  -12.42,    0.00 /
      DATA B(55009), B(55010), B(55011) /    -5.24,  -12.31,    0.00 /
      DATA B(55156), B(55157), B(55158) /    -5.23,  -12.20,    0.00 /
      DATA B(55303), B(55304), B(55305) /    -5.23,  -12.10,    0.00 /
      DATA B(55450), B(55451), B(55452) /    -5.22,  -12.00,    0.00 /
      DATA B(55597), B(55598), B(55599) /    -5.22,  -11.90,    0.00 /
      DATA B(55744), B(55745), B(55746) /    -5.22,  -11.81,    0.00 /
      DATA B(55891), B(55892), B(55893) /    -5.23,  -11.72,    0.00 /
      DATA B(56038), B(56039), B(56040) /    -5.23,  -11.63,    0.00 /
      DATA B(56185), B(56186), B(56187) /    -5.24,  -11.54,    0.00 /
      DATA B(56332), B(56333), B(56334) /    -5.25,  -11.45,    0.00 /
      DATA B(56479), B(56480), B(56481) /    -5.26,  -11.36,    0.00 /
      DATA B(56626), B(56627), B(56628) /    -5.27,  -11.27,    0.00 /
      DATA B(56773), B(56774), B(56775) /    -5.29,  -11.19,    0.00 /
      DATA B(56920), B(56921), B(56922) /    -5.30,  -11.10,    0.00 /
      DATA B(57067), B(57068), B(57069) /    -5.31,  -11.01,    0.00 /
      DATA B(57214), B(57215), B(57216) /    -5.33,  -10.92,    0.00 /
      DATA B(57361), B(57362), B(57363) /    -5.34,  -10.84,    0.00 /
      DATA B(57508), B(57509), B(57510) /    -5.36,  -10.75,    0.00 /
      DATA B(57655), B(57656), B(57657) /    -5.38,  -10.68,    0.00 /
      DATA B(57802), B(57803), B(57804) /    -5.40,  -10.60,    0.00 /
      DATA B(57949), B(57950), B(57951) /    -5.42,  -10.54,    0.00 /
      DATA B(58096), B(58097), B(58098) /    -5.44,  -10.48,    0.00 /
      DATA B(58243), B(58244), B(58245) /    -5.47,  -10.43,    0.00 /
      DATA B(58390), B(58391), B(58392) /    -5.49,  -10.39,    0.00 /
      DATA B(58537), B(58538), B(58539) /    -5.51,  -10.35,    0.00 /
      DATA B(58684), B(58685), B(58686) /    -5.52,  -10.30,    0.00 /
      DATA B(58831), B(58832), B(58833) /    -5.53,  -10.23,    0.00 /
      DATA B(58978), B(58979), B(58980) /    -5.55,  -10.16,    0.00 /
      DATA B(59125), B(59126), B(59127) /    -5.56,  -10.06,    0.00 /
      DATA B(59272), B(59273), B(59274) /    -5.58,   -9.98,    0.00 /
      DATA B(59419), B(59420), B(59421) /    -5.61,   -9.90,    0.00 /
      DATA B(59566), B(59567), B(59568) /    -5.63,   -9.82,    0.00 /
      DATA B(59713), B(59714), B(59715) /    -5.66,   -9.73,    0.00 /
      DATA B(59860), B(59861), B(59862) /    -5.69,   -9.65,    0.00 /
      DATA B(60007), B(60008), B(60009) /    -5.71,   -9.58,    0.00 /
      DATA B(60154), B(60155), B(60156) /    -5.74,   -9.52,    0.00 /
      DATA B(60301), B(60302), B(60303) /    -5.78,   -9.46,    0.00 /
      DATA B(60448), B(60449), B(60450) /    -5.82,   -9.40,    0.00 /
      DATA B(60595), B(60596), B(60597) /    -5.85,   -9.33,    0.00 /
      DATA B(60742), B(60743), B(60744) /    -5.89,   -9.25,    0.00 /
      DATA B(60889), B(60890), B(60891) /    -5.92,   -9.16,    0.00 /
      DATA B(61036), B(61037), B(61038) /    -5.95,   -9.07,    0.00 /
      DATA B(61183), B(61184), B(61185) /    -5.98,   -8.98,    0.00 /
      DATA B(61330), B(61331), B(61332) /    -6.02,   -8.88,    0.00 /
      DATA B(61477), B(61478), B(61479) /    -6.06,   -8.79,    0.00 /
      DATA B(61624), B(61625), B(61626) /    -6.11,   -8.71,    0.00 /
      DATA B(61771), B(61772), B(61773) /    -6.16,   -8.64,    0.00 /
      DATA B(61918), B(61919), B(61920) /    -6.23,   -8.60,    0.00 /
      DATA B(62065), B(62066), B(62067) /    -6.28,   -8.62,    0.00 /
      DATA B(62212), B(62213), B(62214) /    -6.41,   -8.80,    0.00 /
      DATA B(62359), B(62360), B(62361) /    -6.49,   -8.85,    0.00 /
      DATA B(62506), B(62507), B(62508) /    -6.57,   -8.85,    0.00 /
      DATA B(62653), B(62654), B(62655) /    -6.65,   -8.84,    0.00 /
      DATA B(62800), B(62801), B(62802) /    -6.71,   -8.80,    0.00 /
      DATA B(62947), B(62948), B(62949) /    -6.78,   -8.76,    0.00 /
      DATA B(63094), B(63095), B(63096) /    -6.84,   -8.72,    0.00 /
      DATA B(63241), B(63242), B(63243) /    -6.90,   -8.67,    0.00 /
      DATA B(63388), B(63389), B(63390) /    -6.98,   -8.63,    0.00 /
      DATA B(63535), B(63536), B(63537) /    -7.06,   -8.58,    0.00 /
      DATA B(63682), B(63683), B(63684) /    -7.17,   -8.53,    0.00 /
      DATA B(63829), B(63830), B(63831) /    -7.30,   -8.47,    0.00 /
      DATA B(63976), B(63977), B(63978) /    -7.41,   -8.41,    0.00 /
      DATA B(64123), B(64124), B(64125) /    -7.44,   -8.36,    0.00 /
      DATA B(64270), B(64271), B(64272) /    -7.49,   -8.36,    0.00 /
      DATA B(64417), B(64418), B(64419) /    -7.58,   -8.37,    0.00 /
      DATA B(64564), B(64565), B(64566) /    -7.62,   -8.35,    0.00 /
      DATA B(64711), B(64712), B(64713) /    -7.64,   -8.34,    0.00 /
      DATA B(64858), B(64859), B(64860) /    -7.64,   -8.34,    0.00 /
      DATA B(65005), B(65006), B(65007) /    -7.62,   -8.36,    0.00 /
      DATA B(65152), B(65153), B(65154) /    -7.59,   -8.40,    0.00 /
      DATA B(65299), B(65300), B(65301) /    -7.56,   -8.45,    0.00 /
      DATA B(65446), B(65447), B(65448) /    -7.54,   -8.55,    0.00 /
      DATA B(65593), B(65594), B(65595) /    -7.56,   -8.97,    0.00 /
      DATA B(65740), B(65741), B(65742) /    -7.54,   -9.13,    0.00 /
      DATA B(65887), B(65888), B(65889) /    -7.60,   -9.24,    0.00 /
      DATA B(66034), B(66035), B(66036) /    -7.67,   -9.35,    0.00 /
      DATA B(66181), B(66182), B(66183) /    -7.75,   -9.44,    0.00 /
      DATA B(66328), B(66329), B(66330) /    -7.81,   -9.52,    0.00 /
      DATA B(66475), B(66476), B(66477) /    -7.87,   -9.59,    0.00 /
      DATA B(66622), B(66623), B(66624) /    -7.93,   -9.66,    0.00 /
      DATA B(66769), B(66770), B(66771) /    -7.99,   -9.73,    0.00 /
      DATA B(66916), B(66917), B(66918) /    -8.04,   -9.79,    0.00 /
      DATA B(67063), B(67064), B(67065) /    -8.09,   -9.85,    0.00 /
      DATA B(67210), B(67211), B(67212) /    -8.14,   -9.91,    0.00 /
      DATA B(67357), B(67358), B(67359) /    -8.20,   -9.97,    0.00 /
      DATA B(67504), B(67505), B(67506) /    -8.25,  -10.03,    0.00 /
      DATA B(67651), B(67652), B(67653) /    -8.30,  -10.08,    0.00 /
      DATA B(46486), B(46487), B(46488) /    -4.92,  -22.63,    0.00 /
      DATA B(46633), B(46634), B(46635) /    -5.02,  -22.42,    0.00 /
      DATA B(46780), B(46781), B(46782) /    -5.10,  -22.21,    0.00 /
      DATA B(46927), B(46928), B(46929) /    -5.19,  -22.00,    0.00 /
      DATA B(47074), B(47075), B(47076) /    -5.26,  -21.79,    0.00 /
      DATA B(47221), B(47222), B(47223) /    -5.33,  -21.57,    0.00 /
      DATA B(47368), B(47369), B(47370) /    -5.40,  -21.34,    0.00 /
      DATA B(47515), B(47516), B(47517) /    -5.46,  -21.09,    0.00 /
      DATA B(47662), B(47663), B(47664) /    -5.51,  -20.84,    0.00 /
      DATA B(47809), B(47810), B(47811) /    -5.56,  -20.57,    0.00 /
      DATA B(47956), B(47957), B(47958) /    -5.58,  -20.28,    0.00 /
      DATA B(48103), B(48104), B(48105) /    -5.59,  -19.99,    0.00 /
      DATA B(48250), B(48251), B(48252) /    -5.58,  -19.69,    0.00 /
      DATA B(48397), B(48398), B(48399) /    -5.54,  -19.39,    0.00 /
      DATA B(48544), B(48545), B(48546) /    -5.48,  -19.10,    0.00 /
      DATA B(48691), B(48692), B(48693) /    -5.38,  -18.81,    0.00 /
      DATA B(48838), B(48839), B(48840) /    -5.27,  -18.53,    0.00 /
      DATA B(48985), B(48986), B(48987) /    -5.03,  -18.16,    0.00 /
      DATA B(49132), B(49133), B(49134) /    -4.89,  -17.81,    0.00 /
      DATA B(49279), B(49280), B(49281) /    -4.77,  -17.54,    0.00 /
      DATA B(49426), B(49427), B(49428) /    -4.70,  -17.34,    0.00 /
      DATA B(49573), B(49574), B(49575) /    -4.66,  -17.19,    0.00 /
      DATA B(49720), B(49721), B(49722) /    -4.65,  -17.06,    0.00 /
      DATA B(49867), B(49868), B(49869) /    -4.66,  -16.95,    0.00 /
      DATA B(50014), B(50015), B(50016) /    -4.68,  -16.83,    0.00 /
      DATA B(50161), B(50162), B(50163) /    -4.72,  -16.68,    0.00 /
      DATA B(50308), B(50309), B(50310) /    -4.75,  -16.47,    0.00 /
      DATA B(50455), B(50456), B(50457) /    -4.78,  -16.14,    0.00 /
      DATA B(50602), B(50603), B(50604) /    -4.79,  -15.66,    0.00 /
      DATA B(50749), B(50750), B(50751) /    -4.78,  -15.25,    0.00 /
      DATA B(50896), B(50897), B(50898) /    -4.85,  -15.12,    0.00 /
      DATA B(51043), B(51044), B(51045) /    -4.87,  -15.00,    0.00 /
      DATA B(51190), B(51191), B(51192) /    -4.89,  -14.92,    0.00 /
      DATA B(51337), B(51338), B(51339) /    -4.91,  -14.85,    0.00 /
      DATA B(51484), B(51485), B(51486) /    -4.94,  -14.78,    0.00 /
      DATA B(51631), B(51632), B(51633) /    -4.97,  -14.72,    0.00 /
      DATA B(51778), B(51779), B(51780) /    -5.00,  -14.65,    0.00 /
      DATA B(51925), B(51926), B(51927) /    -5.03,  -14.59,    0.00 /
      DATA B(52072), B(52073), B(52074) /    -5.06,  -14.51,    0.00 /
      DATA B(52219), B(52220), B(52221) /    -5.08,  -14.44,    0.00 /
      DATA B(52366), B(52367), B(52368) /    -5.11,  -14.36,    0.00 /
      DATA B(52513), B(52514), B(52515) /    -5.14,  -14.28,    0.00 /
      DATA B(52660), B(52661), B(52662) /    -5.16,  -14.20,    0.00 /
      DATA B(52807), B(52808), B(52809) /    -5.19,  -14.11,    0.00 /
      DATA B(52954), B(52955), B(52956) /    -5.21,  -14.02,    0.00 /
      DATA B(53101), B(53102), B(53103) /    -5.23,  -13.93,    0.00 /
      DATA B(53248), B(53249), B(53250) /    -5.25,  -13.83,    0.00 /
      DATA B(53395), B(53396), B(53397) /    -5.28,  -13.72,    0.00 /
      DATA B(53542), B(53543), B(53544) /    -5.29,  -13.61,    0.00 /
      DATA B(53689), B(53690), B(53691) /    -5.31,  -13.50,    0.00 /
      DATA B(53836), B(53837), B(53838) /    -5.33,  -13.38,    0.00 /
      DATA B(53983), B(53984), B(53985) /    -5.34,  -13.26,    0.00 /
      DATA B(54130), B(54131), B(54132) /    -5.35,  -13.14,    0.00 /
      DATA B(54277), B(54278), B(54279) /    -5.35,  -13.02,    0.00 /
      DATA B(54424), B(54425), B(54426) /    -5.35,  -12.89,    0.00 /
      DATA B(54571), B(54572), B(54573) /    -5.35,  -12.77,    0.00 /
      DATA B(54718), B(54719), B(54720) /    -5.35,  -12.65,    0.00 /
      DATA B(54865), B(54866), B(54867) /    -5.35,  -12.54,    0.00 /
      DATA B(55012), B(55013), B(55014) /    -5.34,  -12.43,    0.00 /
      DATA B(55159), B(55160), B(55161) /    -5.34,  -12.32,    0.00 /
      DATA B(55306), B(55307), B(55308) /    -5.33,  -12.22,    0.00 /
      DATA B(55453), B(55454), B(55455) /    -5.33,  -12.12,    0.00 /
      DATA B(55600), B(55601), B(55602) /    -5.33,  -12.02,    0.00 /
      DATA B(55747), B(55748), B(55749) /    -5.33,  -11.93,    0.00 /
      DATA B(55894), B(55895), B(55896) /    -5.34,  -11.83,    0.00 /
      DATA B(56041), B(56042), B(56043) /    -5.34,  -11.74,    0.00 /
      DATA B(56188), B(56189), B(56190) /    -5.35,  -11.65,    0.00 /
      DATA B(56335), B(56336), B(56337) /    -5.36,  -11.56,    0.00 /
      DATA B(56482), B(56483), B(56484) /    -5.37,  -11.47,    0.00 /
      DATA B(56629), B(56630), B(56631) /    -5.38,  -11.39,    0.00 /
      DATA B(56776), B(56777), B(56778) /    -5.40,  -11.30,    0.00 /
      DATA B(56923), B(56924), B(56925) /    -5.41,  -11.21,    0.00 /
      DATA B(57070), B(57071), B(57072) /    -5.42,  -11.12,    0.00 /
      DATA B(57217), B(57218), B(57219) /    -5.44,  -11.04,    0.00 /
      DATA B(57364), B(57365), B(57366) /    -5.45,  -10.95,    0.00 /
      DATA B(57511), B(57512), B(57513) /    -5.47,  -10.87,    0.00 /
      DATA B(57658), B(57659), B(57660) /    -5.50,  -10.79,    0.00 /
      DATA B(57805), B(57806), B(57807) /    -5.52,  -10.73,    0.00 /
      DATA B(57952), B(57953), B(57954) /    -5.55,  -10.67,    0.00 /
      DATA B(58099), B(58100), B(58101) /    -5.58,  -10.62,    0.00 /
      DATA B(58246), B(58247), B(58248) /    -5.61,  -10.58,    0.00 /
      DATA B(58393), B(58394), B(58395) /    -5.63,  -10.53,    0.00 /
      DATA B(58540), B(58541), B(58542) /    -5.65,  -10.50,    0.00 /
      DATA B(58687), B(58688), B(58689) /    -5.66,  -10.45,    0.00 /
      DATA B(58834), B(58835), B(58836) /    -5.68,  -10.38,    0.00 /
      DATA B(58981), B(58982), B(58983) /    -5.70,  -10.29,    0.00 /
      DATA B(59128), B(59129), B(59130) /    -5.72,  -10.21,    0.00 /
      DATA B(59275), B(59276), B(59277) /    -5.74,  -10.13,    0.00 /
      DATA B(59422), B(59423), B(59424) /    -5.77,  -10.05,    0.00 /
      DATA B(59569), B(59570), B(59571) /    -5.80,   -9.97,    0.00 /
      DATA B(59716), B(59717), B(59718) /    -5.82,   -9.89,    0.00 /
      DATA B(59863), B(59864), B(59865) /    -5.85,   -9.82,    0.00 /
      DATA B(60010), B(60011), B(60012) /    -5.88,   -9.76,    0.00 /
      DATA B(60157), B(60158), B(60159) /    -5.91,   -9.70,    0.00 /
      DATA B(60304), B(60305), B(60306) /    -5.94,   -9.64,    0.00 /
      DATA B(60451), B(60452), B(60453) /    -5.97,   -9.57,    0.00 /
      DATA B(60598), B(60599), B(60600) /    -6.00,   -9.49,    0.00 /
      DATA B(60745), B(60746), B(60747) /    -6.03,   -9.41,    0.00 /
      DATA B(60892), B(60893), B(60894) /    -6.06,   -9.32,    0.00 /
      DATA B(61039), B(61040), B(61041) /    -6.09,   -9.23,    0.00 /
      DATA B(61186), B(61187), B(61188) /    -6.12,   -9.14,    0.00 /
      DATA B(61333), B(61334), B(61335) /    -6.15,   -9.04,    0.00 /
      DATA B(61480), B(61481), B(61482) /    -6.19,   -8.95,    0.00 /
      DATA B(61627), B(61628), B(61629) /    -6.23,   -8.87,    0.00 /
      DATA B(61774), B(61775), B(61776) /    -6.29,   -8.80,    0.00 /
      DATA B(61921), B(61922), B(61923) /    -6.35,   -8.76,    0.00 /
      DATA B(62068), B(62069), B(62070) /    -6.40,   -8.78,    0.00 /
      DATA B(62215), B(62216), B(62217) /    -6.54,   -8.99,    0.00 /
      DATA B(62362), B(62363), B(62364) /    -6.62,   -9.04,    0.00 /
      DATA B(62509), B(62510), B(62511) /    -6.70,   -9.05,    0.00 /
      DATA B(62656), B(62657), B(62658) /    -6.77,   -9.04,    0.00 /
      DATA B(62803), B(62804), B(62805) /    -6.84,   -9.01,    0.00 /
      DATA B(62950), B(62951), B(62952) /    -6.90,   -8.97,    0.00 /
      DATA B(63097), B(63098), B(63099) /    -6.96,   -8.92,    0.00 /
      DATA B(63244), B(63245), B(63246) /    -7.03,   -8.88,    0.00 /
      DATA B(63391), B(63392), B(63393) /    -7.10,   -8.83,    0.00 /
      DATA B(63538), B(63539), B(63540) /    -7.19,   -8.78,    0.00 /
      DATA B(63685), B(63686), B(63687) /    -7.29,   -8.72,    0.00 /
      DATA B(63832), B(63833), B(63834) /    -7.41,   -8.67,    0.00 /
      DATA B(63979), B(63980), B(63981) /    -7.51,   -8.61,    0.00 /
      DATA B(64126), B(64127), B(64128) /    -7.54,   -8.56,    0.00 /
      DATA B(64273), B(64274), B(64275) /    -7.60,   -8.55,    0.00 /
      DATA B(64420), B(64421), B(64422) /    -7.65,   -8.55,    0.00 /
      DATA B(64567), B(64568), B(64569) /    -7.70,   -8.53,    0.00 /
      DATA B(64714), B(64715), B(64716) /    -7.72,   -8.53,    0.00 /
      DATA B(64861), B(64862), B(64863) /    -7.71,   -8.53,    0.00 /
      DATA B(65008), B(65009), B(65010) /    -7.69,   -8.55,    0.00 /
      DATA B(65155), B(65156), B(65157) /    -7.66,   -8.57,    0.00 /
      DATA B(65302), B(65303), B(65304) /    -7.61,   -8.61,    0.00 /
      DATA B(65449), B(65450), B(65451) /    -7.52,   -8.67,    0.00 /
      DATA B(65596), B(65597), B(65598) /    -7.61,   -9.24,    0.00 /
      DATA B(65743), B(65744), B(65745) /    -7.63,   -9.29,    0.00 /
      DATA B(65890), B(65891), B(65892) /    -7.69,   -9.38,    0.00 /
      DATA B(66037), B(66038), B(66039) /    -7.76,   -9.47,    0.00 /
      DATA B(66184), B(66185), B(66186) /    -7.83,   -9.55,    0.00 /
      DATA B(66331), B(66332), B(66333) /    -7.89,   -9.62,    0.00 /
      DATA B(66478), B(66479), B(66480) /    -7.94,   -9.69,    0.00 /
      DATA B(66625), B(66626), B(66627) /    -8.00,   -9.76,    0.00 /
      DATA B(66772), B(66773), B(66774) /    -8.05,   -9.82,    0.00 /
      DATA B(66919), B(66920), B(66921) /    -8.10,   -9.88,    0.00 /
      DATA B(67066), B(67067), B(67068) /    -8.15,   -9.94,    0.00 /
      DATA B(67213), B(67214), B(67215) /    -8.20,   -9.99,    0.00 /
      DATA B(67360), B(67361), B(67362) /    -8.25,  -10.05,    0.00 /
      DATA B(67507), B(67508), B(67509) /    -8.30,  -10.10,    0.00 /
      DATA B(67654), B(67655), B(67656) /    -8.35,  -10.16,    0.00 /
      DATA B(46489), B(46490), B(46491) /    -4.98,  -22.52,    0.00 /
      DATA B(46636), B(46637), B(46638) /    -5.06,  -22.33,    0.00 /
      DATA B(46783), B(46784), B(46785) /    -5.14,  -22.14,    0.00 /
      DATA B(46930), B(46931), B(46932) /    -5.22,  -21.94,    0.00 /
      DATA B(47077), B(47078), B(47079) /    -5.29,  -21.74,    0.00 /
      DATA B(47224), B(47225), B(47226) /    -5.36,  -21.53,    0.00 /
      DATA B(47371), B(47372), B(47373) /    -5.42,  -21.31,    0.00 /
      DATA B(47518), B(47519), B(47520) /    -5.48,  -21.08,    0.00 /
      DATA B(47665), B(47666), B(47667) /    -5.53,  -20.83,    0.00 /
      DATA B(47812), B(47813), B(47814) /    -5.57,  -20.58,    0.00 /
      DATA B(47959), B(47960), B(47961) /    -5.60,  -20.31,    0.00 /
      DATA B(48106), B(48107), B(48108) /    -5.61,  -20.04,    0.00 /
      DATA B(48253), B(48254), B(48255) /    -5.59,  -19.76,    0.00 /
      DATA B(48400), B(48401), B(48402) /    -5.56,  -19.48,    0.00 /
      DATA B(48547), B(48548), B(48549) /    -5.49,  -19.20,    0.00 /
      DATA B(48694), B(48695), B(48696) /    -5.40,  -18.93,    0.00 /
      DATA B(48841), B(48842), B(48843) /    -5.28,  -18.66,    0.00 /
      DATA B(48988), B(48989), B(48990) /    -5.06,  -18.27,    0.00 /
      DATA B(49135), B(49136), B(49137) /    -4.89,  -17.91,    0.00 /
      DATA B(49282), B(49283), B(49284) /    -4.77,  -17.62,    0.00 /
      DATA B(49429), B(49430), B(49431) /    -4.70,  -17.40,    0.00 /
      DATA B(49576), B(49577), B(49578) /    -4.67,  -17.23,    0.00 /
      DATA B(49723), B(49724), B(49725) /    -4.66,  -17.09,    0.00 /
      DATA B(49870), B(49871), B(49872) /    -4.67,  -16.96,    0.00 /
      DATA B(50017), B(50018), B(50019) /    -4.71,  -16.84,    0.00 /
      DATA B(50164), B(50165), B(50166) /    -4.75,  -16.69,    0.00 /
      DATA B(50311), B(50312), B(50313) /    -4.80,  -16.48,    0.00 /
      DATA B(50458), B(50459), B(50460) /    -4.84,  -16.18,    0.00 /
      DATA B(50605), B(50606), B(50607) /    -4.87,  -15.74,    0.00 /
      DATA B(50752), B(50753), B(50754) /    -4.93,  -15.36,    0.00 /
      DATA B(50899), B(50900), B(50901) /    -4.93,  -15.21,    0.00 /
      DATA B(51046), B(51047), B(51048) /    -4.96,  -15.10,    0.00 /
      DATA B(51193), B(51194), B(51195) /    -4.99,  -15.01,    0.00 /
      DATA B(51340), B(51341), B(51342) /    -5.01,  -14.94,    0.00 /
      DATA B(51487), B(51488), B(51489) /    -5.04,  -14.87,    0.00 /
      DATA B(51634), B(51635), B(51636) /    -5.07,  -14.81,    0.00 /
      DATA B(51781), B(51782), B(51783) /    -5.10,  -14.74,    0.00 /
      DATA B(51928), B(51929), B(51930) /    -5.13,  -14.67,    0.00 /
      DATA B(52075), B(52076), B(52077) /    -5.16,  -14.60,    0.00 /
      DATA B(52222), B(52223), B(52224) /    -5.19,  -14.53,    0.00 /
      DATA B(52369), B(52370), B(52371) /    -5.22,  -14.45,    0.00 /
      DATA B(52516), B(52517), B(52518) /    -5.24,  -14.37,    0.00 /
      DATA B(52663), B(52664), B(52665) /    -5.27,  -14.29,    0.00 /
      DATA B(52810), B(52811), B(52812) /    -5.29,  -14.20,    0.00 /
      DATA B(52957), B(52958), B(52959) /    -5.31,  -14.11,    0.00 /
      DATA B(53104), B(53105), B(53106) /    -5.33,  -14.01,    0.00 /
      DATA B(53251), B(53252), B(53253) /    -5.36,  -13.91,    0.00 /
      DATA B(53398), B(53399), B(53400) /    -5.38,  -13.81,    0.00 /
      DATA B(53545), B(53546), B(53547) /    -5.39,  -13.70,    0.00 /
      DATA B(53692), B(53693), B(53694) /    -5.41,  -13.59,    0.00 /
      DATA B(53839), B(53840), B(53841) /    -5.42,  -13.48,    0.00 /
      DATA B(53986), B(53987), B(53988) /    -5.43,  -13.36,    0.00 /
      DATA B(54133), B(54134), B(54135) /    -5.44,  -13.24,    0.00 /
      DATA B(54280), B(54281), B(54282) /    -5.45,  -13.12,    0.00 /
      DATA B(54427), B(54428), B(54429) /    -5.45,  -13.00,    0.00 /
      DATA B(54574), B(54575), B(54576) /    -5.45,  -12.88,    0.00 /
      DATA B(54721), B(54722), B(54723) /    -5.45,  -12.76,    0.00 /
      DATA B(54868), B(54869), B(54870) /    -5.45,  -12.65,    0.00 /
      DATA B(55015), B(55016), B(55017) /    -5.44,  -12.54,    0.00 /
      DATA B(55162), B(55163), B(55164) /    -5.44,  -12.43,    0.00 /
      DATA B(55309), B(55310), B(55311) /    -5.44,  -12.33,    0.00 /
      DATA B(55456), B(55457), B(55458) /    -5.44,  -12.23,    0.00 /
      DATA B(55603), B(55604), B(55605) /    -5.44,  -12.13,    0.00 /
      DATA B(55750), B(55751), B(55752) /    -5.44,  -12.04,    0.00 /
      DATA B(55897), B(55898), B(55899) /    -5.44,  -11.94,    0.00 /
      DATA B(56044), B(56045), B(56046) /    -5.45,  -11.85,    0.00 /
      DATA B(56191), B(56192), B(56193) /    -5.46,  -11.76,    0.00 /
      DATA B(56338), B(56339), B(56340) /    -5.47,  -11.67,    0.00 /
      DATA B(56485), B(56486), B(56487) /    -5.48,  -11.58,    0.00 /
      DATA B(56632), B(56633), B(56634) /    -5.49,  -11.49,    0.00 /
      DATA B(56779), B(56780), B(56781) /    -5.50,  -11.41,    0.00 /
      DATA B(56926), B(56927), B(56928) /    -5.52,  -11.32,    0.00 /
      DATA B(57073), B(57074), B(57075) /    -5.53,  -11.23,    0.00 /
      DATA B(57220), B(57221), B(57222) /    -5.55,  -11.15,    0.00 /
      DATA B(57367), B(57368), B(57369) /    -5.57,  -11.06,    0.00 /
      DATA B(57514), B(57515), B(57516) /    -5.59,  -10.98,    0.00 /
      DATA B(57661), B(57662), B(57663) /    -5.61,  -10.91,    0.00 /
      DATA B(57808), B(57809), B(57810) /    -5.64,  -10.84,    0.00 /
      DATA B(57955), B(57956), B(57957) /    -5.68,  -10.79,    0.00 /
      DATA B(58102), B(58103), B(58104) /    -5.72,  -10.75,    0.00 /
      DATA B(58249), B(58250), B(58251) /    -5.75,  -10.72,    0.00 /
      DATA B(58396), B(58397), B(58398) /    -5.77,  -10.68,    0.00 /
      DATA B(58543), B(58544), B(58545) /    -5.79,  -10.65,    0.00 /
      DATA B(58690), B(58691), B(58692) /    -5.80,  -10.57,    0.00 /
      DATA B(58837), B(58838), B(58839) /    -5.83,  -10.51,    0.00 /
      DATA B(58984), B(58985), B(58986) /    -5.86,  -10.44,    0.00 /
      DATA B(59131), B(59132), B(59133) /    -5.88,  -10.35,    0.00 /
      DATA B(59278), B(59279), B(59280) /    -5.91,  -10.28,    0.00 /
      DATA B(59425), B(59426), B(59427) /    -5.94,  -10.21,    0.00 /
      DATA B(59572), B(59573), B(59574) /    -5.96,  -10.14,    0.00 /
      DATA B(59719), B(59720), B(59721) /    -5.99,  -10.07,    0.00 /
      DATA B(59866), B(59867), B(59868) /    -6.02,  -10.01,    0.00 /
      DATA B(60013), B(60014), B(60015) /    -6.04,   -9.94,    0.00 /
      DATA B(60160), B(60161), B(60162) /    -6.07,   -9.88,    0.00 /
      DATA B(60307), B(60308), B(60309) /    -6.10,   -9.81,    0.00 /
      DATA B(60454), B(60455), B(60456) /    -6.12,   -9.74,    0.00 /
      DATA B(60601), B(60602), B(60603) /    -6.15,   -9.66,    0.00 /
      DATA B(60748), B(60749), B(60750) /    -6.18,   -9.57,    0.00 /
      DATA B(60895), B(60896), B(60897) /    -6.20,   -9.48,    0.00 /
      DATA B(61042), B(61043), B(61044) /    -6.23,   -9.39,    0.00 /
      DATA B(61189), B(61190), B(61191) /    -6.26,   -9.30,    0.00 /
      DATA B(61336), B(61337), B(61338) /    -6.29,   -9.20,    0.00 /
      DATA B(61483), B(61484), B(61485) /    -6.32,   -9.11,    0.00 /
      DATA B(61630), B(61631), B(61632) /    -6.36,   -9.03,    0.00 /
      DATA B(61777), B(61778), B(61779) /    -6.41,   -8.96,    0.00 /
      DATA B(61924), B(61925), B(61926) /    -6.47,   -8.92,    0.00 /
      DATA B(62071), B(62072), B(62073) /    -6.53,   -8.94,    0.00 /
      DATA B(62218), B(62219), B(62220) /    -6.66,   -9.16,    0.00 /
      DATA B(62365), B(62366), B(62367) /    -6.74,   -9.23,    0.00 /
      DATA B(62512), B(62513), B(62514) /    -6.83,   -9.24,    0.00 /
      DATA B(62659), B(62660), B(62661) /    -6.90,   -9.23,    0.00 /
      DATA B(62806), B(62807), B(62808) /    -6.97,   -9.20,    0.00 /
      DATA B(62953), B(62954), B(62955) /    -7.03,   -9.16,    0.00 /
      DATA B(63100), B(63101), B(63102) /    -7.09,   -9.12,    0.00 /
      DATA B(63247), B(63248), B(63249) /    -7.15,   -9.07,    0.00 /
      DATA B(63394), B(63395), B(63396) /    -7.22,   -9.02,    0.00 /
      DATA B(63541), B(63542), B(63543) /    -7.30,   -8.97,    0.00 /
      DATA B(63688), B(63689), B(63690) /    -7.40,   -8.92,    0.00 /
      DATA B(63835), B(63836), B(63837) /    -7.52,   -8.86,    0.00 /
      DATA B(63982), B(63983), B(63984) /    -7.60,   -8.81,    0.00 /
      DATA B(64129), B(64130), B(64131) /    -7.63,   -8.76,    0.00 /
      DATA B(64276), B(64277), B(64278) /    -7.67,   -8.74,    0.00 /
      DATA B(64423), B(64424), B(64425) /    -7.75,   -8.72,    0.00 /
      DATA B(64570), B(64571), B(64572) /    -7.78,   -8.70,    0.00 /
      DATA B(64717), B(64718), B(64719) /    -7.79,   -8.70,    0.00 /
      DATA B(64864), B(64865), B(64866) /    -7.78,   -8.71,    0.00 /
      DATA B(65011), B(65012), B(65013) /    -7.76,   -8.73,    0.00 /
      DATA B(65158), B(65159), B(65160) /    -7.73,   -8.75,    0.00 /
      DATA B(65305), B(65306), B(65307) /    -7.68,   -8.78,    0.00 /
      DATA B(65452), B(65453), B(65454) /    -7.65,   -8.79,    0.00 /
      DATA B(65599), B(65600), B(65601) /    -7.85,   -9.55,    0.00 /
      DATA B(65746), B(65747), B(65748) /    -7.78,   -9.46,    0.00 /
      DATA B(65893), B(65894), B(65895) /    -7.80,   -9.52,    0.00 /
      DATA B(66040), B(66041), B(66042) /    -7.85,   -9.59,    0.00 /
      DATA B(66187), B(66188), B(66189) /    -7.90,   -9.66,    0.00 /
      DATA B(66334), B(66335), B(66336) /    -7.96,   -9.73,    0.00 /
      DATA B(66481), B(66482), B(66483) /    -8.01,   -9.79,    0.00 /
      DATA B(66628), B(66629), B(66630) /    -8.06,   -9.85,    0.00 /
      DATA B(66775), B(66776), B(66777) /    -8.11,   -9.91,    0.00 /
      DATA B(66922), B(66923), B(66924) /    -8.16,   -9.96,    0.00 /
      DATA B(67069), B(67070), B(67071) /    -8.20,  -10.02,    0.00 /
      DATA B(67216), B(67217), B(67218) /    -8.25,  -10.07,    0.00 /
      DATA B(67363), B(67364), B(67365) /    -8.30,  -10.13,    0.00 /
      DATA B(67510), B(67511), B(67512) /    -8.35,  -10.18,    0.00 /
      DATA B(67657), B(67658), B(67659) /    -8.40,  -10.23,    0.00 /
      DATA B(46492), B(46493), B(46494) /    -5.01,  -22.42,    0.00 /
      DATA B(46639), B(46640), B(46641) /    -5.09,  -22.24,    0.00 /
      DATA B(46786), B(46787), B(46788) /    -5.17,  -22.06,    0.00 /
      DATA B(46933), B(46934), B(46935) /    -5.24,  -21.87,    0.00 /
      DATA B(47080), B(47081), B(47082) /    -5.31,  -21.68,    0.00 /
      DATA B(47227), B(47228), B(47229) /    -5.38,  -21.48,    0.00 /
      DATA B(47374), B(47375), B(47376) /    -5.44,  -21.27,    0.00 /
      DATA B(47521), B(47522), B(47523) /    -5.49,  -21.06,    0.00 /
      DATA B(47668), B(47669), B(47670) /    -5.54,  -20.83,    0.00 /
      DATA B(47815), B(47816), B(47817) /    -5.57,  -20.59,    0.00 /
      DATA B(47962), B(47963), B(47964) /    -5.60,  -20.34,    0.00 /
      DATA B(48109), B(48110), B(48111) /    -5.61,  -20.08,    0.00 /
      DATA B(48256), B(48257), B(48258) /    -5.60,  -19.82,    0.00 /
      DATA B(48403), B(48404), B(48405) /    -5.56,  -19.56,    0.00 /
      DATA B(48550), B(48551), B(48552) /    -5.50,  -19.30,    0.00 /
      DATA B(48697), B(48698), B(48699) /    -5.41,  -19.04,    0.00 /
      DATA B(48844), B(48845), B(48846) /    -5.29,  -18.77,    0.00 /
      DATA B(48991), B(48992), B(48993) /    -5.02,  -18.39,    0.00 /
      DATA B(49138), B(49139), B(49140) /    -4.88,  -17.99,    0.00 /
      DATA B(49285), B(49286), B(49287) /    -4.76,  -17.68,    0.00 /
      DATA B(49432), B(49433), B(49434) /    -4.69,  -17.44,    0.00 /
      DATA B(49579), B(49580), B(49581) /    -4.66,  -17.25,    0.00 /
      DATA B(49726), B(49727), B(49728) /    -4.66,  -17.10,    0.00 /
      DATA B(49873), B(49874), B(49875) /    -4.68,  -16.96,    0.00 /
      DATA B(50020), B(50021), B(50022) /    -4.72,  -16.83,    0.00 /
      DATA B(50167), B(50168), B(50169) /    -4.78,  -16.68,    0.00 /
      DATA B(50314), B(50315), B(50316) /    -4.84,  -16.48,    0.00 /
      DATA B(50461), B(50462), B(50463) /    -4.90,  -16.19,    0.00 /
      DATA B(50608), B(50609), B(50610) /    -4.91,  -15.76,    0.00 /
      DATA B(50755), B(50756), B(50757) /    -4.91,  -15.40,    0.00 /
      DATA B(50902), B(50903), B(50904) /    -5.00,  -15.30,    0.00 /
      DATA B(51049), B(51050), B(51051) /    -5.04,  -15.19,    0.00 /
      DATA B(51196), B(51197), B(51198) /    -5.08,  -15.11,    0.00 /
      DATA B(51343), B(51344), B(51345) /    -5.11,  -15.03,    0.00 /
      DATA B(51490), B(51491), B(51492) /    -5.14,  -14.97,    0.00 /
      DATA B(51637), B(51638), B(51639) /    -5.18,  -14.90,    0.00 /
      DATA B(51784), B(51785), B(51786) /    -5.21,  -14.83,    0.00 /
      DATA B(51931), B(51932), B(51933) /    -5.24,  -14.76,    0.00 /
      DATA B(52078), B(52079), B(52080) /    -5.27,  -14.69,    0.00 /
      DATA B(52225), B(52226), B(52227) /    -5.29,  -14.61,    0.00 /
      DATA B(52372), B(52373), B(52374) /    -5.32,  -14.54,    0.00 /
      DATA B(52519), B(52520), B(52521) /    -5.35,  -14.45,    0.00 /
      DATA B(52666), B(52667), B(52668) /    -5.37,  -14.37,    0.00 /
      DATA B(52813), B(52814), B(52815) /    -5.39,  -14.28,    0.00 /
      DATA B(52960), B(52961), B(52962) /    -5.41,  -14.19,    0.00 /
      DATA B(53107), B(53108), B(53109) /    -5.44,  -14.10,    0.00 /
      DATA B(53254), B(53255), B(53256) /    -5.46,  -14.00,    0.00 /
      DATA B(53401), B(53402), B(53403) /    -5.47,  -13.89,    0.00 /
      DATA B(53548), B(53549), B(53550) /    -5.49,  -13.79,    0.00 /
      DATA B(53695), B(53696), B(53697) /    -5.51,  -13.68,    0.00 /
      DATA B(53842), B(53843), B(53844) /    -5.52,  -13.57,    0.00 /
      DATA B(53989), B(53990), B(53991) /    -5.53,  -13.45,    0.00 /
      DATA B(54136), B(54137), B(54138) /    -5.54,  -13.34,    0.00 /
      DATA B(54283), B(54284), B(54285) /    -5.54,  -13.22,    0.00 /
      DATA B(54430), B(54431), B(54432) /    -5.55,  -13.10,    0.00 /
      DATA B(54577), B(54578), B(54579) /    -5.55,  -12.99,    0.00 /
      DATA B(54724), B(54725), B(54726) /    -5.55,  -12.87,    0.00 /
      DATA B(54871), B(54872), B(54873) /    -5.55,  -12.76,    0.00 /
      DATA B(55018), B(55019), B(55020) /    -5.54,  -12.65,    0.00 /
      DATA B(55165), B(55166), B(55167) /    -5.54,  -12.54,    0.00 /
      DATA B(55312), B(55313), B(55314) /    -5.54,  -12.44,    0.00 /
      DATA B(55459), B(55460), B(55461) /    -5.54,  -12.34,    0.00 /
      DATA B(55606), B(55607), B(55608) /    -5.54,  -12.24,    0.00 /
      DATA B(55753), B(55754), B(55755) /    -5.54,  -12.14,    0.00 /
      DATA B(55900), B(55901), B(55902) /    -5.55,  -12.05,    0.00 /
      DATA B(56047), B(56048), B(56049) /    -5.56,  -11.96,    0.00 /
      DATA B(56194), B(56195), B(56196) /    -5.56,  -11.87,    0.00 /
      DATA B(56341), B(56342), B(56343) /    -5.57,  -11.78,    0.00 /
      DATA B(56488), B(56489), B(56490) /    -5.58,  -11.69,    0.00 /
      DATA B(56635), B(56636), B(56637) /    -5.60,  -11.60,    0.00 /
      DATA B(56782), B(56783), B(56784) /    -5.61,  -11.51,    0.00 /
      DATA B(56929), B(56930), B(56931) /    -5.62,  -11.42,    0.00 /
      DATA B(57076), B(57077), B(57078) /    -5.64,  -11.34,    0.00 /
      DATA B(57223), B(57224), B(57225) /    -5.66,  -11.25,    0.00 /
      DATA B(57370), B(57371), B(57372) /    -5.68,  -11.17,    0.00 /
      DATA B(57517), B(57518), B(57519) /    -5.70,  -11.09,    0.00 /
      DATA B(57664), B(57665), B(57666) /    -5.73,  -11.02,    0.00 /
      DATA B(57811), B(57812), B(57813) /    -5.77,  -10.96,    0.00 /
      DATA B(57958), B(57959), B(57960) /    -5.81,  -10.91,    0.00 /
      DATA B(58105), B(58106), B(58107) /    -5.86,  -10.88,    0.00 /
      DATA B(58252), B(58253), B(58254) /    -5.91,  -10.86,    0.00 /
      DATA B(58399), B(58400), B(58401) /    -5.94,  -10.83,    0.00 /
      DATA B(58546), B(58547), B(58548) /    -5.98,  -10.84,    0.00 /
      DATA B(58693), B(58694), B(58695) /    -5.97,  -10.73,    0.00 /
      DATA B(58840), B(58841), B(58842) /    -5.99,  -10.65,    0.00 /
      DATA B(58987), B(58988), B(58989) /    -6.02,  -10.58,    0.00 /
      DATA B(59134), B(59135), B(59136) /    -6.05,  -10.51,    0.00 /
      DATA B(59281), B(59282), B(59283) /    -6.08,  -10.45,    0.00 /
      DATA B(59428), B(59429), B(59430) /    -6.11,  -10.39,    0.00 /
      DATA B(59575), B(59576), B(59577) /    -6.13,  -10.32,    0.00 /
      DATA B(59722), B(59723), B(59724) /    -6.16,  -10.26,    0.00 /
      DATA B(59869), B(59870), B(59871) /    -6.18,  -10.19,    0.00 /
      DATA B(60016), B(60017), B(60018) /    -6.21,  -10.12,    0.00 /
      DATA B(60163), B(60164), B(60165) /    -6.23,  -10.05,    0.00 /
      DATA B(60310), B(60311), B(60312) /    -6.25,   -9.98,    0.00 /
      DATA B(60457), B(60458), B(60459) /    -6.28,   -9.90,    0.00 /
      DATA B(60604), B(60605), B(60606) /    -6.30,   -9.82,    0.00 /
      DATA B(60751), B(60752), B(60753) /    -6.32,   -9.73,    0.00 /
      DATA B(60898), B(60899), B(60900) /    -6.34,   -9.64,    0.00 /
      DATA B(61045), B(61046), B(61047) /    -6.37,   -9.55,    0.00 /
      DATA B(61192), B(61193), B(61194) /    -6.39,   -9.45,    0.00 /
      DATA B(61339), B(61340), B(61341) /    -6.42,   -9.36,    0.00 /
      DATA B(61486), B(61487), B(61488) /    -6.45,   -9.27,    0.00 /
      DATA B(61633), B(61634), B(61635) /    -6.48,   -9.18,    0.00 /
      DATA B(61780), B(61781), B(61782) /    -6.53,   -9.11,    0.00 /
      DATA B(61927), B(61928), B(61929) /    -6.59,   -9.08,    0.00 /
      DATA B(62074), B(62075), B(62076) /    -6.65,   -9.09,    0.00 /
      DATA B(62221), B(62222), B(62223) /    -6.80,   -9.34,    0.00 /
      DATA B(62368), B(62369), B(62370) /    -6.87,   -9.41,    0.00 /
      DATA B(62515), B(62516), B(62517) /    -6.95,   -9.43,    0.00 /
      DATA B(62662), B(62663), B(62664) /    -7.03,   -9.42,    0.00 /
      DATA B(62809), B(62810), B(62811) /    -7.09,   -9.39,    0.00 /
      DATA B(62956), B(62957), B(62958) /    -7.15,   -9.36,    0.00 /
      DATA B(63103), B(63104), B(63105) /    -7.21,   -9.31,    0.00 /
      DATA B(63250), B(63251), B(63252) /    -7.27,   -9.27,    0.00 /
      DATA B(63397), B(63398), B(63399) /    -7.34,   -9.22,    0.00 /
      DATA B(63544), B(63545), B(63546) /    -7.41,   -9.16,    0.00 /
      DATA B(63691), B(63692), B(63693) /    -7.51,   -9.11,    0.00 /
      DATA B(63838), B(63839), B(63840) /    -7.61,   -9.05,    0.00 /
      DATA B(63985), B(63986), B(63987) /    -7.70,   -9.01,    0.00 /
      DATA B(64132), B(64133), B(64134) /    -7.72,   -8.97,    0.00 /
      DATA B(64279), B(64280), B(64281) /    -7.78,   -8.92,    0.00 /
      DATA B(64426), B(64427), B(64428) /    -7.84,   -8.89,    0.00 /
      DATA B(64573), B(64574), B(64575) /    -7.86,   -8.88,    0.00 /
      DATA B(64720), B(64721), B(64722) /    -7.86,   -8.88,    0.00 /
      DATA B(64867), B(64868), B(64869) /    -7.85,   -8.89,    0.00 /
      DATA B(65014), B(65015), B(65016) /    -7.83,   -8.90,    0.00 /
      DATA B(65161), B(65162), B(65163) /    -7.80,   -8.92,    0.00 /
      DATA B(65308), B(65309), B(65310) /    -7.77,   -8.94,    0.00 /
      DATA B(65455), B(65456), B(65457) /    -7.90,   -9.89,    0.00 /
      DATA B(65602), B(65603), B(65604) /    -7.94,   -9.72,    0.00 /
      DATA B(65749), B(65750), B(65751) /    -7.91,   -9.64,    0.00 /
      DATA B(65896), B(65897), B(65898) /    -7.91,   -9.66,    0.00 /
      DATA B(66043), B(66044), B(66045) /    -7.94,   -9.71,    0.00 /
      DATA B(66190), B(66191), B(66192) /    -7.98,   -9.77,    0.00 /
      DATA B(66337), B(66338), B(66339) /    -8.03,   -9.83,    0.00 /
      DATA B(66484), B(66485), B(66486) /    -8.07,   -9.88,    0.00 /
      DATA B(66631), B(66632), B(66633) /    -8.12,   -9.94,    0.00 /
      DATA B(66778), B(66779), B(66780) /    -8.17,   -9.99,    0.00 /
      DATA B(66925), B(66926), B(66927) /    -8.21,  -10.05,    0.00 /
      DATA B(67072), B(67073), B(67074) /    -8.26,  -10.10,    0.00 /
      DATA B(67219), B(67220), B(67221) /    -8.31,  -10.15,    0.00 /
      DATA B(67366), B(67367), B(67368) /    -8.35,  -10.21,    0.00 /
      DATA B(67513), B(67514), B(67515) /    -8.40,  -10.26,    0.00 /
      DATA B(67660), B(67661), B(67662) /    -8.45,  -10.31,    0.00 /
      DATA B(46495), B(46496), B(46497) /    -5.04,  -22.33,    0.00 /
      DATA B(46642), B(46643), B(46644) /    -5.12,  -22.16,    0.00 /
      DATA B(46789), B(46790), B(46791) /    -5.19,  -21.99,    0.00 /
      DATA B(46936), B(46937), B(46938) /    -5.26,  -21.81,    0.00 /
      DATA B(47083), B(47084), B(47085) /    -5.32,  -21.63,    0.00 /
      DATA B(47230), B(47231), B(47232) /    -5.38,  -21.44,    0.00 /
      DATA B(47377), B(47378), B(47379) /    -5.44,  -21.24,    0.00 /
      DATA B(47524), B(47525), B(47526) /    -5.49,  -21.04,    0.00 /
      DATA B(47671), B(47672), B(47673) /    -5.54,  -20.82,    0.00 /
      DATA B(47818), B(47819), B(47820) /    -5.57,  -20.60,    0.00 /
      DATA B(47965), B(47966), B(47967) /    -5.59,  -20.36,    0.00 /
      DATA B(48112), B(48113), B(48114) /    -5.60,  -20.12,    0.00 /
      DATA B(48259), B(48260), B(48261) /    -5.59,  -19.88,    0.00 /
      DATA B(48406), B(48407), B(48408) /    -5.56,  -19.63,    0.00 /
      DATA B(48553), B(48554), B(48555) /    -5.50,  -19.39,    0.00 /
      DATA B(48700), B(48701), B(48702) /    -5.42,  -19.14,    0.00 /
      DATA B(48847), B(48848), B(48849) /    -5.29,  -18.87,    0.00 /
      DATA B(48994), B(48995), B(48996) /    -5.03,  -18.47,    0.00 /
      DATA B(49141), B(49142), B(49143) /    -4.86,  -18.06,    0.00 /
      DATA B(49288), B(49289), B(49290) /    -4.74,  -17.72,    0.00 /
      DATA B(49435), B(49436), B(49437) /    -4.67,  -17.46,    0.00 /
      DATA B(49582), B(49583), B(49584) /    -4.65,  -17.26,    0.00 /
      DATA B(49729), B(49730), B(49731) /    -4.65,  -17.09,    0.00 /
      DATA B(49876), B(49877), B(49878) /    -4.67,  -16.95,    0.00 /
      DATA B(50023), B(50024), B(50025) /    -4.72,  -16.81,    0.00 /
      DATA B(50170), B(50171), B(50172) /    -4.79,  -16.66,    0.00 /
      DATA B(50317), B(50318), B(50319) /    -4.87,  -16.47,    0.00 /
      DATA B(50464), B(50465), B(50466) /    -4.94,  -16.19,    0.00 /
      DATA B(50611), B(50612), B(50613) /    -4.98,  -15.82,    0.00 /
      DATA B(50758), B(50759), B(50760) /    -5.03,  -15.49,    0.00 /
      DATA B(50905), B(50906), B(50907) /    -5.06,  -15.38,    0.00 /
      DATA B(51052), B(51053), B(51054) /    -5.12,  -15.28,    0.00 /
      DATA B(51199), B(51200), B(51201) /    -5.16,  -15.20,    0.00 /
      DATA B(51346), B(51347), B(51348) /    -5.20,  -15.12,    0.00 /
      DATA B(51493), B(51494), B(51495) /    -5.24,  -15.05,    0.00 /
      DATA B(51640), B(51641), B(51642) /    -5.28,  -14.99,    0.00 /
      DATA B(51787), B(51788), B(51789) /    -5.31,  -14.92,    0.00 /
      DATA B(51934), B(51935), B(51936) /    -5.34,  -14.85,    0.00 /
      DATA B(52081), B(52082), B(52083) /    -5.37,  -14.77,    0.00 /
      DATA B(52228), B(52229), B(52230) /    -5.40,  -14.70,    0.00 /
      DATA B(52375), B(52376), B(52377) /    -5.42,  -14.62,    0.00 /
      DATA B(52522), B(52523), B(52524) /    -5.45,  -14.54,    0.00 /
      DATA B(52669), B(52670), B(52671) /    -5.47,  -14.45,    0.00 /
      DATA B(52816), B(52817), B(52818) /    -5.49,  -14.37,    0.00 /
      DATA B(52963), B(52964), B(52965) /    -5.52,  -14.27,    0.00 /
      DATA B(53110), B(53111), B(53112) /    -5.54,  -14.18,    0.00 /
      DATA B(53257), B(53258), B(53259) /    -5.55,  -14.08,    0.00 /
      DATA B(53404), B(53405), B(53406) /    -5.57,  -13.98,    0.00 /
      DATA B(53551), B(53552), B(53553) /    -5.59,  -13.88,    0.00 /
      DATA B(53698), B(53699), B(53700) /    -5.60,  -13.77,    0.00 /
      DATA B(53845), B(53846), B(53847) /    -5.62,  -13.66,    0.00 /
      DATA B(53992), B(53993), B(53994) /    -5.63,  -13.55,    0.00 /
      DATA B(54139), B(54140), B(54141) /    -5.63,  -13.43,    0.00 /
      DATA B(54286), B(54287), B(54288) /    -5.64,  -13.32,    0.00 /
      DATA B(54433), B(54434), B(54435) /    -5.64,  -13.20,    0.00 /
      DATA B(54580), B(54581), B(54582) /    -5.64,  -13.09,    0.00 /
      DATA B(54727), B(54728), B(54729) /    -5.64,  -12.98,    0.00 /
      DATA B(54874), B(54875), B(54876) /    -5.64,  -12.87,    0.00 /
      DATA B(55021), B(55022), B(55023) /    -5.64,  -12.76,    0.00 /
      DATA B(55168), B(55169), B(55170) /    -5.64,  -12.65,    0.00 /
      DATA B(55315), B(55316), B(55317) /    -5.64,  -12.55,    0.00 /
      DATA B(55462), B(55463), B(55464) /    -5.64,  -12.44,    0.00 /
      DATA B(55609), B(55610), B(55611) /    -5.64,  -12.35,    0.00 /
      DATA B(55756), B(55757), B(55758) /    -5.65,  -12.25,    0.00 /
      DATA B(55903), B(55904), B(55905) /    -5.65,  -12.15,    0.00 /
      DATA B(56050), B(56051), B(56052) /    -5.66,  -12.06,    0.00 /
      DATA B(56197), B(56198), B(56199) /    -5.67,  -11.97,    0.00 /
      DATA B(56344), B(56345), B(56346) /    -5.68,  -11.88,    0.00 /
      DATA B(56491), B(56492), B(56493) /    -5.69,  -11.79,    0.00 /
      DATA B(56638), B(56639), B(56640) /    -5.70,  -11.70,    0.00 /
      DATA B(56785), B(56786), B(56787) /    -5.71,  -11.61,    0.00 /
      DATA B(56932), B(56933), B(56934) /    -5.73,  -11.53,    0.00 /
      DATA B(57079), B(57080), B(57081) /    -5.75,  -11.44,    0.00 /
      DATA B(57226), B(57227), B(57228) /    -5.77,  -11.36,    0.00 /
      DATA B(57373), B(57374), B(57375) /    -5.79,  -11.27,    0.00 /
      DATA B(57520), B(57521), B(57522) /    -5.82,  -11.20,    0.00 /
      DATA B(57667), B(57668), B(57669) /    -5.86,  -11.13,    0.00 /
      DATA B(57814), B(57815), B(57816) /    -5.90,  -11.07,    0.00 /
      DATA B(57961), B(57962), B(57963) /    -5.95,  -11.03,    0.00 /
      DATA B(58108), B(58109), B(58110) /    -6.01,  -11.01,    0.00 /
      DATA B(58255), B(58256), B(58257) /    -6.05,  -10.99,    0.00 /
      DATA B(58402), B(58403), B(58404) /    -6.08,  -11.00,    0.00 /
      DATA B(58549), B(58550), B(58551) /    -6.09,  -10.95,    0.00 /
      DATA B(58696), B(58697), B(58698) /    -6.12,  -10.87,    0.00 /
      DATA B(58843), B(58844), B(58845) /    -6.16,  -10.80,    0.00 /
      DATA B(58990), B(58991), B(58992) /    -6.19,  -10.74,    0.00 /
      DATA B(59137), B(59138), B(59139) /    -6.22,  -10.69,    0.00 /
      DATA B(59284), B(59285), B(59286) /    -6.25,  -10.63,    0.00 /
      DATA B(59431), B(59432), B(59433) /    -6.28,  -10.57,    0.00 /
      DATA B(59578), B(59579), B(59580) /    -6.30,  -10.51,    0.00 /
      DATA B(59725), B(59726), B(59727) /    -6.32,  -10.44,    0.00 /
      DATA B(59872), B(59873), B(59874) /    -6.34,  -10.37,    0.00 /
      DATA B(60019), B(60020), B(60021) /    -6.36,  -10.30,    0.00 /
      DATA B(60166), B(60167), B(60168) /    -6.38,  -10.22,    0.00 /
      DATA B(60313), B(60314), B(60315) /    -6.40,  -10.15,    0.00 /
      DATA B(60460), B(60461), B(60462) /    -6.42,  -10.06,    0.00 /
      DATA B(60607), B(60608), B(60609) /    -6.44,   -9.98,    0.00 /
      DATA B(60754), B(60755), B(60756) /    -6.46,   -9.89,    0.00 /
      DATA B(60901), B(60902), B(60903) /    -6.48,   -9.80,    0.00 /
      DATA B(61048), B(61049), B(61050) /    -6.50,   -9.70,    0.00 /
      DATA B(61195), B(61196), B(61197) /    -6.52,   -9.61,    0.00 /
      DATA B(61342), B(61343), B(61344) /    -6.55,   -9.51,    0.00 /
      DATA B(61489), B(61490), B(61491) /    -6.57,   -9.42,    0.00 /
      DATA B(61636), B(61637), B(61638) /    -6.60,   -9.33,    0.00 /
      DATA B(61783), B(61784), B(61785) /    -6.65,   -9.26,    0.00 /
      DATA B(61930), B(61931), B(61932) /    -6.70,   -9.22,    0.00 /
      DATA B(62077), B(62078), B(62079) /    -6.77,   -9.24,    0.00 /
      DATA B(62224), B(62225), B(62226) /    -6.91,   -9.50,    0.00 /
      DATA B(62371), B(62372), B(62373) /    -7.00,   -9.60,    0.00 /
      DATA B(62518), B(62519), B(62520) /    -7.08,   -9.62,    0.00 /
      DATA B(62665), B(62666), B(62667) /    -7.15,   -9.61,    0.00 /
      DATA B(62812), B(62813), B(62814) /    -7.21,   -9.58,    0.00 /
      DATA B(62959), B(62960), B(62961) /    -7.27,   -9.55,    0.00 /
      DATA B(63106), B(63107), B(63108) /    -7.33,   -9.50,    0.00 /
      DATA B(63253), B(63254), B(63255) /    -7.39,   -9.46,    0.00 /
      DATA B(63400), B(63401), B(63402) /    -7.45,   -9.41,    0.00 /
      DATA B(63547), B(63548), B(63549) /    -7.52,   -9.35,    0.00 /
      DATA B(63694), B(63695), B(63696) /    -7.61,   -9.30,    0.00 /
      DATA B(63841), B(63842), B(63843) /    -7.70,   -9.24,    0.00 /
      DATA B(63988), B(63989), B(63990) /    -7.79,   -9.20,    0.00 /
      DATA B(64135), B(64136), B(64137) /    -7.83,   -9.19,    0.00 /
      DATA B(64282), B(64283), B(64284) /    -7.83,   -9.09,    0.00 /
      DATA B(64429), B(64430), B(64431) /    -7.95,   -9.05,    0.00 /
      DATA B(64576), B(64577), B(64578) /    -7.94,   -9.05,    0.00 /
      DATA B(64723), B(64724), B(64725) /    -7.93,   -9.05,    0.00 /
      DATA B(64870), B(64871), B(64872) /    -7.92,   -9.06,    0.00 /
      DATA B(65017), B(65018), B(65019) /    -7.90,   -9.07,    0.00 /
      DATA B(65164), B(65165), B(65166) /    -7.87,   -9.08,    0.00 /
      DATA B(65311), B(65312), B(65313) /    -7.84,   -9.09,    0.00 /
      DATA B(65458), B(65459), B(65460) /    -7.99,   -9.91,    0.00 /
      DATA B(65605), B(65606), B(65607) /    -8.01,   -9.85,    0.00 /
      DATA B(65752), B(65753), B(65754) /    -8.01,   -9.79,    0.00 /
      DATA B(65899), B(65900), B(65901) /    -8.00,   -9.79,    0.00 /
      DATA B(66046), B(66047), B(66048) /    -8.02,   -9.83,    0.00 /
      DATA B(66193), B(66194), B(66195) /    -8.06,   -9.87,    0.00 /
      DATA B(66340), B(66341), B(66342) /    -8.10,   -9.92,    0.00 /
      DATA B(66487), B(66488), B(66489) /    -8.14,   -9.97,    0.00 /
      DATA B(66634), B(66635), B(66636) /    -8.18,  -10.03,    0.00 /
      DATA B(66781), B(66782), B(66783) /    -8.22,  -10.08,    0.00 /
      DATA B(66928), B(66929), B(66930) /    -8.27,  -10.13,    0.00 /
      DATA B(67075), B(67076), B(67077) /    -8.31,  -10.18,    0.00 /
      DATA B(67222), B(67223), B(67224) /    -8.36,  -10.23,    0.00 /
      DATA B(67369), B(67370), B(67371) /    -8.40,  -10.28,    0.00 /
      DATA B(67516), B(67517), B(67518) /    -8.45,  -10.33,    0.00 /
      DATA B(67663), B(67664), B(67665) /    -8.50,  -10.38,    0.00 /
      DATA B(46498), B(46499), B(46500) /    -5.06,  -22.25,    0.00 /
      DATA B(46645), B(46646), B(46647) /    -5.14,  -22.09,    0.00 /
      DATA B(46792), B(46793), B(46794) /    -5.20,  -21.92,    0.00 /
      DATA B(46939), B(46940), B(46941) /    -5.27,  -21.75,    0.00 /
      DATA B(47086), B(47087), B(47088) /    -5.33,  -21.58,    0.00 /
      DATA B(47233), B(47234), B(47235) /    -5.39,  -21.40,    0.00 /
      DATA B(47380), B(47381), B(47382) /    -5.44,  -21.21,    0.00 /
      DATA B(47527), B(47528), B(47529) /    -5.49,  -21.02,    0.00 /
      DATA B(47674), B(47675), B(47676) /    -5.53,  -20.81,    0.00 /
      DATA B(47821), B(47822), B(47823) /    -5.56,  -20.60,    0.00 /
      DATA B(47968), B(47969), B(47970) /    -5.58,  -20.38,    0.00 /
      DATA B(48115), B(48116), B(48117) /    -5.59,  -20.16,    0.00 /
      DATA B(48262), B(48263), B(48264) /    -5.58,  -19.93,    0.00 /
      DATA B(48409), B(48410), B(48411) /    -5.55,  -19.70,    0.00 /
      DATA B(48556), B(48557), B(48558) /    -5.50,  -19.46,    0.00 /
      DATA B(48703), B(48704), B(48705) /    -5.41,  -19.22,    0.00 /
      DATA B(48850), B(48851), B(48852) /    -5.29,  -18.95,    0.00 /
      DATA B(48997), B(48998), B(48999) /    -4.96,  -18.55,    0.00 /
      DATA B(49144), B(49145), B(49146) /    -4.83,  -18.10,    0.00 /
      DATA B(49291), B(49292), B(49293) /    -4.71,  -17.75,    0.00 /
      DATA B(49438), B(49439), B(49440) /    -4.64,  -17.47,    0.00 /
      DATA B(49585), B(49586), B(49587) /    -4.62,  -17.25,    0.00 /
      DATA B(49732), B(49733), B(49734) /    -4.62,  -17.07,    0.00 /
      DATA B(49879), B(49880), B(49881) /    -4.65,  -16.92,    0.00 /
      DATA B(50026), B(50027), B(50028) /    -4.71,  -16.77,    0.00 /
      DATA B(50173), B(50174), B(50175) /    -4.79,  -16.62,    0.00 /
      DATA B(50320), B(50321), B(50322) /    -4.89,  -16.44,    0.00 /
      DATA B(50467), B(50468), B(50469) /    -4.98,  -16.18,    0.00 /
      DATA B(50614), B(50615), B(50616) /    -5.00,  -15.82,    0.00 /
      DATA B(50761), B(50762), B(50763) /    -5.00,  -15.52,    0.00 /
      DATA B(50908), B(50909), B(50910) /    -5.12,  -15.45,    0.00 /
      DATA B(51055), B(51056), B(51057) /    -5.19,  -15.36,    0.00 /
      DATA B(51202), B(51203), B(51204) /    -5.25,  -15.28,    0.00 /
      DATA B(51349), B(51350), B(51351) /    -5.30,  -15.21,    0.00 /
      DATA B(51496), B(51497), B(51498) /    -5.34,  -15.14,    0.00 /
      DATA B(51643), B(51644), B(51645) /    -5.38,  -15.07,    0.00 /
      DATA B(51790), B(51791), B(51792) /    -5.41,  -15.00,    0.00 /
      DATA B(51937), B(51938), B(51939) /    -5.44,  -14.93,    0.00 /
      DATA B(52084), B(52085), B(52086) /    -5.47,  -14.86,    0.00 /
      DATA B(52231), B(52232), B(52233) /    -5.50,  -14.78,    0.00 /
      DATA B(52378), B(52379), B(52380) /    -5.53,  -14.70,    0.00 /
      DATA B(52525), B(52526), B(52527) /    -5.55,  -14.62,    0.00 /
      DATA B(52672), B(52673), B(52674) /    -5.57,  -14.54,    0.00 /
      DATA B(52819), B(52820), B(52821) /    -5.60,  -14.45,    0.00 /
      DATA B(52966), B(52967), B(52968) /    -5.62,  -14.36,    0.00 /
      DATA B(53113), B(53114), B(53115) /    -5.63,  -14.26,    0.00 /
      DATA B(53260), B(53261), B(53262) /    -5.65,  -14.17,    0.00 /
      DATA B(53407), B(53408), B(53409) /    -5.67,  -14.07,    0.00 /
      DATA B(53554), B(53555), B(53556) /    -5.69,  -13.96,    0.00 /
      DATA B(53701), B(53702), B(53703) /    -5.70,  -13.86,    0.00 /
      DATA B(53848), B(53849), B(53850) /    -5.71,  -13.75,    0.00 /
      DATA B(53995), B(53996), B(53997) /    -5.72,  -13.64,    0.00 /
      DATA B(54142), B(54143), B(54144) /    -5.73,  -13.53,    0.00 /
      DATA B(54289), B(54290), B(54291) /    -5.73,  -13.41,    0.00 /
      DATA B(54436), B(54437), B(54438) /    -5.74,  -13.30,    0.00 /
      DATA B(54583), B(54584), B(54585) /    -5.74,  -13.19,    0.00 /
      DATA B(54730), B(54731), B(54732) /    -5.74,  -13.08,    0.00 /
      DATA B(54877), B(54878), B(54879) /    -5.74,  -12.97,    0.00 /
      DATA B(55024), B(55025), B(55026) /    -5.74,  -12.86,    0.00 /
      DATA B(55171), B(55172), B(55173) /    -5.74,  -12.75,    0.00 /
      DATA B(55318), B(55319), B(55320) /    -5.74,  -12.65,    0.00 /
      DATA B(55465), B(55466), B(55467) /    -5.74,  -12.55,    0.00 /
      DATA B(55612), B(55613), B(55614) /    -5.75,  -12.45,    0.00 /
      DATA B(55759), B(55760), B(55761) /    -5.75,  -12.35,    0.00 /
      DATA B(55906), B(55907), B(55908) /    -5.75,  -12.25,    0.00 /
      DATA B(56053), B(56054), B(56055) /    -5.76,  -12.16,    0.00 /
      DATA B(56200), B(56201), B(56202) /    -5.77,  -12.07,    0.00 /
      DATA B(56347), B(56348), B(56349) /    -5.78,  -11.98,    0.00 /
      DATA B(56494), B(56495), B(56496) /    -5.79,  -11.89,    0.00 /
      DATA B(56641), B(56642), B(56643) /    -5.80,  -11.80,    0.00 /
      DATA B(56788), B(56789), B(56790) /    -5.82,  -11.71,    0.00 /
      DATA B(56935), B(56936), B(56937) /    -5.84,  -11.63,    0.00 /
      DATA B(57082), B(57083), B(57084) /    -5.85,  -11.54,    0.00 /
      DATA B(57229), B(57230), B(57231) /    -5.88,  -11.46,    0.00 /
      DATA B(57376), B(57377), B(57378) /    -5.90,  -11.38,    0.00 /
      DATA B(57523), B(57524), B(57525) /    -5.94,  -11.30,    0.00 /
      DATA B(57670), B(57671), B(57672) /    -5.98,  -11.23,    0.00 /
      DATA B(57817), B(57818), B(57819) /    -6.03,  -11.18,    0.00 /
      DATA B(57964), B(57965), B(57966) /    -6.09,  -11.15,    0.00 /
      DATA B(58111), B(58112), B(58113) /    -6.15,  -11.14,    0.00 /
      DATA B(58258), B(58259), B(58260) /    -6.20,  -11.18,    0.00 /
      DATA B(58405), B(58406), B(58407) /    -6.20,  -11.13,    0.00 /
      DATA B(58552), B(58553), B(58554) /    -6.23,  -11.08,    0.00 /
      DATA B(58699), B(58700), B(58701) /    -6.28,  -11.03,    0.00 /
      DATA B(58846), B(58847), B(58848) /    -6.33,  -10.97,    0.00 /
      DATA B(58993), B(58994), B(58995) /    -6.36,  -10.92,    0.00 /
      DATA B(59140), B(59141), B(59142) /    -6.39,  -10.87,    0.00 /
      DATA B(59287), B(59288), B(59289) /    -6.42,  -10.82,    0.00 /
      DATA B(59434), B(59435), B(59436) /    -6.44,  -10.76,    0.00 /
      DATA B(59581), B(59582), B(59583) /    -6.46,  -10.69,    0.00 /
      DATA B(59728), B(59729), B(59730) /    -6.48,  -10.62,    0.00 /
      DATA B(59875), B(59876), B(59877) /    -6.50,  -10.55,    0.00 /
      DATA B(60022), B(60023), B(60024) /    -6.52,  -10.47,    0.00 /
      DATA B(60169), B(60170), B(60171) /    -6.53,  -10.39,    0.00 /
      DATA B(60316), B(60317), B(60318) /    -6.55,  -10.31,    0.00 /
      DATA B(60463), B(60464), B(60465) /    -6.57,  -10.22,    0.00 /
      DATA B(60610), B(60611), B(60612) /    -6.59,  -10.13,    0.00 /
      DATA B(60757), B(60758), B(60759) /    -6.60,  -10.04,    0.00 /
      DATA B(60904), B(60905), B(60906) /    -6.62,   -9.95,    0.00 /
      DATA B(61051), B(61052), B(61053) /    -6.64,   -9.85,    0.00 /
      DATA B(61198), B(61199), B(61200) /    -6.66,   -9.76,    0.00 /
      DATA B(61345), B(61346), B(61347) /    -6.68,   -9.66,    0.00 /
      DATA B(61492), B(61493), B(61494) /    -6.70,   -9.57,    0.00 /
      DATA B(61639), B(61640), B(61641) /    -6.72,   -9.48,    0.00 /
      DATA B(61786), B(61787), B(61788) /    -6.76,   -9.41,    0.00 /
      DATA B(61933), B(61934), B(61935) /    -6.81,   -9.36,    0.00 /
      DATA B(62080), B(62081), B(62082) /    -6.88,   -9.38,    0.00 /
      DATA B(62227), B(62228), B(62229) /    -7.05,   -9.67,    0.00 /
      DATA B(62374), B(62375), B(62376) /    -7.12,   -9.78,    0.00 /
      DATA B(62521), B(62522), B(62523) /    -7.20,   -9.81,    0.00 /
      DATA B(62668), B(62669), B(62670) /    -7.27,   -9.80,    0.00 /
      DATA B(62815), B(62816), B(62817) /    -7.33,   -9.77,    0.00 /
      DATA B(62962), B(62963), B(62964) /    -7.39,   -9.73,    0.00 /
      DATA B(63109), B(63110), B(63111) /    -7.45,   -9.69,    0.00 /
      DATA B(63256), B(63257), B(63258) /    -7.50,   -9.64,    0.00 /
      DATA B(63403), B(63404), B(63405) /    -7.56,   -9.60,    0.00 /
      DATA B(63550), B(63551), B(63552) /    -7.63,   -9.54,    0.00 /
      DATA B(63697), B(63698), B(63699) /    -7.70,   -9.49,    0.00 /
      DATA B(63844), B(63845), B(63846) /    -7.78,   -9.43,    0.00 /
      DATA B(63991), B(63992), B(63993) /    -7.86,   -9.38,    0.00 /
      DATA B(64138), B(64139), B(64140) /    -7.94,   -9.37,    0.00 /
      DATA B(64285), B(64286), B(64287) /    -8.07,   -9.25,    0.00 /
      DATA B(64432), B(64433), B(64434) /    -8.00,   -9.23,    0.00 /
      DATA B(64579), B(64580), B(64581) /    -8.00,   -9.22,    0.00 /
      DATA B(64726), B(64727), B(64728) /    -7.99,   -9.22,    0.00 /
      DATA B(64873), B(64874), B(64875) /    -7.98,   -9.22,    0.00 /
      DATA B(65020), B(65021), B(65022) /    -7.96,   -9.23,    0.00 /
      DATA B(65167), B(65168), B(65169) /    -7.94,   -9.24,    0.00 /
      DATA B(65314), B(65315), B(65316) /    -7.99,  -10.07,    0.00 /
      DATA B(65461), B(65462), B(65463) /    -8.05,  -10.00,    0.00 /
      DATA B(65608), B(65609), B(65610) /    -8.07,   -9.95,    0.00 /
      DATA B(65755), B(65756), B(65757) /    -8.08,   -9.92,    0.00 /
      DATA B(65902), B(65903), B(65904) /    -8.08,   -9.91,    0.00 /
      DATA B(66049), B(66050), B(66051) /    -8.10,   -9.94,    0.00 /
      DATA B(66196), B(66197), B(66198) /    -8.13,   -9.97,    0.00 /
      DATA B(66343), B(66344), B(66345) /    -8.16,  -10.02,    0.00 /
      DATA B(66490), B(66491), B(66492) /    -8.20,  -10.06,    0.00 /
      DATA B(66637), B(66638), B(66639) /    -8.24,  -10.11,    0.00 /
      DATA B(66784), B(66785), B(66786) /    -8.28,  -10.16,    0.00 /
      DATA B(66931), B(66932), B(66933) /    -8.32,  -10.21,    0.00 /
      DATA B(67078), B(67079), B(67080) /    -8.36,  -10.26,    0.00 /
      DATA B(67225), B(67226), B(67227) /    -8.41,  -10.31,    0.00 /
      DATA B(67372), B(67373), B(67374) /    -8.45,  -10.36,    0.00 /
      DATA B(67519), B(67520), B(67521) /    -8.50,  -10.41,    0.00 /
      DATA B(67666), B(67667), B(67668) /    -8.55,  -10.46,    0.00 /
      DATA B(46501), B(46502), B(46503) /    -5.08,  -22.17,    0.00 /
      DATA B(46648), B(46649), B(46650) /    -5.14,  -22.02,    0.00 /
      DATA B(46795), B(46796), B(46797) /    -5.21,  -21.86,    0.00 /
      DATA B(46942), B(46943), B(46944) /    -5.27,  -21.70,    0.00 /
      DATA B(47089), B(47090), B(47091) /    -5.33,  -21.53,    0.00 /
      DATA B(47236), B(47237), B(47238) /    -5.38,  -21.36,    0.00 /
      DATA B(47383), B(47384), B(47385) /    -5.43,  -21.18,    0.00 /
      DATA B(47530), B(47531), B(47532) /    -5.48,  -21.00,    0.00 /
      DATA B(47677), B(47678), B(47679) /    -5.52,  -20.80,    0.00 /
      DATA B(47824), B(47825), B(47826) /    -5.55,  -20.60,    0.00 /
      DATA B(47971), B(47972), B(47973) /    -5.57,  -20.40,    0.00 /
      DATA B(48118), B(48119), B(48120) /    -5.57,  -20.18,    0.00 /
      DATA B(48265), B(48266), B(48267) /    -5.56,  -19.97,    0.00 /
      DATA B(48412), B(48413), B(48414) /    -5.54,  -19.75,    0.00 /
      DATA B(48559), B(48560), B(48561) /    -5.49,  -19.52,    0.00 /
      DATA B(48706), B(48707), B(48708) /    -5.41,  -19.29,    0.00 /
      DATA B(48853), B(48854), B(48855) /    -5.29,  -19.02,    0.00 /
      DATA B(49000), B(49001), B(49002) /    -4.97,  -18.62,    0.00 /
      DATA B(49147), B(49148), B(49149) /    -4.80,  -18.14,    0.00 /
      DATA B(49294), B(49295), B(49296) /    -4.67,  -17.75,    0.00 /
      DATA B(49441), B(49442), B(49443) /    -4.60,  -17.46,    0.00 /
      DATA B(49588), B(49589), B(49590) /    -4.57,  -17.22,    0.00 /
      DATA B(49735), B(49736), B(49737) /    -4.58,  -17.03,    0.00 /
      DATA B(49882), B(49883), B(49884) /    -4.62,  -16.87,    0.00 /
      DATA B(50029), B(50030), B(50031) /    -4.69,  -16.72,    0.00 /
      DATA B(50176), B(50177), B(50178) /    -4.79,  -16.57,    0.00 /
      DATA B(50323), B(50324), B(50325) /    -4.90,  -16.39,    0.00 /
      DATA B(50470), B(50471), B(50472) /    -5.01,  -16.17,    0.00 /
      DATA B(50617), B(50618), B(50619) /    -5.05,  -15.86,    0.00 /
      DATA B(50764), B(50765), B(50766) /    -5.11,  -15.60,    0.00 /
      DATA B(50911), B(50912), B(50913) /    -5.17,  -15.52,    0.00 /
      DATA B(51058), B(51059), B(51060) /    -5.26,  -15.44,    0.00 /
      DATA B(51205), B(51206), B(51207) /    -5.33,  -15.37,    0.00 /
      DATA B(51352), B(51353), B(51354) /    -5.39,  -15.29,    0.00 /
      DATA B(51499), B(51500), B(51501) /    -5.44,  -15.22,    0.00 /
      DATA B(51646), B(51647), B(51648) /    -5.48,  -15.16,    0.00 /
      DATA B(51793), B(51794), B(51795) /    -5.52,  -15.09,    0.00 /
      DATA B(51940), B(51941), B(51942) /    -5.55,  -15.01,    0.00 /
      DATA B(52087), B(52088), B(52089) /    -5.58,  -14.94,    0.00 /
      DATA B(52234), B(52235), B(52236) /    -5.60,  -14.86,    0.00 /
      DATA B(52381), B(52382), B(52383) /    -5.63,  -14.78,    0.00 /
      DATA B(52528), B(52529), B(52530) /    -5.65,  -14.70,    0.00 /
      DATA B(52675), B(52676), B(52677) /    -5.67,  -14.62,    0.00 /
      DATA B(52822), B(52823), B(52824) /    -5.70,  -14.53,    0.00 /
      DATA B(52969), B(52970), B(52971) /    -5.72,  -14.44,    0.00 /
      DATA B(53116), B(53117), B(53118) /    -5.73,  -14.35,    0.00 /
      DATA B(53263), B(53264), B(53265) /    -5.75,  -14.25,    0.00 /
      DATA B(53410), B(53411), B(53412) /    -5.77,  -14.15,    0.00 /
      DATA B(53557), B(53558), B(53559) /    -5.78,  -14.05,    0.00 /
      DATA B(53704), B(53705), B(53706) /    -5.79,  -13.94,    0.00 /
      DATA B(53851), B(53852), B(53853) /    -5.81,  -13.84,    0.00 /
      DATA B(53998), B(53999), B(54000) /    -5.82,  -13.73,    0.00 /
      DATA B(54145), B(54146), B(54147) /    -5.82,  -13.62,    0.00 /
      DATA B(54292), B(54293), B(54294) /    -5.83,  -13.51,    0.00 /
      DATA B(54439), B(54440), B(54441) /    -5.83,  -13.40,    0.00 /
      DATA B(54586), B(54587), B(54588) /    -5.84,  -13.29,    0.00 /
      DATA B(54733), B(54734), B(54735) /    -5.84,  -13.18,    0.00 /
      DATA B(54880), B(54881), B(54882) /    -5.84,  -13.07,    0.00 /
      DATA B(55027), B(55028), B(55029) /    -5.84,  -12.96,    0.00 /
      DATA B(55174), B(55175), B(55176) /    -5.84,  -12.85,    0.00 /
      DATA B(55321), B(55322), B(55323) /    -5.84,  -12.75,    0.00 /
      DATA B(55468), B(55469), B(55470) /    -5.84,  -12.65,    0.00 /
      DATA B(55615), B(55616), B(55617) /    -5.84,  -12.54,    0.00 /
      DATA B(55762), B(55763), B(55764) /    -5.85,  -12.45,    0.00 /
      DATA B(55909), B(55910), B(55911) /    -5.85,  -12.35,    0.00 /
      DATA B(56056), B(56057), B(56058) /    -5.86,  -12.25,    0.00 /
      DATA B(56203), B(56204), B(56205) /    -5.87,  -12.16,    0.00 /
      DATA B(56350), B(56351), B(56352) /    -5.88,  -12.07,    0.00 /
      DATA B(56497), B(56498), B(56499) /    -5.89,  -11.98,    0.00 /
      DATA B(56644), B(56645), B(56646) /    -5.91,  -11.89,    0.00 /
      DATA B(56791), B(56792), B(56793) /    -5.92,  -11.81,    0.00 /
      DATA B(56938), B(56939), B(56940) /    -5.94,  -11.72,    0.00 /
      DATA B(57085), B(57086), B(57087) /    -5.96,  -11.64,    0.00 /
      DATA B(57232), B(57233), B(57234) /    -5.99,  -11.55,    0.00 /
      DATA B(57379), B(57380), B(57381) /    -6.02,  -11.47,    0.00 /
      DATA B(57526), B(57527), B(57528) /    -6.06,  -11.40,    0.00 /
      DATA B(57673), B(57674), B(57675) /    -6.11,  -11.34,    0.00 /
      DATA B(57820), B(57821), B(57822) /    -6.17,  -11.29,    0.00 /
      DATA B(57967), B(57968), B(57969) /    -6.24,  -11.27,    0.00 /
      DATA B(58114), B(58115), B(58116) /    -6.29,  -11.26,    0.00 /
      DATA B(58261), B(58262), B(58263) /    -6.32,  -11.32,    0.00 /
      DATA B(58408), B(58409), B(58410) /    -6.34,  -11.27,    0.00 /
      DATA B(58555), B(58556), B(58557) /    -6.39,  -11.23,    0.00 /
      DATA B(58702), B(58703), B(58704) /    -6.45,  -11.19,    0.00 /
      DATA B(58849), B(58850), B(58851) /    -6.50,  -11.15,    0.00 /
      DATA B(58996), B(58997), B(58998) /    -6.53,  -11.11,    0.00 /
      DATA B(59143), B(59144), B(59145) /    -6.56,  -11.06,    0.00 /
      DATA B(59290), B(59291), B(59292) /    -6.58,  -11.00,    0.00 /
      DATA B(59437), B(59438), B(59439) /    -6.60,  -10.94,    0.00 /
      DATA B(59584), B(59585), B(59586) /    -6.62,  -10.87,    0.00 /
      DATA B(59731), B(59732), B(59733) /    -6.64,  -10.79,    0.00 /
      DATA B(59878), B(59879), B(59880) /    -6.65,  -10.72,    0.00 /
      DATA B(60025), B(60026), B(60027) /    -6.67,  -10.63,    0.00 /
      DATA B(60172), B(60173), B(60174) /    -6.68,  -10.55,    0.00 /
      DATA B(60319), B(60320), B(60321) /    -6.70,  -10.46,    0.00 /
      DATA B(60466), B(60467), B(60468) /    -6.71,  -10.38,    0.00 /
      DATA B(60613), B(60614), B(60615) /    -6.73,  -10.29,    0.00 /
      DATA B(60760), B(60761), B(60762) /    -6.74,  -10.19,    0.00 /
      DATA B(60907), B(60908), B(60909) /    -6.76,  -10.10,    0.00 /
      DATA B(61054), B(61055), B(61056) /    -6.77,  -10.00,    0.00 /
      DATA B(61201), B(61202), B(61203) /    -6.79,   -9.91,    0.00 /
      DATA B(61348), B(61349), B(61350) /    -6.80,   -9.81,    0.00 /
      DATA B(61495), B(61496), B(61497) /    -6.82,   -9.72,    0.00 /
      DATA B(61642), B(61643), B(61644) /    -6.84,   -9.63,    0.00 /
      DATA B(61789), B(61790), B(61791) /    -6.87,   -9.55,    0.00 /
      DATA B(61936), B(61937), B(61938) /    -6.92,   -9.50,    0.00 /
      DATA B(62083), B(62084), B(62085) /    -6.98,   -9.51,    0.00 /
      DATA B(62230), B(62231), B(62232) /    -7.04,   -9.64,    0.00 /
      DATA B(62377), B(62378), B(62379) /    -7.24,   -9.96,    0.00 /
      DATA B(62524), B(62525), B(62526) /    -7.32,   -9.99,    0.00 /
      DATA B(62671), B(62672), B(62673) /    -7.39,   -9.98,    0.00 /
      DATA B(62818), B(62819), B(62820) /    -7.46,   -9.95,    0.00 /
      DATA B(62965), B(62966), B(62967) /    -7.51,   -9.91,    0.00 /
      DATA B(63112), B(63113), B(63114) /    -7.57,   -9.87,    0.00 /
      DATA B(63259), B(63260), B(63261) /    -7.62,   -9.83,    0.00 /
      DATA B(63406), B(63407), B(63408) /    -7.67,   -9.78,    0.00 /
      DATA B(63553), B(63554), B(63555) /    -7.73,   -9.73,    0.00 /
      DATA B(63700), B(63701), B(63702) /    -7.79,   -9.68,    0.00 /
      DATA B(63847), B(63848), B(63849) /    -7.85,   -9.64,    0.00 /
      DATA B(63994), B(63995), B(63996) /    -7.91,   -9.59,    0.00 /
      DATA B(64141), B(64142), B(64143) /    -7.94,   -9.58,    0.00 /
      DATA B(64288), B(64289), B(64290) /    -8.01,   -9.38,    0.00 /
      DATA B(64435), B(64436), B(64437) /    -8.02,   -9.38,    0.00 /
      DATA B(64582), B(64583), B(64584) /    -8.04,   -9.38,    0.00 /
      DATA B(64729), B(64730), B(64731) /    -8.05,   -9.38,    0.00 /
      DATA B(64876), B(64877), B(64878) /    -8.04,   -9.39,    0.00 /
      DATA B(65023), B(65024), B(65025) /    -8.03,   -9.39,    0.00 /
      DATA B(65170), B(65171), B(65172) /    -8.00,   -9.40,    0.00 /
      DATA B(65317), B(65318), B(65319) /    -8.07,  -10.10,    0.00 /
      DATA B(65464), B(65465), B(65466) /    -8.10,  -10.08,    0.00 /
      DATA B(65611), B(65612), B(65613) /    -8.12,  -10.05,    0.00 /
      DATA B(65758), B(65759), B(65760) /    -8.14,  -10.03,    0.00 /
      DATA B(65905), B(65906), B(65907) /    -8.15,  -10.02,    0.00 /
      DATA B(66052), B(66053), B(66054) /    -8.16,  -10.04,    0.00 /
      DATA B(66199), B(66200), B(66201) /    -8.19,  -10.07,    0.00 /
      DATA B(66346), B(66347), B(66348) /    -8.22,  -10.11,    0.00 /
      DATA B(66493), B(66494), B(66495) /    -8.26,  -10.15,    0.00 /
      DATA B(66640), B(66641), B(66642) /    -8.29,  -10.20,    0.00 /
      DATA B(66787), B(66788), B(66789) /    -8.33,  -10.24,    0.00 /
      DATA B(66934), B(66935), B(66936) /    -8.37,  -10.29,    0.00 /
      DATA B(67081), B(67082), B(67083) /    -8.42,  -10.34,    0.00 /
      DATA B(67228), B(67229), B(67230) /    -8.46,  -10.39,    0.00 /
      DATA B(67375), B(67376), B(67377) /    -8.50,  -10.44,    0.00 /
      DATA B(67522), B(67523), B(67524) /    -8.55,  -10.49,    0.00 /
      DATA B(67669), B(67670), B(67671) /    -8.60,  -10.54,    0.00 /
      DATA B(46504), B(46505), B(46506) /    -5.09,  -22.09,    0.00 /
      DATA B(46651), B(46652), B(46653) /    -5.15,  -21.95,    0.00 /
      DATA B(46798), B(46799), B(46800) /    -5.21,  -21.80,    0.00 /
      DATA B(46945), B(46946), B(46947) /    -5.27,  -21.64,    0.00 /
      DATA B(47092), B(47093), B(47094) /    -5.32,  -21.49,    0.00 /
      DATA B(47239), B(47240), B(47241) /    -5.37,  -21.32,    0.00 /
      DATA B(47386), B(47387), B(47388) /    -5.42,  -21.15,    0.00 /
      DATA B(47533), B(47534), B(47535) /    -5.47,  -20.97,    0.00 /
      DATA B(47680), B(47681), B(47682) /    -5.50,  -20.79,    0.00 /
      DATA B(47827), B(47828), B(47829) /    -5.53,  -20.60,    0.00 /
      DATA B(47974), B(47975), B(47976) /    -5.55,  -20.41,    0.00 /
      DATA B(48121), B(48122), B(48123) /    -5.55,  -20.21,    0.00 /
      DATA B(48268), B(48269), B(48270) /    -5.55,  -20.00,    0.00 /
      DATA B(48415), B(48416), B(48417) /    -5.52,  -19.79,    0.00 /
      DATA B(48562), B(48563), B(48564) /    -5.48,  -19.58,    0.00 /
      DATA B(48709), B(48710), B(48711) /    -5.40,  -19.34,    0.00 /
      DATA B(48856), B(48857), B(48858) /    -5.28,  -19.07,    0.00 /
      DATA B(49003), B(49004), B(49005) /    -4.86,  -18.66,    0.00 /
      DATA B(49150), B(49151), B(49152) /    -4.76,  -18.16,    0.00 /
      DATA B(49297), B(49298), B(49299) /    -4.62,  -17.75,    0.00 /
      DATA B(49444), B(49445), B(49446) /    -4.54,  -17.43,    0.00 /
      DATA B(49591), B(49592), B(49593) /    -4.52,  -17.18,    0.00 /
      DATA B(49738), B(49739), B(49740) /    -4.53,  -16.98,    0.00 /
      DATA B(49885), B(49886), B(49887) /    -4.58,  -16.81,    0.00 /
      DATA B(50032), B(50033), B(50034) /    -4.65,  -16.65,    0.00 /
      DATA B(50179), B(50180), B(50181) /    -4.76,  -16.50,    0.00 /
      DATA B(50326), B(50327), B(50328) /    -4.90,  -16.34,    0.00 /
      DATA B(50473), B(50474), B(50475) /    -5.03,  -16.13,    0.00 /
      DATA B(50620), B(50621), B(50622) /    -5.06,  -15.84,    0.00 /
      DATA B(50767), B(50768), B(50769) /    -5.07,  -15.62,    0.00 /
      DATA B(50914), B(50915), B(50916) /    -5.21,  -15.59,    0.00 /
      DATA B(51061), B(51062), B(51063) /    -5.32,  -15.52,    0.00 /
      DATA B(51208), B(51209), B(51210) /    -5.41,  -15.45,    0.00 /
      DATA B(51355), B(51356), B(51357) /    -5.48,  -15.38,    0.00 /
      DATA B(51502), B(51503), B(51504) /    -5.53,  -15.31,    0.00 /
      DATA B(51649), B(51650), B(51651) /    -5.58,  -15.24,    0.00 /
      DATA B(51796), B(51797), B(51798) /    -5.62,  -15.17,    0.00 /
      DATA B(51943), B(51944), B(51945) /    -5.65,  -15.10,    0.00 /
      DATA B(52090), B(52091), B(52092) /    -5.68,  -15.02,    0.00 /
      DATA B(52237), B(52238), B(52239) /    -5.71,  -14.95,    0.00 /
      DATA B(52384), B(52385), B(52386) /    -5.73,  -14.87,    0.00 /
      DATA B(52531), B(52532), B(52533) /    -5.75,  -14.78,    0.00 /
      DATA B(52678), B(52679), B(52680) /    -5.78,  -14.70,    0.00 /
      DATA B(52825), B(52826), B(52827) /    -5.80,  -14.61,    0.00 /
      DATA B(52972), B(52973), B(52974) /    -5.81,  -14.52,    0.00 /
      DATA B(53119), B(53120), B(53121) /    -5.83,  -14.43,    0.00 /
      DATA B(53266), B(53267), B(53268) /    -5.85,  -14.33,    0.00 /
      DATA B(53413), B(53414), B(53415) /    -5.86,  -14.23,    0.00 /
      DATA B(53560), B(53561), B(53562) /    -5.88,  -14.13,    0.00 /
      DATA B(53707), B(53708), B(53709) /    -5.89,  -14.03,    0.00 /
      DATA B(53854), B(53855), B(53856) /    -5.90,  -13.93,    0.00 /
      DATA B(54001), B(54002), B(54003) /    -5.91,  -13.82,    0.00 /
      DATA B(54148), B(54149), B(54150) /    -5.92,  -13.71,    0.00 /
      DATA B(54295), B(54296), B(54297) /    -5.92,  -13.60,    0.00 /
      DATA B(54442), B(54443), B(54444) /    -5.93,  -13.49,    0.00 /
      DATA B(54589), B(54590), B(54591) /    -5.93,  -13.38,    0.00 /
      DATA B(54736), B(54737), B(54738) /    -5.93,  -13.27,    0.00 /
      DATA B(54883), B(54884), B(54885) /    -5.93,  -13.16,    0.00 /
      DATA B(55030), B(55031), B(55032) /    -5.93,  -13.06,    0.00 /
      DATA B(55177), B(55178), B(55179) /    -5.93,  -12.95,    0.00 /
      DATA B(55324), B(55325), B(55326) /    -5.94,  -12.84,    0.00 /
      DATA B(55471), B(55472), B(55473) /    -5.94,  -12.74,    0.00 /
      DATA B(55618), B(55619), B(55620) /    -5.94,  -12.64,    0.00 /
      DATA B(55765), B(55766), B(55767) /    -5.95,  -12.54,    0.00 /
      DATA B(55912), B(55913), B(55914) /    -5.95,  -12.44,    0.00 /
      DATA B(56059), B(56060), B(56061) /    -5.96,  -12.35,    0.00 /
      DATA B(56206), B(56207), B(56208) /    -5.97,  -12.25,    0.00 /
      DATA B(56353), B(56354), B(56355) /    -5.98,  -12.16,    0.00 /
      DATA B(56500), B(56501), B(56502) /    -6.00,  -12.07,    0.00 /
      DATA B(56647), B(56648), B(56649) /    -6.01,  -11.98,    0.00 /
      DATA B(56794), B(56795), B(56796) /    -6.03,  -11.90,    0.00 /
      DATA B(56941), B(56942), B(56943) /    -6.05,  -11.81,    0.00 /
      DATA B(57088), B(57089), B(57090) /    -6.07,  -11.73,    0.00 /
      DATA B(57235), B(57236), B(57237) /    -6.10,  -11.65,    0.00 /
      DATA B(57382), B(57383), B(57384) /    -6.13,  -11.57,    0.00 /
      DATA B(57529), B(57530), B(57531) /    -6.18,  -11.49,    0.00 /
      DATA B(57676), B(57677), B(57678) /    -6.24,  -11.43,    0.00 /
      DATA B(57823), B(57824), B(57825) /    -6.31,  -11.40,    0.00 /
      DATA B(57970), B(57971), B(57972) /    -6.38,  -11.39,    0.00 /
      DATA B(58117), B(58118), B(58119) /    -6.44,  -11.49,    0.00 /
      DATA B(58264), B(58265), B(58266) /    -6.45,  -11.44,    0.00 /
      DATA B(58411), B(58412), B(58413) /    -6.50,  -11.40,    0.00 /
      DATA B(58558), B(58559), B(58560) /    -6.56,  -11.38,    0.00 /
      DATA B(58705), B(58706), B(58707) /    -6.62,  -11.35,    0.00 /
      DATA B(58852), B(58853), B(58854) /    -6.66,  -11.32,    0.00 /
      DATA B(58999), B(59000), B(59001) /    -6.70,  -11.28,    0.00 /
      DATA B(59146), B(59147), B(59148) /    -6.72,  -11.23,    0.00 /
      DATA B(59293), B(59294), B(59295) /    -6.74,  -11.18,    0.00 /
      DATA B(59440), B(59441), B(59442) /    -6.76,  -11.11,    0.00 /
      DATA B(59587), B(59588), B(59589) /    -6.77,  -11.04,    0.00 /
      DATA B(59734), B(59735), B(59736) /    -6.79,  -10.96,    0.00 /
      DATA B(59881), B(59882), B(59883) /    -6.80,  -10.88,    0.00 /
      DATA B(60028), B(60029), B(60030) /    -6.81,  -10.79,    0.00 /
      DATA B(60175), B(60176), B(60177) /    -6.83,  -10.71,    0.00 /
      DATA B(60322), B(60323), B(60324) /    -6.84,  -10.62,    0.00 /
      DATA B(60469), B(60470), B(60471) /    -6.86,  -10.53,    0.00 /
      DATA B(60616), B(60617), B(60618) /    -6.87,  -10.44,    0.00 /
      DATA B(60763), B(60764), B(60765) /    -6.88,  -10.34,    0.00 /
      DATA B(60910), B(60911), B(60912) /    -6.90,  -10.25,    0.00 /
      DATA B(61057), B(61058), B(61059) /    -6.91,  -10.15,    0.00 /
      DATA B(61204), B(61205), B(61206) /    -6.92,  -10.05,    0.00 /
      DATA B(61351), B(61352), B(61353) /    -6.93,   -9.96,    0.00 /
      DATA B(61498), B(61499), B(61500) /    -6.95,   -9.86,    0.00 /
      DATA B(61645), B(61646), B(61647) /    -6.96,   -9.77,    0.00 /
      DATA B(61792), B(61793), B(61794) /    -6.98,   -9.69,    0.00 /
      DATA B(61939), B(61940), B(61941) /    -7.01,   -9.63,    0.00 /
      DATA B(62086), B(62087), B(62088) /    -7.07,   -9.63,    0.00 /
      DATA B(62233), B(62234), B(62235) /    -7.14,   -9.79,    0.00 /
      DATA B(62380), B(62381), B(62382) /    -7.35,  -10.14,    0.00 /
      DATA B(62527), B(62528), B(62529) /    -7.43,  -10.17,    0.00 /
      DATA B(62674), B(62675), B(62676) /    -7.51,  -10.16,    0.00 /
      DATA B(62821), B(62822), B(62823) /    -7.58,  -10.13,    0.00 /
      DATA B(62968), B(62969), B(62970) /    -7.63,  -10.09,    0.00 /
      DATA B(63115), B(63116), B(63117) /    -7.68,  -10.05,    0.00 /
      DATA B(63262), B(63263), B(63264) /    -7.73,  -10.01,    0.00 /
      DATA B(63409), B(63410), B(63411) /    -7.78,   -9.97,    0.00 /
      DATA B(63556), B(63557), B(63558) /    -7.84,   -9.92,    0.00 /
      DATA B(63703), B(63704), B(63705) /    -7.89,   -9.88,    0.00 /
      DATA B(63850), B(63851), B(63852) /    -7.94,   -9.84,    0.00 /
      DATA B(63997), B(63998), B(63999) /    -8.02,   -9.68,    0.00 /
      DATA B(64144), B(64145), B(64146) /    -8.06,   -9.65,    0.00 /
      DATA B(64291), B(64292), B(64293) /    -8.09,   -9.55,    0.00 /
      DATA B(64438), B(64439), B(64440) /    -8.08,   -9.51,    0.00 /
      DATA B(64585), B(64586), B(64587) /    -8.09,   -9.52,    0.00 /
      DATA B(64732), B(64733), B(64734) /    -8.10,   -9.53,    0.00 /
      DATA B(64879), B(64880), B(64881) /    -8.10,   -9.55,    0.00 /
      DATA B(65026), B(65027), B(65028) /    -8.09,   -9.56,    0.00 /
      DATA B(65173), B(65174), B(65175) /    -8.07,   -9.55,    0.00 /
      DATA B(65320), B(65321), B(65322) /    -8.11,  -10.17,    0.00 /
      DATA B(65467), B(65468), B(65469) /    -8.15,  -10.16,    0.00 /
      DATA B(65614), B(65615), B(65616) /    -8.17,  -10.14,    0.00 /
      DATA B(65761), B(65762), B(65763) /    -8.19,  -10.12,    0.00 /
      DATA B(65908), B(65909), B(65910) /    -8.20,  -10.12,    0.00 /
      DATA B(66055), B(66056), B(66057) /    -8.22,  -10.14,    0.00 /
      DATA B(66202), B(66203), B(66204) /    -8.25,  -10.16,    0.00 /
      DATA B(66349), B(66350), B(66351) /    -8.28,  -10.20,    0.00 /
      DATA B(66496), B(66497), B(66498) /    -8.31,  -10.23,    0.00 /
      DATA B(66643), B(66644), B(66645) /    -8.35,  -10.28,    0.00 /
      DATA B(66790), B(66791), B(66792) /    -8.39,  -10.32,    0.00 /
      DATA B(66937), B(66938), B(66939) /    -8.43,  -10.37,    0.00 /
      DATA B(67084), B(67085), B(67086) /    -8.47,  -10.42,    0.00 /
      DATA B(67231), B(67232), B(67233) /    -8.51,  -10.47,    0.00 /
      DATA B(67378), B(67379), B(67380) /    -8.55,  -10.52,    0.00 /
      DATA B(67525), B(67526), B(67527) /    -8.60,  -10.57,    0.00 /
      DATA B(67672), B(67673), B(67674) /    -8.65,  -10.62,    0.00 /
      DATA B(46507), B(46508), B(46509) /    -5.09,  -22.02,    0.00 /
      DATA B(46654), B(46655), B(46656) /    -5.15,  -21.88,    0.00 /
      DATA B(46801), B(46802), B(46803) /    -5.21,  -21.74,    0.00 /
      DATA B(46948), B(46949), B(46950) /    -5.26,  -21.59,    0.00 /
      DATA B(47095), B(47096), B(47097) /    -5.31,  -21.44,    0.00 /
      DATA B(47242), B(47243), B(47244) /    -5.36,  -21.28,    0.00 /
      DATA B(47389), B(47390), B(47391) /    -5.41,  -21.12,    0.00 /
      DATA B(47536), B(47537), B(47538) /    -5.45,  -20.95,    0.00 /
      DATA B(47683), B(47684), B(47685) /    -5.48,  -20.78,    0.00 /
      DATA B(47830), B(47831), B(47832) /    -5.51,  -20.60,    0.00 /
      DATA B(47977), B(47978), B(47979) /    -5.53,  -20.41,    0.00 /
      DATA B(48124), B(48125), B(48126) /    -5.53,  -20.22,    0.00 /
      DATA B(48271), B(48272), B(48273) /    -5.53,  -20.03,    0.00 /
      DATA B(48418), B(48419), B(48420) /    -5.51,  -19.83,    0.00 /
      DATA B(48565), B(48566), B(48567) /    -5.46,  -19.62,    0.00 /
      DATA B(48712), B(48713), B(48714) /    -5.39,  -19.39,    0.00 /
      DATA B(48859), B(48860), B(48861) /    -5.27,  -19.12,    0.00 /
      DATA B(49006), B(49007), B(49008) /    -4.88,  -18.70,    0.00 /
      DATA B(49153), B(49154), B(49155) /    -4.72,  -18.17,    0.00 /
      DATA B(49300), B(49301), B(49302) /    -4.56,  -17.73,    0.00 /
      DATA B(49447), B(49448), B(49449) /    -4.48,  -17.39,    0.00 /
      DATA B(49594), B(49595), B(49596) /    -4.46,  -17.13,    0.00 /
      DATA B(49741), B(49742), B(49743) /    -4.47,  -16.91,    0.00 /
      DATA B(49888), B(49889), B(49890) /    -4.51,  -16.73,    0.00 /
      DATA B(50035), B(50036), B(50037) /    -4.59,  -16.56,    0.00 /
      DATA B(50182), B(50183), B(50184) /    -4.71,  -16.41,    0.00 /
      DATA B(50329), B(50330), B(50331) /    -4.87,  -16.26,    0.00 /
      DATA B(50476), B(50477), B(50478) /    -5.03,  -16.09,    0.00 /
      DATA B(50623), B(50624), B(50625) /    -5.10,  -15.87,    0.00 /
      DATA B(50770), B(50771), B(50772) /    -5.15,  -15.70,    0.00 /
      DATA B(50917), B(50918), B(50919) /    -5.26,  -15.66,    0.00 /
      DATA B(51064), B(51065), B(51066) /    -5.39,  -15.59,    0.00 /
      DATA B(51211), B(51212), B(51213) /    -5.50,  -15.52,    0.00 /
      DATA B(51358), B(51359), B(51360) /    -5.57,  -15.45,    0.00 /
      DATA B(51505), B(51506), B(51507) /    -5.63,  -15.39,    0.00 /
      DATA B(51652), B(51653), B(51654) /    -5.68,  -15.32,    0.00 /
      DATA B(51799), B(51800), B(51801) /    -5.72,  -15.25,    0.00 /
      DATA B(51946), B(51947), B(51948) /    -5.75,  -15.18,    0.00 /
      DATA B(52093), B(52094), B(52095) /    -6.00,  -15.06,    0.00 /
      DATA B(52240), B(52241), B(52242) /    -6.04,  -14.99,    0.00 /
      DATA B(52387), B(52388), B(52389) /    -6.07,  -14.91,    0.00 /
      DATA B(52534), B(52535), B(52536) /    -5.86,  -14.87,    0.00 /
      DATA B(52681), B(52682), B(52683) /    -5.88,  -14.78,    0.00 /
      DATA B(52828), B(52829), B(52830) /    -5.90,  -14.69,    0.00 /
      DATA B(52975), B(52976), B(52977) /    -5.91,  -14.60,    0.00 /
      DATA B(53122), B(53123), B(53124) /    -5.93,  -14.51,    0.00 /
      DATA B(53269), B(53270), B(53271) /    -5.95,  -14.42,    0.00 /
      DATA B(53416), B(53417), B(53418) /    -5.96,  -14.32,    0.00 /
      DATA B(53563), B(53564), B(53565) /    -5.97,  -14.22,    0.00 /
      DATA B(53710), B(53711), B(53712) /    -5.99,  -14.12,    0.00 /
      DATA B(53857), B(53858), B(53859) /    -6.00,  -14.01,    0.00 /
      DATA B(54004), B(54005), B(54006) /    -6.00,  -13.91,    0.00 /
      DATA B(54151), B(54152), B(54153) /    -6.01,  -13.80,    0.00 /
      DATA B(54298), B(54299), B(54300) /    -6.02,  -13.69,    0.00 /
      DATA B(54445), B(54446), B(54447) /    -6.02,  -13.58,    0.00 /
      DATA B(54592), B(54593), B(54594) /    -6.02,  -13.48,    0.00 /
      DATA B(54739), B(54740), B(54741) /    -6.03,  -13.37,    0.00 /
      DATA B(54886), B(54887), B(54888) /    -6.03,  -13.26,    0.00 /
      DATA B(55033), B(55034), B(55035) /    -6.03,  -13.15,    0.00 /
      DATA B(55180), B(55181), B(55182) /    -6.03,  -13.04,    0.00 /
      DATA B(55327), B(55328), B(55329) /    -6.03,  -12.94,    0.00 /
      DATA B(55474), B(55475), B(55476) /    -6.03,  -12.83,    0.00 /
      DATA B(55621), B(55622), B(55623) /    -6.04,  -12.73,    0.00 /
      DATA B(55768), B(55769), B(55770) /    -6.04,  -12.63,    0.00 /
      DATA B(55915), B(55916), B(55917) /    -6.05,  -12.53,    0.00 /
      DATA B(56062), B(56063), B(56064) /    -6.06,  -12.43,    0.00 /
      DATA B(56209), B(56210), B(56211) /    -6.07,  -12.34,    0.00 /
      DATA B(56356), B(56357), B(56358) /    -6.08,  -12.25,    0.00 /
      DATA B(56503), B(56504), B(56505) /    -6.10,  -12.16,    0.00 /
      DATA B(56650), B(56651), B(56652) /    -6.11,  -12.07,    0.00 /
      DATA B(56797), B(56798), B(56799) /    -6.13,  -11.99,    0.00 /
      DATA B(56944), B(56945), B(56946) /    -6.15,  -11.90,    0.00 /
      DATA B(57091), B(57092), B(57093) /    -6.18,  -11.82,    0.00 /
      DATA B(57238), B(57239), B(57240) /    -6.21,  -11.74,    0.00 /
      DATA B(57385), B(57386), B(57387) /    -6.25,  -11.66,    0.00 /
      DATA B(57532), B(57533), B(57534) /    -6.30,  -11.59,    0.00 /
      DATA B(57679), B(57680), B(57681) /    -6.38,  -11.53,    0.00 /
      DATA B(57826), B(57827), B(57828) /    -6.46,  -11.50,    0.00 /
      DATA B(57973), B(57974), B(57975) /    -6.55,  -11.64,    0.00 /
      DATA B(58120), B(58121), B(58122) /    -6.55,  -11.60,    0.00 /
      DATA B(58267), B(58268), B(58269) /    -6.60,  -11.56,    0.00 /
      DATA B(58414), B(58415), B(58416) /    -6.66,  -11.54,    0.00 /
      DATA B(58561), B(58562), B(58563) /    -6.73,  -11.52,    0.00 /
      DATA B(58708), B(58709), B(58710) /    -6.79,  -11.51,    0.00 /
      DATA B(58855), B(58856), B(58857) /    -6.83,  -11.49,    0.00 /
      DATA B(59002), B(59003), B(59004) /    -6.86,  -11.45,    0.00 /
      DATA B(59149), B(59150), B(59151) /    -6.88,  -11.41,    0.00 /
      DATA B(59296), B(59297), B(59298) /    -6.90,  -11.35,    0.00 /
      DATA B(59443), B(59444), B(59445) /    -6.91,  -11.28,    0.00 /
      DATA B(59590), B(59591), B(59592) /    -6.92,  -11.20,    0.00 /
      DATA B(59737), B(59738), B(59739) /    -6.93,  -11.12,    0.00 /
      DATA B(59884), B(59885), B(59886) /    -6.95,  -11.04,    0.00 /
      DATA B(60031), B(60032), B(60033) /    -6.96,  -10.95,    0.00 /
      DATA B(60178), B(60179), B(60180) /    -6.97,  -10.86,    0.00 /
      DATA B(60325), B(60326), B(60327) /    -6.98,  -10.77,    0.00 /
      DATA B(60472), B(60473), B(60474) /    -7.00,  -10.68,    0.00 /
      DATA B(60619), B(60620), B(60621) /    -7.01,  -10.58,    0.00 /
      DATA B(60766), B(60767), B(60768) /    -7.02,  -10.49,    0.00 /
      DATA B(60913), B(60914), B(60915) /    -7.03,  -10.39,    0.00 /
      DATA B(61060), B(61061), B(61062) /    -7.04,  -10.30,    0.00 /
      DATA B(61207), B(61208), B(61209) /    -7.05,  -10.20,    0.00 /
      DATA B(61354), B(61355), B(61356) /    -7.06,  -10.10,    0.00 /
      DATA B(61501), B(61502), B(61503) /    -7.07,  -10.01,    0.00 /
      DATA B(61648), B(61649), B(61650) /    -7.08,   -9.92,    0.00 /
      DATA B(61795), B(61796), B(61797) /    -7.09,   -9.83,    0.00 /
      DATA B(61942), B(61943), B(61944) /    -7.10,   -9.76,    0.00 /
      DATA B(62089), B(62090), B(62091) /    -7.13,   -9.73,    0.00 /
      DATA B(62236), B(62237), B(62238) /    -7.24,   -9.89,    0.00 /
      DATA B(62383), B(62384), B(62385) /    -7.45,  -10.34,    0.00 /
      DATA B(62530), B(62531), B(62532) /    -7.56,  -10.35,    0.00 /
      DATA B(62677), B(62678), B(62679) /    -7.64,  -10.33,    0.00 /
      DATA B(62824), B(62825), B(62826) /    -7.70,  -10.30,    0.00 /
      DATA B(62971), B(62972), B(62973) /    -7.75,  -10.27,    0.00 /
      DATA B(63118), B(63119), B(63120) /    -7.80,  -10.23,    0.00 /
      DATA B(63265), B(63266), B(63267) /    -7.85,  -10.19,    0.00 /
      DATA B(63412), B(63413), B(63414) /    -7.90,  -10.15,    0.00 /
      DATA B(63559), B(63560), B(63561) /    -7.94,  -10.12,    0.00 /
      DATA B(63706), B(63707), B(63708) /    -8.00,  -10.09,    0.00 /
      DATA B(63853), B(63854), B(63855) /    -8.02,   -9.82,    0.00 /
      DATA B(64000), B(64001), B(64002) /    -8.07,   -9.77,    0.00 /
      DATA B(64147), B(64148), B(64149) /    -8.13,   -9.73,    0.00 /
      DATA B(64294), B(64295), B(64296) /    -8.18,   -9.67,    0.00 /
      DATA B(64441), B(64442), B(64443) /    -8.15,   -9.65,    0.00 /
      DATA B(64588), B(64589), B(64590) /    -8.15,   -9.66,    0.00 /
      DATA B(64735), B(64736), B(64737) /    -8.16,   -9.68,    0.00 /
      DATA B(64882), B(64883), B(64884) /    -8.16,   -9.71,    0.00 /
      DATA B(65029), B(65030), B(65031) /    -8.14,   -9.71,    0.00 /
      DATA B(65176), B(65177), B(65178) /    -8.11,  -10.30,    0.00 /
      DATA B(65323), B(65324), B(65325) /    -8.17,  -10.24,    0.00 /
      DATA B(65470), B(65471), B(65472) /    -8.19,  -10.23,    0.00 /
      DATA B(65617), B(65618), B(65619) /    -8.22,  -10.22,    0.00 /
      DATA B(65764), B(65765), B(65766) /    -8.24,  -10.21,    0.00 /
      DATA B(65911), B(65912), B(65913) /    -8.26,  -10.21,    0.00 /
      DATA B(66058), B(66059), B(66060) /    -8.28,  -10.23,    0.00 /
      DATA B(66205), B(66206), B(66207) /    -8.30,  -10.25,    0.00 /
      DATA B(66352), B(66353), B(66354) /    -8.33,  -10.28,    0.00 /
      DATA B(66499), B(66500), B(66501) /    -8.36,  -10.32,    0.00 /
      DATA B(66646), B(66647), B(66648) /    -8.40,  -10.36,    0.00 /
      DATA B(66793), B(66794), B(66795) /    -8.44,  -10.40,    0.00 /
      DATA B(66940), B(66941), B(66942) /    -8.48,  -10.45,    0.00 /
      DATA B(67087), B(67088), B(67089) /    -8.52,  -10.50,    0.00 /
      DATA B(67234), B(67235), B(67236) /    -8.56,  -10.55,    0.00 /
      DATA B(67381), B(67382), B(67383) /    -8.60,  -10.60,    0.00 /
      DATA B(67528), B(67529), B(67530) /    -8.65,  -10.65,    0.00 /
      DATA B(67675), B(67676), B(67677) /    -8.70,  -10.70,    0.00 /
      DATA B(46510), B(46511), B(46512) /    -5.09,  -21.95,    0.00 /
      DATA B(46657), B(46658), B(46659) /    -5.14,  -21.82,    0.00 /
      DATA B(46804), B(46805), B(46806) /    -5.20,  -21.68,    0.00 /
      DATA B(46951), B(46952), B(46953) /    -5.25,  -21.54,    0.00 /
      DATA B(47098), B(47099), B(47100) /    -5.30,  -21.39,    0.00 /
      DATA B(47245), B(47246), B(47247) /    -5.35,  -21.24,    0.00 /
      DATA B(47392), B(47393), B(47394) /    -5.39,  -21.09,    0.00 /
      DATA B(47539), B(47540), B(47541) /    -5.43,  -20.93,    0.00 /
      DATA B(47686), B(47687), B(47688) /    -5.46,  -20.76,    0.00 /
      DATA B(47833), B(47834), B(47835) /    -5.49,  -20.59,    0.00 /
      DATA B(47980), B(47981), B(47982) /    -5.51,  -20.41,    0.00 /
      DATA B(48127), B(48128), B(48129) /    -5.51,  -20.23,    0.00 /
      DATA B(48274), B(48275), B(48276) /    -5.51,  -20.04,    0.00 /
      DATA B(48421), B(48422), B(48423) /    -5.49,  -19.85,    0.00 /
      DATA B(48568), B(48569), B(48570) /    -5.45,  -19.64,    0.00 /
      DATA B(48715), B(48716), B(48717) /    -5.38,  -19.41,    0.00 /
      DATA B(48862), B(48863), B(48864) /    -5.25,  -19.14,    0.00 /
      DATA B(49009), B(49010), B(49011) /    -4.76,  -18.64,    0.00 /
      DATA B(49156), B(49157), B(49158) /    -4.67,  -18.16,    0.00 /
      DATA B(49303), B(49304), B(49305) /    -4.50,  -17.69,    0.00 /
      DATA B(49450), B(49451), B(49452) /    -4.41,  -17.33,    0.00 /
      DATA B(49597), B(49598), B(49599) /    -4.38,  -17.06,    0.00 /
      DATA B(49744), B(49745), B(49746) /    -4.39,  -16.83,    0.00 /
      DATA B(49891), B(49892), B(49893) /    -4.44,  -16.64,    0.00 /
      DATA B(50038), B(50039), B(50040) /    -4.52,  -16.47,    0.00 /
      DATA B(50185), B(50186), B(50187) /    -4.64,  -16.31,    0.00 /
      DATA B(50332), B(50333), B(50334) /    -4.82,  -16.16,    0.00 /
      DATA B(50479), B(50480), B(50481) /    -5.00,  -16.01,    0.00 /
      DATA B(50626), B(50627), B(50628) /    -5.08,  -15.84,    0.00 /
      DATA B(50773), B(50774), B(50775) /    -5.12,  -15.72,    0.00 /
      DATA B(50920), B(50921), B(50922) /    -5.31,  -15.72,    0.00 /
      DATA B(51067), B(51068), B(51069) /    -5.47,  -15.66,    0.00 /
      DATA B(51214), B(51215), B(51216) /    -5.59,  -15.59,    0.00 /
      DATA B(51361), B(51362), B(51363) /    -5.68,  -15.53,    0.00 /
      DATA B(51508), B(51509), B(51510) /    -5.74,  -15.46,    0.00 /
      DATA B(51655), B(51656), B(51657) /    -5.79,  -15.40,    0.00 /
      DATA B(51802), B(51803), B(51804) /    -5.93,  -15.23,    0.00 /
      DATA B(51949), B(51950), B(51951) /    -5.98,  -15.16,    0.00 /
      DATA B(52096), B(52097), B(52098) /    -6.02,  -15.09,    0.00 /
      DATA B(52243), B(52244), B(52245) /    -6.06,  -15.02,    0.00 /
      DATA B(52390), B(52391), B(52392) /    -6.09,  -14.94,    0.00 /
      DATA B(52537), B(52538), B(52539) /    -6.13,  -14.86,    0.00 /
      DATA B(52684), B(52685), B(52686) /    -6.16,  -14.78,    0.00 /
      DATA B(52831), B(52832), B(52833) /    -6.19,  -14.70,    0.00 /
      DATA B(52978), B(52979), B(52980) /    -6.01,  -14.68,    0.00 /
      DATA B(53125), B(53126), B(53127) /    -6.03,  -14.59,    0.00 /
      DATA B(53272), B(53273), B(53274) /    -6.04,  -14.50,    0.00 /
      DATA B(53419), B(53420), B(53421) /    -6.06,  -14.40,    0.00 /
      DATA B(53566), B(53567), B(53568) /    -6.07,  -14.30,    0.00 /
      DATA B(53713), B(53714), B(53715) /    -6.08,  -14.20,    0.00 /
      DATA B(53860), B(53861), B(53862) /    -6.09,  -14.10,    0.00 /
      DATA B(54007), B(54008), B(54009) /    -6.10,  -13.99,    0.00 /
      DATA B(54154), B(54155), B(54156) /    -6.11,  -13.89,    0.00 /
      DATA B(54301), B(54302), B(54303) /    -6.11,  -13.78,    0.00 /
      DATA B(54448), B(54449), B(54450) /    -6.12,  -13.68,    0.00 /
      DATA B(54595), B(54596), B(54597) /    -6.12,  -13.57,    0.00 /
      DATA B(54742), B(54743), B(54744) /    -6.12,  -13.46,    0.00 /
      DATA B(54889), B(54890), B(54891) /    -6.12,  -13.35,    0.00 /
      DATA B(55036), B(55037), B(55038) /    -6.12,  -13.24,    0.00 /
      DATA B(55183), B(55184), B(55185) /    -6.12,  -13.14,    0.00 /
      DATA B(55330), B(55331), B(55332) /    -6.12,  -13.03,    0.00 /
      DATA B(55477), B(55478), B(55479) /    -6.13,  -12.92,    0.00 /
      DATA B(55624), B(55625), B(55626) /    -6.13,  -12.82,    0.00 /
      DATA B(55771), B(55772), B(55773) /    -6.14,  -12.71,    0.00 /
      DATA B(55918), B(55919), B(55920) /    -6.15,  -12.61,    0.00 /
      DATA B(56065), B(56066), B(56067) /    -6.16,  -12.52,    0.00 /
      DATA B(56212), B(56213), B(56214) /    -6.17,  -12.42,    0.00 /
      DATA B(56359), B(56360), B(56361) /    -6.18,  -12.33,    0.00 /
      DATA B(56506), B(56507), B(56508) /    -6.20,  -12.24,    0.00 /
      DATA B(56653), B(56654), B(56655) /    -6.21,  -12.16,    0.00 /
      DATA B(56800), B(56801), B(56802) /    -6.23,  -12.07,    0.00 /
      DATA B(56947), B(56948), B(56949) /    -6.26,  -11.99,    0.00 /
      DATA B(57094), B(57095), B(57096) /    -6.29,  -11.91,    0.00 /
      DATA B(57241), B(57242), B(57243) /    -6.32,  -11.83,    0.00 /
      DATA B(57388), B(57389), B(57390) /    -6.37,  -11.75,    0.00 /
      DATA B(57535), B(57536), B(57537) /    -6.43,  -11.67,    0.00 /
      DATA B(57682), B(57683), B(57684) /    -6.52,  -11.62,    0.00 /
      DATA B(57829), B(57830), B(57831) /    -6.60,  -11.60,    0.00 /
      DATA B(57976), B(57977), B(57978) /    -6.66,  -11.74,    0.00 /
      DATA B(58123), B(58124), B(58125) /    -6.70,  -11.70,    0.00 /
      DATA B(58270), B(58271), B(58272) /    -6.76,  -11.68,    0.00 /
      DATA B(58417), B(58418), B(58419) /    -6.84,  -11.66,    0.00 /
      DATA B(58564), B(58565), B(58566) /    -6.90,  -11.66,    0.00 /
      DATA B(58711), B(58712), B(58713) /    -6.96,  -11.65,    0.00 /
      DATA B(58858), B(58859), B(58860) /    -7.00,  -11.64,    0.00 /
      DATA B(59005), B(59006), B(59007) /    -7.02,  -11.62,    0.00 /
      DATA B(59152), B(59153), B(59154) /    -7.03,  -11.57,    0.00 /
      DATA B(59299), B(59300), B(59301) /    -7.05,  -11.51,    0.00 /
      DATA B(59446), B(59447), B(59448) /    -7.06,  -11.44,    0.00 /
      DATA B(59593), B(59594), B(59595) /    -7.07,  -11.36,    0.00 /
      DATA B(59740), B(59741), B(59742) /    -7.08,  -11.28,    0.00 /
      DATA B(59887), B(59888), B(59889) /    -7.09,  -11.19,    0.00 /
      DATA B(60034), B(60035), B(60036) /    -7.10,  -11.10,    0.00 /
      DATA B(60181), B(60182), B(60183) /    -7.11,  -11.01,    0.00 /
      DATA B(60328), B(60329), B(60330) /    -7.13,  -10.92,    0.00 /
      DATA B(60475), B(60476), B(60477) /    -7.14,  -10.83,    0.00 /
      DATA B(60622), B(60623), B(60624) /    -7.15,  -10.73,    0.00 /
      DATA B(60769), B(60770), B(60771) /    -7.16,  -10.63,    0.00 /
      DATA B(60916), B(60917), B(60918) /    -7.17,  -10.54,    0.00 /
      DATA B(61063), B(61064), B(61065) /    -7.18,  -10.44,    0.00 /
      DATA B(61210), B(61211), B(61212) /    -7.18,  -10.34,    0.00 /
      DATA B(61357), B(61358), B(61359) /    -7.58,  -10.54,    0.00 /
      DATA B(61504), B(61505), B(61506) /    -7.61,  -10.51,    0.00 /
      DATA B(61651), B(61652), B(61653) /    -7.64,  -10.49,    0.00 /
      DATA B(61798), B(61799), B(61800) /    -7.66,  -10.47,    0.00 /
      DATA B(61945), B(61946), B(61947) /    -7.68,  -10.45,    0.00 /
      DATA B(62092), B(62093), B(62094) /    -7.68,  -10.47,    0.00 /
      DATA B(62239), B(62240), B(62241) /    -7.62,  -10.53,    0.00 /
      DATA B(62386), B(62387), B(62388) /    -7.61,  -10.53,    0.00 /
      DATA B(62533), B(62534), B(62535) /    -7.70,  -10.52,    0.00 /
      DATA B(62680), B(62681), B(62682) /    -7.76,  -10.50,    0.00 /
      DATA B(62827), B(62828), B(62829) /    -7.82,  -10.47,    0.00 /
      DATA B(62974), B(62975), B(62976) /    -7.87,  -10.44,    0.00 /
      DATA B(63121), B(63122), B(63123) /    -7.92,  -10.41,    0.00 /
      DATA B(63268), B(63269), B(63270) /    -7.97,  -10.38,    0.00 /
      DATA B(63415), B(63416), B(63417) /    -8.01,  -10.34,    0.00 /
      DATA B(63562), B(63563), B(63564) /    -7.98,  -10.00,    0.00 /
      DATA B(63709), B(63710), B(63711) /    -8.02,   -9.95,    0.00 /
      DATA B(63856), B(63857), B(63858) /    -8.07,   -9.91,    0.00 /
      DATA B(64003), B(64004), B(64005) /    -8.12,   -9.86,    0.00 /
      DATA B(64150), B(64151), B(64152) /    -8.18,   -9.82,    0.00 /
      DATA B(64297), B(64298), B(64299) /    -8.20,   -9.79,    0.00 /
      DATA B(64444), B(64445), B(64446) /    -8.19,   -9.78,    0.00 /
      DATA B(64591), B(64592), B(64593) /    -8.20,   -9.80,    0.00 /
      DATA B(64738), B(64739), B(64740) /    -8.21,   -9.83,    0.00 /
      DATA B(64885), B(64886), B(64887) /    -8.21,   -9.87,    0.00 /
      DATA B(65032), B(65033), B(65034) /    -8.19,   -9.87,    0.00 /
      DATA B(65179), B(65180), B(65181) /    -8.18,  -10.32,    0.00 /
      DATA B(65326), B(65327), B(65328) /    -8.21,  -10.31,    0.00 /
      DATA B(65473), B(65474), B(65475) /    -8.24,  -10.31,    0.00 /
      DATA B(65620), B(65621), B(65622) /    -8.26,  -10.30,    0.00 /
      DATA B(65767), B(65768), B(65769) /    -8.28,  -10.30,    0.00 /
      DATA B(65914), B(65915), B(65916) /    -8.30,  -10.30,    0.00 /
      DATA B(66061), B(66062), B(66063) /    -8.33,  -10.31,    0.00 /
      DATA B(66208), B(66209), B(66210) /    -8.35,  -10.33,    0.00 /
      DATA B(66355), B(66356), B(66357) /    -8.38,  -10.36,    0.00 /
      DATA B(66502), B(66503), B(66504) /    -8.42,  -10.40,    0.00 /
      DATA B(66649), B(66650), B(66651) /    -8.45,  -10.44,    0.00 /
      DATA B(66796), B(66797), B(66798) /    -8.49,  -10.48,    0.00 /
      DATA B(66943), B(66944), B(66945) /    -8.53,  -10.53,    0.00 /
      DATA B(67090), B(67091), B(67092) /    -8.57,  -10.58,    0.00 /
      DATA B(67237), B(67238), B(67239) /    -8.61,  -10.63,    0.00 /
      DATA B(67384), B(67385), B(67386) /    -8.65,  -10.68,    0.00 /
      DATA B(67531), B(67532), B(67533) /    -8.70,  -10.73,    0.00 /
      DATA B(67678), B(67679), B(67680) /    -8.75,  -10.78,    0.00 /
      DATA B(46513), B(46514), B(46515) /    -5.08,  -21.89,    0.00 /
      DATA B(46660), B(46661), B(46662) /    -5.13,  -21.76,    0.00 /
      DATA B(46807), B(46808), B(46809) /    -5.19,  -21.63,    0.00 /
      DATA B(46954), B(46955), B(46956) /    -5.24,  -21.49,    0.00 /
      DATA B(47101), B(47102), B(47103) /    -5.29,  -21.35,    0.00 /
      DATA B(47248), B(47249), B(47250) /    -5.33,  -21.20,    0.00 /
      DATA B(47395), B(47396), B(47397) /    -5.37,  -21.05,    0.00 /
      DATA B(47542), B(47543), B(47544) /    -5.41,  -20.90,    0.00 /
      DATA B(47689), B(47690), B(47691) /    -5.44,  -20.74,    0.00 /
      DATA B(47836), B(47837), B(47838) /    -5.47,  -20.57,    0.00 /
      DATA B(47983), B(47984), B(47985) /    -5.48,  -20.41,    0.00 /
      DATA B(48130), B(48131), B(48132) /    -5.49,  -20.23,    0.00 /
      DATA B(48277), B(48278), B(48279) /    -5.49,  -20.05,    0.00 /
      DATA B(48424), B(48425), B(48426) /    -5.47,  -19.86,    0.00 /
      DATA B(48571), B(48572), B(48573) /    -5.43,  -19.66,    0.00 /
      DATA B(48718), B(48719), B(48720) /    -5.36,  -19.43,    0.00 /
      DATA B(48865), B(48866), B(48867) /    -5.24,  -19.16,    0.00 /
      DATA B(49012), B(49013), B(49014) /    -5.09,  -18.80,    0.00 /
      DATA B(49159), B(49160), B(49161) /    -4.63,  -18.14,    0.00 /
      DATA B(49306), B(49307), B(49308) /    -4.44,  -17.64,    0.00 /
      DATA B(49453), B(49454), B(49455) /    -4.34,  -17.26,    0.00 /
      DATA B(49600), B(49601), B(49602) /    -4.30,  -16.97,    0.00 /
      DATA B(49747), B(49748), B(49749) /    -4.31,  -16.74,    0.00 /
      DATA B(49894), B(49895), B(49896) /    -4.34,  -16.54,    0.00 /
      DATA B(50041), B(50042), B(50043) /    -4.41,  -16.36,    0.00 /
      DATA B(50188), B(50189), B(50190) /    -4.53,  -16.19,    0.00 /
      DATA B(50335), B(50336), B(50337) /    -4.71,  -16.03,    0.00 /
      DATA B(50482), B(50483), B(50484) /    -4.92,  -15.90,    0.00 /
      DATA B(50629), B(50630), B(50631) /    -5.08,  -15.83,    0.00 /
      DATA B(50776), B(50777), B(50778) /    -5.18,  -15.81,    0.00 /
      DATA B(50923), B(50924), B(50925) /    -5.38,  -15.77,    0.00 /
      DATA B(51070), B(51071), B(51072) /    -5.57,  -15.71,    0.00 /
      DATA B(51217), B(51218), B(51219) /    -5.70,  -15.66,    0.00 /
      DATA B(51364), B(51365), B(51366) /    -5.79,  -15.60,    0.00 /
      DATA B(51511), B(51512), B(51513) /    -5.84,  -15.39,    0.00 /
      DATA B(51658), B(51659), B(51660) /    -5.90,  -15.33,    0.00 /
      DATA B(51805), B(51806), B(51807) /    -5.95,  -15.26,    0.00 /
      DATA B(51952), B(51953), B(51954) /    -6.00,  -15.20,    0.00 /
      DATA B(52099), B(52100), B(52101) /    -6.04,  -15.13,    0.00 /
      DATA B(52246), B(52247), B(52248) /    -6.08,  -15.05,    0.00 /
      DATA B(52393), B(52394), B(52395) /    -6.11,  -14.98,    0.00 /
      DATA B(52540), B(52541), B(52542) /    -6.15,  -14.90,    0.00 /
      DATA B(52687), B(52688), B(52689) /    -6.18,  -14.82,    0.00 /
      DATA B(52834), B(52835), B(52836) /    -6.21,  -14.73,    0.00 /
      DATA B(52981), B(52982), B(52983) /    -6.24,  -14.64,    0.00 /
      DATA B(53128), B(53129), B(53130) /    -6.27,  -14.56,    0.00 /
      DATA B(53275), B(53276), B(53277) /    -6.30,  -14.46,    0.00 /
      DATA B(53422), B(53423), B(53424) /    -6.33,  -14.37,    0.00 /
      DATA B(53569), B(53570), B(53571) /    -6.17,  -14.38,    0.00 /
      DATA B(53716), B(53717), B(53718) /    -6.18,  -14.28,    0.00 /
      DATA B(53863), B(53864), B(53865) /    -6.19,  -14.18,    0.00 /
      DATA B(54010), B(54011), B(54012) /    -6.19,  -14.08,    0.00 /
      DATA B(54157), B(54158), B(54159) /    -6.20,  -13.98,    0.00 /
      DATA B(54304), B(54305), B(54306) /    -6.21,  -13.87,    0.00 /
      DATA B(54451), B(54452), B(54453) /    -6.21,  -13.76,    0.00 /
      DATA B(54598), B(54599), B(54600) /    -6.21,  -13.66,    0.00 /
      DATA B(54745), B(54746), B(54747) /    -6.21,  -13.55,    0.00 /
      DATA B(54892), B(54893), B(54894) /    -6.22,  -13.44,    0.00 /
      DATA B(55039), B(55040), B(55041) /    -6.22,  -13.33,    0.00 /
      DATA B(55186), B(55187), B(55188) /    -6.22,  -13.22,    0.00 /
      DATA B(55333), B(55334), B(55335) /    -6.22,  -13.11,    0.00 /
      DATA B(55480), B(55481), B(55482) /    -6.22,  -13.01,    0.00 /
      DATA B(55627), B(55628), B(55629) /    -6.22,  -12.90,    0.00 /
      DATA B(55774), B(55775), B(55776) /    -6.23,  -12.80,    0.00 /
      DATA B(55921), B(55922), B(55923) /    -6.24,  -12.69,    0.00 /
      DATA B(56068), B(56069), B(56070) /    -6.25,  -12.60,    0.00 /
      DATA B(56215), B(56216), B(56217) /    -6.26,  -12.50,    0.00 /
      DATA B(56362), B(56363), B(56364) /    -6.28,  -12.41,    0.00 /
      DATA B(56509), B(56510), B(56511) /    -6.29,  -12.32,    0.00 /
      DATA B(56656), B(56657), B(56658) /    -6.31,  -12.24,    0.00 /
      DATA B(56803), B(56804), B(56805) /    -6.34,  -12.15,    0.00 /
      DATA B(56950), B(56951), B(56952) /    -6.36,  -12.07,    0.00 /
      DATA B(57097), B(57098), B(57099) /    -6.40,  -11.99,    0.00 /
      DATA B(57244), B(57245), B(57246) /    -6.44,  -11.92,    0.00 /
      DATA B(57391), B(57392), B(57393) /    -6.49,  -11.84,    0.00 /
      DATA B(57538), B(57539), B(57540) /    -6.56,  -11.75,    0.00 /
      DATA B(57685), B(57686), B(57687) /    -6.67,  -11.70,    0.00 /
      DATA B(57832), B(57833), B(57834) /    -6.77,  -11.87,    0.00 /
      DATA B(57979), B(57980), B(57981) /    -6.79,  -11.83,    0.00 /
      DATA B(58126), B(58127), B(58128) /    -6.86,  -11.80,    0.00 /
      DATA B(58273), B(58274), B(58275) /    -6.93,  -11.78,    0.00 /
      DATA B(58420), B(58421), B(58422) /    -7.01,  -11.78,    0.00 /
      DATA B(58567), B(58568), B(58569) /    -7.07,  -11.78,    0.00 /
      DATA B(58714), B(58715), B(58716) /    -7.12,  -11.79,    0.00 /
      DATA B(58861), B(58862), B(58863) /    -7.16,  -11.79,    0.00 /
      DATA B(59008), B(59009), B(59010) /    -7.17,  -11.77,    0.00 /
      DATA B(59155), B(59156), B(59157) /    -7.18,  -11.74,    0.00 /
      DATA B(59302), B(59303), B(59304) /    -7.19,  -11.68,    0.00 /
      DATA B(59449), B(59450), B(59451) /    -7.20,  -11.60,    0.00 /
      DATA B(59596), B(59597), B(59598) /    -7.21,  -11.52,    0.00 /
      DATA B(59743), B(59744), B(59745) /    -7.22,  -11.43,    0.00 /
      DATA B(59890), B(59891), B(59892) /    -7.23,  -11.34,    0.00 /
      DATA B(60037), B(60038), B(60039) /    -7.24,  -11.25,    0.00 /
      DATA B(60184), B(60185), B(60186) /    -7.26,  -11.16,    0.00 /
      DATA B(60331), B(60332), B(60333) /    -7.27,  -11.07,    0.00 /
      DATA B(60478), B(60479), B(60480) /    -7.28,  -10.97,    0.00 /
      DATA B(60625), B(60626), B(60627) /    -7.29,  -10.87,    0.00 /
      DATA B(60772), B(60773), B(60774) /    -7.29,  -10.78,    0.00 /
      DATA B(60919), B(60920), B(60921) /    -7.54,  -10.70,    0.00 /
      DATA B(61066), B(61067), B(61068) /    -7.56,  -10.67,    0.00 /
      DATA B(61213), B(61214), B(61215) /    -7.59,  -10.64,    0.00 /
      DATA B(61360), B(61361), B(61362) /    -7.62,  -10.61,    0.00 /
      DATA B(61507), B(61508), B(61509) /    -7.65,  -10.58,    0.00 /
      DATA B(61654), B(61655), B(61656) /    -7.67,  -10.55,    0.00 /
      DATA B(61801), B(61802), B(61803) /    -7.69,  -10.53,    0.00 /
      DATA B(61948), B(61949), B(61950) /    -7.70,  -10.52,    0.00 /
      DATA B(62095), B(62096), B(62097) /    -7.70,  -10.52,    0.00 /
      DATA B(62242), B(62243), B(62244) /    -7.72,  -10.48,    0.00 /
      DATA B(62389), B(62390), B(62391) /    -7.83,  -10.75,    0.00 /
      DATA B(62536), B(62537), B(62538) /    -7.85,  -10.69,    0.00 /
      DATA B(62683), B(62684), B(62685) /    -7.90,  -10.67,    0.00 /
      DATA B(62830), B(62831), B(62832) /    -7.94,  -10.64,    0.00 /
      DATA B(62977), B(62978), B(62979) /    -7.99,  -10.62,    0.00 /
      DATA B(63124), B(63125), B(63126) /    -8.04,  -10.59,    0.00 /
      DATA B(63271), B(63272), B(63273) /    -8.09,  -10.57,    0.00 /
      DATA B(63418), B(63419), B(63420) /    -8.00,  -10.13,    0.00 /
      DATA B(63565), B(63566), B(63567) /    -8.04,  -10.09,    0.00 /
      DATA B(63712), B(63713), B(63714) /    -8.07,  -10.04,    0.00 /
      DATA B(63859), B(63860), B(63861) /    -8.12,  -10.00,    0.00 /
      DATA B(64006), B(64007), B(64008) /    -8.17,   -9.95,    0.00 /
      DATA B(64153), B(64154), B(64155) /    -8.22,   -9.91,    0.00 /
      DATA B(64300), B(64301), B(64302) /    -8.26,   -9.89,    0.00 /
      DATA B(64447), B(64448), B(64449) /    -8.24,   -9.89,    0.00 /
      DATA B(64594), B(64595), B(64596) /    -8.24,   -9.93,    0.00 /
      DATA B(64741), B(64742), B(64743) /    -8.25,   -9.97,    0.00 /
      DATA B(64888), B(64889), B(64890) /    -8.25,  -10.02,    0.00 /
      DATA B(65035), B(65036), B(65037) /    -8.25,  -10.05,    0.00 /
      DATA B(65182), B(65183), B(65184) /    -8.23,  -10.38,    0.00 /
      DATA B(65329), B(65330), B(65331) /    -8.26,  -10.38,    0.00 /
      DATA B(65476), B(65477), B(65478) /    -8.28,  -10.38,    0.00 /
      DATA B(65623), B(65624), B(65625) /    -8.30,  -10.37,    0.00 /
      DATA B(65770), B(65771), B(65772) /    -8.32,  -10.37,    0.00 /
      DATA B(65917), B(65918), B(65919) /    -8.35,  -10.38,    0.00 /
      DATA B(66064), B(66065), B(66066) /    -8.37,  -10.39,    0.00 /
      DATA B(66211), B(66212), B(66213) /    -8.40,  -10.41,    0.00 /
      DATA B(66358), B(66359), B(66360) /    -8.43,  -10.44,    0.00 /
      DATA B(66505), B(66506), B(66507) /    -8.46,  -10.47,    0.00 /
      DATA B(66652), B(66653), B(66654) /    -8.50,  -10.51,    0.00 /
      DATA B(66799), B(66800), B(66801) /    -8.54,  -10.56,    0.00 /
      DATA B(66946), B(66947), B(66948) /    -8.58,  -10.61,    0.00 /
      DATA B(67093), B(67094), B(67095) /    -8.62,  -10.67,    0.00 /
      DATA B(67240), B(67241), B(67242) /    -8.66,  -10.72,    0.00 /
      DATA B(67387), B(67388), B(67389) /    -8.70,  -10.77,    0.00 /
      DATA B(67534), B(67535), B(67536) /    -8.75,  -10.82,    0.00 /
      DATA B(67681), B(67682), B(67683) /    -8.81,  -10.87,    0.00 /
      DATA B(46516), B(46517), B(46518) /    -5.07,  -21.82,    0.00 /
      DATA B(46663), B(46664), B(46665) /    -5.12,  -21.70,    0.00 /
      DATA B(46810), B(46811), B(46812) /    -5.17,  -21.57,    0.00 /
      DATA B(46957), B(46958), B(46959) /    -5.22,  -21.44,    0.00 /
      DATA B(47104), B(47105), B(47106) /    -5.27,  -21.30,    0.00 /
      DATA B(47251), B(47252), B(47253) /    -5.31,  -21.16,    0.00 /
      DATA B(47398), B(47399), B(47400) /    -5.35,  -21.02,    0.00 /
      DATA B(47545), B(47546), B(47547) /    -5.39,  -20.87,    0.00 /
      DATA B(47692), B(47693), B(47694) /    -5.42,  -20.72,    0.00 /
      DATA B(47839), B(47840), B(47841) /    -5.45,  -20.56,    0.00 /
      DATA B(47986), B(47987), B(47988) /    -5.46,  -20.39,    0.00 /
      DATA B(48133), B(48134), B(48135) /    -5.47,  -20.23,    0.00 /
      DATA B(48280), B(48281), B(48282) /    -5.47,  -20.05,    0.00 /
      DATA B(48427), B(48428), B(48429) /    -5.45,  -19.87,    0.00 /
      DATA B(48574), B(48575), B(48576) /    -5.42,  -19.67,    0.00 /
      DATA B(48721), B(48722), B(48723) /    -5.35,  -19.44,    0.00 /
      DATA B(48868), B(48869), B(48870) /    -5.23,  -19.16,    0.00 /
      DATA B(49015), B(49016), B(49017) /    -5.02,  -18.78,    0.00 /
      DATA B(49162), B(49163), B(49164) /    -4.57,  -18.10,    0.00 /
      DATA B(49309), B(49310), B(49311) /    -4.37,  -17.58,    0.00 /
      DATA B(49456), B(49457), B(49458) /    -4.26,  -17.18,    0.00 /
      DATA B(49603), B(49604), B(49605) /    -4.22,  -16.88,    0.00 /
      DATA B(49750), B(49751), B(49752) /    -4.21,  -16.64,    0.00 /
      DATA B(49897), B(49898), B(49899) /    -4.23,  -16.43,    0.00 /
      DATA B(50044), B(50045), B(50046) /    -4.29,  -16.25,    0.00 /
      DATA B(50191), B(50192), B(50193) /    -4.38,  -16.06,    0.00 /
      DATA B(50338), B(50339), B(50340) /    -4.53,  -15.89,    0.00 /
      DATA B(50485), B(50486), B(50487) /    -4.73,  -15.74,    0.00 /
      DATA B(50632), B(50633), B(50634) /    -4.94,  -15.70,    0.00 /
      DATA B(50779), B(50780), B(50781) /    -5.15,  -15.86,    0.00 /
      DATA B(50926), B(50927), B(50928) /    -5.51,  -15.80,    0.00 /
      DATA B(51073), B(51074), B(51075) /    -5.58,  -15.55,    0.00 /
      DATA B(51220), B(51221), B(51222) /    -5.72,  -15.52,    0.00 /
      DATA B(51367), B(51368), B(51369) /    -5.81,  -15.47,    0.00 /
      DATA B(51514), B(51515), B(51516) /    -5.88,  -15.42,    0.00 /
      DATA B(51661), B(51662), B(51663) /    -5.93,  -15.36,    0.00 /
      DATA B(51808), B(51809), B(51810) /    -5.98,  -15.30,    0.00 /
      DATA B(51955), B(51956), B(51957) /    -6.02,  -15.23,    0.00 /
      DATA B(52102), B(52103), B(52104) /    -6.06,  -15.16,    0.00 /
      DATA B(52249), B(52250), B(52251) /    -6.10,  -15.09,    0.00 /
      DATA B(52396), B(52397), B(52398) /    -6.13,  -15.01,    0.00 /
      DATA B(52543), B(52544), B(52545) /    -6.17,  -14.93,    0.00 /
      DATA B(52690), B(52691), B(52692) /    -6.20,  -14.85,    0.00 /
      DATA B(52837), B(52838), B(52839) /    -6.23,  -14.76,    0.00 /
      DATA B(52984), B(52985), B(52986) /    -6.26,  -14.68,    0.00 /
      DATA B(53131), B(53132), B(53133) /    -6.29,  -14.59,    0.00 /
      DATA B(53278), B(53279), B(53280) /    -6.31,  -14.50,    0.00 /
      DATA B(53425), B(53426), B(53427) /    -6.34,  -14.41,    0.00 /
      DATA B(53572), B(53573), B(53574) /    -6.37,  -14.31,    0.00 /
      DATA B(53719), B(53720), B(53721) /    -6.39,  -14.21,    0.00 /
      DATA B(53866), B(53867), B(53868) /    -6.41,  -14.12,    0.00 /
      DATA B(54013), B(54014), B(54015) /    -6.43,  -14.02,    0.00 /
      DATA B(54160), B(54161), B(54162) /    -6.30,  -14.06,    0.00 /
      DATA B(54307), B(54308), B(54309) /    -6.30,  -13.96,    0.00 /
      DATA B(54454), B(54455), B(54456) /    -6.31,  -13.85,    0.00 /
      DATA B(54601), B(54602), B(54603) /    -6.31,  -13.75,    0.00 /
      DATA B(54748), B(54749), B(54750) /    -6.31,  -13.64,    0.00 /
      DATA B(54895), B(54896), B(54897) /    -6.31,  -13.53,    0.00 /
      DATA B(55042), B(55043), B(55044) /    -6.31,  -13.42,    0.00 /
      DATA B(55189), B(55190), B(55191) /    -6.31,  -13.31,    0.00 /
      DATA B(55336), B(55337), B(55338) /    -6.31,  -13.20,    0.00 /
      DATA B(55483), B(55484), B(55485) /    -6.31,  -13.09,    0.00 /
      DATA B(55630), B(55631), B(55632) /    -6.32,  -12.98,    0.00 /
      DATA B(55777), B(55778), B(55779) /    -6.32,  -12.87,    0.00 /
      DATA B(55924), B(55925), B(55926) /    -6.33,  -12.77,    0.00 /
      DATA B(56071), B(56072), B(56073) /    -6.34,  -12.67,    0.00 /
      DATA B(56218), B(56219), B(56220) /    -6.36,  -12.58,    0.00 /
      DATA B(56365), B(56366), B(56367) /    -6.37,  -12.48,    0.00 /
      DATA B(56512), B(56513), B(56514) /    -6.39,  -12.40,    0.00 /
      DATA B(56659), B(56660), B(56661) /    -6.41,  -12.31,    0.00 /
      DATA B(56806), B(56807), B(56808) /    -6.44,  -12.23,    0.00 /
      DATA B(56953), B(56954), B(56955) /    -6.47,  -12.15,    0.00 /
      DATA B(57100), B(57101), B(57102) /    -6.51,  -12.07,    0.00 /
      DATA B(57247), B(57248), B(57249) /    -6.55,  -12.00,    0.00 /
      DATA B(57394), B(57395), B(57396) /    -6.61,  -11.92,    0.00 /
      DATA B(57541), B(57542), B(57543) /    -6.69,  -11.81,    0.00 /
      DATA B(57688), B(57689), B(57690) /    -6.86,  -11.99,    0.00 /
      DATA B(57835), B(57836), B(57837) /    -6.88,  -11.95,    0.00 /
      DATA B(57982), B(57983), B(57984) /    -6.95,  -11.92,    0.00 /
      DATA B(58129), B(58130), B(58131) /    -7.02,  -11.89,    0.00 /
      DATA B(58276), B(58277), B(58278) /    -7.10,  -11.88,    0.00 /
      DATA B(58423), B(58424), B(58425) /    -7.17,  -11.88,    0.00 /
      DATA B(58570), B(58571), B(58572) /    -7.23,  -11.89,    0.00 /
      DATA B(58717), B(58718), B(58719) /    -7.28,  -11.91,    0.00 /
      DATA B(58864), B(58865), B(58866) /    -7.31,  -11.93,    0.00 /
      DATA B(59011), B(59012), B(59013) /    -7.32,  -11.93,    0.00 /
      DATA B(59158), B(59159), B(59160) /    -7.33,  -11.90,    0.00 /
      DATA B(59305), B(59306), B(59307) /    -7.33,  -11.84,    0.00 /
      DATA B(59452), B(59453), B(59454) /    -7.34,  -11.76,    0.00 /
      DATA B(59599), B(59600), B(59601) /    -7.35,  -11.68,    0.00 /
      DATA B(59746), B(59747), B(59748) /    -7.36,  -11.59,    0.00 /
      DATA B(59893), B(59894), B(59895) /    -7.37,  -11.49,    0.00 /
      DATA B(60040), B(60041), B(60042) /    -7.39,  -11.40,    0.00 /
      DATA B(60187), B(60188), B(60189) /    -7.40,  -11.31,    0.00 /
      DATA B(60334), B(60335), B(60336) /    -7.41,  -11.21,    0.00 /
      DATA B(60481), B(60482), B(60483) /    -7.41,  -11.11,    0.00 /
      DATA B(60628), B(60629), B(60630) /    -7.52,  -10.83,    0.00 /
      DATA B(60775), B(60776), B(60777) /    -7.55,  -10.80,    0.00 /
      DATA B(60922), B(60923), B(60924) /    -7.58,  -10.77,    0.00 /
      DATA B(61069), B(61070), B(61071) /    -7.60,  -10.74,    0.00 /
      DATA B(61216), B(61217), B(61218) /    -7.63,  -10.70,    0.00 /
      DATA B(61363), B(61364), B(61365) /    -7.66,  -10.67,    0.00 /
      DATA B(61510), B(61511), B(61512) /    -7.68,  -10.64,    0.00 /
      DATA B(61657), B(61658), B(61659) /    -7.70,  -10.61,    0.00 /
      DATA B(61804), B(61805), B(61806) /    -7.72,  -10.59,    0.00 /
      DATA B(61951), B(61952), B(61953) /    -7.74,  -10.57,    0.00 /
      DATA B(62098), B(62099), B(62100) /    -7.75,  -10.56,    0.00 /
      DATA B(62245), B(62246), B(62247) /    -7.79,  -10.51,    0.00 /
      DATA B(62392), B(62393), B(62394) /    -7.80,  -10.42,    0.00 /
      DATA B(62539), B(62540), B(62541) /    -7.98,  -10.88,    0.00 /
      DATA B(62686), B(62687), B(62688) /    -8.02,  -10.85,    0.00 /
      DATA B(62833), B(62834), B(62835) /    -8.07,  -10.82,    0.00 /
      DATA B(62980), B(62981), B(62982) /    -8.11,  -10.79,    0.00 /
      DATA B(63127), B(63128), B(63129) /    -7.98,  -10.29,    0.00 /
      DATA B(63274), B(63275), B(63276) /    -8.02,  -10.26,    0.00 /
      DATA B(63421), B(63422), B(63423) /    -8.06,  -10.21,    0.00 /
      DATA B(63568), B(63569), B(63570) /    -8.09,  -10.17,    0.00 /
      DATA B(63715), B(63716), B(63717) /    -8.13,  -10.13,    0.00 /
      DATA B(63862), B(63863), B(63864) /    -8.17,  -10.08,    0.00 /
      DATA B(64009), B(64010), B(64011) /    -8.21,  -10.04,    0.00 /
      DATA B(64156), B(64157), B(64158) /    -8.26,  -10.00,    0.00 /
      DATA B(64303), B(64304), B(64305) /    -8.28,   -9.98,    0.00 /
      DATA B(64450), B(64451), B(64452) /    -8.28,  -10.01,    0.00 /
      DATA B(64597), B(64598), B(64599) /    -8.27,  -10.06,    0.00 /
      DATA B(64744), B(64745), B(64746) /    -8.28,  -10.12,    0.00 /
      DATA B(64891), B(64892), B(64893) /    -8.27,  -10.18,    0.00 /
      DATA B(65038), B(65039), B(65040) /    -8.25,  -10.42,    0.00 /
      DATA B(65185), B(65186), B(65187) /    -8.27,  -10.45,    0.00 /
      DATA B(65332), B(65333), B(65334) /    -8.30,  -10.45,    0.00 /
      DATA B(65479), B(65480), B(65481) /    -8.32,  -10.45,    0.00 /
      DATA B(65626), B(65627), B(65628) /    -8.34,  -10.45,    0.00 /
      DATA B(65773), B(65774), B(65775) /    -8.36,  -10.45,    0.00 /
      DATA B(65920), B(65921), B(65922) /    -8.39,  -10.45,    0.00 /
      DATA B(66067), B(66068), B(66069) /    -8.41,  -10.46,    0.00 /
      DATA B(66214), B(66215), B(66216) /    -8.44,  -10.48,    0.00 /
      DATA B(66361), B(66362), B(66363) /    -8.48,  -10.51,    0.00 /
      DATA B(66508), B(66509), B(66510) /    -8.51,  -10.54,    0.00 /
      DATA B(66655), B(66656), B(66657) /    -8.55,  -10.59,    0.00 /
      DATA B(66802), B(66803), B(66804) /    -8.59,  -10.64,    0.00 /
      DATA B(66949), B(66950), B(66951) /    -8.63,  -10.69,    0.00 /
      DATA B(67096), B(67097), B(67098) /    -8.67,  -10.75,    0.00 /
      DATA B(67243), B(67244), B(67245) /    -8.71,  -10.81,    0.00 /
      DATA B(67390), B(67391), B(67392) /    -8.76,  -10.86,    0.00 /
      DATA B(67537), B(67538), B(67539) /    -8.81,  -10.91,    0.00 /
      DATA B(67684), B(67685), B(67686) /    -8.86,  -10.97,    0.00 /
      DATA B(46519), B(46520), B(46521) /    -5.06,  -21.76,    0.00 /
      DATA B(46666), B(46667), B(46668) /    -5.11,  -21.64,    0.00 /
      DATA B(46813), B(46814), B(46815) /    -5.16,  -21.52,    0.00 /
      DATA B(46960), B(46961), B(46962) /    -5.21,  -21.39,    0.00 /
      DATA B(47107), B(47108), B(47109) /    -5.25,  -21.26,    0.00 /
      DATA B(47254), B(47255), B(47256) /    -5.29,  -21.12,    0.00 /
      DATA B(47401), B(47402), B(47403) /    -5.33,  -20.98,    0.00 /
      DATA B(47548), B(47549), B(47550) /    -5.37,  -20.84,    0.00 /
      DATA B(47695), B(47696), B(47697) /    -5.40,  -20.69,    0.00 /
      DATA B(47842), B(47843), B(47844) /    -5.42,  -20.54,    0.00 /
      DATA B(47989), B(47990), B(47991) /    -5.44,  -20.38,    0.00 /
      DATA B(48136), B(48137), B(48138) /    -5.45,  -20.21,    0.00 /
      DATA B(48283), B(48284), B(48285) /    -5.45,  -20.04,    0.00 /
      DATA B(48430), B(48431), B(48432) /    -5.44,  -19.86,    0.00 /
      DATA B(48577), B(48578), B(48579) /    -5.41,  -19.66,    0.00 /
      DATA B(48724), B(48725), B(48726) /    -5.34,  -19.43,    0.00 /
      DATA B(48871), B(48872), B(48873) /    -5.22,  -19.15,    0.00 /
      DATA B(49018), B(49019), B(49020) /    -5.04,  -18.76,    0.00 /
      DATA B(49165), B(49166), B(49167) /    -4.53,  -18.06,    0.00 /
      DATA B(49312), B(49313), B(49314) /    -4.31,  -17.50,    0.00 /
      DATA B(49459), B(49460), B(49461) /    -4.18,  -17.08,    0.00 /
      DATA B(49606), B(49607), B(49608) /    -4.12,  -16.77,    0.00 /
      DATA B(49753), B(49754), B(49755) /    -4.10,  -16.53,    0.00 /
      DATA B(49900), B(49901), B(49902) /    -4.11,  -16.32,    0.00 /
      DATA B(50047), B(50048), B(50049) /    -4.14,  -16.13,    0.00 /
      DATA B(50194), B(50195), B(50196) /    -4.20,  -15.94,    0.00 /
      DATA B(50341), B(50342), B(50343) /    -4.29,  -15.76,    0.00 /
      DATA B(50488), B(50489), B(50490) /    -4.38,  -15.58,    0.00 /
      DATA B(50635), B(50636), B(50637) /    -4.42,  -15.50,    0.00 /
      DATA B(50782), B(50783), B(50784) /    -5.42,  -15.62,    0.00 /
      DATA B(50929), B(50930), B(50931) /    -5.57,  -15.58,    0.00 /
      DATA B(51076), B(51077), B(51078) /    -5.69,  -15.57,    0.00 /
      DATA B(51223), B(51224), B(51225) /    -5.78,  -15.54,    0.00 /
      DATA B(51370), B(51371), B(51372) /    -5.86,  -15.50,    0.00 /
      DATA B(51517), B(51518), B(51519) /    -5.92,  -15.45,    0.00 /
      DATA B(51664), B(51665), B(51666) /    -5.97,  -15.39,    0.00 /
      DATA B(51811), B(51812), B(51813) /    -6.01,  -15.33,    0.00 /
      DATA B(51958), B(51959), B(51960) /    -6.05,  -15.26,    0.00 /
      DATA B(52105), B(52106), B(52107) /    -6.09,  -15.19,    0.00 /
      DATA B(52252), B(52253), B(52254) /    -6.12,  -15.12,    0.00 /
      DATA B(52399), B(52400), B(52401) /    -6.15,  -15.04,    0.00 /
      DATA B(52546), B(52547), B(52548) /    -6.19,  -14.96,    0.00 /
      DATA B(52693), B(52694), B(52695) /    -6.22,  -14.88,    0.00 /
      DATA B(52840), B(52841), B(52842) /    -6.25,  -14.80,    0.00 /
      DATA B(52987), B(52988), B(52989) /    -6.27,  -14.71,    0.00 /
      DATA B(53134), B(53135), B(53136) /    -6.30,  -14.62,    0.00 /
      DATA B(53281), B(53282), B(53283) /    -6.33,  -14.53,    0.00 /
      DATA B(53428), B(53429), B(53430) /    -6.35,  -14.44,    0.00 /
      DATA B(53575), B(53576), B(53577) /    -6.38,  -14.35,    0.00 /
      DATA B(53722), B(53723), B(53724) /    -6.40,  -14.25,    0.00 /
      DATA B(53869), B(53870), B(53871) /    -6.43,  -14.15,    0.00 /
      DATA B(54016), B(54017), B(54018) /    -6.45,  -14.06,    0.00 /
      DATA B(54163), B(54164), B(54165) /    -6.47,  -13.96,    0.00 /
      DATA B(54310), B(54311), B(54312) /    -6.49,  -13.86,    0.00 /
      DATA B(54457), B(54458), B(54459) /    -6.50,  -13.75,    0.00 /
      DATA B(54604), B(54605), B(54606) /    -6.52,  -13.65,    0.00 /
      DATA B(54751), B(54752), B(54753) /    -6.40,  -13.73,    0.00 /
      DATA B(54898), B(54899), B(54900) /    -6.40,  -13.62,    0.00 /
      DATA B(55045), B(55046), B(55047) /    -6.40,  -13.51,    0.00 /
      DATA B(55192), B(55193), B(55194) /    -6.40,  -13.40,    0.00 /
      DATA B(55339), B(55340), B(55341) /    -6.40,  -13.28,    0.00 /
      DATA B(55486), B(55487), B(55488) /    -6.40,  -13.17,    0.00 /
      DATA B(55633), B(55634), B(55635) /    -6.41,  -13.05,    0.00 /
      DATA B(55780), B(55781), B(55782) /    -6.41,  -12.94,    0.00 /
      DATA B(55927), B(55928), B(55929) /    -6.42,  -12.84,    0.00 /
      DATA B(56074), B(56075), B(56076) /    -6.44,  -12.74,    0.00 /
      DATA B(56221), B(56222), B(56223) /    -6.45,  -12.64,    0.00 /
      DATA B(56368), B(56369), B(56370) /    -6.47,  -12.55,    0.00 /
      DATA B(56515), B(56516), B(56517) /    -6.49,  -12.46,    0.00 /
      DATA B(56662), B(56663), B(56664) /    -6.51,  -12.38,    0.00 /
      DATA B(56809), B(56810), B(56811) /    -6.54,  -12.30,    0.00 /
      DATA B(56956), B(56957), B(56958) /    -6.57,  -12.22,    0.00 /
      DATA B(57103), B(57104), B(57105) /    -6.61,  -12.14,    0.00 /
      DATA B(57250), B(57251), B(57252) /    -6.67,  -12.07,    0.00 /
      DATA B(57397), B(57398), B(57399) /    -6.73,  -12.00,    0.00 /
      DATA B(57544), B(57545), B(57546) /    -6.81,  -11.90,    0.00 /
      DATA B(57691), B(57692), B(57693) /    -6.94,  -12.09,    0.00 /
      DATA B(57838), B(57839), B(57840) /    -7.02,  -12.04,    0.00 /
      DATA B(57985), B(57986), B(57987) /    -7.09,  -12.02,    0.00 /
      DATA B(58132), B(58133), B(58134) /    -7.17,  -11.99,    0.00 /
      DATA B(58279), B(58280), B(58281) /    -7.24,  -11.97,    0.00 /
      DATA B(58426), B(58427), B(58428) /    -7.30,  -11.96,    0.00 /
      DATA B(58573), B(58574), B(58575) /    -7.36,  -11.98,    0.00 /
      DATA B(58720), B(58721), B(58722) /    -7.42,  -12.01,    0.00 /
      DATA B(58867), B(58868), B(58869) /    -7.46,  -12.07,    0.00 /
      DATA B(59014), B(59015), B(59016) /    -7.46,  -12.09,    0.00 /
      DATA B(59161), B(59162), B(59163) /    -7.46,  -12.06,    0.00 /
      DATA B(59308), B(59309), B(59310) /    -7.47,  -12.00,    0.00 /
      DATA B(59455), B(59456), B(59457) /    -7.48,  -11.92,    0.00 /
      DATA B(59602), B(59603), B(59604) /    -7.49,  -11.83,    0.00 /
      DATA B(59749), B(59750), B(59751) /    -7.50,  -11.73,    0.00 /
      DATA B(59896), B(59897), B(59898) /    -7.51,  -11.64,    0.00 /
      DATA B(60043), B(60044), B(60045) /    -7.53,  -11.55,    0.00 /
      DATA B(60190), B(60191), B(60192) /    -7.54,  -11.45,    0.00 /
      DATA B(60337), B(60338), B(60339) /    -7.50,  -10.96,    0.00 /
      DATA B(60484), B(60485), B(60486) /    -7.53,  -10.93,    0.00 /
      DATA B(60631), B(60632), B(60633) /    -7.56,  -10.90,    0.00 /
      DATA B(60778), B(60779), B(60780) /    -7.59,  -10.86,    0.00 /
      DATA B(60925), B(60926), B(60927) /    -7.62,  -10.83,    0.00 /
      DATA B(61072), B(61073), B(61074) /    -7.64,  -10.80,    0.00 /
      DATA B(61219), B(61220), B(61221) /    -7.67,  -10.77,    0.00 /
      DATA B(61366), B(61367), B(61368) /    -7.70,  -10.73,    0.00 /
      DATA B(61513), B(61514), B(61515) /    -7.72,  -10.70,    0.00 /
      DATA B(61660), B(61661), B(61662) /    -7.74,  -10.68,    0.00 /
      DATA B(61807), B(61808), B(61809) /    -7.76,  -10.65,    0.00 /
      DATA B(61954), B(61955), B(61956) /    -7.78,  -10.63,    0.00 /
      DATA B(62101), B(62102), B(62103) /    -7.81,  -10.60,    0.00 /
      DATA B(62248), B(62249), B(62250) /    -7.84,  -10.56,    0.00 /
      DATA B(62395), B(62396), B(62397) /    -7.86,  -10.50,    0.00 /
      DATA B(62542), B(62543), B(62544) /    -7.88,  -10.48,    0.00 /
      DATA B(62689), B(62690), B(62691) /    -8.14,  -11.02,    0.00 /
      DATA B(62836), B(62837), B(62838) /    -7.97,  -10.45,    0.00 /
      DATA B(62983), B(62984), B(62985) /    -8.01,  -10.41,    0.00 /
      DATA B(63130), B(63131), B(63132) /    -8.04,  -10.37,    0.00 /
      DATA B(63277), B(63278), B(63279) /    -8.08,  -10.33,    0.00 /
      DATA B(63424), B(63425), B(63426) /    -8.12,  -10.29,    0.00 /
      DATA B(63571), B(63572), B(63573) /    -8.15,  -10.25,    0.00 /
      DATA B(63718), B(63719), B(63720) /    -8.18,  -10.21,    0.00 /
      DATA B(63865), B(63866), B(63867) /    -8.22,  -10.17,    0.00 /
      DATA B(64012), B(64013), B(64014) /    -8.26,  -10.13,    0.00 /
      DATA B(64159), B(64160), B(64161) /    -8.30,  -10.09,    0.00 /
      DATA B(64306), B(64307), B(64308) /    -8.32,  -10.08,    0.00 /
      DATA B(64453), B(64454), B(64455) /    -8.30,  -10.12,    0.00 /
      DATA B(64600), B(64601), B(64602) /    -8.30,  -10.18,    0.00 /
      DATA B(64747), B(64748), B(64749) /    -8.30,  -10.26,    0.00 /
      DATA B(64894), B(64895), B(64896) /    -8.28,  -10.35,    0.00 /
      DATA B(65041), B(65042), B(65043) /    -8.28,  -10.48,    0.00 /
      DATA B(65188), B(65189), B(65190) /    -8.31,  -10.51,    0.00 /
      DATA B(65335), B(65336), B(65337) /    -8.33,  -10.52,    0.00 /
      DATA B(65482), B(65483), B(65484) /    -8.35,  -10.52,    0.00 /
      DATA B(65629), B(65630), B(65631) /    -8.38,  -10.52,    0.00 /
      DATA B(65776), B(65777), B(65778) /    -8.40,  -10.52,    0.00 /
      DATA B(65923), B(65924), B(65925) /    -8.43,  -10.52,    0.00 /
      DATA B(66070), B(66071), B(66072) /    -8.46,  -10.53,    0.00 /
      DATA B(66217), B(66218), B(66219) /    -8.49,  -10.55,    0.00 /
      DATA B(66364), B(66365), B(66366) /    -8.52,  -10.58,    0.00 /
      DATA B(66511), B(66512), B(66513) /    -8.56,  -10.62,    0.00 /
      DATA B(66658), B(66659), B(66660) /    -8.60,  -10.66,    0.00 /
      DATA B(66805), B(66806), B(66807) /    -8.64,  -10.72,    0.00 /
      DATA B(66952), B(66953), B(66954) /    -8.69,  -10.78,    0.00 /
      DATA B(67099), B(67100), B(67101) /    -8.73,  -10.84,    0.00 /
      DATA B(67246), B(67247), B(67248) /    -8.77,  -10.90,    0.00 /
      DATA B(67393), B(67394), B(67395) /    -8.81,  -10.96,    0.00 /
      DATA B(67540), B(67541), B(67542) /    -8.86,  -11.01,    0.00 /
      DATA B(67687), B(67688), B(67689) /    -8.92,  -11.07,    0.00 /
      DATA GRDLX( 4) / 235.00000000000 /,
     *     GRDUX( 4) / 260.00000000000 /,
     *     GRDLY( 4) /  31.00000000000 /,
     *     GRDUY( 4) /  49.00000000000 /,
     *     ICNTX( 4) /100 /,
     *     ICNTY( 4) / 72 /,
     *     NBASE( 4) /67689 /
      DATA B(67690), B(67691), B(67692) /    27.13,  -47.03,    0.00 /
      DATA B(67993), B(67994), B(67995) /    27.13,  -46.80,    0.00 /
      DATA B(68296), B(68297), B(68298) /    27.13,  -46.56,    0.00 /
      DATA B(68599), B(68600), B(68601) /    27.13,  -46.32,    0.00 /
      DATA B(68902), B(68903), B(68904) /    27.12,  -46.08,    0.00 /
      DATA B(69205), B(69206), B(69207) /    27.12,  -45.84,    0.00 /
      DATA B(69508), B(69509), B(69510) /    27.11,  -45.60,    0.00 /
      DATA B(69811), B(69812), B(69813) /    27.11,  -45.36,    0.00 /
      DATA B(70114), B(70115), B(70116) /    27.11,  -45.12,    0.00 /
      DATA B(70417), B(70418), B(70419) /    27.10,  -44.87,    0.00 /
      DATA B(70720), B(70721), B(70722) /    27.09,  -44.63,    0.00 /
      DATA B(71023), B(71024), B(71025) /    27.09,  -44.39,    0.00 /
      DATA B(71326), B(71327), B(71328) /    27.08,  -44.14,    0.00 /
      DATA B(71629), B(71630), B(71631) /    27.07,  -43.90,    0.00 /
      DATA B(71932), B(71933), B(71934) /    27.07,  -43.66,    0.00 /
      DATA B(72235), B(72236), B(72237) /    27.06,  -43.41,    0.00 /
      DATA B(72538), B(72539), B(72540) /    27.05,  -43.16,    0.00 /
      DATA B(72841), B(72842), B(72843) /    27.04,  -42.92,    0.00 /
      DATA B(73144), B(73145), B(73146) /    27.03,  -42.67,    0.00 /
      DATA B(73447), B(73448), B(73449) /    27.02,  -42.42,    0.00 /
      DATA B(73750), B(73751), B(73752) /    27.01,  -42.17,    0.00 /
      DATA B(74053), B(74054), B(74055) /    27.00,  -41.91,    0.00 /
      DATA B(74356), B(74357), B(74358) /    26.99,  -41.65,    0.00 /
      DATA B(74659), B(74660), B(74661) /    26.98,  -41.39,    0.00 /
      DATA B(74962), B(74963), B(74964) /    26.97,  -41.13,    0.00 /
      DATA B(75265), B(75266), B(75267) /    26.95,  -40.86,    0.00 /
      DATA B(75568), B(75569), B(75570) /    26.93,  -40.59,    0.00 /
      DATA B(75871), B(75872), B(75873) /    26.90,  -40.31,    0.00 /
      DATA B(76174), B(76175), B(76176) /    26.88,  -40.04,    0.00 /
      DATA B(76477), B(76478), B(76479) /    26.85,  -39.75,    0.00 /
      DATA B(76780), B(76781), B(76782) /    26.83,  -39.46,    0.00 /
      DATA B(77083), B(77084), B(77085) /    26.80,  -39.14,    0.00 /
      DATA B(77386), B(77387), B(77388) /    26.78,  -38.80,    0.00 /
      DATA B(77689), B(77690), B(77691) /    26.77,  -38.43,    0.00 /
      DATA B(77992), B(77993), B(77994) /    26.79,  -38.04,    0.00 /
      DATA B(78295), B(78296), B(78297) /    26.91,  -37.60,    0.00 /
      DATA B(78598), B(78599), B(78600) /    27.29,  -36.98,    0.00 /
      DATA B(78901), B(78902), B(78903) /    28.67,  -35.32,    0.00 /
      DATA B(79204), B(79205), B(79206) /    15.75,   -7.14,    0.00 /
      DATA B(79507), B(79508), B(79509) /    18.73,   -0.62,    0.00 /
      DATA B(79810), B(79811), B(79812) /    15.64,   10.51,    0.00 /
      DATA B(80113), B(80114), B(80115) /    15.45,    1.63,    0.00 /
      DATA B(80416), B(80417), B(80418) /    14.27,   -4.46,    0.00 /
      DATA B(80719), B(80720), B(80721) /    10.30,    5.02,    0.00 /
      DATA B(81022), B(81023), B(81024) /    14.19,    5.07,    0.00 /
      DATA B(81325), B(81326), B(81327) /    15.13,    5.09,    0.00 /
      DATA B(81628), B(81629), B(81630) /    14.41,    4.61,    0.00 /
      DATA B(81931), B(81932), B(81933) /    12.98,    3.13,    0.00 /
      DATA B(82234), B(82235), B(82236) /    12.08,    2.14,    0.00 /
      DATA B(82537), B(82538), B(82539) /    11.83,    2.62,    0.00 /
      DATA B(82840), B(82841), B(82842) /    12.23,    3.51,    0.00 /
      DATA B(83143), B(83144), B(83145) /    14.04,    6.21,    0.00 /
      DATA B(83446), B(83447), B(83448) /    16.06,    9.04,    0.00 /
      DATA B(83749), B(83750), B(83751) /    16.92,    9.94,    0.00 /
      DATA B(84052), B(84053), B(84054) /    17.02,   10.38,    0.00 /
      DATA B(84355), B(84356), B(84357) /    16.86,   10.75,    0.00 /
      DATA B(84658), B(84659), B(84660) /    16.16,   10.80,    0.00 /
      DATA B(84961), B(84962), B(84963) /    15.03,    9.85,    0.00 /
      DATA B(85264), B(85265), B(85266) /    14.26,    9.08,    0.00 /
      DATA B(85567), B(85568), B(85569) /    14.06,    9.49,    0.00 /
      DATA B(85870), B(85871), B(85872) /    14.02,   10.09,    0.00 /
      DATA B(86173), B(86174), B(86175) /    13.80,   10.47,    0.00 /
      DATA B(86476), B(86477), B(86478) /    13.60,   10.85,    0.00 /
      DATA B(86779), B(86780), B(86781) /    13.72,   11.18,    0.00 /
      DATA B(87082), B(87083), B(87084) /     9.76,   11.26,    0.00 /
      DATA B(87385), B(87386), B(87387) /     9.24,   10.91,    0.00 /
      DATA B(87688), B(87689), B(87690) /     6.99,    8.58,    0.00 /
      DATA B(87991), B(87992), B(87993) /     4.18,    5.96,    0.00 /
      DATA B(88294), B(88295), B(88296) /     1.40,    3.31,    0.00 /
      DATA B(88597), B(88598), B(88599) /    -0.84,    0.79,    0.00 /
      DATA B(88900), B(88901), B(88902) /    -2.63,   -1.56,    0.00 /
      DATA B(89203), B(89204), B(89205) /    -3.79,   -3.80,    0.00 /
      DATA B(89506), B(89507), B(89508) /    -4.73,   -5.68,    0.00 /
      DATA B(67693), B(67694), B(67695) /    27.04,  -46.97,    0.00 /
      DATA B(67996), B(67997), B(67998) /    27.04,  -46.73,    0.00 /
      DATA B(68299), B(68300), B(68301) /    27.03,  -46.49,    0.00 /
      DATA B(68602), B(68603), B(68604) /    27.03,  -46.25,    0.00 /
      DATA B(68905), B(68906), B(68907) /    27.03,  -46.01,    0.00 /
      DATA B(69208), B(69209), B(69210) /    27.02,  -45.77,    0.00 /
      DATA B(69511), B(69512), B(69513) /    27.02,  -45.53,    0.00 /
      DATA B(69814), B(69815), B(69816) /    27.01,  -45.29,    0.00 /
      DATA B(70117), B(70118), B(70119) /    27.01,  -45.04,    0.00 /
      DATA B(70420), B(70421), B(70422) /    27.00,  -44.80,    0.00 /
      DATA B(70723), B(70724), B(70725) /    27.00,  -44.56,    0.00 /
      DATA B(71026), B(71027), B(71028) /    26.99,  -44.31,    0.00 /
      DATA B(71329), B(71330), B(71331) /    26.98,  -44.07,    0.00 /
      DATA B(71632), B(71633), B(71634) /    26.98,  -43.82,    0.00 /
      DATA B(71935), B(71936), B(71937) /    26.97,  -43.58,    0.00 /
      DATA B(72238), B(72239), B(72240) /    26.96,  -43.33,    0.00 /
      DATA B(72541), B(72542), B(72543) /    26.95,  -43.09,    0.00 /
      DATA B(72844), B(72845), B(72846) /    26.94,  -42.84,    0.00 /
      DATA B(73147), B(73148), B(73149) /    26.93,  -42.59,    0.00 /
      DATA B(73450), B(73451), B(73452) /    26.92,  -42.34,    0.00 /
      DATA B(73753), B(73754), B(73755) /    26.91,  -42.09,    0.00 /
      DATA B(74056), B(74057), B(74058) /    26.89,  -41.83,    0.00 /
      DATA B(74359), B(74360), B(74361) /    26.88,  -41.57,    0.00 /
      DATA B(74662), B(74663), B(74664) /    26.87,  -41.31,    0.00 /
      DATA B(74965), B(74966), B(74967) /    26.85,  -41.04,    0.00 /
      DATA B(75268), B(75269), B(75270) /    26.83,  -40.77,    0.00 /
      DATA B(75571), B(75572), B(75573) /    26.80,  -40.49,    0.00 /
      DATA B(75874), B(75875), B(75876) /    26.77,  -40.21,    0.00 /
      DATA B(76177), B(76178), B(76179) /    26.73,  -39.93,    0.00 /
      DATA B(76480), B(76481), B(76482) /    26.69,  -39.65,    0.00 /
      DATA B(76783), B(76784), B(76785) /    26.64,  -39.34,    0.00 /
      DATA B(77086), B(77087), B(77088) /    26.59,  -39.01,    0.00 /
      DATA B(77389), B(77390), B(77391) /    26.54,  -38.63,    0.00 /
      DATA B(77692), B(77693), B(77694) /    26.48,  -38.22,    0.00 /
      DATA B(77995), B(77996), B(77997) /    26.43,  -37.78,    0.00 /
      DATA B(78298), B(78299), B(78300) /    26.47,  -37.27,    0.00 /
      DATA B(78601), B(78602), B(78603) /    26.78,  -36.47,    0.00 /
      DATA B(78904), B(78905), B(78906) /    27.95,  -33.49,    0.00 /
      DATA B(79207), B(79208), B(79209) /    14.40,   -6.15,    0.00 /
      DATA B(79510), B(79511), B(79512) /    19.29,   -3.11,    0.00 /
      DATA B(79813), B(79814), B(79815) /    15.75,    1.98,    0.00 /
      DATA B(80116), B(80117), B(80118) /    13.30,   -2.51,    0.00 /
      DATA B(80419), B(80420), B(80421) /     8.19,  -11.48,    0.00 /
      DATA B(80722), B(80723), B(80724) /     7.47,   -1.17,    0.00 /
      DATA B(81025), B(81026), B(81027) /     7.71,   -0.88,    0.00 /
      DATA B(81328), B(81329), B(81330) /     7.56,   -0.68,    0.00 /
      DATA B(81631), B(81632), B(81633) /     6.56,   -1.04,    0.00 /
      DATA B(81934), B(81935), B(81936) /     5.15,   -2.41,    0.00 /
      DATA B(82237), B(82238), B(82239) /     4.85,   -3.32,    0.00 /
      DATA B(82540), B(82541), B(82542) /     6.01,   -1.93,    0.00 /
      DATA B(82843), B(82844), B(82845) /     7.31,   -0.39,    0.00 /
      DATA B(83146), B(83147), B(83148) /     8.62,    1.15,    0.00 /
      DATA B(83449), B(83450), B(83451) /    10.27,    3.08,    0.00 /
      DATA B(83752), B(83753), B(83754) /    11.39,    4.35,    0.00 /
      DATA B(84055), B(84056), B(84057) /    11.64,    5.03,    0.00 /
      DATA B(84358), B(84359), B(84360) /    11.55,    5.50,    0.00 /
      DATA B(84661), B(84662), B(84663) /    10.84,    5.68,    0.00 /
      DATA B(84964), B(84965), B(84966) /     9.75,    4.84,    0.00 /
      DATA B(85267), B(85268), B(85269) /     8.91,    3.92,    0.00 /
      DATA B(85570), B(85571), B(85572) /     8.71,    4.24,    0.00 /
      DATA B(85873), B(85874), B(85875) /     9.12,    5.05,    0.00 /
      DATA B(86176), B(86177), B(86178) /     9.48,    5.93,    0.00 /
      DATA B(86479), B(86480), B(86481) /     9.70,    6.77,    0.00 /
      DATA B(86782), B(86783), B(86784) /     9.56,    7.27,    0.00 /
      DATA B(87085), B(87086), B(87087) /     8.11,    7.71,    0.00 /
      DATA B(87388), B(87389), B(87390) /     5.74,    7.05,    0.00 /
      DATA B(87691), B(87692), B(87693) /     3.93,    5.33,    0.00 /
      DATA B(87994), B(87995), B(87996) /     1.86,    3.61,    0.00 /
      DATA B(88297), B(88298), B(88299) /    -0.40,    1.35,    0.00 /
      DATA B(88600), B(88601), B(88602) /    -2.22,   -0.84,    0.00 /
      DATA B(88903), B(88904), B(88905) /    -3.76,   -3.16,    0.00 /
      DATA B(89206), B(89207), B(89208) /    -4.47,   -5.09,    0.00 /
      DATA B(89509), B(89510), B(89511) /    -5.46,   -6.55,    0.00 /
      DATA B(67696), B(67697), B(67698) /    26.95,  -46.90,    0.00 /
      DATA B(67999), B(68000), B(68001) /    26.94,  -46.66,    0.00 /
      DATA B(68302), B(68303), B(68304) /    26.94,  -46.43,    0.00 /
      DATA B(68605), B(68606), B(68607) /    26.94,  -46.18,    0.00 /
      DATA B(68908), B(68909), B(68910) /    26.93,  -45.94,    0.00 /
      DATA B(69211), B(69212), B(69213) /    26.93,  -45.70,    0.00 /
      DATA B(69514), B(69515), B(69516) /    26.92,  -45.46,    0.00 /
      DATA B(69817), B(69818), B(69819) /    26.92,  -45.22,    0.00 /
      DATA B(70120), B(70121), B(70122) /    26.91,  -44.97,    0.00 /
      DATA B(70423), B(70424), B(70425) /    26.91,  -44.73,    0.00 /
      DATA B(70726), B(70727), B(70728) /    26.90,  -44.48,    0.00 /
      DATA B(71029), B(71030), B(71031) /    26.89,  -44.24,    0.00 /
      DATA B(71332), B(71333), B(71334) /    26.88,  -43.99,    0.00 /
      DATA B(71635), B(71636), B(71637) /    26.88,  -43.75,    0.00 /
      DATA B(71938), B(71939), B(71940) /    26.87,  -43.50,    0.00 /
      DATA B(72241), B(72242), B(72243) /    26.86,  -43.26,    0.00 /
      DATA B(72544), B(72545), B(72546) /    26.84,  -43.01,    0.00 /
      DATA B(72847), B(72848), B(72849) /    26.83,  -42.76,    0.00 /
      DATA B(73150), B(73151), B(73152) /    26.82,  -42.51,    0.00 /
      DATA B(73453), B(73454), B(73455) /    26.81,  -42.26,    0.00 /
      DATA B(73756), B(73757), B(73758) /    26.80,  -42.01,    0.00 /
      DATA B(74059), B(74060), B(74061) /    26.78,  -41.75,    0.00 /
      DATA B(74362), B(74363), B(74364) /    26.77,  -41.49,    0.00 /
      DATA B(74665), B(74666), B(74667) /    26.75,  -41.22,    0.00 /
      DATA B(74968), B(74969), B(74970) /    26.73,  -40.95,    0.00 /
      DATA B(75271), B(75272), B(75273) /    26.71,  -40.67,    0.00 /
      DATA B(75574), B(75575), B(75576) /    26.67,  -40.39,    0.00 /
      DATA B(75877), B(75878), B(75879) /    26.63,  -40.10,    0.00 /
      DATA B(76180), B(76181), B(76182) /    26.57,  -39.82,    0.00 /
      DATA B(76483), B(76484), B(76485) /    26.50,  -39.54,    0.00 /
      DATA B(76786), B(76787), B(76788) /    26.42,  -39.23,    0.00 /
      DATA B(77089), B(77090), B(77091) /    26.33,  -38.86,    0.00 /
      DATA B(77392), B(77393), B(77394) /    26.21,  -38.42,    0.00 /
      DATA B(77695), B(77696), B(77697) /    26.04,  -37.93,    0.00 /
      DATA B(77998), B(77999), B(78000) /    25.83,  -37.40,    0.00 /
      DATA B(78301), B(78302), B(78303) /    25.60,  -36.79,    0.00 /
      DATA B(78604), B(78605), B(78606) /    25.43,  -35.79,    0.00 /
      DATA B(78907), B(78908), B(78909) /    26.47,  -30.53,    0.00 /
      DATA B(79210), B(79211), B(79212) /    16.96,  -12.40,    0.00 /
      DATA B(79513), B(79514), B(79515) /    14.96,   -2.79,    0.00 /
      DATA B(79816), B(79817), B(79818) /    12.33,   -2.39,    0.00 /
      DATA B(80119), B(80120), B(80121) /     6.71,   -8.89,    0.00 /
      DATA B(80422), B(80423), B(80424) /     5.81,   -5.52,    0.00 /
      DATA B(80725), B(80726), B(80727) /     3.47,   -6.38,    0.00 /
      DATA B(81028), B(81029), B(81030) /     2.52,   -6.58,    0.00 /
      DATA B(81331), B(81332), B(81333) /     2.00,   -6.44,    0.00 /
      DATA B(81634), B(81635), B(81636) /     1.47,   -6.50,    0.00 /
      DATA B(81937), B(81938), B(81939) /     1.01,   -7.26,    0.00 /
      DATA B(82240), B(82241), B(82242) /     1.10,   -7.81,    0.00 /
      DATA B(82543), B(82544), B(82545) /     1.78,   -6.22,    0.00 /
      DATA B(82846), B(82847), B(82848) /     2.29,   -4.17,    0.00 /
      DATA B(83149), B(83150), B(83151) /     2.49,   -2.93,    0.00 /
      DATA B(83452), B(83453), B(83454) /     3.04,   -1.82,    0.00 /
      DATA B(83755), B(83756), B(83757) /     3.72,   -0.83,    0.00 /
      DATA B(84058), B(84059), B(84060) /     4.22,   -0.13,    0.00 /
      DATA B(84361), B(84362), B(84363) /     4.45,    0.41,    0.00 /
      DATA B(84664), B(84665), B(84666) /     4.31,    0.84,    0.00 /
      DATA B(84967), B(84968), B(84969) /     3.84,    0.52,    0.00 /
      DATA B(85270), B(85271), B(85272) /     3.15,   -0.20,    0.00 /
      DATA B(85573), B(85574), B(85575) /     2.83,   -0.12,    0.00 /
      DATA B(85876), B(85877), B(85878) /     3.32,    0.48,    0.00 /
      DATA B(86179), B(86180), B(86181) /     4.09,    1.45,    0.00 /
      DATA B(86482), B(86483), B(86484) /     4.80,    2.53,    0.00 /
      DATA B(86785), B(86786), B(86787) /     4.95,    3.46,    0.00 /
      DATA B(87088), B(87089), B(87090) /     4.42,    4.02,    0.00 /
      DATA B(87391), B(87392), B(87393) /     3.06,    3.85,    0.00 /
      DATA B(87694), B(87695), B(87696) /     1.35,    2.44,    0.00 /
      DATA B(87997), B(87998), B(87999) /    -0.26,    1.31,    0.00 /
      DATA B(88300), B(88301), B(88302) /    -1.91,   -0.35,    0.00 /
      DATA B(88603), B(88604), B(88605) /    -3.40,   -2.30,    0.00 /
      DATA B(88906), B(88907), B(88908) /    -4.51,   -4.44,    0.00 /
      DATA B(89209), B(89210), B(89211) /    -5.24,   -6.19,    0.00 /
      DATA B(89512), B(89513), B(89514) /    -6.05,   -7.23,    0.00 /
      DATA B(67699), B(67700), B(67701) /    26.85,  -46.84,    0.00 /
      DATA B(68002), B(68003), B(68004) /    26.85,  -46.60,    0.00 /
      DATA B(68305), B(68306), B(68307) /    26.84,  -46.36,    0.00 /
      DATA B(68608), B(68609), B(68610) /    26.84,  -46.12,    0.00 /
      DATA B(68911), B(68912), B(68913) /    26.84,  -45.87,    0.00 /
      DATA B(69214), B(69215), B(69216) /    26.83,  -45.63,    0.00 /
      DATA B(69517), B(69518), B(69519) /    26.83,  -45.39,    0.00 /
      DATA B(69820), B(69821), B(69822) /    26.82,  -45.14,    0.00 /
      DATA B(70123), B(70124), B(70125) /    26.82,  -44.90,    0.00 /
      DATA B(70426), B(70427), B(70428) /    26.81,  -44.65,    0.00 /
      DATA B(70729), B(70730), B(70731) /    26.80,  -44.41,    0.00 /
      DATA B(71032), B(71033), B(71034) /    26.79,  -44.16,    0.00 /
      DATA B(71335), B(71336), B(71337) /    26.79,  -43.92,    0.00 /
      DATA B(71638), B(71639), B(71640) /    26.78,  -43.67,    0.00 /
      DATA B(71941), B(71942), B(71943) /    26.76,  -43.42,    0.00 /
      DATA B(72244), B(72245), B(72246) /    26.75,  -43.18,    0.00 /
      DATA B(72547), B(72548), B(72549) /    26.74,  -42.93,    0.00 /
      DATA B(72850), B(72851), B(72852) /    26.73,  -42.68,    0.00 /
      DATA B(73153), B(73154), B(73155) /    26.71,  -42.43,    0.00 /
      DATA B(73456), B(73457), B(73458) /    26.70,  -42.18,    0.00 /
      DATA B(73759), B(73760), B(73761) /    26.68,  -41.93,    0.00 /
      DATA B(74062), B(74063), B(74064) /    26.67,  -41.67,    0.00 /
      DATA B(74365), B(74366), B(74367) /    26.65,  -41.41,    0.00 /
      DATA B(74668), B(74669), B(74670) /    26.63,  -41.14,    0.00 /
      DATA B(74971), B(74972), B(74973) /    26.61,  -40.86,    0.00 /
      DATA B(75274), B(75275), B(75276) /    26.58,  -40.57,    0.00 /
      DATA B(75577), B(75578), B(75579) /    26.53,  -40.27,    0.00 /
      DATA B(75880), B(75881), B(75882) /    26.47,  -39.98,    0.00 /
      DATA B(76183), B(76184), B(76185) /    26.39,  -39.69,    0.00 /
      DATA B(76486), B(76487), B(76488) /    26.28,  -39.41,    0.00 /
      DATA B(76789), B(76790), B(76791) /    26.15,  -39.10,    0.00 /
      DATA B(77092), B(77093), B(77094) /    25.98,  -38.70,    0.00 /
      DATA B(77395), B(77396), B(77397) /    25.73,  -38.14,    0.00 /
      DATA B(77698), B(77699), B(77700) /    25.31,  -37.46,    0.00 /
      DATA B(78001), B(78002), B(78003) /    24.71,  -36.73,    0.00 /
      DATA B(78304), B(78305), B(78306) /    23.75,  -35.83,    0.00 /
      DATA B(78607), B(78608), B(78609) /    21.87,  -34.22,    0.00 /
      DATA B(78910), B(78911), B(78912) /    18.13,  -27.44,    0.00 /
      DATA B(79213), B(79214), B(79215) /    12.24,  -13.64,    0.00 /
      DATA B(79516), B(79517), B(79518) /    10.17,   -8.15,    0.00 /
      DATA B(79819), B(79820), B(79821) /     6.53,   -7.82,    0.00 /
      DATA B(80122), B(80123), B(80124) /     1.39,  -14.78,    0.00 /
      DATA B(80425), B(80426), B(80427) /     3.26,   -7.94,    0.00 /
      DATA B(80728), B(80729), B(80730) /     0.89,   -9.32,    0.00 /
      DATA B(81031), B(81032), B(81033) /    -0.27,   -9.64,    0.00 /
      DATA B(81334), B(81335), B(81336) /    -0.85,   -9.57,    0.00 /
      DATA B(81637), B(81638), B(81639) /    -1.05,   -9.52,    0.00 /
      DATA B(81940), B(81941), B(81942) /    -1.06,   -9.82,    0.00 /
      DATA B(82243), B(82244), B(82245) /    -0.90,   -9.87,    0.00 /
      DATA B(82546), B(82547), B(82548) /    -0.70,   -8.47,    0.00 /
      DATA B(82849), B(82850), B(82851) /    -0.54,   -6.61,    0.00 /
      DATA B(83152), B(83153), B(83154) /    -0.45,   -5.82,    0.00 /
      DATA B(83455), B(83456), B(83457) /    -0.49,   -5.47,    0.00 /
      DATA B(83758), B(83759), B(83760) /    -0.48,   -4.73,    0.00 /
      DATA B(84061), B(84062), B(84063) /    -0.28,   -3.85,    0.00 /
      DATA B(84364), B(84365), B(84366) /    -0.11,   -3.11,    0.00 /
      DATA B(84667), B(84668), B(84669) /     0.02,   -2.58,    0.00 /
      DATA B(84970), B(84971), B(84972) /     0.05,   -2.72,    0.00 /
      DATA B(85273), B(85274), B(85275) /    -0.24,   -3.22,    0.00 /
      DATA B(85576), B(85577), B(85578) /    -0.49,   -3.25,    0.00 /
      DATA B(85879), B(85880), B(85881) /    -0.34,   -2.84,    0.00 /
      DATA B(86182), B(86183), B(86184) /     0.06,   -1.95,    0.00 /
      DATA B(86485), B(86486), B(86487) /     0.57,   -0.79,    0.00 /
      DATA B(86788), B(86789), B(86790) /     0.89,    0.35,    0.00 /
      DATA B(87091), B(87092), B(87093) /     0.69,    0.83,    0.00 /
      DATA B(87394), B(87395), B(87396) /    -0.03,    0.95,    0.00 /
      DATA B(87697), B(87698), B(87699) /    -1.05,   -0.01,    0.00 /
      DATA B(88000), B(88001), B(88002) /    -2.21,   -0.71,    0.00 /
      DATA B(88303), B(88304), B(88305) /    -3.33,   -1.94,    0.00 /
      DATA B(88606), B(88607), B(88608) /    -4.41,   -3.63,    0.00 /
      DATA B(88909), B(88910), B(88911) /    -5.06,   -5.60,    0.00 /
      DATA B(89212), B(89213), B(89214) /    -5.86,   -7.00,    0.00 /
      DATA B(89515), B(89516), B(89517) /    -6.53,   -7.80,    0.00 /
      DATA B(67702), B(67703), B(67704) /    26.75,  -46.77,    0.00 /
      DATA B(68005), B(68006), B(68007) /    26.75,  -46.53,    0.00 /
      DATA B(68308), B(68309), B(68310) /    26.75,  -46.29,    0.00 /
      DATA B(68611), B(68612), B(68613) /    26.74,  -46.05,    0.00 /
      DATA B(68914), B(68915), B(68916) /    26.74,  -45.80,    0.00 /
      DATA B(69217), B(69218), B(69219) /    26.74,  -45.56,    0.00 /
      DATA B(69520), B(69521), B(69522) /    26.73,  -45.32,    0.00 /
      DATA B(69823), B(69824), B(69825) /    26.72,  -45.07,    0.00 /
      DATA B(70126), B(70127), B(70128) /    26.72,  -44.82,    0.00 /
      DATA B(70429), B(70430), B(70431) /    26.71,  -44.58,    0.00 /
      DATA B(70732), B(70733), B(70734) /    26.70,  -44.33,    0.00 /
      DATA B(71035), B(71036), B(71037) /    26.69,  -44.08,    0.00 /
      DATA B(71338), B(71339), B(71340) /    26.68,  -43.84,    0.00 /
      DATA B(71641), B(71642), B(71643) /    26.67,  -43.59,    0.00 /
      DATA B(71944), B(71945), B(71946) /    26.66,  -43.34,    0.00 /
      DATA B(72247), B(72248), B(72249) /    26.65,  -43.10,    0.00 /
      DATA B(72550), B(72551), B(72552) /    26.63,  -42.85,    0.00 /
      DATA B(72853), B(72854), B(72855) /    26.62,  -42.60,    0.00 /
      DATA B(73156), B(73157), B(73158) /    26.60,  -42.35,    0.00 /
      DATA B(73459), B(73460), B(73461) /    26.58,  -42.10,    0.00 /
      DATA B(73762), B(73763), B(73764) /    26.56,  -41.85,    0.00 /
      DATA B(74065), B(74066), B(74067) /    26.55,  -41.59,    0.00 /
      DATA B(74368), B(74369), B(74370) /    26.52,  -41.33,    0.00 /
      DATA B(74671), B(74672), B(74673) /    26.50,  -41.05,    0.00 /
      DATA B(74974), B(74975), B(74976) /    26.48,  -40.77,    0.00 /
      DATA B(75277), B(75278), B(75279) /    26.44,  -40.46,    0.00 /
      DATA B(75580), B(75581), B(75582) /    26.39,  -40.15,    0.00 /
      DATA B(75883), B(75884), B(75885) /    26.31,  -39.84,    0.00 /
      DATA B(76186), B(76187), B(76188) /    26.20,  -39.54,    0.00 /
      DATA B(76489), B(76490), B(76491) /    26.04,  -39.26,    0.00 /
      DATA B(76792), B(76793), B(76794) /    25.80,  -38.96,    0.00 /
      DATA B(77095), B(77096), B(77097) /    25.43,  -38.51,    0.00 /
      DATA B(77398), B(77399), B(77400) /    24.82,  -37.64,    0.00 /
      DATA B(77701), B(77702), B(77703) /    23.61,  -36.46,    0.00 /
      DATA B(78004), B(78005), B(78006) /    21.64,  -35.24,    0.00 /
      DATA B(78307), B(78308), B(78309) /    18.75,  -33.79,    0.00 /
      DATA B(78610), B(78611), B(78612) /    15.88,  -31.55,    0.00 /
      DATA B(78913), B(78914), B(78915) /     9.34,  -23.32,    0.00 /
      DATA B(79216), B(79217), B(79218) /     0.66,   -8.15,    0.00 /
      DATA B(79519), B(79520), B(79521) /     3.97,  -12.87,    0.00 /
      DATA B(79822), B(79823), B(79824) /     0.48,  -12.38,    0.00 /
      DATA B(80125), B(80126), B(80127) /     1.56,   -9.12,    0.00 /
      DATA B(80428), B(80429), B(80430) /     1.37,   -9.94,    0.00 /
      DATA B(80731), B(80732), B(80733) /    -0.40,  -11.18,    0.00 /
      DATA B(81034), B(81035), B(81036) /    -1.48,  -11.59,    0.00 /
      DATA B(81337), B(81338), B(81339) /    -2.07,  -11.53,    0.00 /
      DATA B(81640), B(81641), B(81642) /    -2.24,  -11.35,    0.00 /
      DATA B(81943), B(81944), B(81945) /    -2.23,  -11.29,    0.00 /
      DATA B(82246), B(82247), B(82248) /    -2.18,  -11.02,    0.00 /
      DATA B(82549), B(82550), B(82551) /    -2.20,   -9.86,    0.00 /
      DATA B(82852), B(82853), B(82854) /    -2.11,   -8.38,    0.00 /
      DATA B(83155), B(83156), B(83157) /    -1.94,   -7.77,    0.00 /
      DATA B(83458), B(83459), B(83460) /    -2.05,   -7.61,    0.00 /
      DATA B(83761), B(83762), B(83763) /    -2.24,   -7.14,    0.00 /
      DATA B(84064), B(84065), B(84066) /    -2.25,   -6.45,    0.00 /
      DATA B(84367), B(84368), B(84369) /    -2.17,   -5.83,    0.00 /
      DATA B(84670), B(84671), B(84672) /    -2.07,   -5.40,    0.00 /
      DATA B(84973), B(84974), B(84975) /    -2.00,   -5.29,    0.00 /
      DATA B(85276), B(85277), B(85278) /    -2.08,   -5.38,    0.00 /
      DATA B(85579), B(85580), B(85581) /    -2.24,   -5.28,    0.00 /
      DATA B(85882), B(85883), B(85884) /    -2.32,   -4.91,    0.00 /
      DATA B(86185), B(86186), B(86187) /    -2.32,   -4.15,    0.00 /
      DATA B(86488), B(86489), B(86490) /    -2.32,   -3.18,    0.00 /
      DATA B(86791), B(86792), B(86793) /    -1.98,   -2.19,    0.00 /
      DATA B(87094), B(87095), B(87096) /    -2.16,   -1.72,    0.00 /
      DATA B(87397), B(87398), B(87399) /    -2.53,   -1.50,    0.00 /
      DATA B(87700), B(87701), B(87702) /    -3.18,   -2.13,    0.00 /
      DATA B(88003), B(88004), B(88005) /    -3.97,   -2.61,    0.00 /
      DATA B(88306), B(88307), B(88308) /    -4.59,   -3.40,    0.00 /
      DATA B(88609), B(88610), B(88611) /    -5.26,   -4.87,    0.00 /
      DATA B(88912), B(88913), B(88914) /    -5.66,   -6.58,    0.00 /
      DATA B(89215), B(89216), B(89217) /    -6.39,   -7.65,    0.00 /
      DATA B(89518), B(89519), B(89520) /    -6.94,   -8.29,    0.00 /
      DATA B(67705), B(67706), B(67707) /    26.66,  -46.71,    0.00 /
      DATA B(68008), B(68009), B(68010) /    26.65,  -46.47,    0.00 /
      DATA B(68311), B(68312), B(68313) /    26.65,  -46.22,    0.00 /
      DATA B(68614), B(68615), B(68616) /    26.65,  -45.98,    0.00 /
      DATA B(68917), B(68918), B(68919) /    26.64,  -45.73,    0.00 /
      DATA B(69220), B(69221), B(69222) /    26.64,  -45.49,    0.00 /
      DATA B(69523), B(69524), B(69525) /    26.63,  -45.24,    0.00 /
      DATA B(69826), B(69827), B(69828) /    26.63,  -45.00,    0.00 /
      DATA B(70129), B(70130), B(70131) /    26.62,  -44.75,    0.00 /
      DATA B(70432), B(70433), B(70434) /    26.61,  -44.50,    0.00 /
      DATA B(70735), B(70736), B(70737) /    26.60,  -44.25,    0.00 /
      DATA B(71038), B(71039), B(71040) /    26.59,  -44.01,    0.00 /
      DATA B(71341), B(71342), B(71343) /    26.58,  -43.76,    0.00 /
      DATA B(71644), B(71645), B(71646) /    26.57,  -43.51,    0.00 /
      DATA B(71947), B(71948), B(71949) /    26.56,  -43.26,    0.00 /
      DATA B(72250), B(72251), B(72252) /    26.54,  -43.01,    0.00 /
      DATA B(72553), B(72554), B(72555) /    26.53,  -42.77,    0.00 /
      DATA B(72856), B(72857), B(72858) /    26.51,  -42.52,    0.00 /
      DATA B(73159), B(73160), B(73161) /    26.49,  -42.27,    0.00 /
      DATA B(73462), B(73463), B(73464) /    26.47,  -42.02,    0.00 /
      DATA B(73765), B(73766), B(73767) /    26.44,  -41.77,    0.00 /
      DATA B(74068), B(74069), B(74070) /    26.42,  -41.51,    0.00 /
      DATA B(74371), B(74372), B(74373) /    26.39,  -41.25,    0.00 /
      DATA B(74674), B(74675), B(74676) /    26.37,  -40.97,    0.00 /
      DATA B(74977), B(74978), B(74979) /    26.34,  -40.67,    0.00 /
      DATA B(75280), B(75281), B(75282) /    26.30,  -40.35,    0.00 /
      DATA B(75583), B(75584), B(75585) /    26.24,  -40.00,    0.00 /
      DATA B(75886), B(75887), B(75888) /    26.14,  -39.66,    0.00 /
      DATA B(76189), B(76190), B(76191) /    25.99,  -39.35,    0.00 /
      DATA B(76492), B(76493), B(76494) /    25.75,  -39.07,    0.00 /
      DATA B(76795), B(76796), B(76797) /    25.32,  -38.77,    0.00 /
      DATA B(77098), B(77099), B(77100) /    24.41,  -38.18,    0.00 /
      DATA B(77401), B(77402), B(77403) /    22.21,  -36.37,    0.00 /
      DATA B(77704), B(77705), B(77706) /    18.54,  -34.21,    0.00 /
      DATA B(78007), B(78008), B(78009) /    15.87,  -33.03,    0.00 /
      DATA B(78310), B(78311), B(78312) /    13.77,  -31.84,    0.00 /
      DATA B(78613), B(78614), B(78615) /     7.23,  -26.94,    0.00 /
      DATA B(78916), B(78917), B(78918) /     3.70,  -24.17,    0.00 /
      DATA B(79219), B(79220), B(79221) /     0.75,  -19.34,    0.00 /
      DATA B(79522), B(79523), B(79524) /    -1.57,  -16.59,    0.00 /
      DATA B(79825), B(79826), B(79827) /    -1.85,  -14.07,    0.00 /
      DATA B(80128), B(80129), B(80130) /    -1.60,  -12.67,    0.00 /
      DATA B(80431), B(80432), B(80433) /    -0.54,  -11.95,    0.00 /
      DATA B(80734), B(80735), B(80736) /    -1.47,  -12.43,    0.00 /
      DATA B(81037), B(81038), B(81039) /    -2.29,  -12.66,    0.00 /
      DATA B(81340), B(81341), B(81342) /    -2.78,  -12.58,    0.00 /
      DATA B(81643), B(81644), B(81645) /    -2.98,  -12.37,    0.00 /
      DATA B(81946), B(81947), B(81948) /    -3.04,  -12.16,    0.00 /
      DATA B(82249), B(82250), B(82251) /    -3.09,  -11.76,    0.00 /
      DATA B(82552), B(82553), B(82554) /    -3.18,  -10.82,    0.00 /
      DATA B(82855), B(82856), B(82857) /    -3.09,   -9.69,    0.00 /
      DATA B(83158), B(83159), B(83160) /    -2.91,   -9.15,    0.00 /
      DATA B(83461), B(83462), B(83463) /    -2.96,   -8.97,    0.00 /
      DATA B(83764), B(83765), B(83766) /    -3.14,   -8.63,    0.00 /
      DATA B(84067), B(84068), B(84069) /    -3.21,   -8.12,    0.00 /
      DATA B(84370), B(84371), B(84372) /    -3.19,   -7.61,    0.00 /
      DATA B(84673), B(84674), B(84675) /    -3.13,   -7.22,    0.00 /
      DATA B(84976), B(84977), B(84978) /    -3.09,   -6.99,    0.00 /
      DATA B(85279), B(85280), B(85281) /    -3.13,   -6.85,    0.00 /
      DATA B(85582), B(85583), B(85584) /    -3.24,   -6.64,    0.00 /
      DATA B(85885), B(85886), B(85887) /    -3.38,   -6.25,    0.00 /
      DATA B(86188), B(86189), B(86190) /    -3.54,   -5.62,    0.00 /
      DATA B(86491), B(86492), B(86493) /    -3.26,   -4.67,    0.00 /
      DATA B(86794), B(86795), B(86796) /    -3.66,   -4.20,    0.00 /
      DATA B(87097), B(87098), B(87099) /    -3.91,   -3.84,    0.00 /
      DATA B(87400), B(87401), B(87402) /    -4.18,   -3.60,    0.00 /
      DATA B(87703), B(87704), B(87705) /    -4.77,   -3.93,    0.00 /
      DATA B(88006), B(88007), B(88008) /    -5.30,   -4.26,    0.00 /
      DATA B(88309), B(88310), B(88311) /    -5.63,   -4.73,    0.00 /
      DATA B(88612), B(88613), B(88614) /    -5.97,   -5.98,    0.00 /
      DATA B(88915), B(88916), B(88917) /    -6.26,   -7.38,    0.00 /
      DATA B(89218), B(89219), B(89220) /    -6.84,   -8.20,    0.00 /
      DATA B(89521), B(89522), B(89523) /    -7.29,   -8.72,    0.00 /
      DATA B(67708), B(67709), B(67710) /    26.56,  -46.64,    0.00 /
      DATA B(68011), B(68012), B(68013) /    26.56,  -46.40,    0.00 /
      DATA B(68314), B(68315), B(68316) /    26.55,  -46.15,    0.00 /
      DATA B(68617), B(68618), B(68619) /    26.55,  -45.91,    0.00 /
      DATA B(68920), B(68921), B(68922) /    26.55,  -45.66,    0.00 /
      DATA B(69223), B(69224), B(69225) /    26.54,  -45.42,    0.00 /
      DATA B(69526), B(69527), B(69528) /    26.54,  -45.17,    0.00 /
      DATA B(69829), B(69830), B(69831) /    26.53,  -44.92,    0.00 /
      DATA B(70132), B(70133), B(70134) /    26.52,  -44.67,    0.00 /
      DATA B(70435), B(70436), B(70437) /    26.51,  -44.42,    0.00 /
      DATA B(70738), B(70739), B(70740) /    26.50,  -44.18,    0.00 /
      DATA B(71041), B(71042), B(71043) /    26.49,  -43.93,    0.00 /
      DATA B(71344), B(71345), B(71346) /    26.48,  -43.68,    0.00 /
      DATA B(71647), B(71648), B(71649) /    26.47,  -43.43,    0.00 /
      DATA B(71950), B(71951), B(71952) /    26.45,  -43.18,    0.00 /
      DATA B(72253), B(72254), B(72255) /    26.44,  -42.93,    0.00 /
      DATA B(72556), B(72557), B(72558) /    26.42,  -42.68,    0.00 /
      DATA B(72859), B(72860), B(72861) /    26.40,  -42.43,    0.00 /
      DATA B(73162), B(73163), B(73164) /    26.37,  -42.19,    0.00 /
      DATA B(73465), B(73466), B(73467) /    26.35,  -41.94,    0.00 /
      DATA B(73768), B(73769), B(73770) /    26.32,  -41.69,    0.00 /
      DATA B(74071), B(74072), B(74073) /    26.28,  -41.43,    0.00 /
      DATA B(74374), B(74375), B(74376) /    26.25,  -41.17,    0.00 /
      DATA B(74677), B(74678), B(74679) /    26.21,  -40.89,    0.00 /
      DATA B(74980), B(74981), B(74982) /    26.18,  -40.58,    0.00 /
      DATA B(75283), B(75284), B(75285) /    26.14,  -40.23,    0.00 /
      DATA B(75586), B(75587), B(75588) /    26.07,  -39.83,    0.00 /
      DATA B(75889), B(75890), B(75891) /    25.96,  -39.44,    0.00 /
      DATA B(76192), B(76193), B(76194) /    25.77,  -39.10,    0.00 /
      DATA B(76495), B(76496), B(76497) /    25.45,  -38.80,    0.00 /
      DATA B(76798), B(76799), B(76800) /    24.70,  -38.45,    0.00 /
      DATA B(77101), B(77102), B(77103) /    22.54,  -37.04,    0.00 /
      DATA B(77404), B(77405), B(77406) /    16.10,  -33.31,    0.00 /
      DATA B(77707), B(77708), B(77709) /    14.25,  -32.37,    0.00 /
      DATA B(78010), B(78011), B(78012) /    12.41,  -31.37,    0.00 /
      DATA B(78313), B(78314), B(78315) /     5.78,  -27.74,    0.00 /
      DATA B(78616), B(78617), B(78618) /     2.08,  -26.92,    0.00 /
      DATA B(78919), B(78920), B(78921) /    -2.52,  -23.49,    0.00 /
      DATA B(79222), B(79223), B(79224) /    -3.22,  -20.12,    0.00 /
      DATA B(79525), B(79526), B(79527) /    -3.04,  -17.43,    0.00 /
      DATA B(79828), B(79829), B(79830) /    -3.38,  -15.66,    0.00 /
      DATA B(80131), B(80132), B(80133) /    -3.17,  -14.87,    0.00 /
      DATA B(80434), B(80435), B(80436) /    -2.45,  -14.17,    0.00 /
      DATA B(80737), B(80738), B(80739) /    -2.45,  -13.44,    0.00 /
      DATA B(81040), B(81041), B(81042) /    -3.00,  -13.37,    0.00 /
      DATA B(81343), B(81344), B(81345) /    -3.38,  -13.25,    0.00 /
      DATA B(81646), B(81647), B(81648) /    -3.57,  -13.03,    0.00 /
      DATA B(81949), B(81950), B(81951) /    -3.67,  -12.74,    0.00 /
      DATA B(82252), B(82253), B(82254) /    -3.77,  -12.31,    0.00 /
      DATA B(82555), B(82556), B(82557) /    -3.87,  -11.54,    0.00 /
      DATA B(82858), B(82859), B(82860) /    -3.80,  -10.67,    0.00 /
      DATA B(83161), B(83162), B(83163) /    -3.65,  -10.16,    0.00 /
      DATA B(83464), B(83465), B(83466) /    -3.66,   -9.91,    0.00 /
      DATA B(83767), B(83768), B(83769) /    -3.78,   -9.59,    0.00 /
      DATA B(84070), B(84071), B(84072) /    -3.85,   -9.17,    0.00 /
      DATA B(84373), B(84374), B(84375) /    -3.86,   -8.74,    0.00 /
      DATA B(84676), B(84677), B(84678) /    -3.85,   -8.37,    0.00 /
      DATA B(84979), B(84980), B(84981) /    -3.84,   -8.08,    0.00 /
      DATA B(85282), B(85283), B(85284) /    -3.87,   -7.84,    0.00 /
      DATA B(85585), B(85586), B(85587) /    -3.95,   -7.57,    0.00 /
      DATA B(85888), B(85889), B(85890) /    -4.07,   -7.18,    0.00 /
      DATA B(86191), B(86192), B(86193) /    -4.22,   -6.64,    0.00 /
      DATA B(86494), B(86495), B(86496) /    -4.34,   -6.02,    0.00 /
      DATA B(86797), B(86798), B(86799) /    -4.69,   -5.83,    0.00 /
      DATA B(87100), B(87101), B(87102) /    -4.94,   -5.55,    0.00 /
      DATA B(87403), B(87404), B(87405) /    -5.18,   -5.32,    0.00 /
      DATA B(87706), B(87707), B(87708) /    -5.85,   -5.35,    0.00 /
      DATA B(88009), B(88010), B(88011) /    -6.18,   -5.63,    0.00 /
      DATA B(88312), B(88313), B(88314) /    -6.40,   -5.91,    0.00 /
      DATA B(88615), B(88616), B(88617) /    -6.50,   -6.95,    0.00 /
      DATA B(88918), B(88919), B(88920) /    -6.79,   -8.06,    0.00 /
      DATA B(89221), B(89222), B(89223) /    -7.23,   -8.68,    0.00 /
      DATA B(89524), B(89525), B(89526) /    -7.60,   -9.11,    0.00 /
      DATA B(67711), B(67712), B(67713) /    26.46,  -46.58,    0.00 /
      DATA B(68014), B(68015), B(68016) /    26.46,  -46.33,    0.00 /
      DATA B(68317), B(68318), B(68319) /    26.46,  -46.09,    0.00 /
      DATA B(68620), B(68621), B(68622) /    26.45,  -45.84,    0.00 /
      DATA B(68923), B(68924), B(68925) /    26.45,  -45.59,    0.00 /
      DATA B(69226), B(69227), B(69228) /    26.44,  -45.34,    0.00 /
      DATA B(69529), B(69530), B(69531) /    26.44,  -45.10,    0.00 /
      DATA B(69832), B(69833), B(69834) /    26.43,  -44.85,    0.00 /
      DATA B(70135), B(70136), B(70137) /    26.42,  -44.60,    0.00 /
      DATA B(70438), B(70439), B(70440) /    26.41,  -44.35,    0.00 /
      DATA B(70741), B(70742), B(70743) /    26.40,  -44.10,    0.00 /
      DATA B(71044), B(71045), B(71046) /    26.39,  -43.85,    0.00 /
      DATA B(71347), B(71348), B(71349) /    26.38,  -43.59,    0.00 /
      DATA B(71650), B(71651), B(71652) /    26.37,  -43.34,    0.00 /
      DATA B(71953), B(71954), B(71955) /    26.35,  -43.09,    0.00 /
      DATA B(72256), B(72257), B(72258) /    26.33,  -42.84,    0.00 /
      DATA B(72559), B(72560), B(72561) /    26.31,  -42.60,    0.00 /
      DATA B(72862), B(72863), B(72864) /    26.28,  -42.35,    0.00 /
      DATA B(73165), B(73166), B(73167) /    26.25,  -42.10,    0.00 /
      DATA B(73468), B(73469), B(73470) /    26.22,  -41.85,    0.00 /
      DATA B(73771), B(73772), B(73773) /    26.18,  -41.60,    0.00 /
      DATA B(74074), B(74075), B(74076) /    26.14,  -41.35,    0.00 /
      DATA B(74377), B(74378), B(74379) /    26.09,  -41.08,    0.00 /
      DATA B(74680), B(74681), B(74682) /    26.04,  -40.80,    0.00 /
      DATA B(74983), B(74984), B(74985) /    25.99,  -40.49,    0.00 /
      DATA B(75286), B(75287), B(75288) /    25.93,  -40.11,    0.00 /
      DATA B(75589), B(75590), B(75591) /    25.86,  -39.63,    0.00 /
      DATA B(75892), B(75893), B(75894) /    25.72,  -39.11,    0.00 /
      DATA B(76195), B(76196), B(76197) /    25.49,  -38.74,    0.00 /
      DATA B(76498), B(76499), B(76500) /    25.11,  -38.40,    0.00 /
      DATA B(76801), B(76802), B(76803) /    24.12,  -37.77,    0.00 /
      DATA B(77104), B(77105), B(77106) /    14.21,  -32.33,    0.00 /
      DATA B(77407), B(77408), B(77409) /    13.00,  -31.76,    0.00 /
      DATA B(77710), B(77711), B(77712) /    11.24,  -30.79,    0.00 /
      DATA B(78013), B(78014), B(78015) /     4.79,  -27.96,    0.00 /
      DATA B(78316), B(78317), B(78318) /     1.21,  -27.55,    0.00 /
      DATA B(78619), B(78620), B(78621) /    -2.83,  -24.78,    0.00 /
      DATA B(78922), B(78923), B(78924) /    -4.19,  -22.46,    0.00 /
      DATA B(79225), B(79226), B(79227) /    -4.45,  -20.51,    0.00 /
      DATA B(79528), B(79529), B(79530) /    -4.44,  -18.49,    0.00 /
      DATA B(79831), B(79832), B(79833) /    -4.36,  -16.82,    0.00 /
      DATA B(80134), B(80135), B(80136) /    -3.98,  -16.09,    0.00 /
      DATA B(80437), B(80438), B(80439) /    -3.89,  -15.76,    0.00 /
      DATA B(80740), B(80741), B(80742) /    -3.40,  -14.38,    0.00 /
      DATA B(81043), B(81044), B(81045) /    -3.67,  -13.92,    0.00 /
      DATA B(81346), B(81347), B(81348) /    -3.92,  -13.75,    0.00 /
      DATA B(81649), B(81650), B(81651) /    -4.09,  -13.51,    0.00 /
      DATA B(81952), B(81953), B(81954) /    -4.20,  -13.19,    0.00 /
      DATA B(82255), B(82256), B(82257) /    -4.32,  -12.76,    0.00 /
      DATA B(82558), B(82559), B(82560) /    -4.40,  -12.12,    0.00 /
      DATA B(82861), B(82862), B(82863) /    -4.36,  -11.43,    0.00 /
      DATA B(83164), B(83165), B(83166) /    -4.26,  -10.94,    0.00 /
      DATA B(83467), B(83468), B(83469) /    -4.25,  -10.63,    0.00 /
      DATA B(83770), B(83771), B(83772) /    -4.32,  -10.30,    0.00 /
      DATA B(84073), B(84074), B(84075) /    -4.38,   -9.92,    0.00 /
      DATA B(84376), B(84377), B(84378) /    -4.41,   -9.54,    0.00 /
      DATA B(84679), B(84680), B(84681) /    -4.42,   -9.19,    0.00 /
      DATA B(84982), B(84983), B(84984) /    -4.43,   -8.89,    0.00 /
      DATA B(85285), B(85286), B(85287) /    -4.47,   -8.61,    0.00 /
      DATA B(85588), B(85589), B(85590) /    -4.55,   -8.31,    0.00 /
      DATA B(85891), B(85892), B(85893) /    -4.67,   -7.92,    0.00 /
      DATA B(86194), B(86195), B(86196) /    -4.81,   -7.51,    0.00 /
      DATA B(86497), B(86498), B(86499) /    -5.06,   -7.08,    0.00 /
      DATA B(86800), B(86801), B(86802) /    -5.39,   -7.05,    0.00 /
      DATA B(87103), B(87104), B(87105) /    -5.65,   -6.85,    0.00 /
      DATA B(87406), B(87407), B(87408) /    -5.88,   -6.64,    0.00 /
      DATA B(87709), B(87710), B(87711) /    -6.33,   -6.47,    0.00 /
      DATA B(88012), B(88013), B(88014) /    -6.73,   -6.71,    0.00 /
      DATA B(88315), B(88316), B(88317) /    -6.95,   -6.91,    0.00 /
      DATA B(88618), B(88619), B(88620) /    -6.95,   -7.83,    0.00 /
      DATA B(88921), B(88922), B(88923) /    -7.23,   -8.65,    0.00 /
      DATA B(89224), B(89225), B(89226) /    -7.56,   -9.12,    0.00 /
      DATA B(89527), B(89528), B(89529) /    -7.86,   -9.46,    0.00 /
      DATA B(67714), B(67715), B(67716) /    26.36,  -46.51,    0.00 /
      DATA B(68017), B(68018), B(68019) /    26.36,  -46.26,    0.00 /
      DATA B(68320), B(68321), B(68322) /    26.36,  -46.02,    0.00 /
      DATA B(68623), B(68624), B(68625) /    26.35,  -45.77,    0.00 /
      DATA B(68926), B(68927), B(68928) /    26.35,  -45.52,    0.00 /
      DATA B(69229), B(69230), B(69231) /    26.34,  -45.27,    0.00 /
      DATA B(69532), B(69533), B(69534) /    26.34,  -45.02,    0.00 /
      DATA B(69835), B(69836), B(69837) /    26.33,  -44.77,    0.00 /
      DATA B(70138), B(70139), B(70140) /    26.32,  -44.52,    0.00 /
      DATA B(70441), B(70442), B(70443) /    26.31,  -44.27,    0.00 /
      DATA B(70744), B(70745), B(70746) /    26.30,  -44.01,    0.00 /
      DATA B(71047), B(71048), B(71049) /    26.29,  -43.76,    0.00 /
      DATA B(71350), B(71351), B(71352) /    26.28,  -43.51,    0.00 /
      DATA B(71653), B(71654), B(71655) /    26.26,  -43.26,    0.00 /
      DATA B(71956), B(71957), B(71958) /    26.24,  -43.01,    0.00 /
      DATA B(72259), B(72260), B(72261) /    26.22,  -42.75,    0.00 /
      DATA B(72562), B(72563), B(72564) /    26.20,  -42.50,    0.00 /
      DATA B(72865), B(72866), B(72867) /    26.17,  -42.25,    0.00 /
      DATA B(73168), B(73169), B(73170) /    26.13,  -42.01,    0.00 /
      DATA B(73471), B(73472), B(73473) /    26.09,  -41.76,    0.00 /
      DATA B(73774), B(73775), B(73776) /    26.04,  -41.51,    0.00 /
      DATA B(74077), B(74078), B(74079) /    25.98,  -41.26,    0.00 /
      DATA B(74380), B(74381), B(74382) /    25.92,  -40.99,    0.00 /
      DATA B(74683), B(74684), B(74685) /    25.84,  -40.71,    0.00 /
      DATA B(74986), B(74987), B(74988) /    25.74,  -40.40,    0.00 /
      DATA B(75289), B(75290), B(75291) /    25.64,  -39.98,    0.00 /
      DATA B(75592), B(75593), B(75594) /    25.52,  -39.35,    0.00 /
      DATA B(75895), B(75896), B(75897) /    25.34,  -38.53,    0.00 /
      DATA B(76198), B(76199), B(76200) /    24.97,  -38.15,    0.00 /
      DATA B(76501), B(76502), B(76503) /    24.32,  -37.65,    0.00 /
      DATA B(76804), B(76805), B(76806) /    13.27,  -31.24,    0.00 /
      DATA B(77107), B(77108), B(77109) /    12.01,  -30.99,    0.00 /
      DATA B(77410), B(77411), B(77412) /     6.69,  -27.86,    0.00 /
      DATA B(77713), B(77714), B(77715) /     3.89,  -28.06,    0.00 /
      DATA B(78016), B(78017), B(78018) /     0.23,  -27.72,    0.00 /
      DATA B(78319), B(78320), B(78321) /    -3.11,  -25.08,    0.00 /
      DATA B(78622), B(78623), B(78624) /    -4.36,  -23.40,    0.00 /
      DATA B(78925), B(78926), B(78927) /    -4.90,  -22.09,    0.00 /
      DATA B(79228), B(79229), B(79230) /    -5.17,  -20.79,    0.00 /
      DATA B(79531), B(79532), B(79533) /    -5.25,  -19.22,    0.00 /
      DATA B(79834), B(79835), B(79836) /    -4.93,  -17.68,    0.00 /
      DATA B(80137), B(80138), B(80139) /    -4.45,  -16.82,    0.00 /
      DATA B(80440), B(80441), B(80442) /    -4.45,  -16.51,    0.00 /
      DATA B(80743), B(80744), B(80745) /    -4.33,  -15.17,    0.00 /
      DATA B(81046), B(81047), B(81048) /    -4.28,  -14.39,    0.00 /
      DATA B(81349), B(81350), B(81351) /    -4.43,  -14.18,    0.00 /
      DATA B(81652), B(81653), B(81654) /    -4.56,  -13.91,    0.00 /
      DATA B(81955), B(81956), B(81957) /    -4.67,  -13.58,    0.00 /
      DATA B(82258), B(82259), B(82260) /    -4.78,  -13.15,    0.00 /
      DATA B(82561), B(82562), B(82563) /    -4.85,  -12.61,    0.00 /
      DATA B(82864), B(82865), B(82866) /    -4.83,  -12.03,    0.00 /
      DATA B(83167), B(83168), B(83169) /    -4.77,  -11.57,    0.00 /
      DATA B(83470), B(83471), B(83472) /    -4.77,  -11.22,    0.00 /
      DATA B(83773), B(83774), B(83775) /    -4.81,  -10.88,    0.00 /
      DATA B(84076), B(84077), B(84078) /    -4.86,  -10.51,    0.00 /
      DATA B(84379), B(84380), B(84381) /    -4.91,  -10.16,    0.00 /
      DATA B(84682), B(84683), B(84684) /    -4.94,   -9.84,    0.00 /
      DATA B(84985), B(84986), B(84987) /    -4.97,   -9.57,    0.00 /
      DATA B(85288), B(85289), B(85290) /    -5.02,   -9.29,    0.00 /
      DATA B(85591), B(85592), B(85593) /    -5.13,   -8.97,    0.00 /
      DATA B(85894), B(85895), B(85896) /    -5.24,   -8.62,    0.00 /
      DATA B(86197), B(86198), B(86199) /    -5.42,   -8.29,    0.00 /
      DATA B(86500), B(86501), B(86502) /    -5.65,   -7.93,    0.00 /
      DATA B(86803), B(86804), B(86805) /    -5.95,   -8.02,    0.00 /
      DATA B(87106), B(87107), B(87108) /    -6.24,   -7.89,    0.00 /
      DATA B(87409), B(87410), B(87411) /    -6.50,   -7.70,    0.00 /
      DATA B(87712), B(87713), B(87714) /    -6.81,   -7.53,    0.00 /
      DATA B(88015), B(88016), B(88017) /    -7.17,   -7.53,    0.00 /
      DATA B(88318), B(88319), B(88320) /    -7.34,   -7.75,    0.00 /
      DATA B(88621), B(88622), B(88623) /    -7.31,   -8.59,    0.00 /
      DATA B(88924), B(88925), B(88926) /    -7.58,   -9.16,    0.00 /
      DATA B(89227), B(89228), B(89229) /    -7.85,   -9.50,    0.00 /
      DATA B(89530), B(89531), B(89532) /    -8.09,   -9.78,    0.00 /
      DATA B(67717), B(67718), B(67719) /    26.26,  -46.44,    0.00 /
      DATA B(68020), B(68021), B(68022) /    26.26,  -46.20,    0.00 /
      DATA B(68323), B(68324), B(68325) /    26.26,  -45.95,    0.00 /
      DATA B(68626), B(68627), B(68628) /    26.25,  -45.70,    0.00 /
      DATA B(68929), B(68930), B(68931) /    26.25,  -45.45,    0.00 /
      DATA B(69232), B(69233), B(69234) /    26.24,  -45.20,    0.00 /
      DATA B(69535), B(69536), B(69537) /    26.24,  -44.95,    0.00 /
      DATA B(69838), B(69839), B(69840) /    26.23,  -44.69,    0.00 /
      DATA B(70141), B(70142), B(70143) /    26.22,  -44.44,    0.00 /
      DATA B(70444), B(70445), B(70446) /    26.21,  -44.19,    0.00 /
      DATA B(70747), B(70748), B(70749) /    26.20,  -43.93,    0.00 /
      DATA B(71050), B(71051), B(71052) /    26.19,  -43.68,    0.00 /
      DATA B(71353), B(71354), B(71355) /    26.17,  -43.42,    0.00 /
      DATA B(71656), B(71657), B(71658) /    26.16,  -43.17,    0.00 /
      DATA B(71959), B(71960), B(71961) /    26.14,  -42.92,    0.00 /
      DATA B(72262), B(72263), B(72264) /    26.11,  -42.66,    0.00 /
      DATA B(72565), B(72566), B(72567) /    26.08,  -42.41,    0.00 /
      DATA B(72868), B(72869), B(72870) /    26.05,  -42.16,    0.00 /
      DATA B(73171), B(73172), B(73173) /    26.00,  -41.91,    0.00 /
      DATA B(73474), B(73475), B(73476) /    25.95,  -41.66,    0.00 /
      DATA B(73777), B(73778), B(73779) /    25.89,  -41.41,    0.00 /
      DATA B(74080), B(74081), B(74082) /    25.81,  -41.16,    0.00 /
      DATA B(74383), B(74384), B(74385) /    25.72,  -40.89,    0.00 /
      DATA B(74686), B(74687), B(74688) /    25.59,  -40.60,    0.00 /
      DATA B(74989), B(74990), B(74991) /    25.41,  -40.31,    0.00 /
      DATA B(75292), B(75293), B(75294) /    25.17,  -39.83,    0.00 /
      DATA B(75595), B(75596), B(75597) /    24.74,  -38.91,    0.00 /
      DATA B(75898), B(75899), B(75900) /    24.17,  -37.38,    0.00 /
      DATA B(76201), B(76202), B(76203) /    24.04,  -37.25,    0.00 /
      DATA B(76504), B(76505), B(76506) /    12.91,  -30.57,    0.00 /
      DATA B(76807), B(76808), B(76809) /    11.32,  -30.07,    0.00 /
      DATA B(77110), B(77111), B(77112) /     5.74,  -27.60,    0.00 /
      DATA B(77413), B(77414), B(77415) /     3.03,  -27.98,    0.00 /
      DATA B(77716), B(77717), B(77718) /    -1.01,  -27.08,    0.00 /
      DATA B(78019), B(78020), B(78021) /    -3.34,  -25.01,    0.00 /
      DATA B(78322), B(78323), B(78324) /    -4.32,  -23.71,    0.00 /
      DATA B(78625), B(78626), B(78627) /    -4.86,  -22.75,    0.00 /
      DATA B(78928), B(78929), B(78930) /    -5.22,  -21.85,    0.00 /
      DATA B(79231), B(79232), B(79233) /    -5.48,  -20.84,    0.00 /
      DATA B(79534), B(79535), B(79536) /    -5.56,  -19.61,    0.00 /
      DATA B(79837), B(79838), B(79839) /    -5.23,  -18.39,    0.00 /
      DATA B(80140), B(80141), B(80142) /    -4.68,  -17.27,    0.00 /
      DATA B(80443), B(80444), B(80445) /    -4.65,  -16.80,    0.00 /
      DATA B(80746), B(80747), B(80748) /    -4.72,  -15.62,    0.00 /
      DATA B(81049), B(81050), B(81051) /    -4.78,  -14.82,    0.00 /
      DATA B(81352), B(81353), B(81354) /    -4.89,  -14.56,    0.00 /
      DATA B(81655), B(81656), B(81657) /    -5.00,  -14.28,    0.00 /
      DATA B(81958), B(81959), B(81960) /    -5.11,  -13.94,    0.00 /
      DATA B(82261), B(82262), B(82263) /    -5.19,  -13.52,    0.00 /
      DATA B(82564), B(82565), B(82566) /    -5.25,  -13.04,    0.00 /
      DATA B(82867), B(82868), B(82869) /    -5.25,  -12.54,    0.00 /
      DATA B(83170), B(83171), B(83172) /    -5.23,  -12.10,    0.00 /
      DATA B(83473), B(83474), B(83475) /    -5.23,  -11.72,    0.00 /
      DATA B(83776), B(83777), B(83778) /    -5.26,  -11.36,    0.00 /
      DATA B(84079), B(84080), B(84081) /    -5.31,  -11.01,    0.00 /
      DATA B(84382), B(84383), B(84384) /    -5.38,  -10.68,    0.00 /
      DATA B(84685), B(84686), B(84687) /    -5.47,  -10.43,    0.00 /
      DATA B(84988), B(84989), B(84990) /    -5.53,  -10.23,    0.00 /
      DATA B(85291), B(85292), B(85293) /    -5.61,   -9.90,    0.00 /
      DATA B(85594), B(85595), B(85596) /    -5.71,   -9.58,    0.00 /
      DATA B(85897), B(85898), B(85899) /    -5.85,   -9.33,    0.00 /
      DATA B(86200), B(86201), B(86202) /    -5.98,   -8.98,    0.00 /
      DATA B(86503), B(86504), B(86505) /    -6.16,   -8.64,    0.00 /
      DATA B(86806), B(86807), B(86808) /    -6.49,   -8.85,    0.00 /
      DATA B(87109), B(87110), B(87111) /    -6.78,   -8.76,    0.00 /
      DATA B(87412), B(87413), B(87414) /    -7.06,   -8.58,    0.00 /
      DATA B(87715), B(87716), B(87717) /    -7.44,   -8.36,    0.00 /
      DATA B(88018), B(88019), B(88020) /    -7.64,   -8.34,    0.00 /
      DATA B(88321), B(88322), B(88323) /    -7.56,   -8.45,    0.00 /
      DATA B(88624), B(88625), B(88626) /    -7.60,   -9.24,    0.00 /
      DATA B(88927), B(88928), B(88929) /    -7.87,   -9.59,    0.00 /
      DATA B(89230), B(89231), B(89232) /    -8.09,   -9.85,    0.00 /
      DATA B(89533), B(89534), B(89535) /    -8.30,  -10.08,    0.00 /
      DATA B(67720), B(67721), B(67722) /    26.16,  -46.38,    0.00 /
      DATA B(68023), B(68024), B(68025) /    26.16,  -46.13,    0.00 /
      DATA B(68326), B(68327), B(68328) /    26.16,  -45.88,    0.00 /
      DATA B(68629), B(68630), B(68631) /    26.15,  -45.63,    0.00 /
      DATA B(68932), B(68933), B(68934) /    26.15,  -45.38,    0.00 /
      DATA B(69235), B(69236), B(69237) /    26.14,  -45.12,    0.00 /
      DATA B(69538), B(69539), B(69540) /    26.14,  -44.87,    0.00 /
      DATA B(69841), B(69842), B(69843) /    26.13,  -44.61,    0.00 /
      DATA B(70144), B(70145), B(70146) /    26.12,  -44.36,    0.00 /
      DATA B(70447), B(70448), B(70449) /    26.11,  -44.10,    0.00 /
      DATA B(70750), B(70751), B(70752) /    26.10,  -43.85,    0.00 /
      DATA B(71053), B(71054), B(71055) /    26.08,  -43.59,    0.00 /
      DATA B(71356), B(71357), B(71358) /    26.07,  -43.33,    0.00 /
      DATA B(71659), B(71660), B(71661) /    26.05,  -43.08,    0.00 /
      DATA B(71962), B(71963), B(71964) /    26.03,  -42.82,    0.00 /
      DATA B(72265), B(72266), B(72267) /    26.00,  -42.56,    0.00 /
      DATA B(72568), B(72569), B(72570) /    25.97,  -42.31,    0.00 /
      DATA B(72871), B(72872), B(72873) /    25.93,  -42.05,    0.00 /
      DATA B(73174), B(73175), B(73176) /    25.87,  -41.80,    0.00 /
      DATA B(73477), B(73478), B(73479) /    25.81,  -41.55,    0.00 /
      DATA B(73780), B(73781), B(73782) /    25.72,  -41.30,    0.00 /
      DATA B(74083), B(74084), B(74085) /    25.61,  -41.05,    0.00 /
      DATA B(74386), B(74387), B(74388) /    25.47,  -40.77,    0.00 /
      DATA B(74689), B(74690), B(74691) /    25.30,  -40.41,    0.00 /
      DATA B(74992), B(74993), B(74994) /    24.95,  -40.19,    0.00 /
      DATA B(75295), B(75296), B(75297) /    24.31,  -39.58,    0.00 /
      DATA B(75598), B(75599), B(75600) /    22.51,  -37.67,    0.00 /
      DATA B(75901), B(75902), B(75903) /    18.87,  -33.76,    0.00 /
      DATA B(76204), B(76205), B(76206) /    13.79,  -29.77,    0.00 /
      DATA B(76507), B(76508), B(76509) /     7.28,  -26.57,    0.00 /
      DATA B(76810), B(76811), B(76812) /     4.63,  -27.26,    0.00 /
      DATA B(77113), B(77114), B(77115) /     1.78,  -27.53,    0.00 /
      DATA B(77416), B(77417), B(77418) /    -1.82,  -26.55,    0.00 /
      DATA B(77719), B(77720), B(77721) /    -3.51,  -24.84,    0.00 /
      DATA B(78022), B(78023), B(78024) /    -4.25,  -23.77,    0.00 /
      DATA B(78325), B(78326), B(78327) /    -4.70,  -23.01,    0.00 /
      DATA B(78628), B(78629), B(78630) /    -5.04,  -22.33,    0.00 /
      DATA B(78931), B(78932), B(78933) /    -5.32,  -21.63,    0.00 /
      DATA B(79234), B(79235), B(79236) /    -5.54,  -20.82,    0.00 /
      DATA B(79537), B(79538), B(79539) /    -5.59,  -19.88,    0.00 /
      DATA B(79840), B(79841), B(79842) /    -5.29,  -18.87,    0.00 /
      DATA B(80143), B(80144), B(80145) /    -4.67,  -17.46,    0.00 /
      DATA B(80446), B(80447), B(80448) /    -4.72,  -16.81,    0.00 /
      DATA B(80749), B(80750), B(80751) /    -4.98,  -15.82,    0.00 /
      DATA B(81052), B(81053), B(81054) /    -5.16,  -15.20,    0.00 /
      DATA B(81355), B(81356), B(81357) /    -5.31,  -14.92,    0.00 /
      DATA B(81658), B(81659), B(81660) /    -5.42,  -14.62,    0.00 /
      DATA B(81961), B(81962), B(81963) /    -5.52,  -14.27,    0.00 /
      DATA B(82264), B(82265), B(82266) /    -5.59,  -13.88,    0.00 /
      DATA B(82567), B(82568), B(82569) /    -5.63,  -13.43,    0.00 /
      DATA B(82870), B(82871), B(82872) /    -5.64,  -12.98,    0.00 /
      DATA B(83173), B(83174), B(83175) /    -5.64,  -12.55,    0.00 /
      DATA B(83476), B(83477), B(83478) /    -5.65,  -12.15,    0.00 /
      DATA B(83779), B(83780), B(83781) /    -5.69,  -11.79,    0.00 /
      DATA B(84082), B(84083), B(84084) /    -5.75,  -11.44,    0.00 /
      DATA B(84385), B(84386), B(84387) /    -5.86,  -11.13,    0.00 /
      DATA B(84688), B(84689), B(84690) /    -6.05,  -10.99,    0.00 /
      DATA B(84991), B(84992), B(84993) /    -6.16,  -10.80,    0.00 /
      DATA B(85294), B(85295), B(85296) /    -6.28,  -10.57,    0.00 /
      DATA B(85597), B(85598), B(85599) /    -6.36,  -10.30,    0.00 /
      DATA B(85900), B(85901), B(85902) /    -6.44,   -9.98,    0.00 /
      DATA B(86203), B(86204), B(86205) /    -6.52,   -9.61,    0.00 /
      DATA B(86506), B(86507), B(86508) /    -6.65,   -9.26,    0.00 /
      DATA B(86809), B(86810), B(86811) /    -7.00,   -9.60,    0.00 /
      DATA B(87112), B(87113), B(87114) /    -7.27,   -9.55,    0.00 /
      DATA B(87415), B(87416), B(87417) /    -7.52,   -9.35,    0.00 /
      DATA B(87718), B(87719), B(87720) /    -7.83,   -9.19,    0.00 /
      DATA B(88021), B(88022), B(88023) /    -7.93,   -9.05,    0.00 /
      DATA B(88324), B(88325), B(88326) /    -7.84,   -9.09,    0.00 /
      DATA B(88627), B(88628), B(88629) /    -8.00,   -9.79,    0.00 /
      DATA B(88930), B(88931), B(88932) /    -8.14,   -9.97,    0.00 /
      DATA B(89233), B(89234), B(89235) /    -8.31,  -10.18,    0.00 /
      DATA B(89536), B(89537), B(89538) /    -8.50,  -10.38,    0.00 /
      DATA B(67723), B(67724), B(67725) /    26.06,  -46.31,    0.00 /
      DATA B(68026), B(68027), B(68028) /    26.06,  -46.06,    0.00 /
      DATA B(68329), B(68330), B(68331) /    26.06,  -45.81,    0.00 /
      DATA B(68632), B(68633), B(68634) /    26.05,  -45.56,    0.00 /
      DATA B(68935), B(68936), B(68937) /    26.05,  -45.30,    0.00 /
      DATA B(69238), B(69239), B(69240) /    26.04,  -45.05,    0.00 /
      DATA B(69541), B(69542), B(69543) /    26.03,  -44.79,    0.00 /
      DATA B(69844), B(69845), B(69846) /    26.03,  -44.53,    0.00 /
      DATA B(70147), B(70148), B(70149) /    26.02,  -44.28,    0.00 /
      DATA B(70450), B(70451), B(70452) /    26.01,  -44.02,    0.00 /
      DATA B(70753), B(70754), B(70755) /    25.99,  -43.76,    0.00 /
      DATA B(71056), B(71057), B(71058) /    25.98,  -43.50,    0.00 /
      DATA B(71359), B(71360), B(71361) /    25.96,  -43.24,    0.00 /
      DATA B(71662), B(71663), B(71664) /    25.94,  -42.98,    0.00 /
      DATA B(71965), B(71966), B(71967) /    25.92,  -42.72,    0.00 /
      DATA B(72268), B(72269), B(72270) /    25.89,  -42.46,    0.00 /
      DATA B(72571), B(72572), B(72573) /    25.85,  -42.20,    0.00 /
      DATA B(72874), B(72875), B(72876) /    25.81,  -41.93,    0.00 /
      DATA B(73177), B(73178), B(73179) /    25.74,  -41.67,    0.00 /
      DATA B(73480), B(73481), B(73482) /    25.65,  -41.42,    0.00 /
      DATA B(73783), B(73784), B(73785) /    25.54,  -41.17,    0.00 /
      DATA B(74086), B(74087), B(74088) /    25.36,  -40.90,    0.00 /
      DATA B(74389), B(74390), B(74391) /    25.09,  -40.60,    0.00 /
      DATA B(74692), B(74693), B(74694) /    24.67,  -40.16,    0.00 /
      DATA B(74995), B(74996), B(74997) /    24.70,  -40.19,    0.00 /
      DATA B(75298), B(75299), B(75300) /    21.92,  -37.91,    0.00 /
      DATA B(75601), B(75602), B(75603) /    16.64,  -33.25,    0.00 /
      DATA B(75904), B(75905), B(75906) /    12.80,  -30.51,    0.00 /
      DATA B(76207), B(76208), B(76209) /     6.18,  -26.44,    0.00 /
      DATA B(76510), B(76511), B(76512) /     2.87,  -26.87,    0.00 /
      DATA B(76813), B(76814), B(76815) /    -0.58,  -26.46,    0.00 /
      DATA B(77116), B(77117), B(77118) /    -2.51,  -25.63,    0.00 /
      DATA B(77419), B(77420), B(77421) /    -3.60,  -24.60,    0.00 /
      DATA B(77722), B(77723), B(77724) /    -4.15,  -23.74,    0.00 /
      DATA B(78025), B(78026), B(78027) /    -4.52,  -23.11,    0.00 /
      DATA B(78328), B(78329), B(78330) /    -4.83,  -22.56,    0.00 /
      DATA B(78631), B(78632), B(78633) /    -5.09,  -22.02,    0.00 /
      DATA B(78934), B(78935), B(78936) /    -5.31,  -21.44,    0.00 /
      DATA B(79237), B(79238), B(79239) /    -5.48,  -20.78,    0.00 /
      DATA B(79540), B(79541), B(79542) /    -5.53,  -20.03,    0.00 /
      DATA B(79843), B(79844), B(79845) /    -5.27,  -19.12,    0.00 /
      DATA B(80146), B(80147), B(80148) /    -4.48,  -17.39,    0.00 /
      DATA B(80449), B(80450), B(80451) /    -4.59,  -16.56,    0.00 /
      DATA B(80752), B(80753), B(80754) /    -5.10,  -15.87,    0.00 /
      DATA B(81055), B(81056), B(81057) /    -5.50,  -15.52,    0.00 /
      DATA B(81358), B(81359), B(81360) /    -5.72,  -15.25,    0.00 /
      DATA B(81661), B(81662), B(81663) /    -6.07,  -14.91,    0.00 /
      DATA B(81964), B(81965), B(81966) /    -5.91,  -14.60,    0.00 /
      DATA B(82267), B(82268), B(82269) /    -5.97,  -14.22,    0.00 /
      DATA B(82570), B(82571), B(82572) /    -6.01,  -13.80,    0.00 /
      DATA B(82873), B(82874), B(82875) /    -6.03,  -13.37,    0.00 /
      DATA B(83176), B(83177), B(83178) /    -6.03,  -12.94,    0.00 /
      DATA B(83479), B(83480), B(83481) /    -6.05,  -12.53,    0.00 /
      DATA B(83782), B(83783), B(83784) /    -6.10,  -12.16,    0.00 /
      DATA B(84085), B(84086), B(84087) /    -6.18,  -11.82,    0.00 /
      DATA B(84388), B(84389), B(84390) /    -6.38,  -11.53,    0.00 /
      DATA B(84691), B(84692), B(84693) /    -6.60,  -11.56,    0.00 /
      DATA B(84994), B(84995), B(84996) /    -6.83,  -11.49,    0.00 /
      DATA B(85297), B(85298), B(85299) /    -6.91,  -11.28,    0.00 /
      DATA B(85600), B(85601), B(85602) /    -6.96,  -10.95,    0.00 /
      DATA B(85903), B(85904), B(85905) /    -7.01,  -10.58,    0.00 /
      DATA B(86206), B(86207), B(86208) /    -7.05,  -10.20,    0.00 /
      DATA B(86509), B(86510), B(86511) /    -7.09,   -9.83,    0.00 /
      DATA B(86812), B(86813), B(86814) /    -7.45,  -10.34,    0.00 /
      DATA B(87115), B(87116), B(87117) /    -7.75,  -10.27,    0.00 /
      DATA B(87418), B(87419), B(87420) /    -7.94,  -10.12,    0.00 /
      DATA B(87721), B(87722), B(87723) /    -8.13,   -9.73,    0.00 /
      DATA B(88024), B(88025), B(88026) /    -8.16,   -9.68,    0.00 /
      DATA B(88327), B(88328), B(88329) /    -8.17,  -10.24,    0.00 /
      DATA B(88630), B(88631), B(88632) /    -8.26,  -10.21,    0.00 /
      DATA B(88933), B(88934), B(88935) /    -8.36,  -10.32,    0.00 /
      DATA B(89236), B(89237), B(89238) /    -8.52,  -10.50,    0.00 /
      DATA B(89539), B(89540), B(89541) /    -8.70,  -10.70,    0.00 /
      DATA B(67726), B(67727), B(67728) /    25.96,  -46.24,    0.00 /
      DATA B(68029), B(68030), B(68031) /    25.96,  -45.99,    0.00 /
      DATA B(68332), B(68333), B(68334) /    25.95,  -45.74,    0.00 /
      DATA B(68635), B(68636), B(68637) /    25.95,  -45.49,    0.00 /
      DATA B(68938), B(68939), B(68940) /    25.94,  -45.23,    0.00 /
      DATA B(69241), B(69242), B(69243) /    25.94,  -44.97,    0.00 /
      DATA B(69544), B(69545), B(69546) /    25.93,  -44.71,    0.00 /
      DATA B(69847), B(69848), B(69849) /    25.92,  -44.45,    0.00 /
      DATA B(70150), B(70151), B(70152) /    25.91,  -44.19,    0.00 /
      DATA B(70453), B(70454), B(70455) /    25.90,  -43.93,    0.00 /
      DATA B(70756), B(70757), B(70758) /    25.89,  -43.67,    0.00 /
      DATA B(71059), B(71060), B(71061) /    25.87,  -43.40,    0.00 /
      DATA B(71362), B(71363), B(71364) /    25.86,  -43.14,    0.00 /
      DATA B(71665), B(71666), B(71667) /    25.83,  -42.88,    0.00 /
      DATA B(71968), B(71969), B(71970) /    25.81,  -42.62,    0.00 /
      DATA B(72271), B(72272), B(72273) /    25.78,  -42.35,    0.00 /
      DATA B(72574), B(72575), B(72576) /    25.74,  -42.08,    0.00 /
      DATA B(72877), B(72878), B(72879) /    25.68,  -41.80,    0.00 /
      DATA B(73180), B(73181), B(73182) /    25.60,  -41.53,    0.00 /
      DATA B(73483), B(73484), B(73485) /    25.49,  -41.26,    0.00 /
      DATA B(73786), B(73787), B(73788) /    25.32,  -40.99,    0.00 /
      DATA B(74089), B(74090), B(74091) /    25.05,  -40.69,    0.00 /
      DATA B(74392), B(74393), B(74394) /    24.46,  -40.25,    0.00 /
      DATA B(74695), B(74696), B(74697) /    25.31,  -39.88,    0.00 /
      DATA B(74998), B(74999), B(75000) /    22.98,  -38.15,    0.00 /
      DATA B(75301), B(75302), B(75303) /    14.41,  -32.84,    0.00 /
      DATA B(75604), B(75605), B(75606) /    10.99,  -30.14,    0.00 /
      DATA B(75907), B(75908), B(75909) /     4.35,  -26.71,    0.00 /
      DATA B(76210), B(76211), B(76212) /     0.37,  -26.18,    0.00 /
      DATA B(76513), B(76514), B(76515) /    -1.66,  -25.13,    0.00 /
      DATA B(76816), B(76817), B(76818) /    -2.74,  -24.57,    0.00 /
      DATA B(77119), B(77120), B(77121) /    -3.45,  -24.09,    0.00 /
      DATA B(77422), B(77423), B(77424) /    -3.95,  -23.59,    0.00 /
      DATA B(77725), B(77726), B(77727) /    -4.31,  -23.11,    0.00 /
      DATA B(78028), B(78029), B(78030) /    -4.59,  -22.66,    0.00 /
      DATA B(78331), B(78332), B(78333) /    -4.84,  -22.22,    0.00 /
      DATA B(78634), B(78635), B(78636) /    -5.06,  -21.76,    0.00 /
      DATA B(78937), B(78938), B(78939) /    -5.25,  -21.26,    0.00 /
      DATA B(79240), B(79241), B(79242) /    -5.40,  -20.69,    0.00 /
      DATA B(79543), B(79544), B(79545) /    -5.45,  -20.04,    0.00 /
      DATA B(79846), B(79847), B(79848) /    -5.22,  -19.15,    0.00 /
      DATA B(80149), B(80150), B(80151) /    -4.18,  -17.08,    0.00 /
      DATA B(80452), B(80453), B(80454) /    -4.14,  -16.13,    0.00 /
      DATA B(80755), B(80756), B(80757) /    -4.42,  -15.50,    0.00 /
      DATA B(81058), B(81059), B(81060) /    -5.78,  -15.54,    0.00 /
      DATA B(81361), B(81362), B(81363) /    -6.01,  -15.33,    0.00 /
      DATA B(81664), B(81665), B(81666) /    -6.15,  -15.04,    0.00 /
      DATA B(81967), B(81968), B(81969) /    -6.27,  -14.71,    0.00 /
      DATA B(82270), B(82271), B(82272) /    -6.38,  -14.35,    0.00 /
      DATA B(82573), B(82574), B(82575) /    -6.47,  -13.96,    0.00 /
      DATA B(82876), B(82877), B(82878) /    -6.40,  -13.73,    0.00 /
      DATA B(83179), B(83180), B(83181) /    -6.40,  -13.28,    0.00 /
      DATA B(83482), B(83483), B(83484) /    -6.42,  -12.84,    0.00 /
      DATA B(83785), B(83786), B(83787) /    -6.49,  -12.46,    0.00 /
      DATA B(84088), B(84089), B(84090) /    -6.61,  -12.14,    0.00 /
      DATA B(84391), B(84392), B(84393) /    -6.94,  -12.09,    0.00 /
      DATA B(84694), B(84695), B(84696) /    -7.24,  -11.97,    0.00 /
      DATA B(84997), B(84998), B(84999) /    -7.46,  -12.07,    0.00 /
      DATA B(85300), B(85301), B(85302) /    -7.48,  -11.92,    0.00 /
      DATA B(85603), B(85604), B(85605) /    -7.53,  -11.55,    0.00 /
      DATA B(85906), B(85907), B(85908) /    -7.56,  -10.90,    0.00 /
      DATA B(86209), B(86210), B(86211) /    -7.67,  -10.77,    0.00 /
      DATA B(86512), B(86513), B(86514) /    -7.76,  -10.65,    0.00 /
      DATA B(86815), B(86816), B(86817) /    -7.86,  -10.50,    0.00 /
      DATA B(87118), B(87119), B(87120) /    -8.01,  -10.41,    0.00 /
      DATA B(87421), B(87422), B(87423) /    -8.15,  -10.25,    0.00 /
      DATA B(87724), B(87725), B(87726) /    -8.30,  -10.09,    0.00 /
      DATA B(88027), B(88028), B(88029) /    -8.30,  -10.26,    0.00 /
      DATA B(88330), B(88331), B(88332) /    -8.33,  -10.52,    0.00 /
      DATA B(88633), B(88634), B(88635) /    -8.43,  -10.52,    0.00 /
      DATA B(88936), B(88937), B(88938) /    -8.56,  -10.62,    0.00 /
      DATA B(89239), B(89240), B(89241) /    -8.73,  -10.84,    0.00 /
      DATA B(89542), B(89543), B(89544) /    -8.92,  -11.07,    0.00 /
      DATA B(67729), B(67730), B(67731) /    25.86,  -46.18,    0.00 /
      DATA B(68032), B(68033), B(68034) /    25.85,  -45.92,    0.00 /
      DATA B(68335), B(68336), B(68337) /    25.85,  -45.67,    0.00 /
      DATA B(68638), B(68639), B(68640) /    25.85,  -45.41,    0.00 /
      DATA B(68941), B(68942), B(68943) /    25.84,  -45.15,    0.00 /
      DATA B(69244), B(69245), B(69246) /    25.83,  -44.89,    0.00 /
      DATA B(69547), B(69548), B(69549) /    25.83,  -44.63,    0.00 /
      DATA B(69850), B(69851), B(69852) /    25.82,  -44.37,    0.00 /
      DATA B(70153), B(70154), B(70155) /    25.81,  -44.10,    0.00 /
      DATA B(70456), B(70457), B(70458) /    25.80,  -43.84,    0.00 /
      DATA B(70759), B(70760), B(70761) /    25.79,  -43.57,    0.00 /
      DATA B(71062), B(71063), B(71064) /    25.77,  -43.30,    0.00 /
      DATA B(71365), B(71366), B(71367) /    25.75,  -43.04,    0.00 /
      DATA B(71668), B(71669), B(71670) /    25.72,  -42.77,    0.00 /
      DATA B(71971), B(71972), B(71973) /    25.69,  -42.50,    0.00 /
      DATA B(72274), B(72275), B(72276) /    25.66,  -42.23,    0.00 /
      DATA B(72577), B(72578), B(72579) /    25.61,  -41.95,    0.00 /
      DATA B(72880), B(72881), B(72882) /    25.55,  -41.65,    0.00 /
      DATA B(73183), B(73184), B(73185) /    25.45,  -41.35,    0.00 /
      DATA B(73486), B(73487), B(73488) /    25.30,  -41.05,    0.00 /
      DATA B(73789), B(73790), B(73791) /    25.04,  -40.73,    0.00 /
      DATA B(74092), B(74093), B(74094) /    24.52,  -40.31,    0.00 /
      DATA B(74395), B(74396), B(74397) /    25.34,  -40.28,    0.00 /
      DATA B(74698), B(74699), B(74700) /    23.69,  -38.60,    0.00 /
      DATA B(75001), B(75002), B(75003) /    21.93,  -37.59,    0.00 /
      DATA B(75304), B(75305), B(75306) /    10.88,  -30.60,    0.00 /
      DATA B(75607), B(75608), B(75609) /     0.69,  -25.63,    0.00 /
      DATA B(75910), B(75911), B(75912) /    -1.86,  -24.08,    0.00 /
      DATA B(76213), B(76214), B(76215) /    -2.18,  -24.38,    0.00 /
      DATA B(76516), B(76517), B(76518) /    -2.81,  -23.94,    0.00 /
      DATA B(76819), B(76820), B(76821) /    -3.29,  -23.62,    0.00 /
      DATA B(77122), B(77123), B(77124) /    -3.70,  -23.32,    0.00 /
      DATA B(77425), B(77426), B(77427) /    -4.04,  -23.00,    0.00 /
      DATA B(77728), B(77729), B(77730) /    -4.33,  -22.66,    0.00 /
      DATA B(78031), B(78032), B(78033) /    -4.57,  -22.30,    0.00 /
      DATA B(78334), B(78335), B(78336) /    -4.79,  -21.93,    0.00 /
      DATA B(78637), B(78638), B(78639) /    -4.99,  -21.52,    0.00 /
      DATA B(78940), B(78941), B(78942) /    -5.17,  -21.07,    0.00 /
      DATA B(79243), B(79244), B(79245) /    -5.31,  -20.54,    0.00 /
      DATA B(79546), B(79547), B(79548) /    -5.40,  -19.90,    0.00 /
      DATA B(79849), B(79850), B(79851) /    -5.36,  -18.96,    0.00 /
      DATA B(80152), B(80153), B(80154) /    -6.46,  -16.90,    0.00 /
      DATA B(80455), B(80456), B(80457) /    -6.15,  -16.24,    0.00 /
      DATA B(80758), B(80759), B(80760) /    -6.04,  -15.99,    0.00 /
      DATA B(81061), B(81062), B(81063) /    -6.04,  -15.74,    0.00 /
      DATA B(81364), B(81365), B(81366) /    -6.13,  -15.48,    0.00 /
      DATA B(81667), B(81668), B(81669) /    -6.24,  -15.17,    0.00 /
      DATA B(81970), B(81971), B(81972) /    -6.34,  -14.84,    0.00 /
      DATA B(82273), B(82274), B(82275) /    -6.44,  -14.48,    0.00 /
      DATA B(82576), B(82577), B(82578) /    -6.52,  -14.10,    0.00 /
      DATA B(82879), B(82880), B(82881) /    -6.59,  -13.70,    0.00 /
      DATA B(83182), B(83183), B(83184) /    -6.76,  -13.60,    0.00 /
      DATA B(83485), B(83486), B(83487) /    -6.78,  -13.04,    0.00 /
      DATA B(83788), B(83789), B(83790) /    -6.89,  -12.69,    0.00 /
      DATA B(84091), B(84092), B(84093) /    -7.05,  -12.37,    0.00 /
      DATA B(84394), B(84395), B(84396) /    -7.15,  -12.13,    0.00 /
      DATA B(84697), B(84698), B(84699) /    -7.32,  -12.19,    0.00 /
      DATA B(85000), B(85001), B(85002) /    -7.31,  -12.39,    0.00 /
      DATA B(85303), B(85304), B(85305) /    -7.48,  -11.41,    0.00 /
      DATA B(85606), B(85607), B(85608) /    -7.61,  -11.27,    0.00 /
      DATA B(85909), B(85910), B(85911) /    -7.73,  -11.13,    0.00 /
      DATA B(86212), B(86213), B(86214) /    -7.83,  -11.00,    0.00 /
      DATA B(86515), B(86516), B(86517) /    -7.93,  -10.87,    0.00 /
      DATA B(86818), B(86819), B(86820) /    -8.05,  -10.74,    0.00 /
      DATA B(87121), B(87122), B(87123) /    -8.22,  -10.65,    0.00 /
      DATA B(87424), B(87425), B(87426) /    -8.42,  -10.59,    0.00 /
      DATA B(87727), B(87728), B(87729) /    -8.44,  -10.48,    0.00 /
      DATA B(88030), B(88031), B(88032) /    -8.40,  -10.76,    0.00 /
      DATA B(88333), B(88334), B(88335) /    -8.47,  -10.78,    0.00 /
      DATA B(88636), B(88637), B(88638) /    -8.58,  -10.77,    0.00 /
      DATA B(88939), B(88940), B(88941) /    -8.75,  -10.87,    0.00 /
      DATA B(89242), B(89243), B(89244) /    -8.99,  -11.25,    0.00 /
      DATA B(89545), B(89546), B(89547) /    -9.20,  -11.55,    0.00 /
      DATA B(67732), B(67733), B(67734) /    25.75,  -46.11,    0.00 /
      DATA B(68035), B(68036), B(68037) /    25.75,  -45.85,    0.00 /
      DATA B(68338), B(68339), B(68340) /    25.75,  -45.60,    0.00 /
      DATA B(68641), B(68642), B(68643) /    25.74,  -45.34,    0.00 /
      DATA B(68944), B(68945), B(68946) /    25.74,  -45.08,    0.00 /
      DATA B(69247), B(69248), B(69249) /    25.73,  -44.81,    0.00 /
      DATA B(69550), B(69551), B(69552) /    25.72,  -44.55,    0.00 /
      DATA B(69853), B(69854), B(69855) /    25.72,  -44.28,    0.00 /
      DATA B(70156), B(70157), B(70158) /    25.71,  -44.01,    0.00 /
      DATA B(70459), B(70460), B(70461) /    25.70,  -43.74,    0.00 /
      DATA B(70762), B(70763), B(70764) /    25.68,  -43.47,    0.00 /
      DATA B(71065), B(71066), B(71067) /    25.66,  -43.20,    0.00 /
      DATA B(71368), B(71369), B(71370) /    25.64,  -42.93,    0.00 /
      DATA B(71671), B(71672), B(71673) /    25.61,  -42.65,    0.00 /
      DATA B(71974), B(71975), B(71976) /    25.57,  -42.38,    0.00 /
      DATA B(72277), B(72278), B(72279) /    25.53,  -42.10,    0.00 /
      DATA B(72580), B(72581), B(72582) /    25.47,  -41.80,    0.00 /
      DATA B(72883), B(72884), B(72885) /    25.39,  -41.47,    0.00 /
      DATA B(73186), B(73187), B(73188) /    25.26,  -41.12,    0.00 /
      DATA B(73489), B(73490), B(73491) /    25.02,  -40.72,    0.00 /
      DATA B(73792), B(73793), B(73794) /    25.82,  -40.81,    0.00 /
      DATA B(74095), B(74096), B(74097) /    24.97,  -40.35,    0.00 /
      DATA B(74398), B(74399), B(74400) /    23.43,  -39.29,    0.00 /
      DATA B(74701), B(74702), B(74703) /    21.88,  -37.69,    0.00 /
      DATA B(75004), B(75005), B(75006) /    10.54,  -29.39,    0.00 /
      DATA B(75307), B(75308), B(75309) /    -0.53,  -23.59,    0.00 /
      DATA B(75610), B(75611), B(75612) /    -2.13,  -24.71,    0.00 /
      DATA B(75913), B(75914), B(75915) /    -2.51,  -24.06,    0.00 /
      DATA B(76216), B(76217), B(76218) /    -2.85,  -23.63,    0.00 /
      DATA B(76519), B(76520), B(76521) /    -3.18,  -23.33,    0.00 /
      DATA B(76822), B(76823), B(76824) /    -3.48,  -23.08,    0.00 /
      DATA B(77125), B(77126), B(77127) /    -3.77,  -22.84,    0.00 /
      DATA B(77428), B(77429), B(77430) /    -4.04,  -22.58,    0.00 /
      DATA B(77731), B(77732), B(77733) /    -4.29,  -22.30,    0.00 /
      DATA B(78034), B(78035), B(78036) /    -4.52,  -22.00,    0.00 /
      DATA B(78337), B(78338), B(78339) /    -4.72,  -21.66,    0.00 /
      DATA B(78640), B(78641), B(78642) /    -4.91,  -21.29,    0.00 /
      DATA B(78943), B(78944), B(78945) /    -5.08,  -20.85,    0.00 /
      DATA B(79246), B(79247), B(79248) /    -5.23,  -20.30,    0.00 /
      DATA B(79549), B(79550), B(79551) /    -5.40,  -19.51,    0.00 /
      DATA B(79852), B(79853), B(79854) /    -5.91,  -18.46,    0.00 /
      DATA B(80155), B(80156), B(80157) /    -6.23,  -17.13,    0.00 /
      DATA B(80458), B(80459), B(80460) /    -6.17,  -16.57,    0.00 /
      DATA B(80761), B(80762), B(80763) /    -6.14,  -16.23,    0.00 /
      DATA B(81064), B(81065), B(81066) /    -6.17,  -15.93,    0.00 /
      DATA B(81367), B(81368), B(81369) /    -6.23,  -15.63,    0.00 /
      DATA B(81670), B(81671), B(81672) /    -6.31,  -15.31,    0.00 /
      DATA B(81973), B(81974), B(81975) /    -6.41,  -14.96,    0.00 /
      DATA B(82276), B(82277), B(82278) /    -6.50,  -14.60,    0.00 /
      DATA B(82579), B(82580), B(82581) /    -6.59,  -14.23,    0.00 /
      DATA B(82882), B(82883), B(82884) /    -6.68,  -13.85,    0.00 /
      DATA B(83185), B(83186), B(83187) /    -6.81,  -13.40,    0.00 /
      DATA B(83488), B(83489), B(83490) /    -7.10,  -13.19,    0.00 /
      DATA B(83791), B(83792), B(83793) /    -7.24,  -12.83,    0.00 /
      DATA B(84094), B(84095), B(84096) /    -7.33,  -12.52,    0.00 /
      DATA B(84397), B(84398), B(84399) /    -7.40,  -12.31,    0.00 /
      DATA B(84700), B(84701), B(84702) /    -7.49,  -12.21,    0.00 /
      DATA B(85003), B(85004), B(85005) /    -7.65,  -12.01,    0.00 /
      DATA B(85306), B(85307), B(85308) /    -7.70,  -11.67,    0.00 /
      DATA B(85609), B(85610), B(85611) /    -7.79,  -11.50,    0.00 /
      DATA B(85912), B(85913), B(85914) /    -7.89,  -11.36,    0.00 /
      DATA B(86215), B(86216), B(86217) /    -7.99,  -11.21,    0.00 /
      DATA B(86518), B(86519), B(86520) /    -8.10,  -11.08,    0.00 /
      DATA B(86821), B(86822), B(86823) /    -8.22,  -10.94,    0.00 /
      DATA B(87124), B(87125), B(87126) /    -8.44,  -10.89,    0.00 /
      DATA B(87427), B(87428), B(87429) /    -8.68,  -10.88,    0.00 /
      DATA B(87730), B(87731), B(87732) /    -8.60,  -11.06,    0.00 /
      DATA B(88033), B(88034), B(88035) /    -8.62,  -11.10,    0.00 /
      DATA B(88336), B(88337), B(88338) /    -8.69,  -11.05,    0.00 /
      DATA B(88639), B(88640), B(88641) /    -8.79,  -10.99,    0.00 /
      DATA B(88942), B(88943), B(88944) /    -8.95,  -11.05,    0.00 /
      DATA B(89245), B(89246), B(89247) /    -9.28,  -11.73,    0.00 /
      DATA B(89548), B(89549), B(89550) /   -10.21,  -11.63,    0.00 /
      DATA B(67735), B(67736), B(67737) /    25.65,  -46.04,    0.00 /
      DATA B(68038), B(68039), B(68040) /    25.64,  -45.78,    0.00 /
      DATA B(68341), B(68342), B(68343) /    25.64,  -45.53,    0.00 /
      DATA B(68644), B(68645), B(68646) /    25.63,  -45.26,    0.00 /
      DATA B(68947), B(68948), B(68949) /    25.63,  -45.00,    0.00 /
      DATA B(69250), B(69251), B(69252) /    25.62,  -44.73,    0.00 /
      DATA B(69553), B(69554), B(69555) /    25.62,  -44.46,    0.00 /
      DATA B(69856), B(69857), B(69858) /    25.61,  -44.19,    0.00 /
      DATA B(70159), B(70160), B(70161) /    25.60,  -43.92,    0.00 /
      DATA B(70462), B(70463), B(70464) /    25.59,  -43.64,    0.00 /
      DATA B(70765), B(70766), B(70767) /    25.58,  -43.36,    0.00 /
      DATA B(71068), B(71069), B(71070) /    25.56,  -43.08,    0.00 /
      DATA B(71371), B(71372), B(71373) /    25.54,  -42.80,    0.00 /
      DATA B(71674), B(71675), B(71676) /    25.50,  -42.52,    0.00 /
      DATA B(71977), B(71978), B(71979) /    25.45,  -42.23,    0.00 /
      DATA B(72280), B(72281), B(72282) /    25.38,  -41.95,    0.00 /
      DATA B(72583), B(72584), B(72585) /    25.30,  -41.62,    0.00 /
      DATA B(72886), B(72887), B(72888) /    25.18,  -41.23,    0.00 /
      DATA B(73189), B(73190), B(73191) /    24.95,  -40.75,    0.00 /
      DATA B(73492), B(73493), B(73494) /    25.17,  -40.57,    0.00 /
      DATA B(73795), B(73796), B(73797) /    24.46,  -40.13,    0.00 /
      DATA B(74098), B(74099), B(74100) /    23.16,  -39.30,    0.00 /
      DATA B(74401), B(74402), B(74403) /    21.79,  -38.52,    0.00 /
      DATA B(74704), B(74705), B(74706) /     2.22,  -23.56,    0.00 /
      DATA B(75007), B(75008), B(75009) /    -0.35,  -22.68,    0.00 /
      DATA B(75310), B(75311), B(75312) /    -2.18,  -23.82,    0.00 /
      DATA B(75613), B(75614), B(75615) /    -2.55,  -23.78,    0.00 /
      DATA B(75916), B(75917), B(75918) /    -2.84,  -23.48,    0.00 /
      DATA B(76219), B(76220), B(76221) /    -3.07,  -23.18,    0.00 /
      DATA B(76522), B(76523), B(76524) /    -3.30,  -22.92,    0.00 /
      DATA B(76825), B(76826), B(76827) /    -3.53,  -22.69,    0.00 /
      DATA B(77128), B(77129), B(77130) /    -3.77,  -22.47,    0.00 /
      DATA B(77431), B(77432), B(77433) /    -4.00,  -22.23,    0.00 /
      DATA B(77734), B(77735), B(77736) /    -4.23,  -21.99,    0.00 /
      DATA B(78037), B(78038), B(78039) /    -4.45,  -21.72,    0.00 /
      DATA B(78340), B(78341), B(78342) /    -4.65,  -21.41,    0.00 /
      DATA B(78643), B(78644), B(78645) /    -4.84,  -21.04,    0.00 /
      DATA B(78946), B(78947), B(78948) /    -5.02,  -20.56,    0.00 /
      DATA B(79249), B(79250), B(79251) /    -5.27,  -19.85,    0.00 /
      DATA B(79552), B(79553), B(79554) /    -5.81,  -19.06,    0.00 /
      DATA B(79855), B(79856), B(79857) /    -6.19,  -18.17,    0.00 /
      DATA B(80158), B(80159), B(80160) /    -6.24,  -17.32,    0.00 /
      DATA B(80461), B(80462), B(80463) /    -6.21,  -16.81,    0.00 /
      DATA B(80764), B(80765), B(80766) /    -6.22,  -16.44,    0.00 /
      DATA B(81067), B(81068), B(81069) /    -6.26,  -16.11,    0.00 /
      DATA B(81370), B(81371), B(81372) /    -6.31,  -15.78,    0.00 /
      DATA B(81673), B(81674), B(81675) /    -6.39,  -15.44,    0.00 /
      DATA B(81976), B(81977), B(81978) /    -6.47,  -15.09,    0.00 /
      DATA B(82279), B(82280), B(82281) /    -6.56,  -14.72,    0.00 /
      DATA B(82582), B(82583), B(82584) /    -6.66,  -14.35,    0.00 /
      DATA B(82885), B(82886), B(82887) /    -6.78,  -13.96,    0.00 /
      DATA B(83188), B(83189), B(83190) /    -6.97,  -13.46,    0.00 /
      DATA B(83491), B(83492), B(83493) /    -7.23,  -13.17,    0.00 /
      DATA B(83794), B(83795), B(83796) /    -7.41,  -12.92,    0.00 /
      DATA B(84097), B(84098), B(84099) /    -7.51,  -12.68,    0.00 /
      DATA B(84400), B(84401), B(84402) /    -7.59,  -12.48,    0.00 /
      DATA B(84703), B(84704), B(84705) /    -7.68,  -12.32,    0.00 /
      DATA B(85006), B(85007), B(85008) /    -7.80,  -12.12,    0.00 /
      DATA B(85309), B(85310), B(85311) /    -7.88,  -11.89,    0.00 /
      DATA B(85612), B(85613), B(85614) /    -7.96,  -11.71,    0.00 /
      DATA B(85915), B(85916), B(85917) /    -8.06,  -11.56,    0.00 /
      DATA B(86218), B(86219), B(86220) /    -8.15,  -11.42,    0.00 /
      DATA B(86521), B(86522), B(86523) /    -8.25,  -11.28,    0.00 /
      DATA B(86824), B(86825), B(86826) /    -8.37,  -11.14,    0.00 /
      DATA B(87127), B(87128), B(87129) /    -8.58,  -11.06,    0.00 /
      DATA B(87430), B(87431), B(87432) /    -8.81,  -11.43,    0.00 /
      DATA B(87733), B(87734), B(87735) /    -8.87,  -11.62,    0.00 /
      DATA B(88036), B(88037), B(88038) /    -8.90,  -11.33,    0.00 /
      DATA B(88339), B(88340), B(88341) /    -8.91,  -11.18,    0.00 /
      DATA B(88642), B(88643), B(88644) /    -8.98,  -11.15,    0.00 /
      DATA B(88945), B(88946), B(88947) /    -9.11,  -11.20,    0.00 /
      DATA B(89248), B(89249), B(89250) /    -8.81,  -11.62,    0.00 /
      DATA B(89551), B(89552), B(89553) /    -9.85,  -11.72,    0.00 /
      DATA B(67738), B(67739), B(67740) /    25.54,  -45.97,    0.00 /
      DATA B(68041), B(68042), B(68043) /    25.54,  -45.71,    0.00 /
      DATA B(68344), B(68345), B(68346) /    25.53,  -45.45,    0.00 /
      DATA B(68647), B(68648), B(68649) /    25.53,  -45.19,    0.00 /
      DATA B(68950), B(68951), B(68952) /    25.52,  -44.92,    0.00 /
      DATA B(69253), B(69254), B(69255) /    25.51,  -44.65,    0.00 /
      DATA B(69556), B(69557), B(69558) /    25.51,  -44.38,    0.00 /
      DATA B(69859), B(69860), B(69861) /    25.50,  -44.10,    0.00 /
      DATA B(70162), B(70163), B(70164) /    25.49,  -43.82,    0.00 /
      DATA B(70465), B(70466), B(70467) /    25.48,  -43.53,    0.00 /
      DATA B(70768), B(70769), B(70770) /    25.47,  -43.25,    0.00 /
      DATA B(71071), B(71072), B(71073) /    25.46,  -42.96,    0.00 /
      DATA B(71374), B(71375), B(71376) /    25.43,  -42.66,    0.00 /
      DATA B(71677), B(71678), B(71679) /    25.41,  -42.36,    0.00 /
      DATA B(71980), B(71981), B(71982) /    25.35,  -42.02,    0.00 /
      DATA B(72283), B(72284), B(72285) /    25.19,  -41.72,    0.00 /
      DATA B(72586), B(72587), B(72588) /    25.01,  -41.39,    0.00 /
      DATA B(72889), B(72890), B(72891) /    24.77,  -40.86,    0.00 /
      DATA B(73192), B(73193), B(73194) /    24.47,  -40.38,    0.00 /
      DATA B(73495), B(73496), B(73497) /    23.88,  -39.74,    0.00 /
      DATA B(73798), B(73799), B(73800) /    22.69,  -38.90,    0.00 /
      DATA B(74101), B(74102), B(74103) /    21.92,  -38.60,    0.00 /
      DATA B(74404), B(74405), B(74406) /     1.37,  -22.21,    0.00 /
      DATA B(74707), B(74708), B(74709) /    -0.29,  -22.34,    0.00 /
      DATA B(75010), B(75011), B(75012) /    -2.16,  -23.43,    0.00 /
      DATA B(75313), B(75314), B(75315) /    -2.41,  -23.36,    0.00 /
      DATA B(75616), B(75617), B(75618) /    -2.67,  -23.27,    0.00 /
      DATA B(75919), B(75920), B(75921) /    -2.90,  -23.06,    0.00 /
      DATA B(76222), B(76223), B(76224) /    -3.11,  -22.82,    0.00 /
      DATA B(76525), B(76526), B(76527) /    -3.30,  -22.59,    0.00 /
      DATA B(76828), B(76829), B(76830) /    -3.50,  -22.37,    0.00 /
      DATA B(77131), B(77132), B(77133) /    -3.71,  -22.15,    0.00 /
      DATA B(77434), B(77435), B(77436) /    -3.94,  -21.92,    0.00 /
      DATA B(77737), B(77738), B(77739) /    -4.16,  -21.70,    0.00 /
      DATA B(78040), B(78041), B(78042) /    -4.38,  -21.45,    0.00 /
      DATA B(78343), B(78344), B(78345) /    -4.59,  -21.15,    0.00 /
      DATA B(78646), B(78647), B(78648) /    -4.82,  -20.73,    0.00 /
      DATA B(78949), B(78950), B(78951) /    -5.18,  -20.07,    0.00 /
      DATA B(79252), B(79253), B(79254) /    -5.75,  -19.42,    0.00 /
      DATA B(79555), B(79556), B(79557) /    -6.07,  -18.69,    0.00 /
      DATA B(79858), B(79859), B(79860) /    -6.20,  -18.03,    0.00 /
      DATA B(80161), B(80162), B(80163) /    -6.25,  -17.45,    0.00 /
      DATA B(80464), B(80465), B(80466) /    -6.27,  -16.99,    0.00 /
      DATA B(80767), B(80768), B(80769) /    -6.30,  -16.62,    0.00 /
      DATA B(81070), B(81071), B(81072) /    -6.34,  -16.27,    0.00 /
      DATA B(81373), B(81374), B(81375) /    -6.39,  -15.93,    0.00 /
      DATA B(81676), B(81677), B(81678) /    -6.46,  -15.57,    0.00 /
      DATA B(81979), B(81980), B(81981) /    -6.54,  -15.20,    0.00 /
      DATA B(82282), B(82283), B(82284) /    -6.63,  -14.83,    0.00 /
      DATA B(82585), B(82586), B(82587) /    -6.74,  -14.46,    0.00 /
      DATA B(82888), B(82889), B(82890) /    -6.90,  -14.07,    0.00 /
      DATA B(83191), B(83192), B(83193) /    -7.10,  -13.49,    0.00 /
      DATA B(83494), B(83495), B(83496) /    -7.39,  -13.24,    0.00 /
      DATA B(83797), B(83798), B(83799) /    -7.56,  -13.04,    0.00 /
      DATA B(84100), B(84101), B(84102) /    -7.67,  -12.83,    0.00 /
      DATA B(84403), B(84404), B(84405) /    -7.76,  -12.65,    0.00 /
      DATA B(84706), B(84707), B(84708) /    -7.86,  -12.47,    0.00 /
      DATA B(85009), B(85010), B(85011) /    -7.95,  -12.28,    0.00 /
      DATA B(85312), B(85313), B(85314) /    -8.04,  -12.09,    0.00 /
      DATA B(85615), B(85616), B(85617) /    -8.13,  -11.91,    0.00 /
      DATA B(85918), B(85919), B(85920) /    -8.22,  -11.76,    0.00 /
      DATA B(86221), B(86222), B(86223) /    -8.31,  -11.61,    0.00 /
      DATA B(86524), B(86525), B(86526) /    -8.41,  -11.48,    0.00 /
      DATA B(86827), B(86828), B(86829) /    -8.50,  -11.34,    0.00 /
      DATA B(87130), B(87131), B(87132) /    -8.56,  -11.20,    0.00 /
      DATA B(87433), B(87434), B(87435) /    -8.89,  -11.75,    0.00 /
      DATA B(87736), B(87737), B(87738) /    -8.92,  -11.66,    0.00 /
      DATA B(88039), B(88040), B(88041) /    -8.91,  -11.40,    0.00 /
      DATA B(88342), B(88343), B(88344) /    -8.93,  -11.29,    0.00 /
      DATA B(88645), B(88646), B(88647) /    -9.01,  -11.28,    0.00 /
      DATA B(88948), B(88949), B(88950) /    -8.93,  -11.93,    0.00 /
      DATA B(89251), B(89252), B(89253) /    -9.01,  -12.00,    0.00 /
      DATA B(89554), B(89555), B(89556) /   -10.09,  -12.21,    0.00 /
      DATA B(67741), B(67742), B(67743) /    25.43,  -45.90,    0.00 /
      DATA B(68044), B(68045), B(68046) /    25.43,  -45.64,    0.00 /
      DATA B(68347), B(68348), B(68349) /    25.42,  -45.38,    0.00 /
      DATA B(68650), B(68651), B(68652) /    25.42,  -45.11,    0.00 /
      DATA B(68953), B(68954), B(68955) /    25.41,  -44.84,    0.00 /
      DATA B(69256), B(69257), B(69258) /    25.40,  -44.56,    0.00 /
      DATA B(69559), B(69560), B(69561) /    25.40,  -44.29,    0.00 /
      DATA B(69862), B(69863), B(69864) /    25.39,  -44.00,    0.00 /
      DATA B(70165), B(70166), B(70167) /    25.38,  -43.71,    0.00 /
      DATA B(70468), B(70469), B(70470) /    25.38,  -43.42,    0.00 /
      DATA B(70771), B(70772), B(70773) /    25.37,  -43.12,    0.00 /
      DATA B(71074), B(71075), B(71076) /    25.36,  -42.81,    0.00 /
      DATA B(71377), B(71378), B(71379) /    25.35,  -42.49,    0.00 /
      DATA B(71680), B(71681), B(71682) /    25.33,  -42.15,    0.00 /
      DATA B(71983), B(71984), B(71985) /    25.34,  -41.72,    0.00 /
      DATA B(72286), B(72287), B(72288) /    25.24,  -41.06,    0.00 /
      DATA B(72589), B(72590), B(72591) /    24.05,  -41.00,    0.00 /
      DATA B(72892), B(72893), B(72894) /    23.65,  -40.39,    0.00 /
      DATA B(73195), B(73196), B(73197) /    23.11,  -39.58,    0.00 /
      DATA B(73498), B(73499), B(73500) /    22.07,  -38.14,    0.00 /
      DATA B(73801), B(73802), B(73803) /    21.43,  -37.57,    0.00 /
      DATA B(74104), B(74105), B(74106) /     1.95,  -21.44,    0.00 /
      DATA B(74407), B(74408), B(74409) /     0.39,  -21.59,    0.00 /
      DATA B(74710), B(74711), B(74712) /    -1.94,  -23.25,    0.00 /
      DATA B(75013), B(75014), B(75015) /    -2.22,  -23.14,    0.00 /
      DATA B(75316), B(75317), B(75318) /    -2.44,  -23.03,    0.00 /
      DATA B(75619), B(75620), B(75621) /    -2.65,  -22.90,    0.00 /
      DATA B(75922), B(75923), B(75924) /    -2.86,  -22.72,    0.00 /
      DATA B(76225), B(76226), B(76227) /    -3.06,  -22.52,    0.00 /
      DATA B(76528), B(76529), B(76530) /    -3.25,  -22.31,    0.00 /
      DATA B(76831), B(76832), B(76833) /    -3.44,  -22.09,    0.00 /
      DATA B(77134), B(77135), B(77136) /    -3.63,  -21.85,    0.00 /
      DATA B(77437), B(77438), B(77439) /    -3.86,  -21.61,    0.00 /
      DATA B(77740), B(77741), B(77742) /    -4.10,  -21.40,    0.00 /
      DATA B(78043), B(78044), B(78045) /    -4.35,  -21.18,    0.00 /
      DATA B(78346), B(78347), B(78348) /    -4.63,  -20.84,    0.00 /
      DATA B(78649), B(78650), B(78651) /    -5.08,  -20.28,    0.00 /
      DATA B(78952), B(78953), B(78954) /    -5.67,  -19.68,    0.00 /
      DATA B(79255), B(79256), B(79257) /    -5.98,  -19.09,    0.00 /
      DATA B(79558), B(79559), B(79560) /    -6.13,  -18.54,    0.00 /
      DATA B(79861), B(79862), B(79863) /    -6.23,  -18.03,    0.00 /
      DATA B(80164), B(80165), B(80166) /    -6.30,  -17.57,    0.00 /
      DATA B(80467), B(80468), B(80469) /    -6.34,  -17.15,    0.00 /
      DATA B(80770), B(80771), B(80772) /    -6.38,  -16.78,    0.00 /
      DATA B(81073), B(81074), B(81075) /    -6.43,  -16.44,    0.00 /
      DATA B(81376), B(81377), B(81378) /    -6.48,  -16.08,    0.00 /
      DATA B(81679), B(81680), B(81681) /    -6.54,  -15.71,    0.00 /
      DATA B(81982), B(81983), B(81984) /    -6.62,  -15.31,    0.00 /
      DATA B(82285), B(82286), B(82287) /    -6.71,  -14.93,    0.00 /
      DATA B(82588), B(82589), B(82590) /    -6.83,  -14.55,    0.00 /
      DATA B(82891), B(82892), B(82893) /    -7.03,  -14.15,    0.00 /
      DATA B(83194), B(83195), B(83196) /    -7.27,  -13.58,    0.00 /
      DATA B(83497), B(83498), B(83499) /    -7.56,  -13.36,    0.00 /
      DATA B(83800), B(83801), B(83802) /    -7.72,  -13.17,    0.00 /
      DATA B(84103), B(84104), B(84105) /    -7.83,  -12.99,    0.00 /
      DATA B(84406), B(84407), B(84408) /    -7.92,  -12.81,    0.00 /
      DATA B(84709), B(84710), B(84711) /    -8.01,  -12.63,    0.00 /
      DATA B(85012), B(85013), B(85014) /    -8.11,  -12.45,    0.00 /
      DATA B(85315), B(85316), B(85317) /    -8.19,  -12.27,    0.00 /
      DATA B(85618), B(85619), B(85620) /    -8.28,  -12.10,    0.00 /
      DATA B(85921), B(85922), B(85923) /    -8.37,  -11.94,    0.00 /
      DATA B(86224), B(86225), B(86226) /    -8.46,  -11.80,    0.00 /
      DATA B(86527), B(86528), B(86529) /    -8.57,  -11.68,    0.00 /
      DATA B(86830), B(86831), B(86832) /    -8.66,  -11.56,    0.00 /
      DATA B(87133), B(87134), B(87135) /    -8.92,  -12.16,    0.00 /
      DATA B(87436), B(87437), B(87438) /    -8.85,  -11.88,    0.00 /
      DATA B(87739), B(87740), B(87741) /    -8.83,  -11.69,    0.00 /
      DATA B(88042), B(88043), B(88044) /    -8.84,  -11.51,    0.00 /
      DATA B(88345), B(88346), B(88347) /    -8.89,  -11.44,    0.00 /
      DATA B(88648), B(88649), B(88650) /    -9.01,  -12.00,    0.00 /
      DATA B(88951), B(88952), B(88953) /    -9.09,  -12.19,    0.00 /
      DATA B(89254), B(89255), B(89256) /   -10.15,  -12.39,    0.00 /
      DATA B(89557), B(89558), B(89559) /   -10.17,  -12.50,    0.00 /
      DATA B(67744), B(67745), B(67746) /    25.32,  -45.83,    0.00 /
      DATA B(68047), B(68048), B(68049) /    25.32,  -45.57,    0.00 /
      DATA B(68350), B(68351), B(68352) /    25.31,  -45.30,    0.00 /
      DATA B(68653), B(68654), B(68655) /    25.30,  -45.03,    0.00 /
      DATA B(68956), B(68957), B(68958) /    25.30,  -44.76,    0.00 /
      DATA B(69259), B(69260), B(69261) /    25.29,  -44.48,    0.00 /
      DATA B(69562), B(69563), B(69564) /    25.28,  -44.19,    0.00 /
      DATA B(69865), B(69866), B(69867) /    25.27,  -43.90,    0.00 /
      DATA B(70168), B(70169), B(70170) /    25.27,  -43.60,    0.00 /
      DATA B(70471), B(70472), B(70473) /    25.27,  -43.30,    0.00 /
      DATA B(70774), B(70775), B(70776) /    25.27,  -42.98,    0.00 /
      DATA B(71077), B(71078), B(71079) /    25.28,  -42.63,    0.00 /
      DATA B(71380), B(71381), B(71382) /    25.29,  -42.27,    0.00 /
      DATA B(71683), B(71684), B(71685) /    25.29,  -41.86,    0.00 /
      DATA B(71986), B(71987), B(71988) /    25.31,  -41.35,    0.00 /
      DATA B(72289), B(72290), B(72291) /    22.19,  -41.77,    0.00 /
      DATA B(72592), B(72593), B(72594) /    22.40,  -40.77,    0.00 /
      DATA B(72895), B(72896), B(72897) /    22.11,  -39.77,    0.00 /
      DATA B(73198), B(73199), B(73200) /    20.92,  -38.01,    0.00 /
      DATA B(73501), B(73502), B(73503) /    19.69,  -36.12,    0.00 /
      DATA B(73804), B(73805), B(73806) /     5.72,  -22.18,    0.00 /
      DATA B(74107), B(74108), B(74109) /     1.76,  -21.09,    0.00 /
      DATA B(74410), B(74411), B(74412) /    -1.37,  -22.98,    0.00 /
      DATA B(74713), B(74714), B(74715) /    -1.83,  -22.95,    0.00 /
      DATA B(75016), B(75017), B(75018) /    -2.13,  -22.86,    0.00 /
      DATA B(75319), B(75320), B(75321) /    -2.36,  -22.74,    0.00 /
      DATA B(75622), B(75623), B(75624) /    -2.58,  -22.60,    0.00 /
      DATA B(75925), B(75926), B(75927) /    -2.78,  -22.43,    0.00 /
      DATA B(76228), B(76229), B(76230) /    -2.98,  -22.24,    0.00 /
      DATA B(76531), B(76532), B(76533) /    -3.17,  -22.04,    0.00 /
      DATA B(76834), B(76835), B(76836) /    -3.35,  -21.82,    0.00 /
      DATA B(77137), B(77138), B(77139) /    -3.54,  -21.55,    0.00 /
      DATA B(77440), B(77441), B(77442) /    -3.77,  -21.24,    0.00 /
      DATA B(77743), B(77744), B(77745) /    -4.08,  -21.03,    0.00 /
      DATA B(78046), B(78047), B(78048) /    -4.47,  -20.85,    0.00 /
      DATA B(78349), B(78350), B(78351) /    -5.02,  -20.40,    0.00 /
      DATA B(78652), B(78653), B(78654) /    -5.59,  -19.88,    0.00 /
      DATA B(78955), B(78956), B(78957) /    -5.89,  -19.41,    0.00 /
      DATA B(79258), B(79259), B(79260) /    -6.07,  -18.95,    0.00 /
      DATA B(79561), B(79562), B(79563) /    -6.20,  -18.51,    0.00 /
      DATA B(79864), B(79865), B(79866) /    -6.29,  -18.08,    0.00 /
      DATA B(80167), B(80168), B(80169) /    -6.37,  -17.67,    0.00 /
      DATA B(80470), B(80471), B(80472) /    -6.44,  -17.30,    0.00 /
      DATA B(80773), B(80774), B(80775) /    -6.51,  -16.95,    0.00 /
      DATA B(81076), B(81077), B(81078) /    -6.57,  -16.61,    0.00 /
      DATA B(81379), B(81380), B(81381) /    -6.62,  -16.26,    0.00 /
      DATA B(81682), B(81683), B(81684) /    -6.66,  -15.85,    0.00 /
      DATA B(81985), B(81986), B(81987) /    -6.73,  -15.41,    0.00 /
      DATA B(82288), B(82289), B(82290) /    -6.81,  -15.01,    0.00 /
      DATA B(82591), B(82592), B(82593) /    -6.94,  -14.63,    0.00 /
      DATA B(82894), B(82895), B(82896) /    -7.19,  -14.22,    0.00 /
      DATA B(83197), B(83198), B(83199) /    -7.46,  -13.69,    0.00 /
      DATA B(83500), B(83501), B(83502) /    -7.73,  -13.49,    0.00 /
      DATA B(83803), B(83804), B(83805) /    -7.88,  -13.31,    0.00 /
      DATA B(84106), B(84107), B(84108) /    -7.99,  -13.14,    0.00 /
      DATA B(84409), B(84410), B(84411) /    -8.08,  -12.96,    0.00 /
      DATA B(84712), B(84713), B(84714) /    -8.17,  -12.79,    0.00 /
      DATA B(85015), B(85016), B(85017) /    -8.25,  -12.61,    0.00 /
      DATA B(85318), B(85319), B(85320) /    -8.34,  -12.44,    0.00 /
      DATA B(85621), B(85622), B(85623) /    -8.42,  -12.27,    0.00 /
      DATA B(85924), B(85925), B(85926) /    -8.51,  -12.12,    0.00 /
      DATA B(86227), B(86228), B(86229) /    -8.61,  -11.98,    0.00 /
      DATA B(86530), B(86531), B(86532) /    -8.72,  -11.88,    0.00 /
      DATA B(86833), B(86834), B(86835) /    -8.83,  -11.83,    0.00 /
      DATA B(87136), B(87137), B(87138) /    -8.78,  -12.14,    0.00 /
      DATA B(87439), B(87440), B(87441) /    -8.75,  -11.93,    0.00 /
      DATA B(87742), B(87743), B(87744) /    -8.74,  -11.76,    0.00 /
      DATA B(88045), B(88046), B(88047) /    -8.76,  -11.61,    0.00 /
      DATA B(88348), B(88349), B(88350) /    -9.10,  -12.10,    0.00 /
      DATA B(88651), B(88652), B(88653) /    -9.16,  -12.29,    0.00 /
      DATA B(88954), B(88955), B(88956) /    -9.21,  -12.46,    0.00 /
      DATA B(89257), B(89258), B(89259) /   -10.17,  -12.59,    0.00 /
      DATA B(89560), B(89561), B(89562) /   -10.18,  -12.68,    0.00 /
      DATA B(67747), B(67748), B(67749) /    25.21,  -45.76,    0.00 /
      DATA B(68050), B(68051), B(68052) /    25.21,  -45.49,    0.00 /
      DATA B(68353), B(68354), B(68355) /    25.20,  -45.22,    0.00 /
      DATA B(68656), B(68657), B(68658) /    25.19,  -44.95,    0.00 /
      DATA B(68959), B(68960), B(68961) /    25.18,  -44.67,    0.00 /
      DATA B(69262), B(69263), B(69264) /    25.17,  -44.38,    0.00 /
      DATA B(69565), B(69566), B(69567) /    25.16,  -44.09,    0.00 /
      DATA B(69868), B(69869), B(69870) /    25.15,  -43.79,    0.00 /
      DATA B(70171), B(70172), B(70173) /    25.15,  -43.49,    0.00 /
      DATA B(70474), B(70475), B(70476) /    25.15,  -43.16,    0.00 /
      DATA B(70777), B(70778), B(70779) /    25.16,  -42.82,    0.00 /
      DATA B(71080), B(71081), B(71082) /    25.23,  -42.42,    0.00 /
      DATA B(71383), B(71384), B(71385) /    25.35,  -41.90,    0.00 /
      DATA B(71686), B(71687), B(71688) /    23.53,  -42.37,    0.00 /
      DATA B(71989), B(71990), B(71991) /    20.89,  -42.57,    0.00 /
      DATA B(72292), B(72293), B(72294) /    21.22,  -41.30,    0.00 /
      DATA B(72595), B(72596), B(72597) /    21.05,  -40.30,    0.00 /
      DATA B(72898), B(72899), B(72900) /    19.86,  -38.36,    0.00 /
      DATA B(73201), B(73202), B(73203) /    18.00,  -35.72,    0.00 /
      DATA B(73504), B(73505), B(73506) /     8.93,  -27.68,    0.00 /
      DATA B(73807), B(73808), B(73809) /     3.47,  -21.37,    0.00 /
      DATA B(74110), B(74111), B(74112) /    -0.49,  -22.79,    0.00 /
      DATA B(74413), B(74414), B(74415) /    -1.25,  -22.76,    0.00 /
      DATA B(74716), B(74717), B(74718) /    -1.69,  -22.71,    0.00 /
      DATA B(75019), B(75020), B(75021) /    -2.00,  -22.61,    0.00 /
      DATA B(75322), B(75323), B(75324) /    -2.25,  -22.48,    0.00 /
      DATA B(75625), B(75626), B(75627) /    -2.47,  -22.33,    0.00 /
      DATA B(75928), B(75929), B(75930) /    -2.68,  -22.16,    0.00 /
      DATA B(76231), B(76232), B(76233) /    -2.88,  -21.97,    0.00 /
      DATA B(76534), B(76535), B(76536) /    -3.08,  -21.77,    0.00 /
      DATA B(76837), B(76838), B(76839) /    -3.28,  -21.55,    0.00 /
      DATA B(77140), B(77141), B(77142) /    -3.46,  -21.25,    0.00 /
      DATA B(77443), B(77444), B(77445) /    -3.71,  -20.65,    0.00 /
      DATA B(77746), B(77747), B(77748) /    -4.57,  -21.11,    0.00 /
      DATA B(78049), B(78050), B(78051) /    -5.07,  -20.45,    0.00 /
      DATA B(78352), B(78353), B(78354) /    -5.51,  -19.99,    0.00 /
      DATA B(78655), B(78656), B(78657) /    -5.81,  -19.63,    0.00 /
      DATA B(78958), B(78959), B(78960) /    -6.02,  -19.26,    0.00 /
      DATA B(79261), B(79262), B(79263) /    -6.17,  -18.88,    0.00 /
      DATA B(79564), B(79565), B(79566) /    -6.31,  -18.50,    0.00 /
      DATA B(79867), B(79868), B(79869) /    -6.42,  -18.12,    0.00 /
      DATA B(80170), B(80171), B(80172) /    -6.53,  -17.77,    0.00 /
      DATA B(80473), B(80474), B(80475) /    -6.64,  -17.43,    0.00 /
      DATA B(80776), B(80777), B(80778) /    -6.77,  -17.12,    0.00 /
      DATA B(81079), B(81080), B(81081) /    -6.89,  -16.83,    0.00 /
      DATA B(81382), B(81383), B(81384) /    -6.99,  -16.52,    0.00 /
      DATA B(81685), B(81686), B(81687) /    -9.21,  -16.68,    0.00 /
      DATA B(81988), B(81989), B(81990) /    -6.97,  -15.50,    0.00 /
      DATA B(82291), B(82292), B(82293) /    -6.97,  -15.07,    0.00 /
      DATA B(82594), B(82595), B(82596) /    -7.08,  -14.69,    0.00 /
      DATA B(82897), B(82898), B(82899) /    -7.38,  -14.26,    0.00 /
      DATA B(83200), B(83201), B(83202) /    -7.68,  -13.79,    0.00 /
      DATA B(83503), B(83504), B(83505) /    -7.92,  -13.62,    0.00 /
      DATA B(83806), B(83807), B(83808) /    -8.05,  -13.46,    0.00 /
      DATA B(84109), B(84110), B(84111) /    -8.14,  -13.29,    0.00 /
      DATA B(84412), B(84413), B(84414) /    -8.23,  -13.12,    0.00 /
      DATA B(84715), B(84716), B(84717) /    -8.32,  -12.95,    0.00 /
      DATA B(85018), B(85019), B(85020) /    -8.40,  -12.77,    0.00 /
      DATA B(85321), B(85322), B(85323) /    -8.48,  -12.60,    0.00 /
      DATA B(85624), B(85625), B(85626) /    -8.56,  -12.43,    0.00 /
      DATA B(85927), B(85928), B(85929) /    -8.64,  -12.28,    0.00 /
      DATA B(86230), B(86231), B(86232) /    -8.73,  -12.15,    0.00 /
      DATA B(86533), B(86534), B(86535) /    -8.81,  -12.07,    0.00 /
      DATA B(86836), B(86837), B(86838) /    -8.72,  -12.25,    0.00 /
      DATA B(87139), B(87140), B(87141) /    -8.67,  -12.15,    0.00 /
      DATA B(87442), B(87443), B(87444) /    -8.68,  -11.99,    0.00 /
      DATA B(87745), B(87746), B(87747) /    -9.10,  -12.20,    0.00 /
      DATA B(88048), B(88049), B(88050) /    -9.17,  -12.23,    0.00 /
      DATA B(88351), B(88352), B(88353) /    -9.22,  -12.38,    0.00 /
      DATA B(88654), B(88655), B(88656) /    -9.25,  -12.53,    0.00 /
      DATA B(88957), B(88958), B(88959) /    -9.27,  -12.65,    0.00 /
      DATA B(89260), B(89261), B(89262) /   -10.16,  -12.74,    0.00 /
      DATA B(89563), B(89564), B(89565) /   -10.17,  -12.82,    0.00 /
      DATA B(67750), B(67751), B(67752) /    25.10,  -45.69,    0.00 /
      DATA B(68053), B(68054), B(68055) /    25.09,  -45.42,    0.00 /
      DATA B(68356), B(68357), B(68358) /    25.08,  -45.14,    0.00 /
      DATA B(68659), B(68660), B(68661) /    25.07,  -44.86,    0.00 /
      DATA B(68962), B(68963), B(68964) /    25.06,  -44.58,    0.00 /
      DATA B(69265), B(69266), B(69267) /    25.05,  -44.29,    0.00 /
      DATA B(69568), B(69569), B(69570) /    25.04,  -43.99,    0.00 /
      DATA B(69871), B(69872), B(69873) /    25.02,  -43.68,    0.00 /
      DATA B(70174), B(70175), B(70176) /    25.01,  -43.36,    0.00 /
      DATA B(70477), B(70478), B(70479) /    25.01,  -43.01,    0.00 /
      DATA B(70780), B(70781), B(70782) /    25.02,  -42.64,    0.00 /
      DATA B(71083), B(71084), B(71085) /    25.11,  -42.20,    0.00 /
      DATA B(71386), B(71387), B(71388) /    25.11,  -41.44,    0.00 /
      DATA B(71689), B(71690), B(71691) /    22.31,  -41.76,    0.00 /
      DATA B(71992), B(71993), B(71994) /    19.59,  -42.03,    0.00 /
      DATA B(72295), B(72296), B(72297) /    20.08,  -40.84,    0.00 /
      DATA B(72598), B(72599), B(72600) /    17.45,  -37.68,    0.00 /
      DATA B(72901), B(72902), B(72903) /    16.75,  -36.18,    0.00 /
      DATA B(73204), B(73205), B(73206) /    10.04,  -29.74,    0.00 /
      DATA B(73507), B(73508), B(73509) /     4.76,  -24.62,    0.00 /
      DATA B(73810), B(73811), B(73812) /    -0.19,  -23.30,    0.00 /
      DATA B(74113), B(74114), B(74115) /    -0.65,  -22.71,    0.00 /
      DATA B(74416), B(74417), B(74418) /    -1.18,  -22.58,    0.00 /
      DATA B(74719), B(74720), B(74721) /    -1.57,  -22.49,    0.00 /
      DATA B(75022), B(75023), B(75024) /    -1.87,  -22.37,    0.00 /
      DATA B(75325), B(75326), B(75327) /    -2.13,  -22.23,    0.00 /
      DATA B(75628), B(75629), B(75630) /    -2.35,  -22.08,    0.00 /
      DATA B(75931), B(75932), B(75933) /    -2.57,  -21.90,    0.00 /
      DATA B(76234), B(76235), B(76236) /    -2.78,  -21.70,    0.00 /
      DATA B(76537), B(76538), B(76539) /    -3.00,  -21.49,    0.00 /
      DATA B(76840), B(76841), B(76842) /    -3.25,  -21.25,    0.00 /
      DATA B(77143), B(77144), B(77145) /    -3.61,  -20.92,    0.00 /
      DATA B(77446), B(77447), B(77448) /    -4.53,  -21.12,    0.00 /
      DATA B(77749), B(77750), B(77751) /    -5.13,  -20.55,    0.00 /
      DATA B(78052), B(78053), B(78054) /    -5.47,  -20.06,    0.00 /
      DATA B(78355), B(78356), B(78357) /    -5.75,  -19.70,    0.00 /
      DATA B(78658), B(78659), B(78660) /    -6.00,  -19.39,    0.00 /
      DATA B(78961), B(78962), B(78963) /    -6.23,  -19.07,    0.00 /
      DATA B(79264), B(79265), B(79266) /    -6.45,  -18.74,    0.00 /
      DATA B(79567), B(79568), B(79569) /    -6.65,  -18.41,    0.00 /
      DATA B(79870), B(79871), B(79872) /    -6.85,  -18.08,    0.00 /
      DATA B(80173), B(80174), B(80175) /    -7.04,  -17.76,    0.00 /
      DATA B(80476), B(80477), B(80478) /    -7.26,  -17.43,    0.00 /
      DATA B(80779), B(80780), B(80781) /    -7.53,  -17.10,    0.00 /
      DATA B(81082), B(81083), B(81084) /    -7.80,  -16.78,    0.00 /
      DATA B(81385), B(81386), B(81387) /    -8.02,  -16.48,    0.00 /
      DATA B(81688), B(81689), B(81690) /    -7.97,  -16.26,    0.00 /
      DATA B(81991), B(81992), B(81993) /    -7.63,  -15.71,    0.00 /
      DATA B(82294), B(82295), B(82296) /    -7.28,  -15.13,    0.00 /
      DATA B(82597), B(82598), B(82599) /    -7.25,  -14.69,    0.00 /
      DATA B(82900), B(82901), B(82902) /    -7.56,  -14.25,    0.00 /
      DATA B(83203), B(83204), B(83205) /    -7.96,  -13.90,    0.00 /
      DATA B(83506), B(83507), B(83508) /    -8.12,  -13.76,    0.00 /
      DATA B(83809), B(83810), B(83811) /    -8.22,  -13.60,    0.00 /
      DATA B(84112), B(84113), B(84114) /    -8.30,  -13.44,    0.00 /
      DATA B(84415), B(84416), B(84417) /    -8.38,  -13.27,    0.00 /
      DATA B(84718), B(84719), B(84720) /    -8.46,  -13.10,    0.00 /
      DATA B(85021), B(85022), B(85023) /    -8.54,  -12.93,    0.00 /
      DATA B(85324), B(85325), B(85326) /    -8.62,  -12.76,    0.00 /
      DATA B(85627), B(85628), B(85629) /    -8.69,  -12.59,    0.00 /
      DATA B(85930), B(85931), B(85932) /    -8.76,  -12.43,    0.00 /
      DATA B(86233), B(86234), B(86235) /    -8.82,  -12.30,    0.00 /
      DATA B(86536), B(86537), B(86538) /    -8.82,  -12.29,    0.00 /
      DATA B(86839), B(86840), B(86841) /    -8.61,  -12.30,    0.00 /
      DATA B(87142), B(87143), B(87144) /    -8.63,  -12.16,    0.00 /
      DATA B(87445), B(87446), B(87447) /    -9.14,  -12.30,    0.00 /
      DATA B(87748), B(87749), B(87750) /    -9.23,  -12.37,    0.00 /
      DATA B(88051), B(88052), B(88053) /    -9.27,  -12.48,    0.00 /
      DATA B(88354), B(88355), B(88356) /    -9.29,  -12.59,    0.00 /
      DATA B(88657), B(88658), B(88659) /    -9.30,  -12.70,    0.00 /
      DATA B(88960), B(88961), B(88962) /   -10.12,  -12.79,    0.00 /
      DATA B(89263), B(89264), B(89265) /   -10.13,  -12.86,    0.00 /
      DATA B(89566), B(89567), B(89568) /   -10.14,  -12.93,    0.00 /
      DATA B(67753), B(67754), B(67755) /    24.99,  -45.61,    0.00 /
      DATA B(68056), B(68057), B(68058) /    24.98,  -45.34,    0.00 /
      DATA B(68359), B(68360), B(68361) /    24.97,  -45.06,    0.00 /
      DATA B(68662), B(68663), B(68664) /    24.95,  -44.77,    0.00 /
      DATA B(68965), B(68966), B(68967) /    24.94,  -44.48,    0.00 /
      DATA B(69268), B(69269), B(69270) /    24.92,  -44.18,    0.00 /
      DATA B(69571), B(69572), B(69573) /    24.90,  -43.87,    0.00 /
      DATA B(69874), B(69875), B(69876) /    24.88,  -43.55,    0.00 /
      DATA B(70177), B(70178), B(70179) /    24.86,  -43.21,    0.00 /
      DATA B(70480), B(70481), B(70482) /    24.84,  -42.84,    0.00 /
      DATA B(70783), B(70784), B(70785) /    24.83,  -42.41,    0.00 /
      DATA B(71086), B(71087), B(71088) /    24.81,  -41.84,    0.00 /
      DATA B(71389), B(71390), B(71391) /    24.30,  -40.89,    0.00 /
      DATA B(71692), B(71693), B(71694) /    21.25,  -41.18,    0.00 /
      DATA B(71995), B(71996), B(71997) /    18.25,  -41.52,    0.00 /
      DATA B(72298), B(72299), B(72300) /    18.36,  -40.22,    0.00 /
      DATA B(72601), B(72602), B(72603) /    16.23,  -37.39,    0.00 /
      DATA B(72904), B(72905), B(72906) /    10.11,  -30.83,    0.00 /
      DATA B(73207), B(73208), B(73209) /     4.71,  -25.77,    0.00 /
      DATA B(73510), B(73511), B(73512) /     0.76,  -23.91,    0.00 /
      DATA B(73813), B(73814), B(73815) /    -0.17,  -23.00,    0.00 /
      DATA B(74116), B(74117), B(74118) /    -0.72,  -22.61,    0.00 /
      DATA B(74419), B(74420), B(74421) /    -1.13,  -22.42,    0.00 /
      DATA B(74722), B(74723), B(74724) /    -1.47,  -22.28,    0.00 /
      DATA B(75025), B(75026), B(75027) /    -1.76,  -22.15,    0.00 /
      DATA B(75328), B(75329), B(75330) /    -2.01,  -22.00,    0.00 /
      DATA B(75631), B(75632), B(75633) /    -2.24,  -21.83,    0.00 /
      DATA B(75934), B(75935), B(75936) /    -2.46,  -21.64,    0.00 /
      DATA B(76237), B(76238), B(76239) /    -2.70,  -21.42,    0.00 /
      DATA B(76540), B(76541), B(76542) /    -2.96,  -21.17,    0.00 /
      DATA B(76843), B(76844), B(76845) /    -3.32,  -20.84,    0.00 /
      DATA B(77146), B(77147), B(77148) /    -4.05,  -20.33,    0.00 /
      DATA B(77449), B(77450), B(77451) /    -4.69,  -20.19,    0.00 /
      DATA B(77752), B(77753), B(77754) /    -5.21,  -19.95,    0.00 /
      DATA B(78055), B(78056), B(78057) /    -5.56,  -19.61,    0.00 /
      DATA B(78358), B(78359), B(78360) /    -5.87,  -19.31,    0.00 /
      DATA B(78661), B(78662), B(78663) /    -6.17,  -19.02,    0.00 /
      DATA B(78964), B(78965), B(78966) /    -6.46,  -18.74,    0.00 /
      DATA B(79267), B(79268), B(79269) /    -6.74,  -18.45,    0.00 /
      DATA B(79570), B(79571), B(79572) /    -7.01,  -18.15,    0.00 /
      DATA B(79873), B(79874), B(79875) /    -7.28,  -17.86,    0.00 /
      DATA B(80176), B(80177), B(80178) /    -7.54,  -17.56,    0.00 /
      DATA B(80479), B(80480), B(80481) /    -7.80,  -17.26,    0.00 /
      DATA B(80782), B(80783), B(80784) /    -8.05,  -16.97,    0.00 /
      DATA B(81085), B(81086), B(81087) /    -8.30,  -16.70,    0.00 /
      DATA B(81388), B(81389), B(81390) /    -8.51,  -16.45,    0.00 /
      DATA B(81691), B(81692), B(81693) /    -8.62,  -16.27,    0.00 /
      DATA B(81994), B(81995), B(81996) /    -8.49,  -16.04,    0.00 /
      DATA B(82297), B(82298), B(82299) /    -7.97,  -15.37,    0.00 /
      DATA B(82600), B(82601), B(82602) /    -7.52,  -14.65,    0.00 /
      DATA B(82903), B(82904), B(82905) /    -8.15,  -14.23,    0.00 /
      DATA B(83206), B(83207), B(83208) /    -8.28,  -14.05,    0.00 /
      DATA B(83509), B(83510), B(83511) /    -8.33,  -13.91,    0.00 /
      DATA B(83812), B(83813), B(83814) /    -8.39,  -13.75,    0.00 /
      DATA B(84115), B(84116), B(84117) /    -8.46,  -13.59,    0.00 /
      DATA B(84418), B(84419), B(84420) /    -8.53,  -13.42,    0.00 /
      DATA B(84721), B(84722), B(84723) /    -8.61,  -13.25,    0.00 /
      DATA B(85024), B(85025), B(85026) /    -8.68,  -13.08,    0.00 /
      DATA B(85327), B(85328), B(85329) /    -8.75,  -12.91,    0.00 /
      DATA B(85630), B(85631), B(85632) /    -8.81,  -12.74,    0.00 /
      DATA B(85933), B(85934), B(85935) /    -8.86,  -12.58,    0.00 /
      DATA B(86236), B(86237), B(86238) /    -8.85,  -12.45,    0.00 /
      DATA B(86539), B(86540), B(86541) /    -8.63,  -12.52,    0.00 /
      DATA B(86842), B(86843), B(86844) /    -8.50,  -12.30,    0.00 /
      DATA B(87145), B(87146), B(87147) /    -9.10,  -12.36,    0.00 /
      DATA B(87448), B(87449), B(87450) /    -9.23,  -12.48,    0.00 /
      DATA B(87751), B(87752), B(87753) /    -9.30,  -12.57,    0.00 /
      DATA B(88054), B(88055), B(88056) /    -9.32,  -12.66,    0.00 /
      DATA B(88357), B(88358), B(88359) /    -9.32,  -12.75,    0.00 /
      DATA B(88660), B(88661), B(88662) /    -9.34,  -12.84,    0.00 /
      DATA B(88963), B(88964), B(88965) /   -10.08,  -12.89,    0.00 /
      DATA B(89266), B(89267), B(89268) /   -10.10,  -12.95,    0.00 /
      DATA B(89569), B(89570), B(89571) /   -10.10,  -13.02,    0.00 /
      DATA B(67756), B(67757), B(67758) /    24.87,  -45.53,    0.00 /
      DATA B(68059), B(68060), B(68061) /    24.86,  -45.25,    0.00 /
      DATA B(68362), B(68363), B(68364) /    24.85,  -44.97,    0.00 /
      DATA B(68665), B(68666), B(68667) /    24.83,  -44.68,    0.00 /
      DATA B(68968), B(68969), B(68970) /    24.81,  -44.38,    0.00 /
      DATA B(69271), B(69272), B(69273) /    24.79,  -44.07,    0.00 /
      DATA B(69574), B(69575), B(69576) /    24.77,  -43.74,    0.00 /
      DATA B(69877), B(69878), B(69879) /    24.74,  -43.40,    0.00 /
      DATA B(70180), B(70181), B(70182) /    24.70,  -43.03,    0.00 /
      DATA B(70483), B(70484), B(70485) /    24.65,  -42.61,    0.00 /
      DATA B(70786), B(70787), B(70788) /    24.59,  -42.08,    0.00 /
      DATA B(71089), B(71090), B(71091) /    24.49,  -41.17,    0.00 /
      DATA B(71392), B(71393), B(71394) /    23.54,  -40.41,    0.00 /
      DATA B(71695), B(71696), B(71697) /    20.22,  -40.64,    0.00 /
      DATA B(71998), B(71999), B(72000) /    16.78,  -40.91,    0.00 /
      DATA B(72301), B(72302), B(72303) /    15.85,  -38.92,    0.00 /
      DATA B(72604), B(72605), B(72606) /     5.64,  -27.66,    0.00 /
      DATA B(72907), B(72908), B(72909) /     3.91,  -26.70,    0.00 /
      DATA B(73210), B(73211), B(73212) /     1.45,  -24.54,    0.00 /
      DATA B(73513), B(73514), B(73515) /     0.35,  -23.45,    0.00 /
      DATA B(73816), B(73817), B(73818) /    -0.29,  -22.83,    0.00 /
      DATA B(74119), B(74120), B(74121) /    -0.73,  -22.47,    0.00 /
      DATA B(74422), B(74423), B(74424) /    -1.08,  -22.25,    0.00 /
      DATA B(74725), B(74726), B(74727) /    -1.38,  -22.08,    0.00 /
      DATA B(75028), B(75029), B(75030) /    -1.66,  -21.93,    0.00 /
      DATA B(75331), B(75332), B(75333) /    -1.91,  -21.76,    0.00 /
      DATA B(75634), B(75635), B(75636) /    -2.14,  -21.58,    0.00 /
      DATA B(75937), B(75938), B(75939) /    -2.38,  -21.35,    0.00 /
      DATA B(76240), B(76241), B(76242) /    -2.67,  -21.07,    0.00 /
      DATA B(76543), B(76544), B(76545) /    -3.07,  -20.71,    0.00 /
      DATA B(76846), B(76847), B(76848) /    -3.84,  -20.18,    0.00 /
      DATA B(77149), B(77150), B(77151) /    -4.44,  -19.78,    0.00 /
      DATA B(77452), B(77453), B(77454) /    -4.87,  -19.59,    0.00 /
      DATA B(77755), B(77756), B(77757) /    -5.27,  -19.39,    0.00 /
      DATA B(78058), B(78059), B(78060) /    -5.62,  -19.14,    0.00 /
      DATA B(78361), B(78362), B(78363) /    -5.94,  -18.89,    0.00 /
      DATA B(78664), B(78665), B(78666) /    -6.25,  -18.64,    0.00 /
      DATA B(78967), B(78968), B(78969) /    -6.55,  -18.39,    0.00 /
      DATA B(79270), B(79271), B(79272) /    -6.84,  -18.13,    0.00 /
      DATA B(79573), B(79574), B(79575) /    -7.13,  -17.87,    0.00 /
      DATA B(79876), B(79877), B(79878) /    -7.41,  -17.61,    0.00 /
      DATA B(80179), B(80180), B(80181) /    -7.69,  -17.35,    0.00 /
      DATA B(80482), B(80483), B(80484) /    -7.96,  -17.08,    0.00 /
      DATA B(80785), B(80786), B(80787) /    -8.22,  -16.83,    0.00 /
      DATA B(81088), B(81089), B(81090) /    -8.47,  -16.58,    0.00 /
      DATA B(81391), B(81392), B(81393) /    -8.70,  -16.35,    0.00 /
      DATA B(81694), B(81695), B(81696) /    -8.89,  -16.15,    0.00 /
      DATA B(81997), B(81998), B(81999) /    -8.99,  -15.96,    0.00 /
      DATA B(82300), B(82301), B(82302) /    -8.81,  -15.68,    0.00 /
      DATA B(82603), B(82604), B(82605) /    -8.24,  -14.85,    0.00 /
      DATA B(82906), B(82907), B(82908) /    -8.79,  -14.39,    0.00 /
      DATA B(83209), B(83210), B(83211) /    -8.55,  -14.22,    0.00 /
      DATA B(83512), B(83513), B(83514) /    -8.52,  -14.07,    0.00 /
      DATA B(83815), B(83816), B(83817) /    -8.55,  -13.90,    0.00 /
      DATA B(84118), B(84119), B(84120) /    -8.61,  -13.74,    0.00 /
      DATA B(84421), B(84422), B(84423) /    -8.68,  -13.57,    0.00 /
      DATA B(84724), B(84725), B(84726) /    -8.75,  -13.40,    0.00 /
      DATA B(85027), B(85028), B(85029) /    -8.81,  -13.22,    0.00 /
      DATA B(85330), B(85331), B(85332) /    -8.88,  -13.05,    0.00 /
      DATA B(85633), B(85634), B(85635) /    -8.92,  -12.87,    0.00 /
      DATA B(85936), B(85937), B(85938) /    -8.93,  -12.70,    0.00 /
      DATA B(86239), B(86240), B(86241) /    -8.83,  -12.63,    0.00 /
      DATA B(86542), B(86543), B(86544) /    -8.46,  -12.54,    0.00 /
      DATA B(86845), B(86846), B(86847) /    -8.38,  -12.28,    0.00 /
      DATA B(87148), B(87149), B(87150) /    -9.05,  -12.43,    0.00 /
      DATA B(87451), B(87452), B(87453) /    -9.24,  -12.62,    0.00 /
      DATA B(87754), B(87755), B(87756) /    -9.31,  -12.71,    0.00 /
      DATA B(88057), B(88058), B(88059) /    -9.33,  -12.79,    0.00 /
      DATA B(88360), B(88361), B(88362) /    -9.34,  -12.87,    0.00 /
      DATA B(88663), B(88664), B(88665) /    -9.35,  -12.95,    0.00 /
      DATA B(88966), B(88967), B(88968) /   -10.04,  -12.98,    0.00 /
      DATA B(89269), B(89270), B(89271) /   -10.05,  -13.04,    0.00 /
      DATA B(89572), B(89573), B(89574) /   -10.05,  -13.10,    0.00 /
      DATA B(67759), B(67760), B(67761) /    24.76,  -45.45,    0.00 /
      DATA B(68062), B(68063), B(68064) /    24.74,  -45.16,    0.00 /
      DATA B(68365), B(68366), B(68367) /    24.72,  -44.87,    0.00 /
      DATA B(68668), B(68669), B(68670) /    24.71,  -44.57,    0.00 /
      DATA B(68971), B(68972), B(68973) /    24.68,  -44.26,    0.00 /
      DATA B(69274), B(69275), B(69276) /    24.66,  -43.94,    0.00 /
      DATA B(69577), B(69578), B(69579) /    24.62,  -43.59,    0.00 /
      DATA B(69880), B(69881), B(69882) /    24.58,  -43.22,    0.00 /
      DATA B(70183), B(70184), B(70185) /    24.52,  -42.80,    0.00 /
      DATA B(70486), B(70487), B(70488) /    24.42,  -42.29,    0.00 /
      DATA B(70789), B(70790), B(70791) /    24.26,  -41.55,    0.00 /
      DATA B(71092), B(71093), B(71094) /    23.65,  -39.88,    0.00 /
      DATA B(71395), B(71396), B(71397) /    22.50,  -40.64,    0.00 /
      DATA B(71698), B(71699), B(71700) /    19.05,  -40.03,    0.00 /
      DATA B(72001), B(72002), B(72003) /    15.64,  -40.08,    0.00 /
      DATA B(72304), B(72305), B(72306) /    11.92,  -36.33,    0.00 /
      DATA B(72607), B(72608), B(72609) /     8.00,  -29.02,    0.00 /
      DATA B(72910), B(72911), B(72912) /     3.03,  -25.45,    0.00 /
      DATA B(73213), B(73214), B(73215) /     1.12,  -23.93,    0.00 /
      DATA B(73516), B(73517), B(73518) /     0.24,  -23.14,    0.00 /
      DATA B(73819), B(73820), B(73821) /    -0.30,  -22.64,    0.00 /
      DATA B(74122), B(74123), B(74124) /    -0.70,  -22.31,    0.00 /
      DATA B(74425), B(74426), B(74427) /    -1.02,  -22.08,    0.00 /
      DATA B(74728), B(74729), B(74730) /    -1.31,  -21.89,    0.00 /
      DATA B(75031), B(75032), B(75033) /    -1.58,  -21.71,    0.00 /
      DATA B(75334), B(75335), B(75336) /    -1.83,  -21.53,    0.00 /
      DATA B(75637), B(75638), B(75639) /    -2.08,  -21.32,    0.00 /
      DATA B(75940), B(75941), B(75942) /    -2.36,  -21.02,    0.00 /
      DATA B(76243), B(76244), B(76245) /    -2.87,  -20.43,    0.00 /
      DATA B(76546), B(76547), B(76548) /    -3.64,  -20.01,    0.00 /
      DATA B(76849), B(76850), B(76851) /    -4.22,  -19.60,    0.00 /
      DATA B(77152), B(77153), B(77154) /    -4.64,  -19.35,    0.00 /
      DATA B(77455), B(77456), B(77457) /    -5.00,  -19.17,    0.00 /
      DATA B(77758), B(77759), B(77760) /    -5.35,  -18.98,    0.00 /
      DATA B(78061), B(78062), B(78063) /    -5.69,  -18.77,    0.00 /
      DATA B(78364), B(78365), B(78366) /    -6.01,  -18.55,    0.00 /
      DATA B(78667), B(78668), B(78669) /    -6.32,  -18.32,    0.00 /
      DATA B(78970), B(78971), B(78972) /    -6.62,  -18.10,    0.00 /
      DATA B(79273), B(79274), B(79275) /    -6.91,  -17.87,    0.00 /
      DATA B(79576), B(79577), B(79578) /    -7.20,  -17.63,    0.00 /
      DATA B(79879), B(79880), B(79881) /    -7.48,  -17.39,    0.00 /
      DATA B(80182), B(80183), B(80184) /    -7.76,  -17.15,    0.00 /
      DATA B(80485), B(80486), B(80487) /    -8.03,  -16.90,    0.00 /
      DATA B(80788), B(80789), B(80790) /    -8.30,  -16.66,    0.00 /
      DATA B(81091), B(81092), B(81093) /    -8.56,  -16.43,    0.00 /
      DATA B(81394), B(81395), B(81396) /    -8.81,  -16.21,    0.00 /
      DATA B(81697), B(81698), B(81699) /    -9.04,  -16.00,    0.00 /
      DATA B(82000), B(82001), B(82002) /    -9.22,  -15.79,    0.00 /
      DATA B(82303), B(82304), B(82305) /    -9.28,  -15.55,    0.00 /
      DATA B(82606), B(82607), B(82608) /    -9.17,  -14.97,    0.00 /
      DATA B(82909), B(82910), B(82911) /    -8.96,  -14.58,    0.00 /
      DATA B(83212), B(83213), B(83214) /    -8.73,  -14.40,    0.00 /
      DATA B(83515), B(83516), B(83517) /    -8.69,  -14.22,    0.00 /
      DATA B(83818), B(83819), B(83820) /    -8.71,  -14.06,    0.00 /
      DATA B(84121), B(84122), B(84123) /    -8.76,  -13.89,    0.00 /
      DATA B(84424), B(84425), B(84426) /    -8.82,  -13.71,    0.00 /
      DATA B(84727), B(84728), B(84729) /    -8.88,  -13.54,    0.00 /
      DATA B(85030), B(85031), B(85032) /    -8.95,  -13.36,    0.00 /
      DATA B(85333), B(85334), B(85335) /    -9.00,  -13.18,    0.00 /
      DATA B(85636), B(85637), B(85638) /    -9.02,  -12.99,    0.00 /
      DATA B(85939), B(85940), B(85941) /    -8.95,  -12.78,    0.00 /
      DATA B(86242), B(86243), B(86244) /    -8.60,  -12.82,    0.00 /
      DATA B(86545), B(86546), B(86547) /    -8.35,  -12.55,    0.00 /
      DATA B(86848), B(86849), B(86850) /    -8.32,  -12.29,    0.00 /
      DATA B(87151), B(87152), B(87153) /    -9.03,  -12.49,    0.00 /
      DATA B(87454), B(87455), B(87456) /    -9.25,  -12.72,    0.00 /
      DATA B(87757), B(87758), B(87759) /    -9.32,  -12.82,    0.00 /
      DATA B(88060), B(88061), B(88062) /    -9.33,  -12.90,    0.00 /
      DATA B(88363), B(88364), B(88365) /    -9.34,  -12.98,    0.00 /
      DATA B(88666), B(88667), B(88668) /    -9.35,  -13.05,    0.00 /
      DATA B(88969), B(88970), B(88971) /   -10.00,  -13.05,    0.00 /
      DATA B(89272), B(89273), B(89274) /   -10.00,  -13.11,    0.00 /
      DATA B(89575), B(89576), B(89577) /   -10.00,  -13.17,    0.00 /
      DATA B(67762), B(67763), B(67764) /    24.64,  -45.36,    0.00 /
      DATA B(68065), B(68066), B(68067) /    24.62,  -45.07,    0.00 /
      DATA B(68368), B(68369), B(68370) /    24.60,  -44.77,    0.00 /
      DATA B(68671), B(68672), B(68673) /    24.58,  -44.46,    0.00 /
      DATA B(68974), B(68975), B(68976) /    24.55,  -44.14,    0.00 /
      DATA B(69277), B(69278), B(69279) /    24.52,  -43.79,    0.00 /
      DATA B(69580), B(69581), B(69582) /    24.48,  -43.41,    0.00 /
      DATA B(69883), B(69884), B(69885) /    24.42,  -42.98,    0.00 /
      DATA B(70186), B(70187), B(70188) /    24.33,  -42.46,    0.00 /
      DATA B(70489), B(70490), B(70491) /    24.16,  -41.78,    0.00 /
      DATA B(70792), B(70793), B(70794) /    23.76,  -40.51,    0.00 /
      DATA B(71095), B(71096), B(71097) /    21.75,  -37.92,    0.00 /
      DATA B(71398), B(71399), B(71400) /    21.05,  -39.58,    0.00 /
      DATA B(71701), B(71702), B(71703) /    17.67,  -39.44,    0.00 /
      DATA B(72004), B(72005), B(72006) /    14.13,  -39.15,    0.00 /
      DATA B(72307), B(72308), B(72309) /     8.79,  -35.70,    0.00 /
      DATA B(72610), B(72611), B(72612) /     6.56,  -26.52,    0.00 /
      DATA B(72913), B(72914), B(72915) /     3.22,  -24.87,    0.00 /
      DATA B(73216), B(73217), B(73218) /     1.12,  -23.54,    0.00 /
      DATA B(73519), B(73520), B(73521) /     0.26,  -22.87,    0.00 /
      DATA B(73822), B(73823), B(73824) /    -0.27,  -22.45,    0.00 /
      DATA B(74125), B(74126), B(74127) /    -0.65,  -22.14,    0.00 /
      DATA B(74428), B(74429), B(74430) /    -0.96,  -21.90,    0.00 /
      DATA B(74731), B(74732), B(74733) /    -1.25,  -21.68,    0.00 /
      DATA B(75034), B(75035), B(75036) /    -1.53,  -21.47,    0.00 /
      DATA B(75337), B(75338), B(75339) /    -1.81,  -21.27,    0.00 /
      DATA B(75640), B(75641), B(75642) /    -2.10,  -21.03,    0.00 /
      DATA B(75943), B(75944), B(75945) /    -2.85,  -20.30,    0.00 /
      DATA B(76246), B(76247), B(76248) /    -3.55,  -19.80,    0.00 /
      DATA B(76549), B(76550), B(76551) /    -4.07,  -19.37,    0.00 /
      DATA B(76852), B(76853), B(76854) /    -4.46,  -19.12,    0.00 /
      DATA B(77155), B(77156), B(77157) /    -4.81,  -18.94,    0.00 /
      DATA B(77458), B(77459), B(77460) /    -5.14,  -18.77,    0.00 /
      DATA B(77761), B(77762), B(77763) /    -5.47,  -18.61,    0.00 /
      DATA B(78064), B(78065), B(78066) /    -5.78,  -18.42,    0.00 /
      DATA B(78367), B(78368), B(78369) /    -6.09,  -18.23,    0.00 /
      DATA B(78670), B(78671), B(78672) /    -6.39,  -18.03,    0.00 /
      DATA B(78973), B(78974), B(78975) /    -6.68,  -17.82,    0.00 /
      DATA B(79276), B(79277), B(79278) /    -6.97,  -17.62,    0.00 /
      DATA B(79579), B(79580), B(79581) /    -7.25,  -17.40,    0.00 /
      DATA B(79882), B(79883), B(79884) /    -7.53,  -17.18,    0.00 /
      DATA B(80185), B(80186), B(80187) /    -7.81,  -16.95,    0.00 /
      DATA B(80488), B(80489), B(80490) /    -8.08,  -16.72,    0.00 /
      DATA B(80791), B(80792), B(80793) /    -8.35,  -16.49,    0.00 /
      DATA B(81094), B(81095), B(81096) /    -8.62,  -16.26,    0.00 /
      DATA B(81397), B(81398), B(81399) /    -8.88,  -16.05,    0.00 /
      DATA B(81700), B(81701), B(81702) /    -9.12,  -15.84,    0.00 /
      DATA B(82003), B(82004), B(82005) /    -9.34,  -15.62,    0.00 /
      DATA B(82306), B(82307), B(82308) /    -9.45,  -15.38,    0.00 /
      DATA B(82609), B(82610), B(82611) /    -9.33,  -15.00,    0.00 /
      DATA B(82912), B(82913), B(82914) /    -9.09,  -14.73,    0.00 /
      DATA B(83215), B(83216), B(83217) /    -8.87,  -14.55,    0.00 /
      DATA B(83518), B(83519), B(83520) /    -8.83,  -14.38,    0.00 /
      DATA B(83821), B(83822), B(83823) /    -8.85,  -14.20,    0.00 /
      DATA B(84124), B(84125), B(84126) /    -8.90,  -14.03,    0.00 /
      DATA B(84427), B(84428), B(84429) /    -8.95,  -13.85,    0.00 /
      DATA B(84730), B(84731), B(84732) /    -9.01,  -13.67,    0.00 /
      DATA B(85033), B(85034), B(85035) /    -9.07,  -13.49,    0.00 /
      DATA B(85336), B(85337), B(85338) /    -9.12,  -13.29,    0.00 /
      DATA B(85639), B(85640), B(85641) /    -9.15,  -13.07,    0.00 /
      DATA B(85942), B(85943), B(85944) /    -9.10,  -12.91,    0.00 /
      DATA B(86245), B(86246), B(86247) /    -9.36,  -12.83,    0.00 /
      DATA B(86548), B(86549), B(86550) /    -9.21,  -12.67,    0.00 /
      DATA B(86851), B(86852), B(86853) /    -9.20,  -12.57,    0.00 /
      DATA B(87154), B(87155), B(87156) /    -9.19,  -12.60,    0.00 /
      DATA B(87457), B(87458), B(87459) /    -9.28,  -12.81,    0.00 /
      DATA B(87760), B(87761), B(87762) /    -9.32,  -12.92,    0.00 /
      DATA B(88063), B(88064), B(88065) /    -9.33,  -13.00,    0.00 /
      DATA B(88366), B(88367), B(88368) /    -9.34,  -13.08,    0.00 /
      DATA B(88669), B(88670), B(88671) /    -9.93,  -13.08,    0.00 /
      DATA B(88972), B(88973), B(88974) /    -9.95,  -13.13,    0.00 /
      DATA B(89275), B(89276), B(89277) /    -9.95,  -13.18,    0.00 /
      DATA B(89578), B(89579), B(89580) /    -9.95,  -13.24,    0.00 /
      DATA B(67765), B(67766), B(67767) /    24.52,  -45.27,    0.00 /
      DATA B(68068), B(68069), B(68070) /    24.50,  -44.97,    0.00 /
      DATA B(68371), B(68372), B(68373) /    24.48,  -44.66,    0.00 /
      DATA B(68674), B(68675), B(68676) /    24.45,  -44.34,    0.00 /
      DATA B(68977), B(68978), B(68979) /    24.42,  -43.99,    0.00 /
      DATA B(69280), B(69281), B(69282) /    24.38,  -43.61,    0.00 /
      DATA B(69583), B(69584), B(69585) /    24.33,  -43.18,    0.00 /
      DATA B(69886), B(69887), B(69888) /    24.27,  -42.63,    0.00 /
      DATA B(70189), B(70190), B(70191) /    24.12,  -41.87,    0.00 /
      DATA B(70492), B(70493), B(70494) /    23.72,  -40.76,    0.00 /
      DATA B(70795), B(70796), B(70797) /    22.15,  -38.88,    0.00 /
      DATA B(71098), B(71099), B(71100) /    20.82,  -37.67,    0.00 /
      DATA B(71401), B(71402), B(71403) /    19.83,  -38.37,    0.00 /
      DATA B(71704), B(71705), B(71706) /    16.30,  -38.76,    0.00 /
      DATA B(72007), B(72008), B(72009) /    12.20,  -37.77,    0.00 /
      DATA B(72310), B(72311), B(72312) /     8.77,  -30.78,    0.00 /
      DATA B(72613), B(72614), B(72615) /     4.79,  -24.42,    0.00 /
      DATA B(72916), B(72917), B(72918) /     3.20,  -24.64,    0.00 /
      DATA B(73219), B(73220), B(73221) /     1.29,  -23.31,    0.00 /
      DATA B(73522), B(73523), B(73524) /     0.32,  -22.64,    0.00 /
      DATA B(73825), B(73826), B(73827) /    -0.21,  -22.25,    0.00 /
      DATA B(74128), B(74129), B(74130) /    -0.60,  -21.96,    0.00 /
      DATA B(74431), B(74432), B(74433) /    -0.92,  -21.70,    0.00 /
      DATA B(74734), B(74735), B(74736) /    -1.23,  -21.45,    0.00 /
      DATA B(75037), B(75038), B(75039) /    -1.55,  -21.20,    0.00 /
      DATA B(75340), B(75341), B(75342) /    -1.90,  -20.96,    0.00 /
      DATA B(75643), B(75644), B(75645) /    -3.56,  -19.62,    0.00 /
      DATA B(75946), B(75947), B(75948) /    -3.39,  -19.55,    0.00 /
      DATA B(76249), B(76250), B(76251) /    -3.98,  -18.93,    0.00 /
      DATA B(76552), B(76553), B(76554) /    -4.44,  -18.69,    0.00 /
      DATA B(76855), B(76856), B(76857) /    -4.77,  -18.56,    0.00 /
      DATA B(77158), B(77159), B(77160) /    -5.06,  -18.45,    0.00 /
      DATA B(77461), B(77462), B(77463) /    -5.36,  -18.32,    0.00 /
      DATA B(77764), B(77765), B(77766) /    -5.65,  -18.19,    0.00 /
      DATA B(78067), B(78068), B(78069) /    -5.93,  -18.05,    0.00 /
      DATA B(78370), B(78371), B(78372) /    -6.22,  -17.88,    0.00 /
      DATA B(78673), B(78674), B(78675) /    -6.50,  -17.72,    0.00 /
      DATA B(78976), B(78977), B(78978) /    -6.78,  -17.55,    0.00 /
      DATA B(79279), B(79280), B(79281) /    -7.05,  -17.36,    0.00 /
      DATA B(79582), B(79583), B(79584) /    -7.32,  -17.17,    0.00 /
      DATA B(79885), B(79886), B(79887) /    -7.59,  -16.97,    0.00 /
      DATA B(80188), B(80189), B(80190) /    -7.86,  -16.76,    0.00 /
      DATA B(80491), B(80492), B(80493) /    -8.12,  -16.53,    0.00 /
      DATA B(80794), B(80795), B(80796) /    -8.39,  -16.31,    0.00 /
      DATA B(81097), B(81098), B(81099) /    -8.66,  -16.09,    0.00 /
      DATA B(81400), B(81401), B(81402) /    -8.92,  -15.88,    0.00 /
      DATA B(81703), B(81704), B(81705) /    -9.18,  -15.67,    0.00 /
      DATA B(82006), B(82007), B(82008) /    -9.41,  -15.46,    0.00 /
      DATA B(82309), B(82310), B(82311) /    -9.53,  -15.24,    0.00 /
      DATA B(82612), B(82613), B(82614) /    -9.43,  -15.00,    0.00 /
      DATA B(82915), B(82916), B(82917) /    -9.18,  -14.87,    0.00 /
      DATA B(83218), B(83219), B(83220) /    -8.99,  -14.70,    0.00 /
      DATA B(83521), B(83522), B(83523) /    -8.96,  -14.52,    0.00 /
      DATA B(83824), B(83825), B(83826) /    -8.98,  -14.34,    0.00 /
      DATA B(84127), B(84128), B(84129) /    -9.03,  -14.16,    0.00 /
      DATA B(84430), B(84431), B(84432) /    -9.08,  -13.98,    0.00 /
      DATA B(84733), B(84734), B(84735) /    -9.14,  -13.80,    0.00 /
      DATA B(85036), B(85037), B(85038) /    -9.19,  -13.60,    0.00 /
      DATA B(85339), B(85340), B(85341) /    -9.23,  -13.36,    0.00 /
      DATA B(85642), B(85643), B(85644) /    -9.32,  -13.07,    0.00 /
      DATA B(85945), B(85946), B(85947) /    -9.42,  -12.88,    0.00 /
      DATA B(86248), B(86249), B(86250) /    -9.41,  -12.84,    0.00 /
      DATA B(86551), B(86552), B(86553) /    -9.38,  -12.78,    0.00 /
      DATA B(86854), B(86855), B(86856) /    -9.34,  -12.75,    0.00 /
      DATA B(87157), B(87158), B(87159) /    -9.31,  -12.80,    0.00 /
      DATA B(87460), B(87461), B(87462) /    -9.31,  -12.92,    0.00 /
      DATA B(87763), B(87764), B(87765) /    -9.32,  -13.01,    0.00 /
      DATA B(88066), B(88067), B(88068) /    -9.33,  -13.09,    0.00 /
      DATA B(88369), B(88370), B(88371) /    -9.33,  -13.16,    0.00 /
      DATA B(88672), B(88673), B(88674) /    -9.88,  -13.14,    0.00 /
      DATA B(88975), B(88976), B(88977) /    -9.89,  -13.19,    0.00 /
      DATA B(89278), B(89279), B(89280) /    -9.89,  -13.25,    0.00 /
      DATA B(89581), B(89582), B(89583) /    -9.89,  -13.30,    0.00 /
      DATA B(67768), B(67769), B(67770) /    24.40,  -45.17,    0.00 /
      DATA B(68071), B(68072), B(68073) /    24.38,  -44.86,    0.00 /
      DATA B(68374), B(68375), B(68376) /    24.35,  -44.53,    0.00 /
      DATA B(68677), B(68678), B(68679) /    24.32,  -44.19,    0.00 /
      DATA B(68980), B(68981), B(68982) /    24.28,  -43.81,    0.00 /
      DATA B(69283), B(69284), B(69285) /    24.24,  -43.38,    0.00 /
      DATA B(69586), B(69587), B(69588) /    24.19,  -42.84,    0.00 /
      DATA B(69889), B(69890), B(69891) /    24.10,  -42.05,    0.00 /
      DATA B(70192), B(70193), B(70194) /    23.75,  -40.69,    0.00 /
      DATA B(70495), B(70496), B(70497) /    22.16,  -39.49,    0.00 /
      DATA B(70798), B(70799), B(70800) /    20.90,  -38.40,    0.00 /
      DATA B(71101), B(71102), B(71103) /    19.94,  -37.95,    0.00 /
      DATA B(71404), B(71405), B(71406) /    18.20,  -37.90,    0.00 /
      DATA B(71707), B(71708), B(71709) /    14.90,  -37.94,    0.00 /
      DATA B(72010), B(72011), B(72012) /    11.25,  -36.44,    0.00 /
      DATA B(72313), B(72314), B(72315) /     7.08,  -26.75,    0.00 /
      DATA B(72616), B(72617), B(72618) /     3.13,  -22.67,    0.00 /
      DATA B(72919), B(72920), B(72921) /     2.76,  -23.89,    0.00 /
      DATA B(73222), B(73223), B(73224) /     1.60,  -23.19,    0.00 /
      DATA B(73525), B(73526), B(73527) /     0.41,  -22.40,    0.00 /
      DATA B(73828), B(73829), B(73830) /    -0.16,  -22.05,    0.00 /
      DATA B(74131), B(74132), B(74133) /    -0.57,  -21.79,    0.00 /
      DATA B(74434), B(74435), B(74436) /    -0.94,  -21.48,    0.00 /
      DATA B(74737), B(74738), B(74739) /    -1.32,  -21.15,    0.00 /
      DATA B(75040), B(75041), B(75042) /    -1.75,  -20.80,    0.00 /
      DATA B(75343), B(75344), B(75345) /    -1.37,  -21.19,    0.00 /
      DATA B(75646), B(75647), B(75648) /    -3.69,  -19.61,    0.00 /
      DATA B(75949), B(75950), B(75951) /    -4.45,  -18.87,    0.00 /
      DATA B(76252), B(76253), B(76254) /    -5.10,  -17.50,    0.00 /
      DATA B(76555), B(76556), B(76557) /    -5.31,  -17.68,    0.00 /
      DATA B(76858), B(76859), B(76860) /    -5.48,  -17.70,    0.00 /
      DATA B(77161), B(77162), B(77163) /    -5.65,  -17.69,    0.00 /
      DATA B(77464), B(77465), B(77466) /    -5.84,  -17.67,    0.00 /
      DATA B(77767), B(77768), B(77769) /    -6.04,  -17.62,    0.00 /
      DATA B(78070), B(78071), B(78072) /    -6.25,  -17.55,    0.00 /
      DATA B(78373), B(78374), B(78375) /    -6.47,  -17.45,    0.00 /
      DATA B(78676), B(78677), B(78678) /    -6.71,  -17.34,    0.00 /
      DATA B(78979), B(78980), B(78981) /    -6.94,  -17.23,    0.00 /
      DATA B(79282), B(79283), B(79284) /    -7.18,  -17.09,    0.00 /
      DATA B(79585), B(79586), B(79587) /    -7.42,  -16.94,    0.00 /
      DATA B(79888), B(79889), B(79890) /    -7.67,  -16.76,    0.00 /
      DATA B(80191), B(80192), B(80193) /    -7.92,  -16.56,    0.00 /
      DATA B(80494), B(80495), B(80496) /    -8.17,  -16.34,    0.00 /
      DATA B(80797), B(80798), B(80799) /    -8.42,  -16.13,    0.00 /
      DATA B(81100), B(81101), B(81102) /    -8.69,  -15.91,    0.00 /
      DATA B(81403), B(81404), B(81405) /    -8.95,  -15.70,    0.00 /
      DATA B(81706), B(81707), B(81708) /    -9.21,  -15.49,    0.00 /
      DATA B(82009), B(82010), B(82011) /    -9.44,  -15.29,    0.00 /
      DATA B(82312), B(82313), B(82314) /    -9.57,  -15.11,    0.00 /
      DATA B(82615), B(82616), B(82617) /    -9.52,  -15.01,    0.00 /
      DATA B(82918), B(82919), B(82920) /    -9.27,  -14.99,    0.00 /
      DATA B(83221), B(83222), B(83223) /    -9.10,  -14.84,    0.00 /
      DATA B(83524), B(83525), B(83526) /    -9.08,  -14.66,    0.00 /
      DATA B(83827), B(83828), B(83829) /    -9.11,  -14.47,    0.00 /
      DATA B(84130), B(84131), B(84132) /    -9.15,  -14.29,    0.00 /
      DATA B(84433), B(84434), B(84435) /    -9.21,  -14.10,    0.00 /
      DATA B(84736), B(84737), B(84738) /    -9.26,  -13.91,    0.00 /
      DATA B(85039), B(85040), B(85041) /    -9.29,  -13.68,    0.00 /
      DATA B(85342), B(85343), B(85344) /    -9.32,  -13.35,    0.00 /
      DATA B(85645), B(85646), B(85647) /    -9.50,  -13.06,    0.00 /
      DATA B(85948), B(85949), B(85950) /    -9.45,  -12.89,    0.00 /
      DATA B(86251), B(86252), B(86253) /    -9.42,  -12.88,    0.00 /
      DATA B(86554), B(86555), B(86556) /    -9.39,  -12.88,    0.00 /
      DATA B(86857), B(86858), B(86859) /    -9.37,  -12.89,    0.00 /
      DATA B(87160), B(87161), B(87162) /    -9.34,  -12.94,    0.00 /
      DATA B(87463), B(87464), B(87465) /    -9.32,  -13.02,    0.00 /
      DATA B(87766), B(87767), B(87768) /    -9.32,  -13.10,    0.00 /
      DATA B(88069), B(88070), B(88071) /    -9.32,  -13.18,    0.00 /
      DATA B(88372), B(88373), B(88374) /    -9.32,  -13.25,    0.00 /
      DATA B(88675), B(88676), B(88677) /    -9.83,  -13.20,    0.00 /
      DATA B(88978), B(88979), B(88980) /    -9.84,  -13.25,    0.00 /
      DATA B(89281), B(89282), B(89283) /    -9.84,  -13.31,    0.00 /
      DATA B(89584), B(89585), B(89586) /    -9.84,  -13.36,    0.00 /
      DATA B(67771), B(67772), B(67773) /    24.28,  -45.05,    0.00 /
      DATA B(68074), B(68075), B(68076) /    24.25,  -44.73,    0.00 /
      DATA B(68377), B(68378), B(68379) /    24.22,  -44.38,    0.00 /
      DATA B(68680), B(68681), B(68682) /    24.18,  -44.01,    0.00 /
      DATA B(68983), B(68984), B(68985) /    24.14,  -43.58,    0.00 /
      DATA B(69286), B(69287), B(69288) /    24.09,  -43.05,    0.00 /
      DATA B(69589), B(69590), B(69591) /    24.01,  -42.27,    0.00 /
      DATA B(69892), B(69893), B(69894) /    23.63,  -40.90,    0.00 /
      DATA B(70195), B(70196), B(70197) /    22.01,  -39.64,    0.00 /
      DATA B(70498), B(70499), B(70500) /    20.96,  -38.90,    0.00 /
      DATA B(70801), B(70802), B(70803) /    20.04,  -38.52,    0.00 /
      DATA B(71104), B(71105), B(71106) /    18.51,  -38.32,    0.00 /
      DATA B(71407), B(71408), B(71409) /    15.96,  -37.44,    0.00 /
      DATA B(71710), B(71711), B(71712) /    13.28,  -36.91,    0.00 /
      DATA B(72013), B(72014), B(72015) /    10.21,  -33.62,    0.00 /
      DATA B(72316), B(72317), B(72318) /     6.02,  -24.68,    0.00 /
      DATA B(72619), B(72620), B(72621) /     3.85,  -22.16,    0.00 /
      DATA B(72922), B(72923), B(72924) /     2.00,  -22.66,    0.00 /
      DATA B(73225), B(73226), B(73227) /     1.77,  -23.22,    0.00 /
      DATA B(73528), B(73529), B(73530) /     0.49,  -22.16,    0.00 /
      DATA B(73831), B(73832), B(73833) /    -0.11,  -21.85,    0.00 /
      DATA B(74134), B(74135), B(74136) /    -0.61,  -21.63,    0.00 /
      DATA B(74437), B(74438), B(74439) /    -1.16,  -21.17,    0.00 /
      DATA B(74740), B(74741), B(74742) /    -1.80,  -20.66,    0.00 /
      DATA B(75043), B(75044), B(75045) /    -3.03,  -19.70,    0.00 /
      DATA B(75346), B(75347), B(75348) /    -5.18,  -18.87,    0.00 /
      DATA B(75649), B(75650), B(75651) /    -6.79,  -18.32,    0.00 /
      DATA B(75952), B(75953), B(75954) /    -8.85,  -17.37,    0.00 /
      DATA B(76255), B(76256), B(76257) /    -6.32,  -16.98,    0.00 /
      DATA B(76558), B(76559), B(76560) /    -7.26,  -17.32,    0.00 /
      DATA B(76861), B(76862), B(76863) /    -7.31,  -17.32,    0.00 /
      DATA B(77164), B(77165), B(77166) /    -7.36,  -17.20,    0.00 /
      DATA B(77467), B(77468), B(77469) /    -7.31,  -17.11,    0.00 /
      DATA B(77770), B(77771), B(77772) /    -7.26,  -17.03,    0.00 /
      DATA B(78073), B(78074), B(78075) /    -7.24,  -16.95,    0.00 /
      DATA B(78376), B(78377), B(78378) /    -7.24,  -16.88,    0.00 /
      DATA B(78679), B(78680), B(78681) /    -7.27,  -16.83,    0.00 /
      DATA B(78982), B(78983), B(78984) /    -7.34,  -16.81,    0.00 /
      DATA B(79285), B(79286), B(79287) /    -7.46,  -16.76,    0.00 /
      DATA B(79588), B(79589), B(79590) /    -7.63,  -16.67,    0.00 /
      DATA B(79891), B(79892), B(79893) /    -7.82,  -16.55,    0.00 /
      DATA B(80194), B(80195), B(80196) /    -8.02,  -16.38,    0.00 /
      DATA B(80497), B(80498), B(80499) /    -8.23,  -16.16,    0.00 /
      DATA B(80800), B(80801), B(80802) /    -8.46,  -15.94,    0.00 /
      DATA B(81103), B(81104), B(81105) /    -8.71,  -15.72,    0.00 /
      DATA B(81406), B(81407), B(81408) /    -8.97,  -15.52,    0.00 /
      DATA B(81709), B(81710), B(81711) /    -9.23,  -15.31,    0.00 /
      DATA B(82012), B(82013), B(82014) /    -9.46,  -15.12,    0.00 /
      DATA B(82315), B(82316), B(82317) /    -9.60,  -14.98,    0.00 /
      DATA B(82618), B(82619), B(82620) /    -9.58,  -15.03,    0.00 /
      DATA B(82921), B(82922), B(82923) /    -9.33,  -15.12,    0.00 /
      DATA B(83224), B(83225), B(83226) /    -9.20,  -14.97,    0.00 /
      DATA B(83527), B(83528), B(83529) /    -9.19,  -14.79,    0.00 /
      DATA B(83830), B(83831), B(83832) /    -9.22,  -14.59,    0.00 /
      DATA B(84133), B(84134), B(84135) /    -9.27,  -14.40,    0.00 /
      DATA B(84436), B(84437), B(84438) /    -9.32,  -14.20,    0.00 /
      DATA B(84739), B(84740), B(84741) /    -9.37,  -13.99,    0.00 /
      DATA B(85042), B(85043), B(85044) /    -9.37,  -13.72,    0.00 /
      DATA B(85345), B(85346), B(85347) /    -9.47,  -13.30,    0.00 /
      DATA B(85648), B(85649), B(85650) /    -9.52,  -13.02,    0.00 /
      DATA B(85951), B(85952), B(85953) /    -9.45,  -12.93,    0.00 /
      DATA B(86254), B(86255), B(86256) /    -9.41,  -12.94,    0.00 /
      DATA B(86557), B(86558), B(86559) /    -9.38,  -12.96,    0.00 /
      DATA B(86860), B(86861), B(86862) /    -9.36,  -12.99,    0.00 /
      DATA B(87163), B(87164), B(87165) /    -9.34,  -13.04,    0.00 /
      DATA B(87466), B(87467), B(87468) /    -9.32,  -13.11,    0.00 /
      DATA B(87769), B(87770), B(87771) /    -9.31,  -13.19,    0.00 /
      DATA B(88072), B(88073), B(88074) /    -9.31,  -13.26,    0.00 /
      DATA B(88375), B(88376), B(88377) /    -9.31,  -13.33,    0.00 /
      DATA B(88678), B(88679), B(88680) /    -9.77,  -13.26,    0.00 /
      DATA B(88981), B(88982), B(88983) /    -9.78,  -13.31,    0.00 /
      DATA B(89284), B(89285), B(89286) /    -9.78,  -13.36,    0.00 /
      DATA B(89587), B(89588), B(89589) /    -9.77,  -13.42,    0.00 /
      DATA B(67774), B(67775), B(67776) /    24.16,  -44.92,    0.00 /
      DATA B(68077), B(68078), B(68079) /    24.13,  -44.57,    0.00 /
      DATA B(68380), B(68381), B(68382) /    24.09,  -44.19,    0.00 /
      DATA B(68683), B(68684), B(68685) /    24.05,  -43.77,    0.00 /
      DATA B(68986), B(68987), B(68988) /    24.00,  -43.25,    0.00 /
      DATA B(69289), B(69290), B(69291) /    23.92,  -42.49,    0.00 /
      DATA B(69592), B(69593), B(69594) /    23.54,  -41.13,    0.00 /
      DATA B(69895), B(69896), B(69897) /    21.93,  -39.84,    0.00 /
      DATA B(70198), B(70199), B(70200) /    21.02,  -39.13,    0.00 /
      DATA B(70501), B(70502), B(70503) /    20.22,  -38.88,    0.00 /
      DATA B(70804), B(70805), B(70806) /    18.63,  -38.89,    0.00 /
      DATA B(71107), B(71108), B(71109) /    16.70,  -37.84,    0.00 /
      DATA B(71410), B(71411), B(71412) /    15.13,  -36.81,    0.00 /
      DATA B(71713), B(71714), B(71715) /    12.96,  -35.57,    0.00 /
      DATA B(72016), B(72017), B(72018) /     9.40,  -29.44,    0.00 /
      DATA B(72319), B(72320), B(72321) /     5.37,  -23.64,    0.00 /
      DATA B(72622), B(72623), B(72624) /     3.74,  -22.20,    0.00 /
      DATA B(72925), B(72926), B(72927) /     2.35,  -21.47,    0.00 /
      DATA B(73228), B(73229), B(73230) /    -0.01,  -21.24,    0.00 /
      DATA B(73531), B(73532), B(73533) /     0.62,  -21.95,    0.00 /
      DATA B(73834), B(73835), B(73836) /     0.05,  -21.61,    0.00 /
      DATA B(74137), B(74138), B(74139) /    -3.49,  -21.00,    0.00 /
      DATA B(74440), B(74441), B(74442) /    -3.57,  -19.76,    0.00 /
      DATA B(74743), B(74744), B(74745) /    -4.70,  -19.02,    0.00 /
      DATA B(75046), B(75047), B(75048) /    -5.90,  -18.30,    0.00 /
      DATA B(75349), B(75350), B(75351) /    -6.76,  -17.55,    0.00 /
      DATA B(75652), B(75653), B(75654) /    -8.56,  -17.00,    0.00 /
      DATA B(75955), B(75956), B(75957) /    -7.92,  -16.83,    0.00 /
      DATA B(76258), B(76259), B(76260) /    -8.21,  -16.44,    0.00 /
      DATA B(76561), B(76562), B(76563) /    -8.43,  -16.51,    0.00 /
      DATA B(76864), B(76865), B(76866) /    -8.57,  -16.61,    0.00 /
      DATA B(77167), B(77168), B(77169) /    -8.64,  -16.67,    0.00 /
      DATA B(77470), B(77471), B(77472) /    -8.68,  -16.71,    0.00 /
      DATA B(77773), B(77774), B(77775) /    -8.69,  -16.73,    0.00 /
      DATA B(78076), B(78077), B(78078) /    -8.68,  -16.74,    0.00 /
      DATA B(78379), B(78380), B(78381) /    -8.60,  -16.77,    0.00 /
      DATA B(78682), B(78683), B(78684) /    -8.49,  -16.75,    0.00 /
      DATA B(78985), B(78986), B(78987) /    -8.37,  -16.64,    0.00 /
      DATA B(79288), B(79289), B(79290) /    -8.26,  -16.52,    0.00 /
      DATA B(79591), B(79592), B(79593) /    -8.20,  -16.42,    0.00 /
      DATA B(79894), B(79895), B(79896) /    -8.25,  -16.36,    0.00 /
      DATA B(80197), B(80198), B(80199) /    -8.32,  -16.23,    0.00 /
      DATA B(80500), B(80501), B(80502) /    -8.39,  -16.00,    0.00 /
      DATA B(80803), B(80804), B(80805) /    -8.51,  -15.77,    0.00 /
      DATA B(81106), B(81107), B(81108) /    -8.72,  -15.54,    0.00 /
      DATA B(81409), B(81410), B(81411) /    -8.97,  -15.33,    0.00 /
      DATA B(81712), B(81713), B(81714) /    -9.22,  -15.13,    0.00 /
      DATA B(82015), B(82016), B(82017) /    -9.46,  -14.94,    0.00 /
      DATA B(82318), B(82319), B(82320) /    -9.61,  -14.84,    0.00 /
      DATA B(82621), B(82622), B(82623) /    -9.62,  -15.10,    0.00 /
      DATA B(82924), B(82925), B(82926) /    -9.38,  -15.26,    0.00 /
      DATA B(83227), B(83228), B(83229) /    -9.28,  -15.10,    0.00 /
      DATA B(83530), B(83531), B(83532) /    -9.29,  -14.90,    0.00 /
      DATA B(83833), B(83834), B(83835) /    -9.32,  -14.69,    0.00 /
      DATA B(84136), B(84137), B(84138) /    -9.37,  -14.48,    0.00 /
      DATA B(84439), B(84440), B(84441) /    -9.43,  -14.26,    0.00 /
      DATA B(84742), B(84743), B(84744) /    -9.46,  -14.02,    0.00 /
      DATA B(85045), B(85046), B(85047) /    -9.44,  -13.67,    0.00 /
      DATA B(85348), B(85349), B(85350) /    -9.63,  -13.25,    0.00 /
      DATA B(85651), B(85652), B(85653) /    -9.50,  -13.02,    0.00 /
      DATA B(85954), B(85955), B(85956) /    -9.43,  -12.99,    0.00 /
      DATA B(86257), B(86258), B(86259) /    -9.39,  -13.00,    0.00 /
      DATA B(86560), B(86561), B(86562) /    -9.37,  -13.04,    0.00 /
      DATA B(86863), B(86864), B(86865) /    -9.35,  -13.08,    0.00 /
      DATA B(87166), B(87167), B(87168) /    -9.33,  -13.13,    0.00 /
      DATA B(87469), B(87470), B(87471) /    -9.31,  -13.20,    0.00 /
      DATA B(87772), B(87773), B(87774) /    -9.30,  -13.27,    0.00 /
      DATA B(88075), B(88076), B(88077) /    -9.29,  -13.34,    0.00 /
      DATA B(88378), B(88379), B(88380) /    -9.71,  -13.27,    0.00 /
      DATA B(88681), B(88682), B(88683) /    -9.71,  -13.32,    0.00 /
      DATA B(88984), B(88985), B(88986) /    -9.71,  -13.37,    0.00 /
      DATA B(89287), B(89288), B(89289) /    -9.71,  -13.42,    0.00 /
      DATA B(89590), B(89591), B(89592) /    -9.71,  -13.47,    0.00 /
      DATA B(67777), B(67778), B(67779) /    24.04,  -44.76,    0.00 /
      DATA B(68080), B(68081), B(68082) /    24.01,  -44.37,    0.00 /
      DATA B(68383), B(68384), B(68385) /    23.97,  -43.93,    0.00 /
      DATA B(68686), B(68687), B(68688) /    23.91,  -43.40,    0.00 /
      DATA B(68989), B(68990), B(68991) /    23.81,  -42.66,    0.00 /
      DATA B(69292), B(69293), B(69294) /    23.45,  -41.36,    0.00 /
      DATA B(69595), B(69596), B(69597) /    21.88,  -40.10,    0.00 /
      DATA B(69898), B(69899), B(69900) /    21.01,  -39.41,    0.00 /
      DATA B(70201), B(70202), B(70203) /    20.31,  -39.21,    0.00 /
      DATA B(70504), B(70505), B(70506) /    18.82,  -39.37,    0.00 /
      DATA B(70807), B(70808), B(70809) /    17.22,  -38.35,    0.00 /
      DATA B(71110), B(71111), B(71112) /    16.11,  -37.28,    0.00 /
      DATA B(71413), B(71414), B(71415) /    14.26,  -35.51,    0.00 /
      DATA B(71716), B(71717), B(71718) /    12.54,  -33.57,    0.00 /
      DATA B(72019), B(72020), B(72021) /     7.68,  -26.52,    0.00 /
      DATA B(72322), B(72323), B(72324) /     4.86,  -23.14,    0.00 /
      DATA B(72625), B(72626), B(72627) /     3.53,  -22.24,    0.00 /
      DATA B(72928), B(72929), B(72930) /     2.29,  -21.65,    0.00 /
      DATA B(73231), B(73232), B(73233) /     0.69,  -20.80,    0.00 /
      DATA B(73534), B(73535), B(73536) /    -1.16,  -20.14,    0.00 /
      DATA B(73837), B(73838), B(73839) /    -2.68,  -19.52,    0.00 /
      DATA B(74140), B(74141), B(74142) /    -3.82,  -19.31,    0.00 /
      DATA B(74443), B(74444), B(74445) /    -5.07,  -18.79,    0.00 /
      DATA B(74746), B(74747), B(74748) /    -6.22,  -17.87,    0.00 /
      DATA B(75049), B(75050), B(75051) /    -7.00,  -17.22,    0.00 /
      DATA B(75352), B(75353), B(75354) /    -7.87,  -16.22,    0.00 /
      DATA B(75655), B(75656), B(75657) /    -8.58,  -16.46,    0.00 /
      DATA B(75958), B(75959), B(75960) /    -8.69,  -16.23,    0.00 /
      DATA B(76261), B(76262), B(76263) /    -8.77,  -16.11,    0.00 /
      DATA B(76564), B(76565), B(76566) /    -8.85,  -16.13,    0.00 /
      DATA B(76867), B(76868), B(76869) /    -8.94,  -16.20,    0.00 /
      DATA B(77170), B(77171), B(77172) /    -9.01,  -16.26,    0.00 /
      DATA B(77473), B(77474), B(77475) /    -9.07,  -16.31,    0.00 /
      DATA B(77776), B(77777), B(77778) /    -9.11,  -16.35,    0.00 /
      DATA B(78079), B(78080), B(78081) /    -9.14,  -16.39,    0.00 /
      DATA B(78382), B(78383), B(78384) /    -9.15,  -16.43,    0.00 /
      DATA B(78685), B(78686), B(78687) /    -9.15,  -16.47,    0.00 /
      DATA B(78988), B(78989), B(78990) /    -9.15,  -16.48,    0.00 /
      DATA B(79291), B(79292), B(79293) /    -9.13,  -16.47,    0.00 /
      DATA B(79594), B(79595), B(79596) /    -9.11,  -16.42,    0.00 /
      DATA B(79897), B(79898), B(79899) /    -9.12,  -16.31,    0.00 /
      DATA B(80200), B(80201), B(80202) /    -9.13,  -16.20,    0.00 /
      DATA B(80503), B(80504), B(80505) /    -9.34,  -16.16,    0.00 /
      DATA B(80806), B(80807), B(80808) /    -8.61,  -15.65,    0.00 /
      DATA B(81109), B(81110), B(81111) /    -8.70,  -15.34,    0.00 /
      DATA B(81412), B(81413), B(81414) /    -9.76,  -16.66,    0.00 /
      DATA B(81715), B(81716), B(81717) /    -9.20,  -14.93,    0.00 /
      DATA B(82018), B(82019), B(82020) /    -9.42,  -14.74,    0.00 /
      DATA B(82321), B(82322), B(82323) /    -9.53,  -14.68,    0.00 /
      DATA B(82624), B(82625), B(82626) /    -9.49,  -15.38,    0.00 /
      DATA B(82927), B(82928), B(82929) /    -9.41,  -15.41,    0.00 /
      DATA B(83230), B(83231), B(83232) /    -9.35,  -15.22,    0.00 /
      DATA B(83533), B(83534), B(83535) /    -9.37,  -14.99,    0.00 /
      DATA B(83836), B(83837), B(83838) /    -9.41,  -14.75,    0.00 /
      DATA B(84139), B(84140), B(84141) /    -9.46,  -14.50,    0.00 /
      DATA B(84442), B(84443), B(84444) /    -9.50,  -14.23,    0.00 /
      DATA B(84745), B(84746), B(84747) /    -9.52,  -13.92,    0.00 /
      DATA B(85048), B(85049), B(85050) /    -9.60,  -13.56,    0.00 /
      DATA B(85351), B(85352), B(85353) /    -9.60,  -13.18,    0.00 /
      DATA B(85654), B(85655), B(85656) /    -9.47,  -13.06,    0.00 /
      DATA B(85957), B(85958), B(85959) /    -9.41,  -13.05,    0.00 /
      DATA B(86260), B(86261), B(86262) /    -9.37,  -13.07,    0.00 /
      DATA B(86563), B(86564), B(86565) /    -9.35,  -13.11,    0.00 /
      DATA B(86866), B(86867), B(86868) /    -9.33,  -13.16,    0.00 /
      DATA B(87169), B(87170), B(87171) /    -9.31,  -13.22,    0.00 /
      DATA B(87472), B(87473), B(87474) /    -9.29,  -13.28,    0.00 /
      DATA B(87775), B(87776), B(87777) /    -9.28,  -13.35,    0.00 /
      DATA B(88078), B(88079), B(88080) /    -9.28,  -13.42,    0.00 /
      DATA B(88381), B(88382), B(88383) /    -9.65,  -13.32,    0.00 /
      DATA B(88684), B(88685), B(88686) /    -9.65,  -13.37,    0.00 /
      DATA B(88987), B(88988), B(88989) /    -9.65,  -13.42,    0.00 /
      DATA B(89290), B(89291), B(89292) /    -9.65,  -13.47,    0.00 /
      DATA B(89593), B(89594), B(89595) /    -9.65,  -13.52,    0.00 /
      DATA B(67780), B(67781), B(67782) /    23.93,  -44.55,    0.00 /
      DATA B(68083), B(68084), B(68085) /    23.89,  -44.09,    0.00 /
      DATA B(68386), B(68387), B(68388) /    23.85,  -43.52,    0.00 /
      DATA B(68689), B(68690), B(68691) /    23.75,  -42.72,    0.00 /
      DATA B(68992), B(68993), B(68994) /    23.31,  -41.46,    0.00 /
      DATA B(69295), B(69296), B(69297) /    21.80,  -40.37,    0.00 /
      DATA B(69598), B(69599), B(69600) /    20.99,  -39.70,    0.00 /
      DATA B(69901), B(69902), B(69903) /    20.33,  -39.53,    0.00 /
      DATA B(70204), B(70205), B(70206) /    19.01,  -39.77,    0.00 /
      DATA B(70507), B(70508), B(70509) /    17.74,  -38.72,    0.00 /
      DATA B(70810), B(70811), B(70812) /    16.81,  -37.74,    0.00 /
      DATA B(71113), B(71114), B(71115) /    15.29,  -36.13,    0.00 /
      DATA B(71416), B(71417), B(71418) /    13.41,  -34.17,    0.00 /
      DATA B(71719), B(71720), B(71721) /     9.57,  -30.15,    0.00 /
      DATA B(72022), B(72023), B(72024) /     6.15,  -24.53,    0.00 /
      DATA B(72325), B(72326), B(72327) /     4.31,  -22.86,    0.00 /
      DATA B(72628), B(72629), B(72630) /     3.17,  -22.22,    0.00 /
      DATA B(72931), B(72932), B(72933) /     1.96,  -21.62,    0.00 /
      DATA B(73234), B(73235), B(73236) /     0.22,  -20.25,    0.00 /
      DATA B(73537), B(73538), B(73539) /    -1.35,  -19.34,    0.00 /
      DATA B(73840), B(73841), B(73842) /    -3.07,  -18.71,    0.00 /
      DATA B(74143), B(74144), B(74145) /    -4.53,  -18.29,    0.00 /
      DATA B(74446), B(74447), B(74448) /    -6.08,  -17.49,    0.00 /
      DATA B(74749), B(74750), B(74751) /    -7.00,  -16.93,    0.00 /
      DATA B(75052), B(75053), B(75054) /    -7.88,  -16.21,    0.00 /
      DATA B(75355), B(75356), B(75357) /    -8.58,  -16.03,    0.00 /
      DATA B(75658), B(75659), B(75660) /    -8.83,  -16.00,    0.00 /
      DATA B(75961), B(75962), B(75963) /    -8.93,  -15.95,    0.00 /
      DATA B(76264), B(76265), B(76266) /    -8.99,  -15.92,    0.00 /
      DATA B(76567), B(76568), B(76569) /    -9.04,  -15.95,    0.00 /
      DATA B(76870), B(76871), B(76872) /    -9.09,  -16.01,    0.00 /
      DATA B(77173), B(77174), B(77175) /    -9.15,  -16.07,    0.00 /
      DATA B(77476), B(77477), B(77478) /    -9.20,  -16.13,    0.00 /
      DATA B(77779), B(77780), B(77781) /    -9.24,  -16.18,    0.00 /
      DATA B(78082), B(78083), B(78084) /    -9.27,  -16.22,    0.00 /
      DATA B(78385), B(78386), B(78387) /    -9.30,  -16.27,    0.00 /
      DATA B(78688), B(78689), B(78690) /    -9.33,  -16.31,    0.00 /
      DATA B(78991), B(78992), B(78993) /    -9.35,  -16.34,    0.00 /
      DATA B(79294), B(79295), B(79296) /    -9.38,  -16.35,    0.00 /
      DATA B(79597), B(79598), B(79599) /    -9.41,  -16.35,    0.00 /
      DATA B(79900), B(79901), B(79902) /    -9.44,  -16.32,    0.00 /
      DATA B(80203), B(80204), B(80205) /    -9.48,  -16.29,    0.00 /
      DATA B(80506), B(80507), B(80508) /    -9.53,  -16.28,    0.00 /
      DATA B(80809), B(80810), B(80811) /    -9.60,  -16.38,    0.00 /
      DATA B(81112), B(81113), B(81114) /    -9.65,  -16.56,    0.00 /
      DATA B(81415), B(81416), B(81417) /    -9.65,  -16.66,    0.00 /
      DATA B(81718), B(81719), B(81720) /    -9.60,  -16.74,    0.00 /
      DATA B(82021), B(82022), B(82023) /    -9.34,  -14.51,    0.00 /
      DATA B(82324), B(82325), B(82326) /    -9.28,  -14.52,    0.00 /
      DATA B(82627), B(82628), B(82629) /    -8.88,  -15.87,    0.00 /
      DATA B(82930), B(82931), B(82932) /    -8.77,  -16.15,    0.00 /
      DATA B(83233), B(83234), B(83235) /    -9.42,  -15.31,    0.00 /
      DATA B(83536), B(83537), B(83538) /    -9.44,  -15.04,    0.00 /
      DATA B(83839), B(83840), B(83841) /    -9.47,  -14.74,    0.00 /
      DATA B(84142), B(84143), B(84144) /    -9.50,  -14.41,    0.00 /
      DATA B(84445), B(84446), B(84447) /    -9.51,  -14.03,    0.00 /
      DATA B(84748), B(84749), B(84750) /    -9.59,  -13.73,    0.00 /
      DATA B(85051), B(85052), B(85053) /    -9.70,  -13.52,    0.00 /
      DATA B(85354), B(85355), B(85356) /    -9.54,  -13.18,    0.00 /
      DATA B(85657), B(85658), B(85659) /    -9.43,  -13.11,    0.00 /
      DATA B(85960), B(85961), B(85962) /    -9.38,  -13.11,    0.00 /
      DATA B(86263), B(86264), B(86265) /    -9.35,  -13.14,    0.00 /
      DATA B(86566), B(86567), B(86568) /    -9.33,  -13.19,    0.00 /
      DATA B(86869), B(86870), B(86871) /    -9.31,  -13.24,    0.00 /
      DATA B(87172), B(87173), B(87174) /    -9.29,  -13.29,    0.00 /
      DATA B(87475), B(87476), B(87477) /    -9.28,  -13.36,    0.00 /
      DATA B(87778), B(87779), B(87780) /    -9.26,  -13.42,    0.00 /
      DATA B(88081), B(88082), B(88083) /    -9.26,  -13.49,    0.00 /
      DATA B(88384), B(88385), B(88386) /    -9.59,  -13.37,    0.00 /
      DATA B(88687), B(88688), B(88689) /    -9.59,  -13.42,    0.00 /
      DATA B(88990), B(88991), B(88992) /    -9.59,  -13.47,    0.00 /
      DATA B(89293), B(89294), B(89295) /    -9.58,  -13.52,    0.00 /
      DATA B(89596), B(89597), B(89598) /    -9.58,  -13.57,    0.00 /
      DATA B(67783), B(67784), B(67785) /    23.82,  -44.24,    0.00 /
      DATA B(68086), B(68087), B(68088) /    23.78,  -43.63,    0.00 /
      DATA B(68389), B(68390), B(68391) /    23.70,  -42.73,    0.00 /
      DATA B(68692), B(68693), B(68694) /    23.13,  -41.42,    0.00 /
      DATA B(68995), B(68996), B(68997) /    21.66,  -40.56,    0.00 /
      DATA B(69298), B(69299), B(69300) /    20.92,  -40.00,    0.00 /
      DATA B(69601), B(69602), B(69603) /    20.30,  -39.81,    0.00 /
      DATA B(69904), B(69905), B(69906) /    19.09,  -40.25,    0.00 /
      DATA B(70207), B(70208), B(70209) /    18.24,  -38.98,    0.00 /
      DATA B(70510), B(70511), B(70512) /    17.42,  -38.14,    0.00 /
      DATA B(70813), B(70814), B(70815) /    16.38,  -36.96,    0.00 /
      DATA B(71116), B(71117), B(71118) /    14.79,  -34.81,    0.00 /
      DATA B(71419), B(71420), B(71421) /    12.63,  -32.22,    0.00 /
      DATA B(71722), B(71723), B(71724) /     6.80,  -27.04,    0.00 /
      DATA B(72025), B(72026), B(72027) /     4.61,  -23.82,    0.00 /
      DATA B(72328), B(72329), B(72330) /     3.61,  -22.67,    0.00 /
      DATA B(72631), B(72632), B(72633) /     2.44,  -21.95,    0.00 /
      DATA B(72934), B(72935), B(72936) /     0.53,  -20.96,    0.00 /
      DATA B(73237), B(73238), B(73239) /    -2.71,  -18.64,    0.00 /
      DATA B(73540), B(73541), B(73542) /    -2.56,  -18.60,    0.00 /
      DATA B(73843), B(73844), B(73845) /    -4.39,  -17.58,    0.00 /
      DATA B(74146), B(74147), B(74148) /    -5.86,  -17.10,    0.00 /
      DATA B(74449), B(74450), B(74451) /    -6.89,  -16.51,    0.00 /
      DATA B(74752), B(74753), B(74754) /    -7.75,  -16.07,    0.00 /
      DATA B(75055), B(75056), B(75057) /    -8.46,  -15.62,    0.00 /
      DATA B(75358), B(75359), B(75360) /    -8.78,  -15.69,    0.00 /
      DATA B(75661), B(75662), B(75663) /    -8.94,  -15.75,    0.00 /
      DATA B(75964), B(75965), B(75966) /    -9.02,  -15.78,    0.00 /
      DATA B(76267), B(76268), B(76269) /    -9.07,  -15.81,    0.00 /
      DATA B(76570), B(76571), B(76572) /    -9.12,  -15.85,    0.00 /
      DATA B(76873), B(76874), B(76875) /    -9.16,  -15.90,    0.00 /
      DATA B(77176), B(77177), B(77178) /    -9.20,  -15.97,    0.00 /
      DATA B(77479), B(77480), B(77481) /    -9.24,  -16.02,    0.00 /
      DATA B(77782), B(77783), B(77784) /    -9.28,  -16.08,    0.00 /
      DATA B(78085), B(78086), B(78087) /    -9.32,  -16.13,    0.00 /
      DATA B(78388), B(78389), B(78390) /    -9.35,  -16.18,    0.00 /
      DATA B(78691), B(78692), B(78693) /    -9.38,  -16.23,    0.00 /
      DATA B(78994), B(78995), B(78996) /    -9.40,  -16.27,    0.00 /
      DATA B(79297), B(79298), B(79299) /    -9.43,  -16.30,    0.00 /
      DATA B(79600), B(79601), B(79602) /    -9.46,  -16.32,    0.00 /
      DATA B(79903), B(79904), B(79905) /    -9.49,  -16.33,    0.00 /
      DATA B(80206), B(80207), B(80208) /    -9.52,  -16.34,    0.00 /
      DATA B(80509), B(80510), B(80511) /    -9.54,  -16.37,    0.00 /
      DATA B(80812), B(80813), B(80814) /    -9.55,  -16.45,    0.00 /
      DATA B(81115), B(81116), B(81117) /    -9.56,  -16.56,    0.00 /
      DATA B(81418), B(81419), B(81420) /    -9.54,  -16.65,    0.00 /
      DATA B(81721), B(81722), B(81723) /    -9.46,  -16.70,    0.00 /
      DATA B(82024), B(82025), B(82026) /    -9.19,  -14.23,    0.00 /
      DATA B(82327), B(82328), B(82329) /    -9.05,  -15.75,    0.00 /
      DATA B(82630), B(82631), B(82632) /    -8.77,  -15.98,    0.00 /
      DATA B(82933), B(82934), B(82935) /    -8.73,  -16.12,    0.00 /
      DATA B(83236), B(83237), B(83238) /    -8.74,  -16.18,    0.00 /
      DATA B(83539), B(83540), B(83541) /    -9.47,  -15.01,    0.00 /
      DATA B(83842), B(83843), B(83844) /    -9.48,  -14.57,    0.00 /
      DATA B(84145), B(84146), B(84147) /    -9.49,  -14.11,    0.00 /
      DATA B(84448), B(84449), B(84450) /    -9.63,  -13.89,    0.00 /
      DATA B(84751), B(84752), B(84753) /    -9.65,  -13.63,    0.00 /
      DATA B(85054), B(85055), B(85056) /    -9.56,  -13.34,    0.00 /
      DATA B(85357), B(85358), B(85359) /    -9.46,  -13.19,    0.00 /
      DATA B(85660), B(85661), B(85662) /    -9.40,  -13.16,    0.00 /
      DATA B(85963), B(85964), B(85965) /    -9.35,  -13.17,    0.00 /
      DATA B(86266), B(86267), B(86268) /    -9.33,  -13.21,    0.00 /
      DATA B(86569), B(86570), B(86571) /    -9.30,  -13.26,    0.00 /
      DATA B(86872), B(86873), B(86874) /    -9.29,  -13.31,    0.00 /
      DATA B(87175), B(87176), B(87177) /    -9.27,  -13.37,    0.00 /
      DATA B(87478), B(87479), B(87480) /    -9.25,  -13.43,    0.00 /
      DATA B(87781), B(87782), B(87783) /    -9.24,  -13.50,    0.00 /
      DATA B(88084), B(88085), B(88086) /    -9.24,  -13.56,    0.00 /
      DATA B(88387), B(88388), B(88389) /    -9.52,  -13.42,    0.00 /
      DATA B(88690), B(88691), B(88692) /    -9.52,  -13.47,    0.00 /
      DATA B(88993), B(88994), B(88995) /    -9.52,  -13.52,    0.00 /
      DATA B(89296), B(89297), B(89298) /    -9.52,  -13.57,    0.00 /
      DATA B(89599), B(89600), B(89601) /    -9.52,  -13.62,    0.00 /
      DATA B(67786), B(67787), B(67788) /    23.70,  -43.72,    0.00 /
      DATA B(68089), B(68090), B(68091) /    23.62,  -42.72,    0.00 /
      DATA B(68392), B(68393), B(68394) /    22.85,  -41.40,    0.00 /
      DATA B(68695), B(68696), B(68697) /    21.55,  -40.65,    0.00 /
      DATA B(68998), B(68999), B(69000) /    20.90,  -40.21,    0.00 /
      DATA B(69301), B(69302), B(69303) /    20.26,  -40.16,    0.00 /
      DATA B(69604), B(69605), B(69606) /    19.52,  -39.78,    0.00 /
      DATA B(69907), B(69908), B(69909) /    18.74,  -39.16,    0.00 /
      DATA B(70210), B(70211), B(70212) /    17.94,  -38.45,    0.00 /
      DATA B(70513), B(70514), B(70515) /    17.02,  -37.46,    0.00 /
      DATA B(70816), B(70817), B(70818) /    15.53,  -35.36,    0.00 /
      DATA B(71119), B(71120), B(71121) /    13.82,  -32.92,    0.00 /
      DATA B(71422), B(71423), B(71424) /     8.88,  -28.42,    0.00 /
      DATA B(71725), B(71726), B(71727) /     5.46,  -24.50,    0.00 /
      DATA B(72028), B(72029), B(72030) /     3.89,  -23.16,    0.00 /
      DATA B(72331), B(72332), B(72333) /     2.55,  -22.20,    0.00 /
      DATA B(72634), B(72635), B(72636) /     0.20,  -20.67,    0.00 /
      DATA B(72937), B(72938), B(72939) /    -2.83,  -18.51,    0.00 /
      DATA B(73240), B(73241), B(73242) /    -4.41,  -18.07,    0.00 /
      DATA B(73543), B(73544), B(73545) /    -5.05,  -17.19,    0.00 /
      DATA B(73846), B(73847), B(73848) /    -6.11,  -16.54,    0.00 /
      DATA B(74149), B(74150), B(74151) /    -6.93,  -16.08,    0.00 /
      DATA B(74452), B(74453), B(74454) /    -7.66,  -15.64,    0.00 /
      DATA B(74755), B(74756), B(74757) /    -8.40,  -15.40,    0.00 /
      DATA B(75058), B(75059), B(75060) /    -8.76,  -15.42,    0.00 /
      DATA B(75361), B(75362), B(75363) /    -8.91,  -15.53,    0.00 /
      DATA B(75664), B(75665), B(75666) /    -9.00,  -15.61,    0.00 /
      DATA B(75967), B(75968), B(75969) /    -9.06,  -15.67,    0.00 /
      DATA B(76270), B(76271), B(76272) /    -9.11,  -15.72,    0.00 /
      DATA B(76573), B(76574), B(76575) /    -9.15,  -15.78,    0.00 /
      DATA B(76876), B(76877), B(76878) /    -9.18,  -15.84,    0.00 /
      DATA B(77179), B(77180), B(77181) /    -9.22,  -15.90,    0.00 /
      DATA B(77482), B(77483), B(77484) /    -9.25,  -15.96,    0.00 /
      DATA B(77785), B(77786), B(77787) /    -9.29,  -16.02,    0.00 /
      DATA B(78088), B(78089), B(78090) /    -9.32,  -16.08,    0.00 /
      DATA B(78391), B(78392), B(78393) /    -9.35,  -16.13,    0.00 /
      DATA B(78694), B(78695), B(78696) /    -9.38,  -16.19,    0.00 /
      DATA B(78997), B(78998), B(78999) /    -9.40,  -16.23,    0.00 /
      DATA B(79300), B(79301), B(79302) /    -9.43,  -16.27,    0.00 /
      DATA B(79603), B(79604), B(79605) /    -9.45,  -16.31,    0.00 /
      DATA B(79906), B(79907), B(79908) /    -9.47,  -16.34,    0.00 /
      DATA B(80209), B(80210), B(80211) /    -9.49,  -16.38,    0.00 /
      DATA B(80512), B(80513), B(80514) /    -9.50,  -16.42,    0.00 /
      DATA B(80815), B(80816), B(80817) /    -9.50,  -16.49,    0.00 /
      DATA B(81118), B(81119), B(81120) /    -9.48,  -16.57,    0.00 /
      DATA B(81421), B(81422), B(81423) /    -9.43,  -16.63,    0.00 /
      DATA B(81724), B(81725), B(81726) /    -9.30,  -16.62,    0.00 /
      DATA B(82027), B(82028), B(82029) /    -8.99,  -13.90,    0.00 /
      DATA B(82330), B(82331), B(82332) /    -8.87,  -15.94,    0.00 /
      DATA B(82633), B(82634), B(82635) /    -8.75,  -16.02,    0.00 /
      DATA B(82936), B(82937), B(82938) /    -8.72,  -16.09,    0.00 /
      DATA B(83239), B(83240), B(83241) /    -8.69,  -16.03,    0.00 /
      DATA B(83542), B(83543), B(83544) /    -8.63,  -15.81,    0.00 /
      DATA B(83845), B(83846), B(83847) /    -9.49,  -14.21,    0.00 /
      DATA B(84148), B(84149), B(84150) /    -9.66,  -14.01,    0.00 /
      DATA B(84451), B(84452), B(84453) /    -9.61,  -13.66,    0.00 /
      DATA B(84754), B(84755), B(84756) /    -9.52,  -13.41,    0.00 /
      DATA B(85057), B(85058), B(85059) /    -9.45,  -13.28,    0.00 /
      DATA B(85360), B(85361), B(85362) /    -9.40,  -13.22,    0.00 /
      DATA B(85663), B(85664), B(85665) /    -9.36,  -13.21,    0.00 /
      DATA B(85966), B(85967), B(85968) /    -9.32,  -13.24,    0.00 /
      DATA B(86269), B(86270), B(86271) /    -9.30,  -13.28,    0.00 /
      DATA B(86572), B(86573), B(86574) /    -9.28,  -13.32,    0.00 /
      DATA B(86875), B(86876), B(86877) /    -9.26,  -13.38,    0.00 /
      DATA B(87178), B(87179), B(87180) /    -9.25,  -13.44,    0.00 /
      DATA B(87481), B(87482), B(87483) /    -9.23,  -13.50,    0.00 /
      DATA B(87784), B(87785), B(87786) /    -9.22,  -13.57,    0.00 /
      DATA B(88087), B(88088), B(88089) /    -9.46,  -13.43,    0.00 /
      DATA B(88390), B(88391), B(88392) /    -9.46,  -13.47,    0.00 /
      DATA B(88693), B(88694), B(88695) /    -9.46,  -13.51,    0.00 /
      DATA B(88996), B(88997), B(88998) /    -9.45,  -13.56,    0.00 /
      DATA B(89299), B(89300), B(89301) /    -9.45,  -13.61,    0.00 /
      DATA B(89602), B(89603), B(89604) /    -9.45,  -13.66,    0.00 /
      DATA B(67789), B(67790), B(67791) /    23.47,  -42.65,    0.00 /
      DATA B(68092), B(68093), B(68094) /    22.46,  -41.54,    0.00 /
      DATA B(68395), B(68396), B(68397) /    21.45,  -40.77,    0.00 /
      DATA B(68698), B(68699), B(68700) /    20.89,  -40.37,    0.00 /
      DATA B(69001), B(69002), B(69003) /    20.52,  -40.59,    0.00 /
      DATA B(69304), B(69305), B(69306) /    19.88,  -39.92,    0.00 /
      DATA B(69607), B(69608), B(69609) /    19.17,  -39.32,    0.00 /
      DATA B(69910), B(69911), B(69912) /    18.40,  -38.67,    0.00 /
      DATA B(70213), B(70214), B(70215) /    17.53,  -37.87,    0.00 /
      DATA B(70516), B(70517), B(70518) /    16.09,  -35.98,    0.00 /
      DATA B(70819), B(70820), B(70821) /    14.52,  -33.68,    0.00 /
      DATA B(71122), B(71123), B(71124) /     9.93,  -28.46,    0.00 /
      DATA B(71425), B(71426), B(71427) /     6.59,  -25.32,    0.00 /
      DATA B(71728), B(71729), B(71730) /     4.52,  -23.16,    0.00 /
      DATA B(72031), B(72032), B(72033) /     2.58,  -22.07,    0.00 /
      DATA B(72334), B(72335), B(72336) /    -0.23,  -20.46,    0.00 /
      DATA B(72637), B(72638), B(72639) /    -3.30,  -18.28,    0.00 /
      DATA B(72940), B(72941), B(72942) /    -4.49,  -17.62,    0.00 /
      DATA B(73243), B(73244), B(73245) /    -4.89,  -17.66,    0.00 /
      DATA B(73546), B(73547), B(73548) /    -6.82,  -16.07,    0.00 /
      DATA B(73849), B(73850), B(73851) /    -7.46,  -15.54,    0.00 /
      DATA B(74152), B(74153), B(74154) /    -8.84,  -15.85,    0.00 /
      DATA B(74455), B(74456), B(74457) /    -9.11,  -15.69,    0.00 /
      DATA B(74758), B(74759), B(74760) /    -9.07,  -15.41,    0.00 /
      DATA B(75061), B(75062), B(75063) /    -8.98,  -15.36,    0.00 /
      DATA B(75364), B(75365), B(75366) /    -8.99,  -15.45,    0.00 /
      DATA B(75667), B(75668), B(75669) /    -9.04,  -15.53,    0.00 /
      DATA B(75970), B(75971), B(75972) /    -9.08,  -15.60,    0.00 /
      DATA B(76273), B(76274), B(76275) /    -9.12,  -15.66,    0.00 /
      DATA B(76576), B(76577), B(76578) /    -9.15,  -15.73,    0.00 /
      DATA B(76879), B(76880), B(76881) /    -9.19,  -15.79,    0.00 /
      DATA B(77182), B(77183), B(77184) /    -9.22,  -15.85,    0.00 /
      DATA B(77485), B(77486), B(77487) /    -9.24,  -15.92,    0.00 /
      DATA B(77788), B(77789), B(77790) /    -9.27,  -15.98,    0.00 /
      DATA B(78091), B(78092), B(78093) /    -9.30,  -16.04,    0.00 /
      DATA B(78394), B(78395), B(78396) /    -9.33,  -16.10,    0.00 /
      DATA B(78697), B(78698), B(78699) /    -9.35,  -16.16,    0.00 /
      DATA B(79000), B(79001), B(79002) /    -9.38,  -16.21,    0.00 /
      DATA B(79303), B(79304), B(79305) /    -9.40,  -16.26,    0.00 /
      DATA B(79606), B(79607), B(79608) /    -9.42,  -16.31,    0.00 /
      DATA B(79909), B(79910), B(79911) /    -9.43,  -16.35,    0.00 /
      DATA B(80212), B(80213), B(80214) /    -9.44,  -16.40,    0.00 /
      DATA B(80515), B(80516), B(80517) /    -9.44,  -16.45,    0.00 /
      DATA B(80818), B(80819), B(80820) /    -9.43,  -16.52,    0.00 /
      DATA B(81121), B(81122), B(81123) /    -9.40,  -16.57,    0.00 /
      DATA B(81424), B(81425), B(81426) /    -9.32,  -16.59,    0.00 /
      DATA B(81727), B(81728), B(81729) /    -9.08,  -16.47,    0.00 /
      DATA B(82030), B(82031), B(82032) /    -9.00,  -16.09,    0.00 /
      DATA B(82333), B(82334), B(82335) /    -8.83,  -15.98,    0.00 /
      DATA B(82636), B(82637), B(82638) /    -8.79,  -16.06,    0.00 /
      DATA B(82939), B(82940), B(82941) /    -8.71,  -16.05,    0.00 /
      DATA B(83242), B(83243), B(83244) /    -8.60,  -15.72,    0.00 /
      DATA B(83545), B(83546), B(83547) /    -8.66,  -15.29,    0.00 /
      DATA B(83848), B(83849), B(83850) /    -9.68,  -14.09,    0.00 /
      DATA B(84151), B(84152), B(84153) /    -9.56,  -13.67,    0.00 /
      DATA B(84454), B(84455), B(84456) /    -9.48,  -13.44,    0.00 /
      DATA B(84757), B(84758), B(84759) /    -9.42,  -13.33,    0.00 /
      DATA B(85060), B(85061), B(85062) /    -9.38,  -13.27,    0.00 /
      DATA B(85363), B(85364), B(85365) /    -9.35,  -13.25,    0.00 /
      DATA B(85666), B(85667), B(85668) /    -9.32,  -13.27,    0.00 /
      DATA B(85969), B(85970), B(85971) /    -9.29,  -13.30,    0.00 /
      DATA B(86272), B(86273), B(86274) /    -9.27,  -13.34,    0.00 /
      DATA B(86575), B(86576), B(86577) /    -9.25,  -13.39,    0.00 /
      DATA B(86878), B(86879), B(86880) /    -9.24,  -13.45,    0.00 /
      DATA B(87181), B(87182), B(87183) /    -9.22,  -13.51,    0.00 /
      DATA B(87484), B(87485), B(87486) /    -9.21,  -13.57,    0.00 /
      DATA B(87787), B(87788), B(87789) /    -9.20,  -13.63,    0.00 /
      DATA B(88090), B(88091), B(88092) /    -9.39,  -13.47,    0.00 /
      DATA B(88393), B(88394), B(88395) /    -9.39,  -13.51,    0.00 /
      DATA B(88696), B(88697), B(88698) /    -9.39,  -13.56,    0.00 /
      DATA B(88999), B(89000), B(89001) /    -9.38,  -13.61,    0.00 /
      DATA B(89302), B(89303), B(89304) /    -9.38,  -13.66,    0.00 /
      DATA B(89605), B(89606), B(89607) /    -9.38,  -13.71,    0.00 /
      DATA B(67792), B(67793), B(67794) /    22.04,  -41.69,    0.00 /
      DATA B(68095), B(68096), B(68097) /    21.34,  -40.94,    0.00 /
      DATA B(68398), B(68399), B(68400) /    20.84,  -40.60,    0.00 /
      DATA B(68701), B(68702), B(68703) /    21.02,  -40.78,    0.00 /
      DATA B(69004), B(69005), B(69006) /    20.34,  -40.07,    0.00 /
      DATA B(69307), B(69308), B(69309) /    19.62,  -39.44,    0.00 /
      DATA B(69610), B(69611), B(69612) /    18.84,  -38.82,    0.00 /
      DATA B(69913), B(69914), B(69915) /    17.98,  -38.10,    0.00 /
      DATA B(70216), B(70217), B(70218) /    16.91,  -37.06,    0.00 /
      DATA B(70519), B(70520), B(70521) /    15.07,  -34.43,    0.00 /
      DATA B(70822), B(70823), B(70824) /    10.31,  -28.96,    0.00 /
      DATA B(71125), B(71126), B(71127) /     6.77,  -26.27,    0.00 /
      DATA B(71428), B(71429), B(71430) /     6.36,  -23.33,    0.00 /
      DATA B(71731), B(71732), B(71733) /     2.23,  -21.06,    0.00 /
      DATA B(72034), B(72035), B(72036) /    -2.38,  -19.65,    0.00 /
      DATA B(72337), B(72338), B(72339) /    -4.23,  -17.67,    0.00 /
      DATA B(72640), B(72641), B(72642) /    -5.37,  -17.13,    0.00 /
      DATA B(72943), B(72944), B(72945) /    -5.95,  -16.99,    0.00 /
      DATA B(73246), B(73247), B(73248) /    -6.52,  -16.91,    0.00 /
      DATA B(73549), B(73550), B(73551) /    -8.70,  -15.85,    0.00 /
      DATA B(73852), B(73853), B(73854) /    -9.07,  -15.69,    0.00 /
      DATA B(74155), B(74156), B(74157) /    -9.26,  -15.62,    0.00 /
      DATA B(74458), B(74459), B(74460) /    -9.32,  -15.58,    0.00 /
      DATA B(74761), B(74762), B(74763) /    -9.25,  -15.48,    0.00 /
      DATA B(75064), B(75065), B(75066) /    -9.11,  -15.37,    0.00 /
      DATA B(75367), B(75368), B(75369) /    -9.06,  -15.42,    0.00 /
      DATA B(75670), B(75671), B(75672) /    -9.07,  -15.49,    0.00 /
      DATA B(75973), B(75974), B(75975) /    -9.10,  -15.56,    0.00 /
      DATA B(76276), B(76277), B(76278) /    -9.12,  -15.62,    0.00 /
      DATA B(76579), B(76580), B(76581) /    -9.15,  -15.69,    0.00 /
      DATA B(76882), B(76883), B(76884) /    -9.18,  -15.75,    0.00 /
      DATA B(77185), B(77186), B(77187) /    -9.20,  -15.82,    0.00 /
      DATA B(77488), B(77489), B(77490) /    -9.23,  -15.89,    0.00 /
      DATA B(77791), B(77792), B(77793) /    -9.25,  -15.95,    0.00 /
      DATA B(78094), B(78095), B(78096) /    -9.27,  -16.02,    0.00 /
      DATA B(78397), B(78398), B(78399) /    -9.30,  -16.08,    0.00 /
      DATA B(78700), B(78701), B(78702) /    -9.32,  -16.14,    0.00 /
      DATA B(79003), B(79004), B(79005) /    -9.34,  -16.20,    0.00 /
      DATA B(79306), B(79307), B(79308) /    -9.36,  -16.25,    0.00 /
      DATA B(79609), B(79610), B(79611) /    -9.37,  -16.31,    0.00 /
      DATA B(79912), B(79913), B(79914) /    -9.38,  -16.36,    0.00 /
      DATA B(80215), B(80216), B(80217) /    -9.39,  -16.41,    0.00 /
      DATA B(80518), B(80519), B(80520) /    -9.38,  -16.47,    0.00 /
      DATA B(80821), B(80822), B(80823) /    -9.36,  -16.53,    0.00 /
      DATA B(81124), B(81125), B(81126) /    -9.32,  -16.56,    0.00 /
      DATA B(81427), B(81428), B(81429) /    -9.20,  -16.53,    0.00 /
      DATA B(81730), B(81731), B(81732) /    -8.97,  -16.26,    0.00 /
      DATA B(82033), B(82034), B(82035) /    -8.93,  -15.99,    0.00 /
      DATA B(82336), B(82337), B(82338) /    -8.87,  -15.99,    0.00 /
      DATA B(82639), B(82640), B(82641) /    -8.89,  -16.12,    0.00 /
      DATA B(82942), B(82943), B(82944) /    -8.78,  -16.09,    0.00 /
      DATA B(83245), B(83246), B(83247) /    -8.72,  -15.22,    0.00 /
      DATA B(83548), B(83549), B(83550) /    -9.56,  -14.25,    0.00 /
      DATA B(83851), B(83852), B(83853) /    -9.48,  -13.72,    0.00 /
      DATA B(84154), B(84155), B(84156) /    -9.42,  -13.49,    0.00 /
      DATA B(84457), B(84458), B(84459) /    -9.38,  -13.37,    0.00 /
      DATA B(84760), B(84761), B(84762) /    -9.35,  -13.31,    0.00 /
      DATA B(85063), B(85064), B(85065) /    -9.33,  -13.29,    0.00 /
      DATA B(85366), B(85367), B(85368) /    -9.30,  -13.30,    0.00 /
      DATA B(85669), B(85670), B(85671) /    -9.28,  -13.32,    0.00 /
      DATA B(85972), B(85973), B(85974) /    -9.26,  -13.36,    0.00 /
      DATA B(86275), B(86276), B(86277) /    -9.24,  -13.40,    0.00 /
      DATA B(86578), B(86579), B(86580) /    -9.23,  -13.46,    0.00 /
      DATA B(86881), B(86882), B(86883) /    -9.21,  -13.51,    0.00 /
      DATA B(87184), B(87185), B(87186) /    -9.20,  -13.57,    0.00 /
      DATA B(87487), B(87488), B(87489) /    -9.19,  -13.64,    0.00 /
      DATA B(87790), B(87791), B(87792) /    -9.18,  -13.70,    0.00 /
      DATA B(88093), B(88094), B(88095) /    -9.32,  -13.51,    0.00 /
      DATA B(88396), B(88397), B(88398) /    -9.32,  -13.56,    0.00 /
      DATA B(88699), B(88700), B(88701) /    -9.32,  -13.60,    0.00 /
      DATA B(89002), B(89003), B(89004) /    -9.32,  -13.65,    0.00 /
      DATA B(89305), B(89306), B(89307) /    -9.31,  -13.70,    0.00 /
      DATA B(89608), B(89609), B(89610) /    -9.31,  -13.75,    0.00 /
      DATA B(67795), B(67796), B(67797) /    21.25,  -41.16,    0.00 /
      DATA B(68098), B(68099), B(68100) /    20.78,  -40.89,    0.00 /
      DATA B(68401), B(68402), B(68403) /    20.28,  -40.78,    0.00 /
      DATA B(68704), B(68705), B(68706) /    20.83,  -40.22,    0.00 /
      DATA B(69007), B(69008), B(69009) /    20.12,  -39.53,    0.00 /
      DATA B(69310), B(69311), B(69312) /    19.34,  -38.87,    0.00 /
      DATA B(69613), B(69614), B(69615) /    18.46,  -38.16,    0.00 /
      DATA B(69916), B(69917), B(69918) /    17.41,  -37.23,    0.00 /
      DATA B(70219), B(70220), B(70221) /    15.65,  -35.16,    0.00 /
      DATA B(70522), B(70523), B(70524) /    13.15,  -31.97,    0.00 /
      DATA B(70825), B(70826), B(70827) /     7.06,  -26.48,    0.00 /
      DATA B(71128), B(71129), B(71130) /     2.40,  -22.78,    0.00 /
      DATA B(71431), B(71432), B(71433) /     0.42,  -20.18,    0.00 /
      DATA B(71734), B(71735), B(71736) /    -3.89,  -18.29,    0.00 /
      DATA B(72037), B(72038), B(72039) /    -5.72,  -16.48,    0.00 /
      DATA B(72340), B(72341), B(72342) /    -6.67,  -16.16,    0.00 /
      DATA B(72643), B(72644), B(72645) /    -7.31,  -16.25,    0.00 /
      DATA B(72946), B(72947), B(72948) /    -8.03,  -16.16,    0.00 /
      DATA B(73249), B(73250), B(73251) /    -8.65,  -15.98,    0.00 /
      DATA B(73552), B(73553), B(73554) /    -9.08,  -15.52,    0.00 /
      DATA B(73855), B(73856), B(73857) /    -9.29,  -15.50,    0.00 /
      DATA B(74158), B(74159), B(74160) /    -9.39,  -15.50,    0.00 /
      DATA B(74461), B(74462), B(74463) /    -9.42,  -15.52,    0.00 /
      DATA B(74764), B(74765), B(74766) /    -9.36,  -15.52,    0.00 /
      DATA B(75067), B(75068), B(75069) /    -9.21,  -15.42,    0.00 /
      DATA B(75370), B(75371), B(75372) /    -9.13,  -15.44,    0.00 /
      DATA B(75673), B(75674), B(75675) /    -9.11,  -15.49,    0.00 /
      DATA B(75976), B(75977), B(75978) /    -9.12,  -15.54,    0.00 /
      DATA B(76279), B(76280), B(76281) /    -9.13,  -15.60,    0.00 /
      DATA B(76582), B(76583), B(76584) /    -9.15,  -15.67,    0.00 /
      DATA B(76885), B(76886), B(76887) /    -9.16,  -15.73,    0.00 /
      DATA B(77188), B(77189), B(77190) /    -9.18,  -15.80,    0.00 /
      DATA B(77491), B(77492), B(77493) /    -9.20,  -15.87,    0.00 /
      DATA B(77794), B(77795), B(77796) /    -9.22,  -15.93,    0.00 /
      DATA B(78097), B(78098), B(78099) /    -9.24,  -16.00,    0.00 /
      DATA B(78400), B(78401), B(78402) /    -9.26,  -16.06,    0.00 /
      DATA B(78703), B(78704), B(78705) /    -9.28,  -16.13,    0.00 /
      DATA B(79006), B(79007), B(79008) /    -9.30,  -16.19,    0.00 /
      DATA B(79309), B(79310), B(79311) /    -9.31,  -16.25,    0.00 /
      DATA B(79612), B(79613), B(79614) /    -9.32,  -16.31,    0.00 /
      DATA B(79915), B(79916), B(79917) /    -9.33,  -16.37,    0.00 /
      DATA B(80218), B(80219), B(80220) /    -9.33,  -16.43,    0.00 /
      DATA B(80521), B(80522), B(80523) /    -9.32,  -16.48,    0.00 /
      DATA B(80824), B(80825), B(80826) /    -9.29,  -16.53,    0.00 /
      DATA B(81127), B(81128), B(81129) /    -9.22,  -16.54,    0.00 /
      DATA B(81430), B(81431), B(81432) /    -9.03,  -16.39,    0.00 /
      DATA B(81733), B(81734), B(81735) /    -9.02,  -16.05,    0.00 /
      DATA B(82036), B(82037), B(82038) /    -8.90,  -15.90,    0.00 /
      DATA B(82339), B(82340), B(82341) /    -8.93,  -15.99,    0.00 /
      DATA B(82642), B(82643), B(82644) /    -9.05,  -16.17,    0.00 /
      DATA B(82945), B(82946), B(82947) /    -9.31,  -16.33,    0.00 /
      DATA B(83248), B(83249), B(83250) /    -9.40,  -14.53,    0.00 /
      DATA B(83551), B(83552), B(83553) /    -9.36,  -13.91,    0.00 /
      DATA B(83854), B(83855), B(83856) /    -9.34,  -13.59,    0.00 /
      DATA B(84157), B(84158), B(84159) /    -9.32,  -13.44,    0.00 /
      DATA B(84460), B(84461), B(84462) /    -9.31,  -13.36,    0.00 /
      DATA B(84763), B(84764), B(84765) /    -9.30,  -13.33,    0.00 /
      DATA B(85066), B(85067), B(85068) /    -9.28,  -13.33,    0.00 /
      DATA B(85369), B(85370), B(85371) /    -9.27,  -13.35,    0.00 /
      DATA B(85672), B(85673), B(85674) /    -9.25,  -13.38,    0.00 /
      DATA B(85975), B(85976), B(85977) /    -9.23,  -13.42,    0.00 /
      DATA B(86278), B(86279), B(86280) /    -9.22,  -13.47,    0.00 /
      DATA B(86581), B(86582), B(86583) /    -9.20,  -13.52,    0.00 /
      DATA B(86884), B(86885), B(86886) /    -9.19,  -13.58,    0.00 /
      DATA B(87187), B(87188), B(87189) /    -9.17,  -13.64,    0.00 /
      DATA B(87490), B(87491), B(87492) /    -9.16,  -13.70,    0.00 /
      DATA B(87793), B(87794), B(87795) /    -9.15,  -13.76,    0.00 /
      DATA B(88096), B(88097), B(88098) /    -9.26,  -13.56,    0.00 /
      DATA B(88399), B(88400), B(88401) /    -9.25,  -13.60,    0.00 /
      DATA B(88702), B(88703), B(88704) /    -9.25,  -13.65,    0.00 /
      DATA B(89005), B(89006), B(89007) /    -9.25,  -13.69,    0.00 /
      DATA B(89308), B(89309), B(89310) /    -9.24,  -13.74,    0.00 /
      DATA B(89611), B(89612), B(89613) /    -9.24,  -13.79,    0.00 /
      DATA B(67798), B(67799), B(67800) /    20.71,  -41.24,    0.00 /
      DATA B(68101), B(68102), B(68103) /    20.23,  -41.14,    0.00 /
      DATA B(68404), B(68405), B(68406) /    21.32,  -40.40,    0.00 /
      DATA B(68707), B(68708), B(68709) /    20.63,  -39.61,    0.00 /
      DATA B(69010), B(69011), B(69012) /    19.89,  -38.85,    0.00 /
      DATA B(69313), B(69314), B(69315) /    19.05,  -38.02,    0.00 /
      DATA B(69616), B(69617), B(69618) /    17.90,  -37.10,    0.00 /
      DATA B(69919), B(69920), B(69921) /    18.14,  -37.03,    0.00 /
      DATA B(70222), B(70223), B(70224) /    14.22,  -33.04,    0.00 /
      DATA B(70525), B(70526), B(70527) /     7.73,  -26.67,    0.00 /
      DATA B(70828), B(70829), B(70830) /     2.58,  -23.35,    0.00 /
      DATA B(71131), B(71132), B(71133) /    -3.03,  -18.02,    0.00 /
      DATA B(71434), B(71435), B(71436) /    -4.02,  -17.17,    0.00 /
      DATA B(71737), B(71738), B(71739) /    -6.76,  -15.57,    0.00 /
      DATA B(72040), B(72041), B(72042) /    -8.91,  -15.16,    0.00 /
      DATA B(72343), B(72344), B(72345) /    -8.90,  -15.54,    0.00 /
      DATA B(72646), B(72647), B(72648) /    -8.94,  -15.50,    0.00 /
      DATA B(72949), B(72950), B(72951) /    -9.06,  -15.52,    0.00 /
      DATA B(73252), B(73253), B(73254) /    -9.21,  -15.46,    0.00 /
      DATA B(73555), B(73556), B(73557) /    -9.31,  -15.37,    0.00 /
      DATA B(73858), B(73859), B(73860) /    -9.38,  -15.38,    0.00 /
      DATA B(74161), B(74162), B(74163) /    -9.44,  -15.41,    0.00 /
      DATA B(74464), B(74465), B(74466) /    -9.47,  -15.46,    0.00 /
      DATA B(74767), B(74768), B(74769) /    -9.46,  -15.51,    0.00 /
      DATA B(75070), B(75071), B(75072) /    -9.46,  -15.48,    0.00 /
      DATA B(75373), B(75374), B(75375) /    -9.38,  -15.49,    0.00 /
      DATA B(75676), B(75677), B(75678) /    -9.30,  -15.54,    0.00 /
      DATA B(75979), B(75980), B(75981) /    -9.23,  -15.57,    0.00 /
      DATA B(76282), B(76283), B(76284) /    -9.19,  -15.61,    0.00 /
      DATA B(76585), B(76586), B(76587) /    -9.17,  -15.67,    0.00 /
      DATA B(76888), B(76889), B(76890) /    -9.17,  -15.72,    0.00 /
      DATA B(77191), B(77192), B(77193) /    -9.17,  -15.79,    0.00 /
      DATA B(77494), B(77495), B(77496) /    -9.18,  -15.85,    0.00 /
      DATA B(77797), B(77798), B(77799) /    -9.20,  -15.92,    0.00 /
      DATA B(78100), B(78101), B(78102) /    -9.21,  -15.98,    0.00 /
      DATA B(78403), B(78404), B(78405) /    -9.22,  -16.05,    0.00 /
      DATA B(78706), B(78707), B(78708) /    -9.24,  -16.12,    0.00 /
      DATA B(79009), B(79010), B(79011) /    -9.25,  -16.18,    0.00 /
      DATA B(79312), B(79313), B(79314) /    -9.26,  -16.24,    0.00 /
      DATA B(79615), B(79616), B(79617) /    -9.27,  -16.31,    0.00 /
      DATA B(79918), B(79919), B(79920) /    -9.28,  -16.37,    0.00 /
      DATA B(80221), B(80222), B(80223) /    -9.27,  -16.43,    0.00 /
      DATA B(80524), B(80525), B(80526) /    -9.26,  -16.49,    0.00 /
      DATA B(80827), B(80828), B(80829) /    -9.21,  -16.53,    0.00 /
      DATA B(81130), B(81131), B(81132) /    -9.10,  -16.48,    0.00 /
      DATA B(81433), B(81434), B(81435) /    -8.90,  -16.17,    0.00 /
      DATA B(81736), B(81737), B(81738) /    -8.93,  -15.85,    0.00 /
      DATA B(82039), B(82040), B(82041) /    -8.90,  -15.85,    0.00 /
      DATA B(82342), B(82343), B(82344) /    -9.00,  -15.98,    0.00 /
      DATA B(82645), B(82646), B(82647) /    -9.20,  -16.19,    0.00 /
      DATA B(82948), B(82949), B(82950) /    -9.56,  -16.34,    0.00 /
      DATA B(83251), B(83252), B(83253) /    -9.85,  -16.43,    0.00 /
      DATA B(83554), B(83555), B(83556) /    -9.21,  -13.87,    0.00 /
      DATA B(83857), B(83858), B(83859) /    -9.23,  -13.59,    0.00 /
      DATA B(84160), B(84161), B(84162) /    -9.25,  -13.45,    0.00 /
      DATA B(84463), B(84464), B(84465) /    -9.25,  -13.39,    0.00 /
      DATA B(84766), B(84767), B(84768) /    -9.25,  -13.37,    0.00 /
      DATA B(85069), B(85070), B(85071) /    -9.24,  -13.37,    0.00 /
      DATA B(85372), B(85373), B(85374) /    -9.23,  -13.40,    0.00 /
      DATA B(85675), B(85676), B(85677) /    -9.22,  -13.43,    0.00 /
      DATA B(85978), B(85979), B(85980) /    -9.20,  -13.48,    0.00 /
      DATA B(86281), B(86282), B(86283) /    -9.19,  -13.53,    0.00 /
      DATA B(86584), B(86585), B(86586) /    -9.17,  -13.58,    0.00 /
      DATA B(86887), B(86888), B(86889) /    -9.16,  -13.64,    0.00 /
      DATA B(87190), B(87191), B(87192) /    -9.15,  -13.70,    0.00 /
      DATA B(87493), B(87494), B(87495) /    -9.13,  -13.77,    0.00 /
      DATA B(87796), B(87797), B(87798) /    -9.19,  -13.56,    0.00 /
      DATA B(88099), B(88100), B(88101) /    -9.19,  -13.60,    0.00 /
      DATA B(88402), B(88403), B(88404) /    -9.18,  -13.64,    0.00 /
      DATA B(88705), B(88706), B(88707) /    -9.18,  -13.69,    0.00 /
      DATA B(89008), B(89009), B(89010) /    -9.18,  -13.73,    0.00 /
      DATA B(89311), B(89312), B(89313) /    -9.17,  -13.78,    0.00 /
      DATA B(89614), B(89615), B(89616) /    -9.17,  -13.83,    0.00 /
      DATA B(67801), B(67802), B(67803) /    20.13,  -41.61,    0.00 /
      DATA B(68104), B(68105), B(68106) /    19.66,  -41.47,    0.00 /
      DATA B(68407), B(68408), B(68409) /    21.10,  -39.71,    0.00 /
      DATA B(68710), B(68711), B(68712) /    20.38,  -38.78,    0.00 /
      DATA B(69013), B(69014), B(69015) /    19.65,  -37.90,    0.00 /
      DATA B(69316), B(69317), B(69318) /    19.20,  -37.23,    0.00 /
      DATA B(69619), B(69620), B(69621) /    17.90,  -37.25,    0.00 /
      DATA B(69922), B(69923), B(69924) /    15.03,  -33.81,    0.00 /
      DATA B(70225), B(70226), B(70227) /     8.64,  -26.77,    0.00 /
      DATA B(70528), B(70529), B(70530) /     3.43,  -23.84,    0.00 /
      DATA B(70831), B(70832), B(70833) /    -5.25,  -17.00,    0.00 /
      DATA B(71134), B(71135), B(71136) /    -6.65,  -15.24,    0.00 /
      DATA B(71437), B(71438), B(71439) /    -7.22,  -15.02,    0.00 /
      DATA B(71740), B(71741), B(71742) /    -7.35,  -15.76,    0.00 /
      DATA B(72043), B(72044), B(72045) /    -9.13,  -12.77,    0.00 /
      DATA B(72346), B(72347), B(72348) /    -9.70,  -14.39,    0.00 /
      DATA B(72649), B(72650), B(72651) /    -9.43,  -14.94,    0.00 /
      DATA B(72952), B(72953), B(72954) /    -9.36,  -15.14,    0.00 /
      DATA B(73255), B(73256), B(73257) /    -9.36,  -15.21,    0.00 /
      DATA B(73558), B(73559), B(73560) /    -9.39,  -15.24,    0.00 /
      DATA B(73861), B(73862), B(73863) /    -9.41,  -15.28,    0.00 /
      DATA B(74164), B(74165), B(74166) /    -9.44,  -15.34,    0.00 /
      DATA B(74467), B(74468), B(74469) /    -9.47,  -15.40,    0.00 /
      DATA B(74770), B(74771), B(74772) /    -9.50,  -15.45,    0.00 /
      DATA B(75073), B(75074), B(75075) /    -9.52,  -15.48,    0.00 /
      DATA B(75376), B(75377), B(75378) /    -9.52,  -15.52,    0.00 /
      DATA B(75679), B(75680), B(75681) /    -9.51,  -15.58,    0.00 /
      DATA B(75982), B(75983), B(75984) /    -9.51,  -15.64,    0.00 /
      DATA B(76285), B(76286), B(76287) /    -9.44,  -15.68,    0.00 /
      DATA B(76588), B(76589), B(76590) /    -9.35,  -15.71,    0.00 /
      DATA B(76891), B(76892), B(76893) /    -9.26,  -15.75,    0.00 /
      DATA B(77194), B(77195), B(77196) /    -9.22,  -15.79,    0.00 /
      DATA B(77497), B(77498), B(77499) /    -9.20,  -15.85,    0.00 /
      DATA B(77800), B(77801), B(77802) /    -9.19,  -15.91,    0.00 /
      DATA B(78103), B(78104), B(78105) /    -9.19,  -15.98,    0.00 /
      DATA B(78406), B(78407), B(78408) /    -9.19,  -16.04,    0.00 /
      DATA B(78709), B(78710), B(78711) /    -9.20,  -16.11,    0.00 /
      DATA B(79012), B(79013), B(79014) /    -9.21,  -16.17,    0.00 /
      DATA B(79315), B(79316), B(79317) /    -9.22,  -16.24,    0.00 /
      DATA B(79618), B(79619), B(79620) /    -9.22,  -16.31,    0.00 /
      DATA B(79921), B(79922), B(79923) /    -9.22,  -16.37,    0.00 /
      DATA B(80224), B(80225), B(80226) /    -9.22,  -16.44,    0.00 /
      DATA B(80527), B(80528), B(80529) /    -9.20,  -16.50,    0.00 /
      DATA B(80830), B(80831), B(80832) /    -9.13,  -16.52,    0.00 /
      DATA B(81133), B(81134), B(81135) /    -8.94,  -16.37,    0.00 /
      DATA B(81436), B(81437), B(81438) /    -8.97,  -15.92,    0.00 /
      DATA B(81739), B(81740), B(81741) /    -8.88,  -15.73,    0.00 /
      DATA B(82042), B(82043), B(82044) /    -8.92,  -15.80,    0.00 /
      DATA B(82345), B(82346), B(82347) /    -9.05,  -15.97,    0.00 /
      DATA B(82648), B(82649), B(82650) /    -9.31,  -16.21,    0.00 /
      DATA B(82951), B(82952), B(82953) /    -9.57,  -16.19,    0.00 /
      DATA B(83254), B(83255), B(83256) /    -9.87,  -15.99,    0.00 /
      DATA B(83557), B(83558), B(83559) /    -9.32,  -13.87,    0.00 /
      DATA B(83860), B(83861), B(83862) /    -9.17,  -13.73,    0.00 /
      DATA B(84163), B(84164), B(84165) /    -9.19,  -13.52,    0.00 /
      DATA B(84466), B(84467), B(84468) /    -9.21,  -13.43,    0.00 /
      DATA B(84769), B(84770), B(84771) /    -9.21,  -13.41,    0.00 /
      DATA B(85072), B(85073), B(85074) /    -9.21,  -13.42,    0.00 /
      DATA B(85375), B(85376), B(85377) /    -9.20,  -13.45,    0.00 /
      DATA B(85678), B(85679), B(85680) /    -9.19,  -13.49,    0.00 /
      DATA B(85981), B(85982), B(85983) /    -9.17,  -13.53,    0.00 /
      DATA B(86284), B(86285), B(86286) /    -9.16,  -13.59,    0.00 /
      DATA B(86587), B(86588), B(86589) /    -9.15,  -13.64,    0.00 /
      DATA B(86890), B(86891), B(86892) /    -9.13,  -13.70,    0.00 /
      DATA B(87193), B(87194), B(87195) /    -9.12,  -13.77,    0.00 /
      DATA B(87496), B(87497), B(87498) /    -9.11,  -13.83,    0.00 /
      DATA B(87799), B(87800), B(87801) /    -9.12,  -13.60,    0.00 /
      DATA B(88102), B(88103), B(88104) /    -9.12,  -13.64,    0.00 /
      DATA B(88405), B(88406), B(88407) /    -9.11,  -13.68,    0.00 /
      DATA B(88708), B(88709), B(88710) /    -9.11,  -13.73,    0.00 /
      DATA B(89011), B(89012), B(89013) /    -9.10,  -13.77,    0.00 /
      DATA B(89314), B(89315), B(89316) /    -9.10,  -13.82,    0.00 /
      DATA B(89617), B(89618), B(89619) /    -9.10,  -13.87,    0.00 /
      DATA B(67804), B(67805), B(67806) /    19.50,  -42.11,    0.00 /
      DATA B(68107), B(68108), B(68109) /    18.98,  -41.93,    0.00 /
      DATA B(68410), B(68411), B(68412) /    20.61,  -38.75,    0.00 /
      DATA B(68713), B(68714), B(68715) /    19.43,  -37.89,    0.00 /
      DATA B(69016), B(69017), B(69018) /    18.43,  -37.82,    0.00 /
      DATA B(69319), B(69320), B(69321) /    17.73,  -36.66,    0.00 /
      DATA B(69622), B(69623), B(69624) /    15.42,  -33.25,    0.00 /
      DATA B(69925), B(69926), B(69927) /    12.47,  -30.02,    0.00 /
      DATA B(70228), B(70229), B(70230) /    -6.00,  -15.90,    0.00 /
      DATA B(70531), B(70532), B(70533) /    -7.35,  -16.42,    0.00 /
      DATA B(70834), B(70835), B(70836) /    -7.64,  -14.88,    0.00 /
      DATA B(71137), B(71138), B(71139) /    -7.81,  -14.33,    0.00 /
      DATA B(71440), B(71441), B(71442) /    -7.90,  -14.24,    0.00 /
      DATA B(71743), B(71744), B(71745) /    -7.84,  -14.63,    0.00 /
      DATA B(72046), B(72047), B(72048) /    -7.99,  -18.31,    0.00 /
      DATA B(72349), B(72350), B(72351) /    -9.80,  -13.05,    0.00 /
      DATA B(72652), B(72653), B(72654) /    -9.65,  -14.41,    0.00 /
      DATA B(72955), B(72956), B(72957) /    -9.48,  -14.84,    0.00 /
      DATA B(73258), B(73259), B(73260) /    -9.42,  -15.03,    0.00 /
      DATA B(73561), B(73562), B(73563) /    -9.40,  -15.12,    0.00 /
      DATA B(73864), B(73865), B(73866) /    -9.41,  -15.20,    0.00 /
      DATA B(74167), B(74168), B(74169) /    -9.42,  -15.27,    0.00 /
      DATA B(74470), B(74471), B(74472) /    -9.44,  -15.33,    0.00 /
      DATA B(74773), B(74774), B(74775) /    -9.47,  -15.40,    0.00 /
      DATA B(75076), B(75077), B(75078) /    -9.49,  -15.46,    0.00 /
      DATA B(75379), B(75380), B(75381) /    -9.51,  -15.51,    0.00 /
      DATA B(75682), B(75683), B(75684) /    -9.52,  -15.58,    0.00 /
      DATA B(75985), B(75986), B(75987) /    -9.53,  -15.64,    0.00 /
      DATA B(76288), B(76289), B(76290) /    -9.54,  -15.70,    0.00 /
      DATA B(76591), B(76592), B(76593) /    -9.53,  -15.75,    0.00 /
      DATA B(76894), B(76895), B(76896) /    -9.52,  -15.81,    0.00 /
      DATA B(77197), B(77198), B(77199) /    -9.45,  -15.85,    0.00 /
      DATA B(77500), B(77501), B(77502) /    -9.35,  -15.89,    0.00 /
      DATA B(77803), B(77804), B(77805) /    -9.27,  -15.93,    0.00 /
      DATA B(78106), B(78107), B(78108) /    -9.22,  -15.98,    0.00 /
      DATA B(78409), B(78410), B(78411) /    -9.20,  -16.04,    0.00 /
      DATA B(78712), B(78713), B(78714) /    -9.19,  -16.10,    0.00 /
      DATA B(79015), B(79016), B(79017) /    -9.18,  -16.17,    0.00 /
      DATA B(79318), B(79319), B(79320) /    -9.18,  -16.23,    0.00 /
      DATA B(79621), B(79622), B(79623) /    -9.18,  -16.30,    0.00 /
      DATA B(79924), B(79925), B(79926) /    -9.18,  -16.37,    0.00 /
      DATA B(80227), B(80228), B(80229) /    -9.17,  -16.44,    0.00 /
      DATA B(80530), B(80531), B(80532) /    -9.14,  -16.51,    0.00 /
      DATA B(80833), B(80834), B(80835) /    -9.05,  -16.53,    0.00 /
      DATA B(81136), B(81137), B(81138) /    -8.80,  -16.21,    0.00 /
      DATA B(81439), B(81440), B(81441) /    -8.88,  -15.71,    0.00 /
      DATA B(81742), B(81743), B(81744) /    -8.86,  -15.66,    0.00 /
      DATA B(82045), B(82046), B(82047) /    -8.93,  -15.76,    0.00 /
      DATA B(82348), B(82349), B(82350) /    -9.08,  -15.93,    0.00 /
      DATA B(82651), B(82652), B(82653) /    -9.34,  -16.21,    0.00 /
      DATA B(82954), B(82955), B(82956) /    -9.55,  -16.10,    0.00 /
      DATA B(83257), B(83258), B(83259) /    -9.77,  -15.90,    0.00 /
      DATA B(83560), B(83561), B(83562) /    -9.86,  -15.47,    0.00 /
      DATA B(83863), B(83864), B(83865) /    -9.27,  -14.01,    0.00 /
      DATA B(84166), B(84167), B(84168) /    -9.16,  -13.63,    0.00 /
      DATA B(84469), B(84470), B(84471) /    -9.18,  -13.49,    0.00 /
      DATA B(84772), B(84773), B(84774) /    -9.19,  -13.46,    0.00 /
      DATA B(85075), B(85076), B(85077) /    -9.18,  -13.47,    0.00 /
      DATA B(85378), B(85379), B(85380) /    -9.17,  -13.50,    0.00 /
      DATA B(85681), B(85682), B(85683) /    -9.16,  -13.54,    0.00 /
      DATA B(85984), B(85985), B(85986) /    -9.15,  -13.59,    0.00 /
      DATA B(86287), B(86288), B(86289) /    -9.13,  -13.65,    0.00 /
      DATA B(86590), B(86591), B(86592) /    -9.12,  -13.70,    0.00 /
      DATA B(86893), B(86894), B(86895) /    -9.11,  -13.76,    0.00 /
      DATA B(87196), B(87197), B(87198) /    -9.09,  -13.83,    0.00 /
      DATA B(87499), B(87500), B(87501) /    -9.08,  -13.89,    0.00 /
      DATA B(87802), B(87803), B(87804) /    -9.05,  -13.63,    0.00 /
      DATA B(88105), B(88106), B(88107) /    -9.04,  -13.67,    0.00 /
      DATA B(88408), B(88409), B(88410) /    -9.04,  -13.72,    0.00 /
      DATA B(88711), B(88712), B(88713) /    -9.04,  -13.77,    0.00 /
      DATA B(89014), B(89015), B(89016) /    -9.03,  -13.81,    0.00 /
      DATA B(89317), B(89318), B(89319) /    -9.03,  -13.86,    0.00 /
      DATA B(89620), B(89621), B(89622) /    -9.03,  -13.91,    0.00 /
      DATA B(67807), B(67808), B(67809) /    20.42,  -37.84,    0.00 /
      DATA B(68110), B(68111), B(68112) /    19.84,  -38.29,    0.00 /
      DATA B(68413), B(68414), B(68415) /    18.92,  -38.62,    0.00 /
      DATA B(68716), B(68717), B(68718) /    17.80,  -38.25,    0.00 /
      DATA B(69019), B(69020), B(69021) /    15.66,  -37.86,    0.00 /
      DATA B(69322), B(69323), B(69324) /    17.30,  -35.44,    0.00 /
      DATA B(69625), B(69626), B(69627) /     8.62,  -28.21,    0.00 /
      DATA B(69928), B(69929), B(69930) /    -4.58,  -15.53,    0.00 /
      DATA B(70231), B(70232), B(70233) /    -7.13,  -14.04,    0.00 /
      DATA B(70534), B(70535), B(70536) /    -7.84,  -14.20,    0.00 /
      DATA B(70837), B(70838), B(70839) /    -8.18,  -14.05,    0.00 /
      DATA B(71140), B(71141), B(71142) /    -8.21,  -13.81,    0.00 /
      DATA B(71443), B(71444), B(71445) /    -8.19,  -13.81,    0.00 /
      DATA B(71746), B(71747), B(71748) /    -8.12,  -14.04,    0.00 /
      DATA B(72049), B(72050), B(72051) /    -7.95,  -14.62,    0.00 /
      DATA B(72352), B(72353), B(72354) /    -9.13,  -11.66,    0.00 /
      DATA B(72655), B(72656), B(72657) /    -9.81,  -13.68,    0.00 /
      DATA B(72958), B(72959), B(72960) /    -9.55,  -14.53,    0.00 /
      DATA B(73261), B(73262), B(73263) /    -9.44,  -14.85,    0.00 /
      DATA B(73564), B(73565), B(73566) /    -9.39,  -15.01,    0.00 /
      DATA B(73867), B(73868), B(73869) /    -9.38,  -15.11,    0.00 /
      DATA B(74170), B(74171), B(74172) /    -9.38,  -15.20,    0.00 /
      DATA B(74473), B(74474), B(74475) /    -9.39,  -15.27,    0.00 /
      DATA B(74776), B(74777), B(74778) /    -9.41,  -15.34,    0.00 /
      DATA B(75079), B(75080), B(75081) /    -9.43,  -15.41,    0.00 /
      DATA B(75382), B(75383), B(75384) /    -9.45,  -15.48,    0.00 /
      DATA B(75685), B(75686), B(75687) /    -9.47,  -15.55,    0.00 /
      DATA B(75988), B(75989), B(75990) /    -9.49,  -15.61,    0.00 /
      DATA B(76291), B(76292), B(76293) /    -9.51,  -15.68,    0.00 /
      DATA B(76594), B(76595), B(76596) /    -9.53,  -15.75,    0.00 /
      DATA B(76897), B(76898), B(76899) /    -9.54,  -15.81,    0.00 /
      DATA B(77200), B(77201), B(77202) /    -9.54,  -15.87,    0.00 /
      DATA B(77503), B(77504), B(77505) /    -9.53,  -15.93,    0.00 /
      DATA B(77806), B(77807), B(77808) /    -9.51,  -15.99,    0.00 /
      DATA B(78109), B(78110), B(78111) /    -9.43,  -16.03,    0.00 /
      DATA B(78412), B(78413), B(78414) /    -9.34,  -16.07,    0.00 /
      DATA B(78715), B(78716), B(78717) /    -9.26,  -16.11,    0.00 /
      DATA B(79018), B(79019), B(79020) /    -9.21,  -16.16,    0.00 /
      DATA B(79321), B(79322), B(79323) /    -9.18,  -16.23,    0.00 /
      DATA B(79624), B(79625), B(79626) /    -9.16,  -16.29,    0.00 /
      DATA B(79927), B(79928), B(79929) /    -9.15,  -16.36,    0.00 /
      DATA B(80230), B(80231), B(80232) /    -9.13,  -16.43,    0.00 /
      DATA B(80533), B(80534), B(80535) /    -9.11,  -16.51,    0.00 /
      DATA B(80836), B(80837), B(80838) /    -9.03,  -16.55,    0.00 /
      DATA B(81139), B(81140), B(81141) /    -8.89,  -16.18,    0.00 /
      DATA B(81442), B(81443), B(81444) /    -8.82,  -15.60,    0.00 /
      DATA B(81745), B(81746), B(81747) /    -8.85,  -15.61,    0.00 /
      DATA B(82048), B(82049), B(82050) /    -8.94,  -15.73,    0.00 /
      DATA B(82351), B(82352), B(82353) /    -9.08,  -15.90,    0.00 /
      DATA B(82654), B(82655), B(82656) /    -9.25,  -16.15,    0.00 /
      DATA B(82957), B(82958), B(82959) /    -9.47,  -16.01,    0.00 /
      DATA B(83260), B(83261), B(83262) /    -9.65,  -15.82,    0.00 /
      DATA B(83563), B(83564), B(83565) /    -9.78,  -15.51,    0.00 /
      DATA B(83866), B(83867), B(83868) /    -9.69,  -14.88,    0.00 /
      DATA B(84169), B(84170), B(84171) /    -9.21,  -13.84,    0.00 /
      DATA B(84472), B(84473), B(84474) /    -9.17,  -13.56,    0.00 /
      DATA B(84775), B(84776), B(84777) /    -9.17,  -13.51,    0.00 /
      DATA B(85078), B(85079), B(85080) /    -9.16,  -13.52,    0.00 /
      DATA B(85381), B(85382), B(85383) /    -9.14,  -13.55,    0.00 /
      DATA B(85684), B(85685), B(85686) /    -9.13,  -13.60,    0.00 /
      DATA B(85987), B(85988), B(85989) /    -9.12,  -13.65,    0.00 /
      DATA B(86290), B(86291), B(86292) /    -9.11,  -13.70,    0.00 /
      DATA B(86593), B(86594), B(86595) /    -9.09,  -13.76,    0.00 /
      DATA B(86896), B(86897), B(86898) /    -9.08,  -13.82,    0.00 /
      DATA B(87199), B(87200), B(87201) /    -9.06,  -13.89,    0.00 /
      DATA B(87502), B(87503), B(87504) /    -9.05,  -13.94,    0.00 /
      DATA B(87805), B(87806), B(87807) /    -8.98,  -13.67,    0.00 /
      DATA B(88108), B(88109), B(88110) /    -8.97,  -13.71,    0.00 /
      DATA B(88411), B(88412), B(88413) /    -8.97,  -13.76,    0.00 /
      DATA B(88714), B(88715), B(88716) /    -8.96,  -13.80,    0.00 /
      DATA B(89017), B(89018), B(89019) /    -8.96,  -13.85,    0.00 /
      DATA B(89320), B(89321), B(89322) /    -8.96,  -13.90,    0.00 /
      DATA B(89623), B(89624), B(89625) /    -8.95,  -13.95,    0.00 /
      DATA B(67810), B(67811), B(67812) /    19.13,  -39.37,    0.00 /
      DATA B(68113), B(68114), B(68115) /    18.43,  -39.52,    0.00 /
      DATA B(68416), B(68417), B(68418) /    17.45,  -39.12,    0.00 /
      DATA B(68719), B(68720), B(68721) /    15.95,  -38.00,    0.00 /
      DATA B(69022), B(69023), B(69024) /    13.00,  -35.58,    0.00 /
      DATA B(69325), B(69326), B(69327) /    -2.57,  -19.68,    0.00 /
      DATA B(69628), B(69629), B(69630) /    -5.65,  -16.00,    0.00 /
      DATA B(69931), B(69932), B(69933) /    -7.33,  -14.32,    0.00 /
      DATA B(70234), B(70235), B(70236) /    -7.76,  -13.49,    0.00 /
      DATA B(70537), B(70538), B(70539) /    -8.06,  -13.50,    0.00 /
      DATA B(70840), B(70841), B(70842) /    -8.27,  -13.52,    0.00 /
      DATA B(71143), B(71144), B(71145) /    -8.33,  -13.48,    0.00 /
      DATA B(71446), B(71447), B(71448) /    -8.32,  -13.51,    0.00 /
      DATA B(71749), B(71750), B(71751) /    -8.27,  -13.67,    0.00 /
      DATA B(72052), B(72053), B(72054) /    -8.15,  -14.01,    0.00 /
      DATA B(72355), B(72356), B(72357) /    -7.88,  -14.83,    0.00 /
      DATA B(72658), B(72659), B(72660) /    -9.69,  -12.62,    0.00 /
      DATA B(72961), B(72962), B(72963) /    -9.63,  -14.12,    0.00 /
      DATA B(73264), B(73265), B(73266) /    -9.44,  -14.65,    0.00 /
      DATA B(73567), B(73568), B(73569) /    -9.36,  -14.89,    0.00 /
      DATA B(73870), B(73871), B(73872) /    -9.33,  -15.02,    0.00 /
      DATA B(74173), B(74174), B(74175) /    -9.33,  -15.12,    0.00 /
      DATA B(74476), B(74477), B(74478) /    -9.33,  -15.21,    0.00 /
      DATA B(74779), B(74780), B(74781) /    -9.35,  -15.29,    0.00 /
      DATA B(75082), B(75083), B(75084) /    -9.37,  -15.36,    0.00 /
      DATA B(75385), B(75386), B(75387) /    -9.39,  -15.43,    0.00 /
      DATA B(75688), B(75689), B(75690) /    -9.41,  -15.51,    0.00 /
      DATA B(75991), B(75992), B(75993) /    -9.43,  -15.58,    0.00 /
      DATA B(76294), B(76295), B(76296) /    -9.45,  -15.65,    0.00 /
      DATA B(76597), B(76598), B(76599) /    -9.47,  -15.72,    0.00 /
      DATA B(76900), B(76901), B(76902) /    -9.49,  -15.78,    0.00 /
      DATA B(77203), B(77204), B(77205) /    -9.50,  -15.85,    0.00 /
      DATA B(77506), B(77507), B(77508) /    -9.52,  -15.92,    0.00 /
      DATA B(77809), B(77810), B(77811) /    -9.53,  -15.98,    0.00 /
      DATA B(78112), B(78113), B(78114) /    -9.52,  -16.04,    0.00 /
      DATA B(78415), B(78416), B(78417) /    -9.51,  -16.11,    0.00 /
      DATA B(78718), B(78719), B(78720) /    -9.48,  -16.16,    0.00 /
      DATA B(79021), B(79022), B(79023) /    -9.40,  -16.21,    0.00 /
      DATA B(79324), B(79325), B(79326) /    -9.30,  -16.24,    0.00 /
      DATA B(79627), B(79628), B(79629) /    -9.22,  -16.29,    0.00 /
      DATA B(79930), B(79931), B(79932) /    -9.16,  -16.35,    0.00 /
      DATA B(80233), B(80234), B(80235) /    -9.13,  -16.42,    0.00 /
      DATA B(80536), B(80537), B(80538) /    -9.10,  -16.50,    0.00 /
      DATA B(80839), B(80840), B(80841) /    -9.05,  -16.56,    0.00 /
      DATA B(81142), B(81143), B(81144) /    -8.92,  -16.24,    0.00 /
      DATA B(81445), B(81446), B(81447) /    -8.82,  -15.56,    0.00 /
      DATA B(81748), B(81749), B(81750) /    -8.86,  -15.57,    0.00 /
      DATA B(82051), B(82052), B(82053) /    -8.95,  -15.70,    0.00 /
      DATA B(82354), B(82355), B(82356) /    -9.06,  -15.86,    0.00 /
      DATA B(82657), B(82658), B(82659) /    -9.20,  -16.08,    0.00 /
      DATA B(82960), B(82961), B(82962) /    -9.38,  -15.91,    0.00 /
      DATA B(83263), B(83264), B(83265) /    -9.53,  -15.73,    0.00 /
      DATA B(83566), B(83567), B(83568) /    -9.66,  -15.49,    0.00 /
      DATA B(83869), B(83870), B(83871) /    -9.72,  -15.08,    0.00 /
      DATA B(84172), B(84173), B(84174) /    -9.41,  -14.20,    0.00 /
      DATA B(84475), B(84476), B(84477) /    -9.19,  -13.66,    0.00 /
      DATA B(84778), B(84779), B(84780) /    -9.16,  -13.57,    0.00 /
      DATA B(85081), B(85082), B(85083) /    -9.14,  -13.58,    0.00 /
      DATA B(85384), B(85385), B(85386) /    -9.12,  -13.61,    0.00 /
      DATA B(85687), B(85688), B(85689) /    -9.11,  -13.65,    0.00 /
      DATA B(85990), B(85991), B(85992) /    -9.09,  -13.70,    0.00 /
      DATA B(86293), B(86294), B(86295) /    -9.08,  -13.76,    0.00 /
      DATA B(86596), B(86597), B(86598) /    -9.06,  -13.82,    0.00 /
      DATA B(86899), B(86900), B(86901) /    -9.05,  -13.88,    0.00 /
      DATA B(87202), B(87203), B(87204) /    -9.04,  -13.94,    0.00 /
      DATA B(87505), B(87506), B(87507) /    -8.91,  -13.67,    0.00 /
      DATA B(87808), B(87809), B(87810) /    -8.90,  -13.71,    0.00 /
      DATA B(88111), B(88112), B(88113) /    -8.90,  -13.75,    0.00 /
      DATA B(88414), B(88415), B(88416) /    -8.89,  -13.79,    0.00 /
      DATA B(88717), B(88718), B(88719) /    -8.89,  -13.84,    0.00 /
      DATA B(89020), B(89021), B(89022) /    -8.89,  -13.89,    0.00 /
      DATA B(89323), B(89324), B(89325) /    -8.88,  -13.94,    0.00 /
      DATA B(89626), B(89627), B(89628) /    -8.88,  -13.99,    0.00 /
      DATA B(67813), B(67814), B(67815) /    17.70,  -40.97,    0.00 /
      DATA B(68116), B(68117), B(68118) /    16.87,  -40.74,    0.00 /
      DATA B(68419), B(68420), B(68421) /    15.53,  -39.20,    0.00 /
      DATA B(68722), B(68723), B(68724) /    12.62,  -35.87,    0.00 /
      DATA B(69025), B(69026), B(69027) /     1.61,  -23.69,    0.00 /
      DATA B(69328), B(69329), B(69330) /    -4.96,  -15.64,    0.00 /
      DATA B(69631), B(69632), B(69633) /    -6.93,  -14.23,    0.00 /
      DATA B(69934), B(69935), B(69936) /    -7.72,  -13.55,    0.00 /
      DATA B(70237), B(70238), B(70239) /    -8.04,  -13.21,    0.00 /
      DATA B(70540), B(70541), B(70542) /    -8.20,  -13.18,    0.00 /
      DATA B(70843), B(70844), B(70845) /    -8.32,  -13.21,    0.00 /
      DATA B(71146), B(71147), B(71148) /    -8.38,  -13.24,    0.00 /
      DATA B(71449), B(71450), B(71451) /    -8.38,  -13.30,    0.00 /
      DATA B(71752), B(71753), B(71754) /    -8.34,  -13.42,    0.00 /
      DATA B(72055), B(72056), B(72057) /    -8.26,  -13.65,    0.00 /
      DATA B(72358), B(72359), B(72360) /    -8.07,  -14.11,    0.00 /
      DATA B(72661), B(72662), B(72663) /    -9.04,  -11.51,    0.00 /
      DATA B(72964), B(72965), B(72966) /    -9.72,  -13.49,    0.00 /
      DATA B(73267), B(73268), B(73269) /    -9.45,  -14.41,    0.00 /
      DATA B(73570), B(73571), B(73572) /    -9.33,  -14.75,    0.00 /
      DATA B(73873), B(73874), B(73875) /    -9.28,  -14.93,    0.00 /
      DATA B(74176), B(74177), B(74178) /    -9.26,  -15.04,    0.00 /
      DATA B(74479), B(74480), B(74481) /    -9.27,  -15.14,    0.00 /
      DATA B(74782), B(74783), B(74784) /    -9.28,  -15.23,    0.00 /
      DATA B(75085), B(75086), B(75087) /    -9.29,  -15.31,    0.00 /
      DATA B(75388), B(75389), B(75390) /    -9.31,  -15.38,    0.00 /
      DATA B(75691), B(75692), B(75693) /    -9.33,  -15.46,    0.00 /
      DATA B(75994), B(75995), B(75996) /    -9.35,  -15.54,    0.00 /
      DATA B(76297), B(76298), B(76299) /    -9.37,  -15.61,    0.00 /
      DATA B(76600), B(76601), B(76602) /    -9.39,  -15.68,    0.00 /
      DATA B(76903), B(76904), B(76905) /    -9.42,  -15.75,    0.00 /
      DATA B(77206), B(77207), B(77208) /    -9.44,  -15.82,    0.00 /
      DATA B(77509), B(77510), B(77511) /    -9.45,  -15.89,    0.00 /
      DATA B(77812), B(77813), B(77814) /    -9.47,  -15.95,    0.00 /
      DATA B(78115), B(78116), B(78117) /    -9.48,  -16.02,    0.00 /
      DATA B(78418), B(78419), B(78420) /    -9.50,  -16.08,    0.00 /
      DATA B(78721), B(78722), B(78723) /    -9.50,  -16.15,    0.00 /
      DATA B(79024), B(79025), B(79026) /    -9.49,  -16.21,    0.00 /
      DATA B(79327), B(79328), B(79329) /    -9.47,  -16.28,    0.00 /
      DATA B(79630), B(79631), B(79632) /    -9.43,  -16.34,    0.00 /
      DATA B(79933), B(79934), B(79935) /    -9.34,  -16.38,    0.00 /
      DATA B(80236), B(80237), B(80238) /    -9.23,  -16.41,    0.00 /
      DATA B(80539), B(80540), B(80541) /    -9.13,  -16.48,    0.00 /
      DATA B(80842), B(80843), B(80844) /    -9.05,  -16.57,    0.00 /
      DATA B(81145), B(81146), B(81147) /    -8.96,  -16.41,    0.00 /
      DATA B(81448), B(81449), B(81450) /    -8.85,  -15.59,    0.00 /
      DATA B(81751), B(81752), B(81753) /    -8.88,  -15.56,    0.00 /
      DATA B(82054), B(82055), B(82056) /    -8.96,  -15.68,    0.00 /
      DATA B(82357), B(82358), B(82359) /    -9.05,  -15.83,    0.00 /
      DATA B(82660), B(82661), B(82662) /    -9.17,  -16.03,    0.00 /
      DATA B(82963), B(82964), B(82965) /    -9.28,  -15.82,    0.00 /
      DATA B(83266), B(83267), B(83268) /    -9.42,  -15.65,    0.00 /
      DATA B(83569), B(83570), B(83571) /    -9.54,  -15.44,    0.00 /
      DATA B(83872), B(83873), B(83874) /    -9.64,  -15.14,    0.00 /
      DATA B(84175), B(84176), B(84177) /    -9.58,  -14.55,    0.00 /
      DATA B(84478), B(84479), B(84480) /    -9.24,  -13.81,    0.00 /
      DATA B(84781), B(84782), B(84783) /    -9.15,  -13.64,    0.00 /
      DATA B(85084), B(85085), B(85086) /    -9.12,  -13.63,    0.00 /
      DATA B(85387), B(85388), B(85389) /    -9.10,  -13.66,    0.00 /
      DATA B(85690), B(85691), B(85692) /    -9.08,  -13.71,    0.00 /
      DATA B(85993), B(85994), B(85995) /    -9.07,  -13.76,    0.00 /
      DATA B(86296), B(86297), B(86298) /    -9.05,  -13.82,    0.00 /
      DATA B(86599), B(86600), B(86601) /    -9.04,  -13.88,    0.00 /
      DATA B(86902), B(86903), B(86904) /    -9.02,  -13.94,    0.00 /
      DATA B(87205), B(87206), B(87207) /    -9.01,  -14.00,    0.00 /
      DATA B(87508), B(87509), B(87510) /    -8.84,  -13.70,    0.00 /
      DATA B(87811), B(87812), B(87813) /    -8.83,  -13.74,    0.00 /
      DATA B(88114), B(88115), B(88116) /    -8.83,  -13.79,    0.00 /
      DATA B(88417), B(88418), B(88419) /    -8.82,  -13.83,    0.00 /
      DATA B(88720), B(88721), B(88722) /    -8.82,  -13.88,    0.00 /
      DATA B(89023), B(89024), B(89025) /    -8.81,  -13.93,    0.00 /
      DATA B(89326), B(89327), B(89328) /    -8.81,  -13.97,    0.00 /
      DATA B(89629), B(89630), B(89631) /    -8.81,  -14.02,    0.00 /
      DATA B(67816), B(67817), B(67818) /    16.08,  -42.70,    0.00 /
      DATA B(68119), B(68120), B(68121) /    14.94,  -42.09,    0.00 /
      DATA B(68422), B(68423), B(68424) /    12.37,  -37.43,    0.00 /
      DATA B(68725), B(68726), B(68727) /     3.80,  -28.95,    0.00 /
      DATA B(69028), B(69029), B(69030) /    -5.04,  -18.08,    0.00 /
      DATA B(69331), B(69332), B(69333) /    -6.82,  -14.37,    0.00 /
      DATA B(69634), B(69635), B(69636) /    -7.59,  -13.52,    0.00 /
      DATA B(69937), B(69938), B(69939) /    -7.99,  -13.17,    0.00 /
      DATA B(70240), B(70241), B(70242) /    -8.19,  -13.01,    0.00 /
      DATA B(70543), B(70544), B(70545) /    -8.29,  -12.98,    0.00 /
      DATA B(70846), B(70847), B(70848) /    -8.36,  -13.02,    0.00 /
      DATA B(71149), B(71150), B(71151) /    -8.40,  -13.07,    0.00 /
      DATA B(71452), B(71453), B(71454) /    -8.40,  -13.14,    0.00 /
      DATA B(71755), B(71756), B(71757) /    -8.37,  -13.24,    0.00 /
      DATA B(72058), B(72059), B(72060) /    -8.32,  -13.40,    0.00 /
      DATA B(72361), B(72362), B(72363) /    -8.19,  -13.69,    0.00 /
      DATA B(72664), B(72665), B(72666) /    -7.92,  -14.38,    0.00 /
      DATA B(72967), B(72968), B(72969) /    -9.47,  -12.56,    0.00 /
      DATA B(73270), B(73271), B(73272) /    -9.49,  -14.05,    0.00 /
      DATA B(73573), B(73574), B(73575) /    -9.29,  -14.58,    0.00 /
      DATA B(73876), B(73877), B(73878) /    -9.22,  -14.81,    0.00 /
      DATA B(74179), B(74180), B(74181) /    -9.19,  -14.95,    0.00 /
      DATA B(74482), B(74483), B(74484) /    -9.19,  -15.06,    0.00 /
      DATA B(74785), B(74786), B(74787) /    -9.20,  -15.15,    0.00 /
      DATA B(75088), B(75089), B(75090) /    -9.22,  -15.24,    0.00 /
      DATA B(75391), B(75392), B(75393) /    -9.23,  -15.33,    0.00 /
      DATA B(75694), B(75695), B(75696) /    -9.25,  -15.41,    0.00 /
      DATA B(75997), B(75998), B(75999) /    -9.27,  -15.49,    0.00 /
      DATA B(76300), B(76301), B(76302) /    -9.29,  -15.56,    0.00 /
      DATA B(76603), B(76604), B(76605) /    -9.31,  -15.64,    0.00 /
      DATA B(76906), B(76907), B(76908) /    -9.33,  -15.71,    0.00 /
      DATA B(77209), B(77210), B(77211) /    -9.35,  -15.78,    0.00 /
      DATA B(77512), B(77513), B(77514) /    -9.37,  -15.85,    0.00 /
      DATA B(77815), B(77816), B(77817) /    -9.39,  -15.92,    0.00 /
      DATA B(78118), B(78119), B(78120) /    -9.41,  -15.99,    0.00 /
      DATA B(78421), B(78422), B(78423) /    -9.43,  -16.05,    0.00 /
      DATA B(78724), B(78725), B(78726) /    -9.44,  -16.12,    0.00 /
      DATA B(79027), B(79028), B(79029) /    -9.45,  -16.18,    0.00 /
      DATA B(79330), B(79331), B(79332) /    -9.46,  -16.24,    0.00 /
      DATA B(79633), B(79634), B(79635) /    -9.46,  -16.31,    0.00 /
      DATA B(79936), B(79937), B(79938) /    -9.44,  -16.37,    0.00 /
      DATA B(80239), B(80240), B(80241) /    -9.37,  -16.44,    0.00 /
      DATA B(80542), B(80543), B(80544) /    -9.22,  -16.57,    0.00 /
      DATA B(80845), B(80846), B(80847) /    -9.05,  -16.61,    0.00 /
      DATA B(81148), B(81149), B(81150) /    -8.96,  -16.54,    0.00 /
      DATA B(81451), B(81452), B(81453) /    -8.91,  -15.72,    0.00 /
      DATA B(81754), B(81755), B(81756) /    -8.90,  -15.56,    0.00 /
      DATA B(82057), B(82058), B(82059) /    -8.97,  -15.66,    0.00 /
      DATA B(82360), B(82361), B(82362) /    -9.05,  -15.81,    0.00 /
      DATA B(82663), B(82664), B(82665) /    -9.12,  -15.97,    0.00 /
      DATA B(82966), B(82967), B(82968) /    -9.18,  -15.75,    0.00 /
      DATA B(83269), B(83270), B(83271) /    -9.30,  -15.56,    0.00 /
      DATA B(83572), B(83573), B(83574) /    -9.42,  -15.37,    0.00 /
      DATA B(83875), B(83876), B(83877) /    -9.53,  -15.13,    0.00 /
      DATA B(84178), B(84179), B(84180) /    -9.58,  -14.75,    0.00 /
      DATA B(84481), B(84482), B(84483) /    -9.32,  -14.01,    0.00 /
      DATA B(84784), B(84785), B(84786) /    -9.16,  -13.72,    0.00 /
      DATA B(85087), B(85088), B(85089) /    -9.11,  -13.69,    0.00 /
      DATA B(85390), B(85391), B(85392) /    -9.08,  -13.72,    0.00 /
      DATA B(85693), B(85694), B(85695) /    -9.06,  -13.76,    0.00 /
      DATA B(85996), B(85997), B(85998) /    -9.04,  -13.82,    0.00 /
      DATA B(86299), B(86300), B(86301) /    -9.03,  -13.87,    0.00 /
      DATA B(86602), B(86603), B(86604) /    -9.01,  -13.94,    0.00 /
      DATA B(86905), B(86906), B(86907) /    -8.99,  -14.00,    0.00 /
      DATA B(87208), B(87209), B(87210) /    -8.98,  -14.06,    0.00 /
      DATA B(87511), B(87512), B(87513) /    -8.77,  -13.74,    0.00 /
      DATA B(87814), B(87815), B(87816) /    -8.76,  -13.78,    0.00 /
      DATA B(88117), B(88118), B(88119) /    -8.75,  -13.82,    0.00 /
      DATA B(88420), B(88421), B(88422) /    -8.75,  -13.87,    0.00 /
      DATA B(88723), B(88724), B(88725) /    -8.74,  -13.91,    0.00 /
      DATA B(89026), B(89027), B(89028) /    -8.74,  -13.96,    0.00 /
      DATA B(89329), B(89330), B(89331) /    -8.74,  -14.01,    0.00 /
      DATA B(89632), B(89633), B(89634) /    -8.73,  -14.06,    0.00 /
      DATA B(67819), B(67820), B(67821) /    14.46,  -44.43,    0.00 /
      DATA B(68122), B(68123), B(68124) /    11.50,  -44.58,    0.00 /
      DATA B(68425), B(68426), B(68427) /     2.52,  -29.93,    0.00 /
      DATA B(68728), B(68729), B(68730) /    -5.73,  -20.19,    0.00 /
      DATA B(69031), B(69032), B(69033) /    -7.51,  -15.63,    0.00 /
      DATA B(69334), B(69335), B(69336) /    -7.88,  -13.82,    0.00 /
      DATA B(69637), B(69638), B(69639) /    -8.07,  -13.20,    0.00 /
      DATA B(69940), B(69941), B(69942) /    -8.22,  -12.96,    0.00 /
      DATA B(70243), B(70244), B(70245) /    -8.30,  -12.86,    0.00 /
      DATA B(70546), B(70547), B(70548) /    -8.36,  -12.86,    0.00 /
      DATA B(70849), B(70850), B(70851) /    -8.39,  -12.89,    0.00 /
      DATA B(71152), B(71153), B(71154) /    -8.41,  -12.95,    0.00 /
      DATA B(71455), B(71456), B(71457) /    -8.40,  -13.02,    0.00 /
      DATA B(71758), B(71759), B(71760) /    -8.38,  -13.11,    0.00 /
      DATA B(72061), B(72062), B(72063) /    -8.34,  -13.24,    0.00 /
      DATA B(72364), B(72365), B(72366) /    -8.25,  -13.44,    0.00 /
      DATA B(72667), B(72668), B(72669) /    -8.06,  -13.84,    0.00 /
      DATA B(72970), B(72971), B(72972) /    -8.93,  -11.64,    0.00 /
      DATA B(73273), B(73274), B(73275) /    -9.53,  -13.47,    0.00 /
      DATA B(73576), B(73577), B(73578) /    -9.27,  -14.35,    0.00 /
      DATA B(73879), B(73880), B(73881) /    -9.16,  -14.66,    0.00 /
      DATA B(74182), B(74183), B(74184) /    -9.12,  -14.83,    0.00 /
      DATA B(74485), B(74486), B(74487) /    -9.12,  -14.96,    0.00 /
      DATA B(74788), B(74789), B(74790) /    -9.13,  -15.07,    0.00 /
      DATA B(75091), B(75092), B(75093) /    -9.14,  -15.17,    0.00 /
      DATA B(75394), B(75395), B(75396) /    -9.15,  -15.26,    0.00 /
      DATA B(75697), B(75698), B(75699) /    -9.17,  -15.35,    0.00 /
      DATA B(76000), B(76001), B(76002) /    -9.19,  -15.43,    0.00 /
      DATA B(76303), B(76304), B(76305) /    -9.21,  -15.51,    0.00 /
      DATA B(76606), B(76607), B(76608) /    -9.23,  -15.59,    0.00 /
      DATA B(76909), B(76910), B(76911) /    -9.25,  -15.67,    0.00 /
      DATA B(77212), B(77213), B(77214) /    -9.27,  -15.74,    0.00 /
      DATA B(77515), B(77516), B(77517) /    -9.29,  -15.81,    0.00 /
      DATA B(77818), B(77819), B(77820) /    -9.31,  -15.88,    0.00 /
      DATA B(78121), B(78122), B(78123) /    -9.32,  -15.95,    0.00 /
      DATA B(78424), B(78425), B(78426) /    -9.34,  -16.02,    0.00 /
      DATA B(78727), B(78728), B(78729) /    -9.36,  -16.08,    0.00 /
      DATA B(79030), B(79031), B(79032) /    -9.38,  -16.15,    0.00 /
      DATA B(79333), B(79334), B(79335) /    -9.39,  -16.21,    0.00 /
      DATA B(79636), B(79637), B(79638) /    -9.40,  -16.27,    0.00 /
      DATA B(79939), B(79940), B(79941) /    -9.40,  -16.33,    0.00 /
      DATA B(80242), B(80243), B(80244) /    -9.39,  -16.38,    0.00 /
      DATA B(80545), B(80546), B(80547) /    -9.35,  -16.38,    0.00 /
      DATA B(80848), B(80849), B(80850) /    -9.10,  -16.73,    0.00 /
      DATA B(81151), B(81152), B(81153) /    -8.94,  -16.66,    0.00 /
      DATA B(81454), B(81455), B(81456) /    -8.73,  -16.10,    0.00 /
      DATA B(81757), B(81758), B(81759) /    -8.93,  -15.59,    0.00 /
      DATA B(82060), B(82061), B(82062) /    -8.99,  -15.65,    0.00 /
      DATA B(82363), B(82364), B(82365) /    -9.06,  -15.78,    0.00 /
      DATA B(82666), B(82667), B(82668) /    -9.10,  -15.90,    0.00 /
      DATA B(82969), B(82970), B(82971) /    -9.09,  -15.73,    0.00 /
      DATA B(83272), B(83273), B(83274) /    -9.18,  -15.49,    0.00 /
      DATA B(83575), B(83576), B(83577) /    -9.30,  -15.29,    0.00 /
      DATA B(83878), B(83879), B(83880) /    -9.42,  -15.08,    0.00 /
      DATA B(84181), B(84182), B(84183) /    -9.50,  -14.81,    0.00 /
      DATA B(84484), B(84485), B(84486) /    -9.40,  -14.28,    0.00 /
      DATA B(84787), B(84788), B(84789) /    -9.17,  -13.81,    0.00 /
      DATA B(85090), B(85091), B(85092) /    -9.10,  -13.75,    0.00 /
      DATA B(85393), B(85394), B(85395) /    -9.06,  -13.77,    0.00 /
      DATA B(85696), B(85697), B(85698) /    -9.04,  -13.82,    0.00 /
      DATA B(85999), B(86000), B(86001) /    -9.02,  -13.87,    0.00 /
      DATA B(86302), B(86303), B(86304) /    -9.00,  -13.93,    0.00 /
      DATA B(86605), B(86606), B(86607) /    -8.98,  -13.99,    0.00 /
      DATA B(86908), B(86909), B(86910) /    -8.97,  -14.05,    0.00 /
      DATA B(87211), B(87212), B(87213) /    -8.95,  -14.11,    0.00 /
      DATA B(87514), B(87515), B(87516) /    -8.69,  -13.77,    0.00 /
      DATA B(87817), B(87818), B(87819) /    -8.68,  -13.81,    0.00 /
      DATA B(88120), B(88121), B(88122) /    -8.68,  -13.85,    0.00 /
      DATA B(88423), B(88424), B(88425) /    -8.67,  -13.90,    0.00 /
      DATA B(88726), B(88727), B(88728) /    -8.67,  -13.95,    0.00 /
      DATA B(89029), B(89030), B(89031) /    -8.67,  -14.00,    0.00 /
      DATA B(89332), B(89333), B(89334) /    -8.66,  -14.04,    0.00 /
      DATA B(89635), B(89636), B(89637) /    -8.66,  -14.09,    0.00 /
      DATA B(67822), B(67823), B(67824) /   -10.25,  -11.45,    0.00 /
      DATA B(68125), B(68126), B(68127) /    -9.96,  -12.98,    0.00 /
      DATA B(68428), B(68429), B(68430) /    -9.17,  -20.44,    0.00 /
      DATA B(68731), B(68732), B(68733) /    -8.58,  -16.40,    0.00 /
      DATA B(69034), B(69035), B(69036) /    -8.48,  -14.46,    0.00 /
      DATA B(69337), B(69338), B(69339) /    -8.41,  -13.47,    0.00 /
      DATA B(69640), B(69641), B(69642) /    -8.37,  -13.02,    0.00 /
      DATA B(69943), B(69944), B(69945) /    -8.37,  -12.84,    0.00 /
      DATA B(70246), B(70247), B(70248) /    -8.39,  -12.77,    0.00 /
      DATA B(70549), B(70550), B(70551) /    -8.40,  -12.77,    0.00 /
      DATA B(70852), B(70853), B(70854) /    -8.40,  -12.80,    0.00 /
      DATA B(71155), B(71156), B(71157) /    -8.40,  -12.86,    0.00 /
      DATA B(71458), B(71459), B(71460) /    -8.39,  -12.92,    0.00 /
      DATA B(71761), B(71762), B(71763) /    -8.37,  -13.01,    0.00 /
      DATA B(72064), B(72065), B(72066) /    -8.34,  -13.11,    0.00 /
      DATA B(72367), B(72368), B(72369) /    -8.27,  -13.26,    0.00 /
      DATA B(72670), B(72671), B(72672) /    -8.14,  -13.52,    0.00 /
      DATA B(72973), B(72974), B(72975) /    -7.88,  -14.10,    0.00 /
      DATA B(73276), B(73277), B(73278) /    -9.22,  -12.65,    0.00 /
      DATA B(73579), B(73580), B(73581) /    -9.28,  -13.99,    0.00 /
      DATA B(73882), B(73883), B(73884) /    -9.10,  -14.46,    0.00 /
      DATA B(74185), B(74186), B(74187) /    -9.06,  -14.67,    0.00 /
      DATA B(74488), B(74489), B(74490) /    -9.05,  -14.83,    0.00 /
      DATA B(74791), B(74792), B(74793) /    -9.05,  -14.96,    0.00 /
      DATA B(75094), B(75095), B(75096) /    -9.06,  -15.07,    0.00 /
      DATA B(75397), B(75398), B(75399) /    -9.07,  -15.18,    0.00 /
      DATA B(75700), B(75701), B(75702) /    -9.09,  -15.28,    0.00 /
      DATA B(76003), B(76004), B(76005) /    -9.10,  -15.37,    0.00 /
      DATA B(76306), B(76307), B(76308) /    -9.12,  -15.46,    0.00 /
      DATA B(76609), B(76610), B(76611) /    -9.14,  -15.54,    0.00 /
      DATA B(76912), B(76913), B(76914) /    -9.16,  -15.62,    0.00 /
      DATA B(77215), B(77216), B(77217) /    -9.17,  -15.70,    0.00 /
      DATA B(77518), B(77519), B(77520) /    -9.19,  -15.77,    0.00 /
      DATA B(77821), B(77822), B(77823) /    -9.21,  -15.84,    0.00 /
      DATA B(78124), B(78125), B(78126) /    -9.23,  -15.91,    0.00 /
      DATA B(78427), B(78428), B(78429) /    -9.25,  -15.98,    0.00 /
      DATA B(78730), B(78731), B(78732) /    -9.27,  -16.04,    0.00 /
      DATA B(79033), B(79034), B(79035) /    -9.29,  -16.11,    0.00 /
      DATA B(79336), B(79337), B(79338) /    -9.30,  -16.17,    0.00 /
      DATA B(79639), B(79640), B(79641) /    -9.32,  -16.22,    0.00 /
      DATA B(79942), B(79943), B(79944) /    -9.33,  -16.28,    0.00 /
      DATA B(80245), B(80246), B(80247) /    -9.35,  -16.33,    0.00 /
      DATA B(80548), B(80549), B(80550) /    -9.35,  -16.34,    0.00 /
      DATA B(80851), B(80852), B(80853) /    -9.13,  -16.87,    0.00 /
      DATA B(81154), B(81155), B(81156) /    -8.97,  -16.85,    0.00 /
      DATA B(81457), B(81458), B(81459) /    -8.79,  -16.46,    0.00 /
      DATA B(81760), B(81761), B(81762) /    -8.94,  -15.66,    0.00 /
      DATA B(82063), B(82064), B(82065) /    -9.01,  -15.65,    0.00 /
      DATA B(82366), B(82367), B(82368) /    -9.09,  -15.76,    0.00 /
      DATA B(82669), B(82670), B(82671) /    -9.15,  -15.87,    0.00 /
      DATA B(82972), B(82973), B(82974) /    -9.10,  -15.78,    0.00 /
      DATA B(83275), B(83276), B(83277) /    -9.08,  -15.45,    0.00 /
      DATA B(83578), B(83579), B(83580) /    -9.19,  -15.23,    0.00 /
      DATA B(83881), B(83882), B(83883) /    -9.30,  -15.02,    0.00 /
      DATA B(84184), B(84185), B(84186) /    -9.40,  -14.79,    0.00 /
      DATA B(84487), B(84488), B(84489) /    -9.42,  -14.45,    0.00 /
      DATA B(84790), B(84791), B(84792) /    -9.21,  -13.92,    0.00 /
      DATA B(85093), B(85094), B(85095) /    -9.09,  -13.81,    0.00 /
      DATA B(85396), B(85397), B(85398) /    -9.04,  -13.82,    0.00 /
      DATA B(85699), B(85700), B(85701) /    -9.01,  -13.87,    0.00 /
      DATA B(86002), B(86003), B(86004) /    -8.99,  -13.92,    0.00 /
      DATA B(86305), B(86306), B(86307) /    -8.97,  -13.98,    0.00 /
      DATA B(86608), B(86609), B(86610) /    -8.96,  -14.05,    0.00 /
      DATA B(86911), B(86912), B(86913) /    -8.94,  -14.11,    0.00 /
      DATA B(87214), B(87215), B(87216) /    -8.92,  -14.16,    0.00 /
      DATA B(87517), B(87518), B(87519) /    -8.62,  -13.80,    0.00 /
      DATA B(87820), B(87821), B(87822) /    -8.61,  -13.84,    0.00 /
      DATA B(88123), B(88124), B(88125) /    -8.60,  -13.89,    0.00 /
      DATA B(88426), B(88427), B(88428) /    -8.60,  -13.93,    0.00 /
      DATA B(88729), B(88730), B(88731) /    -8.59,  -13.98,    0.00 /
      DATA B(89032), B(89033), B(89034) /    -8.59,  -14.03,    0.00 /
      DATA B(89335), B(89336), B(89337) /    -8.59,  -14.08,    0.00 /
      DATA B(89638), B(89639), B(89640) /    -8.58,  -14.13,    0.00 /
      DATA B(67825), B(67826), B(67827) /    -9.18,  -11.86,    0.00 /
      DATA B(68128), B(68129), B(68130) /    -8.62,  -13.59,    0.00 /
      DATA B(68431), B(68432), B(68433) /    -8.89,  -15.58,    0.00 /
      DATA B(68734), B(68735), B(68736) /    -8.97,  -14.73,    0.00 /
      DATA B(69037), B(69038), B(69039) /    -8.78,  -13.79,    0.00 /
      DATA B(69340), B(69341), B(69342) /    -8.62,  -13.21,    0.00 /
      DATA B(69643), B(69644), B(69645) /    -8.52,  -12.90,    0.00 /
      DATA B(69946), B(69947), B(69948) /    -8.46,  -12.75,    0.00 /
      DATA B(70249), B(70250), B(70251) /    -8.43,  -12.70,    0.00 /
      DATA B(70552), B(70553), B(70554) /    -8.41,  -12.70,    0.00 /
      DATA B(70855), B(70856), B(70857) /    -8.40,  -12.74,    0.00 /
      DATA B(71158), B(71159), B(71160) /    -8.39,  -12.79,    0.00 /
      DATA B(71461), B(71462), B(71463) /    -8.38,  -12.85,    0.00 /
      DATA B(71764), B(71765), B(71766) /    -8.35,  -12.93,    0.00 /
      DATA B(72067), B(72068), B(72069) /    -8.32,  -13.02,    0.00 /
      DATA B(72370), B(72371), B(72372) /    -8.27,  -13.14,    0.00 /
      DATA B(72673), B(72674), B(72675) /    -8.18,  -13.32,    0.00 /
      DATA B(72976), B(72977), B(72978) /    -8.00,  -13.66,    0.00 /
      DATA B(73279), B(73280), B(73281) /    -8.77,  -11.88,    0.00 /
      DATA B(73582), B(73583), B(73584) /    -9.25,  -13.41,    0.00 /
      DATA B(73885), B(73886), B(73887) /    -9.06,  -14.09,    0.00 /
      DATA B(74188), B(74189), B(74190) /    -9.01,  -14.40,    0.00 /
      DATA B(74491), B(74492), B(74493) /    -8.99,  -14.62,    0.00 /
      DATA B(74794), B(74795), B(74796) /    -8.99,  -14.80,    0.00 /
      DATA B(75097), B(75098), B(75099) /    -8.99,  -14.95,    0.00 /
      DATA B(75400), B(75401), B(75402) /    -9.00,  -15.08,    0.00 /
      DATA B(75703), B(75704), B(75705) /    -9.01,  -15.19,    0.00 /
      DATA B(76006), B(76007), B(76008) /    -9.02,  -15.29,    0.00 /
      DATA B(76309), B(76310), B(76311) /    -9.03,  -15.39,    0.00 /
      DATA B(76612), B(76613), B(76614) /    -9.05,  -15.48,    0.00 /
      DATA B(76915), B(76916), B(76917) /    -9.06,  -15.56,    0.00 /
      DATA B(77218), B(77219), B(77220) /    -9.08,  -15.64,    0.00 /
      DATA B(77521), B(77522), B(77523) /    -9.10,  -15.72,    0.00 /
      DATA B(77824), B(77825), B(77826) /    -9.12,  -15.79,    0.00 /
      DATA B(78127), B(78128), B(78129) /    -9.14,  -15.87,    0.00 /
      DATA B(78430), B(78431), B(78432) /    -9.16,  -15.93,    0.00 /
      DATA B(78733), B(78734), B(78735) /    -9.17,  -16.00,    0.00 /
      DATA B(79036), B(79037), B(79038) /    -9.19,  -16.06,    0.00 /
      DATA B(79339), B(79340), B(79341) /    -9.21,  -16.12,    0.00 /
      DATA B(79642), B(79643), B(79644) /    -9.23,  -16.18,    0.00 /
      DATA B(79945), B(79946), B(79947) /    -9.25,  -16.23,    0.00 /
      DATA B(80248), B(80249), B(80250) /    -9.27,  -16.27,    0.00 /
      DATA B(80551), B(80552), B(80553) /    -9.30,  -16.29,    0.00 /
      DATA B(80854), B(80855), B(80856) /    -9.32,  -16.27,    0.00 /
      DATA B(81157), B(81158), B(81159) /    -9.01,  -17.05,    0.00 /
      DATA B(81460), B(81461), B(81462) /    -8.83,  -16.81,    0.00 /
      DATA B(81763), B(81764), B(81765) /    -8.96,  -15.82,    0.00 /
      DATA B(82066), B(82067), B(82068) /    -9.02,  -15.66,    0.00 /
      DATA B(82369), B(82370), B(82371) /    -9.11,  -15.73,    0.00 /
      DATA B(82672), B(82673), B(82674) /    -9.18,  -15.84,    0.00 /
      DATA B(82975), B(82976), B(82977) /    -9.19,  -15.85,    0.00 /
      DATA B(83278), B(83279), B(83280) /    -9.04,  -15.48,    0.00 /
      DATA B(83581), B(83582), B(83583) /    -9.08,  -15.18,    0.00 /
      DATA B(83884), B(83885), B(83886) /    -9.18,  -14.96,    0.00 /
      DATA B(84187), B(84188), B(84189) /    -9.28,  -14.75,    0.00 /
      DATA B(84490), B(84491), B(84492) /    -9.35,  -14.50,    0.00 /
      DATA B(84793), B(84794), B(84795) /    -9.26,  -14.05,    0.00 /
      DATA B(85096), B(85097), B(85098) /    -9.10,  -13.86,    0.00 /
      DATA B(85399), B(85400), B(85401) /    -9.03,  -13.88,    0.00 /
      DATA B(85702), B(85703), B(85704) /    -8.99,  -13.92,    0.00 /
      DATA B(86005), B(86006), B(86007) /    -8.97,  -13.98,    0.00 /
      DATA B(86308), B(86309), B(86310) /    -8.95,  -14.04,    0.00 /
      DATA B(86611), B(86612), B(86613) /    -8.93,  -14.10,    0.00 /
      DATA B(86914), B(86915), B(86916) /    -8.91,  -14.16,    0.00 /
      DATA B(87217), B(87218), B(87219) /    -8.56,  -13.80,    0.00 /
      DATA B(87520), B(87521), B(87522) /    -8.54,  -13.83,    0.00 /
      DATA B(87823), B(87824), B(87825) /    -8.54,  -13.88,    0.00 /
      DATA B(88126), B(88127), B(88128) /    -8.53,  -13.92,    0.00 /
      DATA B(88429), B(88430), B(88431) /    -8.52,  -13.97,    0.00 /
      DATA B(88732), B(88733), B(88734) /    -8.52,  -14.02,    0.00 /
      DATA B(89035), B(89036), B(89037) /    -8.52,  -14.06,    0.00 /
      DATA B(89338), B(89339), B(89340) /    -8.51,  -14.11,    0.00 /
      DATA B(89641), B(89642), B(89643) /    -8.51,  -14.16,    0.00 /
      DATA B(67828), B(67829), B(67830) /    -8.75,  -12.03,    0.00 /
      DATA B(68131), B(68132), B(68133) /    -8.57,  -12.96,    0.00 /
      DATA B(68434), B(68435), B(68436) /    -8.68,  -13.76,    0.00 /
      DATA B(68737), B(68738), B(68739) /    -8.80,  -13.71,    0.00 /
      DATA B(69040), B(69041), B(69042) /    -8.75,  -13.33,    0.00 /
      DATA B(69343), B(69344), B(69345) /    -8.65,  -13.00,    0.00 /
      DATA B(69646), B(69647), B(69648) /    -8.56,  -12.79,    0.00 /
      DATA B(69949), B(69950), B(69951) /    -8.49,  -12.69,    0.00 /
      DATA B(70252), B(70253), B(70254) /    -8.44,  -12.65,    0.00 /
      DATA B(70555), B(70556), B(70557) /    -8.41,  -12.66,    0.00 /
      DATA B(70858), B(70859), B(70860) /    -8.39,  -12.69,    0.00 /
      DATA B(71161), B(71162), B(71163) /    -8.37,  -12.74,    0.00 /
      DATA B(71464), B(71465), B(71466) /    -8.35,  -12.80,    0.00 /
      DATA B(71767), B(71768), B(71769) /    -8.33,  -12.87,    0.00 /
      DATA B(72070), B(72071), B(72072) /    -8.30,  -12.95,    0.00 /
      DATA B(72373), B(72374), B(72375) /    -8.26,  -13.06,    0.00 /
      DATA B(72676), B(72677), B(72678) /    -8.19,  -13.19,    0.00 /
      DATA B(72979), B(72980), B(72981) /    -8.06,  -13.42,    0.00 /
      DATA B(73282), B(73283), B(73284) /    -7.80,  -13.89,    0.00 /
      DATA B(73585), B(73586), B(73587) /    -8.78,  -12.68,    0.00 /
      DATA B(73888), B(73889), B(73890) /    -9.06,  -13.31,    0.00 /
      DATA B(74191), B(74192), B(74193) /    -9.02,  -13.86,    0.00 /
      DATA B(74494), B(74495), B(74496) /    -8.98,  -14.25,    0.00 /
      DATA B(74797), B(74798), B(74799) /    -8.95,  -14.54,    0.00 /
      DATA B(75100), B(75101), B(75102) /    -8.94,  -14.75,    0.00 /
      DATA B(75403), B(75404), B(75405) /    -8.93,  -14.93,    0.00 /
      DATA B(75706), B(75707), B(75708) /    -8.93,  -15.07,    0.00 /
      DATA B(76009), B(76010), B(76011) /    -8.94,  -15.20,    0.00 /
      DATA B(76312), B(76313), B(76314) /    -8.95,  -15.31,    0.00 /
      DATA B(76615), B(76616), B(76617) /    -8.96,  -15.40,    0.00 /
      DATA B(76918), B(76919), B(76920) /    -8.97,  -15.49,    0.00 /
      DATA B(77221), B(77222), B(77223) /    -8.99,  -15.58,    0.00 /
      DATA B(77524), B(77525), B(77526) /    -9.01,  -15.66,    0.00 /
      DATA B(77827), B(77828), B(77829) /    -9.02,  -15.74,    0.00 /
      DATA B(78130), B(78131), B(78132) /    -9.04,  -15.81,    0.00 /
      DATA B(78433), B(78434), B(78435) /    -9.06,  -15.88,    0.00 /
      DATA B(78736), B(78737), B(78738) /    -9.08,  -15.95,    0.00 /
      DATA B(79039), B(79040), B(79041) /    -9.09,  -16.01,    0.00 /
      DATA B(79342), B(79343), B(79344) /    -9.11,  -16.07,    0.00 /
      DATA B(79645), B(79646), B(79647) /    -9.13,  -16.12,    0.00 /
      DATA B(79948), B(79949), B(79950) /    -9.15,  -16.17,    0.00 /
      DATA B(80251), B(80252), B(80253) /    -9.18,  -16.20,    0.00 /
      DATA B(80554), B(80555), B(80556) /    -9.21,  -16.23,    0.00 /
      DATA B(80857), B(80858), B(80859) /    -9.26,  -16.23,    0.00 /
      DATA B(81160), B(81161), B(81162) /    -9.30,  -16.16,    0.00 /
      DATA B(81463), B(81464), B(81465) /    -8.91,  -17.10,    0.00 /
      DATA B(81766), B(81767), B(81768) /    -9.02,  -16.14,    0.00 /
      DATA B(82069), B(82070), B(82071) /    -9.03,  -15.69,    0.00 /
      DATA B(82372), B(82373), B(82374) /    -9.15,  -15.69,    0.00 /
      DATA B(82675), B(82676), B(82677) /    -9.22,  -15.80,    0.00 /
      DATA B(82978), B(82979), B(82980) /    -9.23,  -15.88,    0.00 /
      DATA B(83281), B(83282), B(83283) /    -9.10,  -15.63,    0.00 /
      DATA B(83584), B(83585), B(83586) /    -8.99,  -15.17,    0.00 /
      DATA B(83887), B(83888), B(83889) /    -9.07,  -14.91,    0.00 /
      DATA B(84190), B(84191), B(84192) /    -9.17,  -14.69,    0.00 /
      DATA B(84493), B(84494), B(84495) /    -9.25,  -14.48,    0.00 /
      DATA B(84796), B(84797), B(84798) /    -9.25,  -14.19,    0.00 /
      DATA B(85099), B(85100), B(85101) /    -9.11,  -13.92,    0.00 /
      DATA B(85402), B(85403), B(85404) /    -9.02,  -13.92,    0.00 /
      DATA B(85705), B(85706), B(85707) /    -8.97,  -13.97,    0.00 /
      DATA B(86008), B(86009), B(86010) /    -8.94,  -14.03,    0.00 /
      DATA B(86311), B(86312), B(86313) /    -8.92,  -14.09,    0.00 /
      DATA B(86614), B(86615), B(86616) /    -8.90,  -14.15,    0.00 /
      DATA B(86917), B(86918), B(86919) /    -8.87,  -14.21,    0.00 /
      DATA B(87220), B(87221), B(87222) /    -8.49,  -13.83,    0.00 /
      DATA B(87523), B(87524), B(87525) /    -8.47,  -13.86,    0.00 /
      DATA B(87826), B(87827), B(87828) /    -8.46,  -13.91,    0.00 /
      DATA B(88129), B(88130), B(88131) /    -8.45,  -13.95,    0.00 /
      DATA B(88432), B(88433), B(88434) /    -8.45,  -14.00,    0.00 /
      DATA B(88735), B(88736), B(88737) /    -8.44,  -14.05,    0.00 /
      DATA B(89038), B(89039), B(89040) /    -8.44,  -14.10,    0.00 /
      DATA B(89341), B(89342), B(89343) /    -8.44,  -14.15,    0.00 /
      DATA B(89644), B(89645), B(89646) /    -9.39,  -14.85,    0.00 /
      DATA B(67831), B(67832), B(67833) /    -8.57,  -12.02,    0.00 /
      DATA B(68134), B(68135), B(68136) /    -8.51,  -12.55,    0.00 /
      DATA B(68437), B(68438), B(68439) /    -8.56,  -12.99,    0.00 /
      DATA B(68740), B(68741), B(68742) /    -8.64,  -13.09,    0.00 /
      DATA B(69043), B(69044), B(69045) /    -8.64,  -12.97,    0.00 /
      DATA B(69346), B(69347), B(69348) /    -8.59,  -12.81,    0.00 /
      DATA B(69649), B(69650), B(69651) /    -8.53,  -12.69,    0.00 /
      DATA B(69952), B(69953), B(69954) /    -8.47,  -12.63,    0.00 /
      DATA B(70255), B(70256), B(70257) /    -8.42,  -12.61,    0.00 /
      DATA B(70558), B(70559), B(70560) /    -8.38,  -12.62,    0.00 /
      DATA B(70861), B(70862), B(70863) /    -8.35,  -12.65,    0.00 /
      DATA B(71164), B(71165), B(71166) /    -8.33,  -12.70,    0.00 /
      DATA B(71467), B(71468), B(71469) /    -8.31,  -12.76,    0.00 /
      DATA B(71770), B(71771), B(71772) /    -8.29,  -12.83,    0.00 /
      DATA B(72073), B(72074), B(72075) /    -8.26,  -12.90,    0.00 /
      DATA B(72376), B(72377), B(72378) /    -8.23,  -12.99,    0.00 /
      DATA B(72679), B(72680), B(72681) /    -8.18,  -13.10,    0.00 /
      DATA B(72982), B(72983), B(72984) /    -8.10,  -13.26,    0.00 /
      DATA B(73285), B(73286), B(73287) /    -7.96,  -13.55,    0.00 /
      DATA B(73588), B(73589), B(73590) /    -7.74,  -14.20,    0.00 /
      DATA B(73891), B(73892), B(73893) /    -8.81,  -12.78,    0.00 /
      DATA B(74194), B(74195), B(74196) /    -8.99,  -13.07,    0.00 /
      DATA B(74497), B(74498), B(74499) /    -9.04,  -13.50,    0.00 /
      DATA B(74800), B(74801), B(74802) /    -8.98,  -14.02,    0.00 /
      DATA B(75103), B(75104), B(75105) /    -8.92,  -14.40,    0.00 /
      DATA B(75406), B(75407), B(75408) /    -8.89,  -14.68,    0.00 /
      DATA B(75709), B(75710), B(75711) /    -8.87,  -14.89,    0.00 /
      DATA B(76012), B(76013), B(76014) /    -8.87,  -15.05,    0.00 /
      DATA B(76315), B(76316), B(76317) /    -8.87,  -15.19,    0.00 /
      DATA B(76618), B(76619), B(76620) /    -8.87,  -15.30,    0.00 /
      DATA B(76921), B(76922), B(76923) /    -8.88,  -15.40,    0.00 /
      DATA B(77224), B(77225), B(77226) /    -8.90,  -15.50,    0.00 /
      DATA B(77527), B(77528), B(77529) /    -8.91,  -15.59,    0.00 /
      DATA B(77830), B(77831), B(77832) /    -8.93,  -15.67,    0.00 /
      DATA B(78133), B(78134), B(78135) /    -8.94,  -15.75,    0.00 /
      DATA B(78436), B(78437), B(78438) /    -8.96,  -15.82,    0.00 /
      DATA B(78739), B(78740), B(78741) /    -8.97,  -15.89,    0.00 /
      DATA B(79042), B(79043), B(79044) /    -8.99,  -15.95,    0.00 /
      DATA B(79345), B(79346), B(79347) /    -9.01,  -16.00,    0.00 /
      DATA B(79648), B(79649), B(79650) /    -9.03,  -16.05,    0.00 /
      DATA B(79951), B(79952), B(79953) /    -9.05,  -16.09,    0.00 /
      DATA B(80254), B(80255), B(80256) /    -9.08,  -16.12,    0.00 /
      DATA B(80557), B(80558), B(80559) /    -9.11,  -16.14,    0.00 /
      DATA B(80860), B(80861), B(80862) /    -9.17,  -16.15,    0.00 /
      DATA B(81163), B(81164), B(81165) /    -9.23,  -16.13,    0.00 /
      DATA B(81466), B(81467), B(81468) /    -9.32,  -16.00,    0.00 /
      DATA B(81769), B(81770), B(81771) /    -8.75,  -16.86,    0.00 /
      DATA B(82072), B(82073), B(82074) /    -9.10,  -15.68,    0.00 /
      DATA B(82375), B(82376), B(82377) /    -9.18,  -15.66,    0.00 /
      DATA B(82678), B(82679), B(82680) /    -9.24,  -15.77,    0.00 /
      DATA B(82981), B(82982), B(82983) /    -9.27,  -15.87,    0.00 /
      DATA B(83284), B(83285), B(83286) /    -9.19,  -15.78,    0.00 /
      DATA B(83587), B(83588), B(83589) /    -8.98,  -15.23,    0.00 /
      DATA B(83890), B(83891), B(83892) /    -8.98,  -14.87,    0.00 /
      DATA B(84193), B(84194), B(84195) /    -9.06,  -14.64,    0.00 /
      DATA B(84496), B(84497), B(84498) /    -9.15,  -14.43,    0.00 /
      DATA B(84799), B(84800), B(84801) /    -9.19,  -14.22,    0.00 /
      DATA B(85102), B(85103), B(85104) /    -9.13,  -13.97,    0.00 /
      DATA B(85405), B(85406), B(85407) /    -9.01,  -13.97,    0.00 /
      DATA B(85708), B(85709), B(85710) /    -8.95,  -14.02,    0.00 /
      DATA B(86011), B(86012), B(86013) /    -8.92,  -14.08,    0.00 /
      DATA B(86314), B(86315), B(86316) /    -8.89,  -14.14,    0.00 /
      DATA B(86617), B(86618), B(86619) /    -8.87,  -14.21,    0.00 /
      DATA B(86920), B(86921), B(86922) /    -8.84,  -14.27,    0.00 /
      DATA B(87223), B(87224), B(87225) /    -8.41,  -13.86,    0.00 /
      DATA B(87526), B(87527), B(87528) /    -8.39,  -13.89,    0.00 /
      DATA B(87829), B(87830), B(87831) /    -8.39,  -13.94,    0.00 /
      DATA B(88132), B(88133), B(88134) /    -8.38,  -13.99,    0.00 /
      DATA B(88435), B(88436), B(88437) /    -8.37,  -14.03,    0.00 /
      DATA B(88738), B(88739), B(88740) /    -8.37,  -14.08,    0.00 /
      DATA B(89041), B(89042), B(89043) /    -9.32,  -14.79,    0.00 /
      DATA B(89344), B(89345), B(89346) /    -9.32,  -14.84,    0.00 /
      DATA B(89647), B(89648), B(89649) /    -9.32,  -14.89,    0.00 /
      DATA B(67834), B(67835), B(67836) /    -8.46,  -11.96,    0.00 /
      DATA B(68137), B(68138), B(68139) /    -8.43,  -12.31,    0.00 /
      DATA B(68440), B(68441), B(68442) /    -8.46,  -12.59,    0.00 /
      DATA B(68743), B(68744), B(68745) /    -8.50,  -12.72,    0.00 /
      DATA B(69046), B(69047), B(69048) /    -8.52,  -12.71,    0.00 /
      DATA B(69349), B(69350), B(69351) /    -8.50,  -12.66,    0.00 /
      DATA B(69652), B(69653), B(69654) /    -8.46,  -12.60,    0.00 /
      DATA B(69955), B(69956), B(69957) /    -8.41,  -12.57,    0.00 /
      DATA B(70258), B(70259), B(70260) /    -8.37,  -12.57,    0.00 /
      DATA B(70561), B(70562), B(70563) /    -8.34,  -12.59,    0.00 /
      DATA B(70864), B(70865), B(70866) /    -8.31,  -12.62,    0.00 /
      DATA B(71167), B(71168), B(71169) /    -8.29,  -12.67,    0.00 /
      DATA B(71470), B(71471), B(71472) /    -8.27,  -12.73,    0.00 /
      DATA B(71773), B(71774), B(71775) /    -8.25,  -12.79,    0.00 /
      DATA B(72076), B(72077), B(72078) /    -8.22,  -12.86,    0.00 /
      DATA B(72379), B(72380), B(72381) /    -8.20,  -12.94,    0.00 /
      DATA B(72682), B(72683), B(72684) /    -8.16,  -13.04,    0.00 /
      DATA B(72985), B(72986), B(72987) /    -8.11,  -13.16,    0.00 /
      DATA B(73288), B(73289), B(73290) /    -8.05,  -13.34,    0.00 /
      DATA B(73591), B(73592), B(73593) /    -7.97,  -13.62,    0.00 /
      DATA B(73894), B(73895), B(73896) /    -7.93,  -14.00,    0.00 /
      DATA B(74197), B(74198), B(74199) /    -7.86,  -14.41,    0.00 /
      DATA B(74500), B(74501), B(74502) /    -8.78,  -13.06,    0.00 /
      DATA B(74803), B(74804), B(74805) /    -8.91,  -13.32,    0.00 /
      DATA B(75106), B(75107), B(75108) /    -8.96,  -13.69,    0.00 /
      DATA B(75409), B(75410), B(75411) /    -8.91,  -14.18,    0.00 /
      DATA B(75712), B(75713), B(75714) /    -8.85,  -14.55,    0.00 /
      DATA B(76015), B(76016), B(76017) /    -8.82,  -14.82,    0.00 /
      DATA B(76318), B(76319), B(76320) /    -8.80,  -15.01,    0.00 /
      DATA B(76621), B(76622), B(76623) /    -8.79,  -15.15,    0.00 /
      DATA B(76924), B(76925), B(76926) /    -8.80,  -15.27,    0.00 /
      DATA B(77227), B(77228), B(77229) /    -8.81,  -15.38,    0.00 /
      DATA B(77530), B(77531), B(77532) /    -8.82,  -15.48,    0.00 /
      DATA B(77833), B(77834), B(77835) /    -8.83,  -15.58,    0.00 /
      DATA B(78136), B(78137), B(78138) /    -8.85,  -15.67,    0.00 /
      DATA B(78439), B(78440), B(78441) /    -8.86,  -15.75,    0.00 /
      DATA B(78742), B(78743), B(78744) /    -8.87,  -15.82,    0.00 /
      DATA B(79045), B(79046), B(79047) /    -8.88,  -15.87,    0.00 /
      DATA B(79348), B(79349), B(79350) /    -8.90,  -15.92,    0.00 /
      DATA B(79651), B(79652), B(79653) /    -8.92,  -15.96,    0.00 /
      DATA B(79954), B(79955), B(79956) /    -8.94,  -15.99,    0.00 /
      DATA B(80257), B(80258), B(80259) /    -8.96,  -16.00,    0.00 /
      DATA B(80560), B(80561), B(80562) /    -9.00,  -16.01,    0.00 /
      DATA B(80863), B(80864), B(80865) /    -9.06,  -16.01,    0.00 /
      DATA B(81166), B(81167), B(81168) /    -9.14,  -16.02,    0.00 /
      DATA B(81469), B(81470), B(81471) /    -9.24,  -16.01,    0.00 /
      DATA B(81772), B(81773), B(81774) /    -9.38,  -15.75,    0.00 /
      DATA B(82075), B(82076), B(82077) /    -9.17,  -15.75,    0.00 /
      DATA B(82378), B(82379), B(82380) /    -9.19,  -15.66,    0.00 /
      DATA B(82681), B(82682), B(82683) /    -9.26,  -15.72,    0.00 /
      DATA B(82984), B(82985), B(82986) /    -9.32,  -15.83,    0.00 /
      DATA B(83287), B(83288), B(83289) /    -9.29,  -15.85,    0.00 /
      DATA B(83590), B(83591), B(83592) /    -9.06,  -15.40,    0.00 /
      DATA B(83893), B(83894), B(83895) /    -8.93,  -14.88,    0.00 /
      DATA B(84196), B(84197), B(84198) /    -8.97,  -14.59,    0.00 /
      DATA B(84499), B(84500), B(84501) /    -9.04,  -14.38,    0.00 /
      DATA B(84802), B(84803), B(84804) /    -9.11,  -14.19,    0.00 /
      DATA B(85105), B(85106), B(85107) /    -9.14,  -14.01,    0.00 /
      DATA B(85408), B(85409), B(85410) /    -9.01,  -14.00,    0.00 /
      DATA B(85711), B(85712), B(85713) /    -8.94,  -14.07,    0.00 /
      DATA B(86014), B(86015), B(86016) /    -8.90,  -14.13,    0.00 /
      DATA B(86317), B(86318), B(86319) /    -8.87,  -14.19,    0.00 /
      DATA B(86620), B(86621), B(86622) /    -8.84,  -14.26,    0.00 /
      DATA B(86923), B(86924), B(86925) /    -8.81,  -14.32,    0.00 /
      DATA B(87226), B(87227), B(87228) /    -8.34,  -13.88,    0.00 /
      DATA B(87529), B(87530), B(87531) /    -8.32,  -13.92,    0.00 /
      DATA B(87832), B(87833), B(87834) /    -8.31,  -13.97,    0.00 /
      DATA B(88135), B(88136), B(88137) /    -8.30,  -14.02,    0.00 /
      DATA B(88438), B(88439), B(88440) /    -8.30,  -14.07,    0.00 /
      DATA B(88741), B(88742), B(88743) /    -9.25,  -14.78,    0.00 /
      DATA B(89044), B(89045), B(89046) /    -9.24,  -14.83,    0.00 /
      DATA B(89347), B(89348), B(89349) /    -9.24,  -14.87,    0.00 /
      DATA B(89650), B(89651), B(89652) /    -9.24,  -14.92,    0.00 /
      DATA B(67837), B(67838), B(67839) /    -8.36,  -11.90,    0.00 /
      DATA B(68140), B(68141), B(68142) /    -8.35,  -12.15,    0.00 /
      DATA B(68443), B(68444), B(68445) /    -8.36,  -12.35,    0.00 /
      DATA B(68746), B(68747), B(68748) /    -8.39,  -12.48,    0.00 /
      DATA B(69049), B(69050), B(69051) /    -8.40,  -12.53,    0.00 /
      DATA B(69352), B(69353), B(69354) /    -8.40,  -12.53,    0.00 /
      DATA B(69655), B(69656), B(69657) /    -8.37,  -12.52,    0.00 /
      DATA B(69958), B(69959), B(69960) /    -8.34,  -12.52,    0.00 /
      DATA B(70261), B(70262), B(70263) /    -8.31,  -12.53,    0.00 /
      DATA B(70564), B(70565), B(70566) /    -8.28,  -12.56,    0.00 /
      DATA B(70867), B(70868), B(70869) /    -8.26,  -12.60,    0.00 /
      DATA B(71170), B(71171), B(71172) /    -8.24,  -12.64,    0.00 /
      DATA B(71473), B(71474), B(71475) /    -8.22,  -12.70,    0.00 /
      DATA B(71776), B(71777), B(71778) /    -8.20,  -12.76,    0.00 /
      DATA B(72079), B(72080), B(72081) /    -8.18,  -12.83,    0.00 /
      DATA B(72382), B(72383), B(72384) /    -8.16,  -12.90,    0.00 /
      DATA B(72685), B(72686), B(72687) /    -8.13,  -12.99,    0.00 /
      DATA B(72988), B(72989), B(72990) /    -8.10,  -13.09,    0.00 /
      DATA B(73291), B(73292), B(73293) /    -8.07,  -13.21,    0.00 /
      DATA B(73594), B(73595), B(73596) /    -8.03,  -13.37,    0.00 /
      DATA B(73897), B(73898), B(73899) /    -8.01,  -13.56,    0.00 /
      DATA B(74200), B(74201), B(74202) /    -7.98,  -13.77,    0.00 /
      DATA B(74503), B(74504), B(74505) /    -7.94,  -14.03,    0.00 /
      DATA B(74806), B(74807), B(74808) /    -7.87,  -14.37,    0.00 /
      DATA B(75109), B(75110), B(75111) /    -8.69,  -13.30,    0.00 /
      DATA B(75412), B(75413), B(75414) /    -8.80,  -13.58,    0.00 /
      DATA B(75715), B(75716), B(75717) /    -8.87,  -13.89,    0.00 /
      DATA B(76018), B(76019), B(76020) /    -8.82,  -14.34,    0.00 /
      DATA B(76321), B(76322), B(76323) /    -8.76,  -14.68,    0.00 /
      DATA B(76624), B(76625), B(76626) /    -8.72,  -14.89,    0.00 /
      DATA B(76927), B(76928), B(76929) /    -8.72,  -15.05,    0.00 /
      DATA B(77230), B(77231), B(77232) /    -8.73,  -15.20,    0.00 /
      DATA B(77533), B(77534), B(77535) /    -8.74,  -15.32,    0.00 /
      DATA B(77836), B(77837), B(77838) /    -8.75,  -15.44,    0.00 /
      DATA B(78139), B(78140), B(78141) /    -8.76,  -15.55,    0.00 /
      DATA B(78442), B(78443), B(78444) /    -8.76,  -15.64,    0.00 /
      DATA B(78745), B(78746), B(78747) /    -8.77,  -15.71,    0.00 /
      DATA B(79048), B(79049), B(79050) /    -8.77,  -15.77,    0.00 /
      DATA B(79351), B(79352), B(79353) /    -8.78,  -15.80,    0.00 /
      DATA B(79654), B(79655), B(79656) /    -8.80,  -15.83,    0.00 /
      DATA B(79957), B(79958), B(79959) /    -8.81,  -15.83,    0.00 /
      DATA B(80260), B(80261), B(80262) /    -8.83,  -15.82,    0.00 /
      DATA B(80563), B(80564), B(80565) /    -8.86,  -15.79,    0.00 /
      DATA B(80866), B(80867), B(80868) /    -8.92,  -15.74,    0.00 /
      DATA B(81169), B(81170), B(81171) /    -9.05,  -15.76,    0.00 /
      DATA B(81472), B(81473), B(81474) /    -9.16,  -15.90,    0.00 /
      DATA B(81775), B(81776), B(81777) /    -9.22,  -15.93,    0.00 /
      DATA B(82078), B(82079), B(82080) /    -9.21,  -15.81,    0.00 /
      DATA B(82381), B(82382), B(82383) /    -9.13,  -15.70,    0.00 /
      DATA B(82684), B(82685), B(82686) /    -9.25,  -15.64,    0.00 /
      DATA B(82987), B(82988), B(82989) /    -9.37,  -15.75,    0.00 /
      DATA B(83290), B(83291), B(83292) /    -9.37,  -15.87,    0.00 /
      DATA B(83593), B(83594), B(83595) /    -9.18,  -15.64,    0.00 /
      DATA B(83896), B(83897), B(83898) /    -8.92,  -14.96,    0.00 /
      DATA B(84199), B(84200), B(84201) /    -8.89,  -14.58,    0.00 /
      DATA B(84502), B(84503), B(84504) /    -8.94,  -14.34,    0.00 /
      DATA B(84805), B(84806), B(84807) /    -9.01,  -14.15,    0.00 /
      DATA B(85108), B(85109), B(85110) /    -9.04,  -14.01,    0.00 /
      DATA B(85411), B(85412), B(85413) /    -9.01,  -14.03,    0.00 /
      DATA B(85714), B(85715), B(85716) /    -8.92,  -14.11,    0.00 /
      DATA B(86017), B(86018), B(86019) /    -8.87,  -14.18,    0.00 /
      DATA B(86320), B(86321), B(86322) /    -8.84,  -14.24,    0.00 /
      DATA B(86623), B(86624), B(86625) /    -8.81,  -14.31,    0.00 /
      DATA B(86926), B(86927), B(86928) /    -8.78,  -14.36,    0.00 /
      DATA B(87229), B(87230), B(87231) /    -8.26,  -13.91,    0.00 /
      DATA B(87532), B(87533), B(87534) /    -8.24,  -13.95,    0.00 /
      DATA B(87835), B(87836), B(87837) /    -8.23,  -14.00,    0.00 /
      DATA B(88138), B(88139), B(88140) /    -8.23,  -14.05,    0.00 /
      DATA B(88441), B(88442), B(88443) /    -9.18,  -14.77,    0.00 /
      DATA B(88744), B(88745), B(88746) /    -9.17,  -14.81,    0.00 /
      DATA B(89047), B(89048), B(89049) /    -9.17,  -14.86,    0.00 /
      DATA B(89350), B(89351), B(89352) /    -9.16,  -14.91,    0.00 /
      DATA B(89653), B(89654), B(89655) /    -9.16,  -14.96,    0.00 /
      DATA B(67840), B(67841), B(67842) /    -8.27,  -11.85,    0.00 /
      DATA B(68143), B(68144), B(68145) /    -8.26,  -12.04,    0.00 /
      DATA B(68446), B(68447), B(68448) /    -8.27,  -12.21,    0.00 /
      DATA B(68749), B(68750), B(68751) /    -8.29,  -12.32,    0.00 /
      DATA B(69052), B(69053), B(69054) /    -8.30,  -12.39,    0.00 /
      DATA B(69355), B(69356), B(69357) /    -8.30,  -12.43,    0.00 /
      DATA B(69658), B(69659), B(69660) /    -8.28,  -12.45,    0.00 /
      DATA B(69961), B(69962), B(69963) /    -8.26,  -12.47,    0.00 /
      DATA B(70264), B(70265), B(70266) /    -8.24,  -12.50,    0.00 /
      DATA B(70567), B(70568), B(70569) /    -8.22,  -12.53,    0.00 /
      DATA B(70870), B(70871), B(70872) /    -8.20,  -12.57,    0.00 /
      DATA B(71173), B(71174), B(71175) /    -8.18,  -12.62,    0.00 /
      DATA B(71476), B(71477), B(71478) /    -8.16,  -12.68,    0.00 /
      DATA B(71779), B(71780), B(71781) /    -8.14,  -12.74,    0.00 /
      DATA B(72082), B(72083), B(72084) /    -8.12,  -12.80,    0.00 /
      DATA B(72385), B(72386), B(72387) /    -8.11,  -12.87,    0.00 /
      DATA B(72688), B(72689), B(72690) /    -8.09,  -12.95,    0.00 /
      DATA B(72991), B(72992), B(72993) /    -8.07,  -13.03,    0.00 /
      DATA B(73294), B(73295), B(73296) /    -8.05,  -13.13,    0.00 /
      DATA B(73597), B(73598), B(73599) /    -8.03,  -13.24,    0.00 /
      DATA B(73900), B(73901), B(73902) /    -8.02,  -13.36,    0.00 /
      DATA B(74203), B(74204), B(74205) /    -8.00,  -13.50,    0.00 /
      DATA B(74506), B(74507), B(74508) /    -7.99,  -13.64,    0.00 /
      DATA B(74809), B(74810), B(74811) /    -7.96,  -13.82,    0.00 /
      DATA B(75112), B(75113), B(75114) /    -7.92,  -14.04,    0.00 /
      DATA B(75415), B(75416), B(75417) /    -7.85,  -14.33,    0.00 /
      DATA B(75718), B(75719), B(75720) /    -8.60,  -13.54,    0.00 /
      DATA B(76021), B(76022), B(76023) /    -8.68,  -13.83,    0.00 /
      DATA B(76324), B(76325), B(76326) /    -8.74,  -14.07,    0.00 /
      DATA B(76627), B(76628), B(76629) /    -8.69,  -14.35,    0.00 /
      DATA B(76930), B(76931), B(76932) /    -8.67,  -14.61,    0.00 /
      DATA B(77233), B(77234), B(77235) /    -8.67,  -14.83,    0.00 /
      DATA B(77536), B(77537), B(77538) /    -8.67,  -15.03,    0.00 /
      DATA B(77839), B(77840), B(77841) /    -8.67,  -15.20,    0.00 /
      DATA B(78142), B(78143), B(78144) /    -8.67,  -15.35,    0.00 /
      DATA B(78445), B(78446), B(78447) /    -8.67,  -15.47,    0.00 /
      DATA B(78748), B(78749), B(78750) /    -8.67,  -15.56,    0.00 /
      DATA B(79051), B(79052), B(79053) /    -8.66,  -15.60,    0.00 /
      DATA B(79354), B(79355), B(79356) /    -8.66,  -15.61,    0.00 /
      DATA B(79657), B(79658), B(79659) /    -8.67,  -15.60,    0.00 /
      DATA B(79960), B(79961), B(79962) /    -8.67,  -15.55,    0.00 /
      DATA B(80263), B(80264), B(80265) /    -8.68,  -15.47,    0.00 /
      DATA B(80566), B(80567), B(80568) /    -8.69,  -15.34,    0.00 /
      DATA B(80869), B(80870), B(80871) /    -8.73,  -15.18,    0.00 /
      DATA B(81172), B(81173), B(81174) /    -8.95,  -15.10,    0.00 /
      DATA B(81475), B(81476), B(81477) /    -9.10,  -15.63,    0.00 /
      DATA B(81778), B(81779), B(81780) /    -9.08,  -15.89,    0.00 /
      DATA B(82081), B(82082), B(82083) /    -9.13,  -15.89,    0.00 /
      DATA B(82384), B(82385), B(82386) /    -9.12,  -15.74,    0.00 /
      DATA B(82687), B(82688), B(82689) /    -9.20,  -15.47,    0.00 /
      DATA B(82990), B(82991), B(82992) /    -9.40,  -15.60,    0.00 /
      DATA B(83293), B(83294), B(83295) /    -9.44,  -15.86,    0.00 /
      DATA B(83596), B(83597), B(83598) /    -9.31,  -15.82,    0.00 /
      DATA B(83899), B(83900), B(83901) /    -8.97,  -15.16,    0.00 /
      DATA B(84202), B(84203), B(84204) /    -8.83,  -14.61,    0.00 /
      DATA B(84505), B(84506), B(84507) /    -8.85,  -14.32,    0.00 /
      DATA B(84808), B(84809), B(84810) /    -8.91,  -14.11,    0.00 /
      DATA B(85111), B(85112), B(85113) /    -8.95,  -13.96,    0.00 /
      DATA B(85414), B(85415), B(85416) /    -9.00,  -14.03,    0.00 /
      DATA B(85717), B(85718), B(85719) /    -8.90,  -14.15,    0.00 /
      DATA B(86020), B(86021), B(86022) /    -8.85,  -14.22,    0.00 /
      DATA B(86323), B(86324), B(86325) /    -8.81,  -14.29,    0.00 /
      DATA B(86626), B(86627), B(86628) /    -8.78,  -14.36,    0.00 /
      DATA B(86929), B(86930), B(86931) /    -8.75,  -14.41,    0.00 /
      DATA B(87232), B(87233), B(87234) /    -8.18,  -13.94,    0.00 /
      DATA B(87535), B(87536), B(87537) /    -8.17,  -13.98,    0.00 /
      DATA B(87838), B(87839), B(87840) /    -9.11,  -14.71,    0.00 /
      DATA B(88141), B(88142), B(88143) /    -9.10,  -14.75,    0.00 /
      DATA B(88444), B(88445), B(88446) /    -9.10,  -14.80,    0.00 /
      DATA B(88747), B(88748), B(88749) /    -9.09,  -14.85,    0.00 /
      DATA B(89050), B(89051), B(89052) /    -9.09,  -14.90,    0.00 /
      DATA B(89353), B(89354), B(89355) /    -9.08,  -14.94,    0.00 /
      DATA B(89656), B(89657), B(89658) /    -9.08,  -14.99,    0.00 /
      DATA B(67843), B(67844), B(67845) /    -8.18,  -11.81,    0.00 /
      DATA B(68146), B(68147), B(68148) /    -8.18,  -11.97,    0.00 /
      DATA B(68449), B(68450), B(68451) /    -8.18,  -12.11,    0.00 /
      DATA B(68752), B(68753), B(68754) /    -8.19,  -12.22,    0.00 /
      DATA B(69055), B(69056), B(69057) /    -8.20,  -12.30,    0.00 /
      DATA B(69358), B(69359), B(69360) /    -8.20,  -12.35,    0.00 /
      DATA B(69661), B(69662), B(69663) /    -8.19,  -12.39,    0.00 /
      DATA B(69964), B(69965), B(69966) /    -8.18,  -12.43,    0.00 /
      DATA B(70267), B(70268), B(70269) /    -8.16,  -12.47,    0.00 /
      DATA B(70570), B(70571), B(70572) /    -8.14,  -12.51,    0.00 /
      DATA B(70873), B(70874), B(70875) /    -8.13,  -12.55,    0.00 /
      DATA B(71176), B(71177), B(71178) /    -8.11,  -12.60,    0.00 /
      DATA B(71479), B(71480), B(71481) /    -8.09,  -12.66,    0.00 /
      DATA B(71782), B(71783), B(71784) /    -8.08,  -12.72,    0.00 /
      DATA B(72085), B(72086), B(72087) /    -8.07,  -12.78,    0.00 /
      DATA B(72388), B(72389), B(72390) /    -8.05,  -12.85,    0.00 /
      DATA B(72691), B(72692), B(72693) /    -8.04,  -12.92,    0.00 /
      DATA B(72994), B(72995), B(72996) /    -8.02,  -12.99,    0.00 /
      DATA B(73297), B(73298), B(73299) /    -8.01,  -13.08,    0.00 /
      DATA B(73600), B(73601), B(73602) /    -8.00,  -13.16,    0.00 /
      DATA B(73903), B(73904), B(73905) /    -7.99,  -13.26,    0.00 /
      DATA B(74206), B(74207), B(74208) /    -7.98,  -13.35,    0.00 /
      DATA B(74509), B(74510), B(74511) /    -7.97,  -13.46,    0.00 /
      DATA B(74812), B(74813), B(74814) /    -7.96,  -13.57,    0.00 /
      DATA B(75115), B(75116), B(75117) /    -7.94,  -13.70,    0.00 /
      DATA B(75418), B(75419), B(75420) /    -7.92,  -13.86,    0.00 /
      DATA B(75721), B(75722), B(75723) /    -7.88,  -14.06,    0.00 /
      DATA B(76024), B(76025), B(76026) /    -7.83,  -14.31,    0.00 /
      DATA B(76327), B(76328), B(76329) /    -8.52,  -13.84,    0.00 /
      DATA B(76630), B(76631), B(76632) /    -8.55,  -14.00,    0.00 /
      DATA B(76933), B(76934), B(76935) /    -8.58,  -14.12,    0.00 /
      DATA B(77236), B(77237), B(77238) /    -8.61,  -14.24,    0.00 /
      DATA B(77539), B(77540), B(77541) /    -8.62,  -14.45,    0.00 /
      DATA B(77842), B(77843), B(77844) /    -8.62,  -14.70,    0.00 /
      DATA B(78145), B(78146), B(78147) /    -8.61,  -14.94,    0.00 /
      DATA B(78448), B(78449), B(78450) /    -8.60,  -15.14,    0.00 /
      DATA B(78751), B(78752), B(78753) /    -8.56,  -15.27,    0.00 /
      DATA B(79054), B(79055), B(79056) /    -8.53,  -15.28,    0.00 /
      DATA B(79357), B(79358), B(79359) /    -8.52,  -15.22,    0.00 /
      DATA B(79660), B(79661), B(79662) /    -8.52,  -15.13,    0.00 /
      DATA B(79963), B(79964), B(79965) /    -8.51,  -15.00,    0.00 /
      DATA B(80266), B(80267), B(80268) /    -8.50,  -14.84,    0.00 /
      DATA B(80569), B(80570), B(80571) /    -8.54,  -14.77,    0.00 /
      DATA B(80872), B(80873), B(80874) /    -8.59,  -14.76,    0.00 /
      DATA B(81175), B(81176), B(81177) /    -8.60,  -14.43,    0.00 /
      DATA B(81478), B(81479), B(81480) /    -8.90,  -15.14,    0.00 /
      DATA B(81781), B(81782), B(81783) /    -8.94,  -15.68,    0.00 /
      DATA B(82084), B(82085), B(82086) /    -8.92,  -15.82,    0.00 /
      DATA B(82387), B(82388), B(82389) /    -9.05,  -15.67,    0.00 /
      DATA B(82690), B(82691), B(82692) /    -9.03,  -15.02,    0.00 /
      DATA B(82993), B(82994), B(82995) /    -9.41,  -15.27,    0.00 /
      DATA B(83296), B(83297), B(83298) /    -9.47,  -15.83,    0.00 /
      DATA B(83599), B(83600), B(83601) /    -9.42,  -15.94,    0.00 /
      DATA B(83902), B(83903), B(83904) /    -9.12,  -15.49,    0.00 /
      DATA B(84205), B(84206), B(84207) /    -8.82,  -14.71,    0.00 /
      DATA B(84508), B(84509), B(84510) /    -8.78,  -14.34,    0.00 /
      DATA B(84811), B(84812), B(84813) /    -8.80,  -14.09,    0.00 /
      DATA B(85114), B(85115), B(85116) /    -8.86,  -13.90,    0.00 /
      DATA B(85417), B(85418), B(85419) /    -8.95,  -14.01,    0.00 /
      DATA B(85720), B(85721), B(85722) /    -8.87,  -14.18,    0.00 /
      DATA B(86023), B(86024), B(86025) /    -8.82,  -14.27,    0.00 /
      DATA B(86326), B(86327), B(86328) /    -8.78,  -14.34,    0.00 /
      DATA B(86629), B(86630), B(86631) /    -8.75,  -14.41,    0.00 /
      DATA B(86932), B(86933), B(86934) /    -8.13,  -13.93,    0.00 /
      DATA B(87235), B(87236), B(87237) /    -8.11,  -13.97,    0.00 /
      DATA B(87538), B(87539), B(87540) /    -9.04,  -14.69,    0.00 /
      DATA B(87841), B(87842), B(87843) /    -9.03,  -14.74,    0.00 /
      DATA B(88144), B(88145), B(88146) /    -9.02,  -14.79,    0.00 /
      DATA B(88447), B(88448), B(88449) /    -9.02,  -14.83,    0.00 /
      DATA B(88750), B(88751), B(88752) /    -9.01,  -14.88,    0.00 /
      DATA B(89053), B(89054), B(89055) /    -9.01,  -14.93,    0.00 /
      DATA B(89356), B(89357), B(89358) /    -9.00,  -14.98,    0.00 /
      DATA B(89659), B(89660), B(89661) /    -9.00,  -15.03,    0.00 /
      DATA B(67846), B(67847), B(67848) /    -8.09,  -11.78,    0.00 /
      DATA B(68149), B(68150), B(68151) /    -8.09,  -11.91,    0.00 /
      DATA B(68452), B(68453), B(68454) /    -8.09,  -12.04,    0.00 /
      DATA B(68755), B(68756), B(68757) /    -8.10,  -12.14,    0.00 /
      DATA B(69058), B(69059), B(69060) /    -8.11,  -12.23,    0.00 /
      DATA B(69361), B(69362), B(69363) /    -8.11,  -12.29,    0.00 /
      DATA B(69664), B(69665), B(69666) /    -8.10,  -12.34,    0.00 /
      DATA B(69967), B(69968), B(69969) /    -8.09,  -12.39,    0.00 /
      DATA B(70270), B(70271), B(70272) /    -8.08,  -12.44,    0.00 /
      DATA B(70573), B(70574), B(70575) /    -8.07,  -12.49,    0.00 /
      DATA B(70876), B(70877), B(70878) /    -8.05,  -12.54,    0.00 /
      DATA B(71179), B(71180), B(71181) /    -8.04,  -12.59,    0.00 /
      DATA B(71482), B(71483), B(71484) /    -8.03,  -12.65,    0.00 /
      DATA B(71785), B(71786), B(71787) /    -8.01,  -12.70,    0.00 /
      DATA B(72088), B(72089), B(72090) /    -8.00,  -12.77,    0.00 /
      DATA B(72391), B(72392), B(72393) /    -7.99,  -12.83,    0.00 /
      DATA B(72694), B(72695), B(72696) /    -7.98,  -12.90,    0.00 /
      DATA B(72997), B(72998), B(72999) /    -7.97,  -12.97,    0.00 /
      DATA B(73300), B(73301), B(73302) /    -7.96,  -13.04,    0.00 /
      DATA B(73603), B(73604), B(73605) /    -7.95,  -13.11,    0.00 /
      DATA B(73906), B(73907), B(73908) /    -7.95,  -13.19,    0.00 /
      DATA B(74209), B(74210), B(74211) /    -7.94,  -13.27,    0.00 /
      DATA B(74512), B(74513), B(74514) /    -7.94,  -13.36,    0.00 /
      DATA B(74815), B(74816), B(74817) /    -7.93,  -13.44,    0.00 /
      DATA B(75118), B(75119), B(75120) /    -7.92,  -13.54,    0.00 /
      DATA B(75421), B(75422), B(75423) /    -7.91,  -13.64,    0.00 /
      DATA B(75724), B(75725), B(75726) /    -7.90,  -13.76,    0.00 /
      DATA B(76027), B(76028), B(76029) /    -7.88,  -13.90,    0.00 /
      DATA B(76330), B(76331), B(76332) /    -7.87,  -14.06,    0.00 /
      DATA B(76633), B(76634), B(76635) /    -8.53,  -13.71,    0.00 /
      DATA B(76936), B(76937), B(76938) /    -8.50,  -13.87,    0.00 /
      DATA B(77239), B(77240), B(77241) /    -8.45,  -14.03,    0.00 /
      DATA B(77542), B(77543), B(77544) /    -8.43,  -14.19,    0.00 /
      DATA B(77845), B(77846), B(77847) /    -8.43,  -14.39,    0.00 /
      DATA B(78148), B(78149), B(78150) /    -8.47,  -14.51,    0.00 /
      DATA B(78451), B(78452), B(78453) /    -8.50,  -14.62,    0.00 /
      DATA B(78754), B(78755), B(78756) /    -8.46,  -14.77,    0.00 /
      DATA B(79057), B(79058), B(79059) /    -8.41,  -14.74,    0.00 /
      DATA B(79360), B(79361), B(79362) /    -8.44,  -14.73,    0.00 /
      DATA B(79663), B(79664), B(79665) /    -8.47,  -14.75,    0.00 /
      DATA B(79966), B(79967), B(79968) /    -8.49,  -14.73,    0.00 /
      DATA B(80269), B(80270), B(80271) /    -8.49,  -14.57,    0.00 /
      DATA B(80572), B(80573), B(80574) /    -8.46,  -14.49,    0.00 /
      DATA B(80875), B(80876), B(80877) /    -8.40,  -14.39,    0.00 /
      DATA B(81178), B(81179), B(81180) /    -8.28,  -14.42,    0.00 /
      DATA B(81481), B(81482), B(81483) /    -8.21,  -14.69,    0.00 /
      DATA B(81784), B(81785), B(81786) /    -8.63,  -15.24,    0.00 /
      DATA B(82087), B(82088), B(82089) /    -8.62,  -15.50,    0.00 /
      DATA B(82390), B(82391), B(82392) /    -8.62,  -15.34,    0.00 /
      DATA B(82693), B(82694), B(82695) /    -8.79,  -15.42,    0.00 /
      DATA B(82996), B(82997), B(82998) /    -9.17,  -14.52,    0.00 /
      DATA B(83299), B(83300), B(83301) /    -9.41,  -15.77,    0.00 /
      DATA B(83602), B(83603), B(83604) /    -9.48,  -16.02,    0.00 /
      DATA B(83905), B(83906), B(83907) /    -9.30,  -15.82,    0.00 /
      DATA B(84208), B(84209), B(84210) /    -8.91,  -14.96,    0.00 /
      DATA B(84511), B(84512), B(84513) /    -8.74,  -14.47,    0.00 /
      DATA B(84814), B(84815), B(84816) /    -8.69,  -14.13,    0.00 /
      DATA B(85117), B(85118), B(85119) /    -8.75,  -13.85,    0.00 /
      DATA B(85420), B(85421), B(85422) /    -8.87,  -13.95,    0.00 /
      DATA B(85723), B(85724), B(85725) /    -8.84,  -14.21,    0.00 /
      DATA B(86026), B(86027), B(86028) /    -8.79,  -14.31,    0.00 /
      DATA B(86329), B(86330), B(86331) /    -8.75,  -14.39,    0.00 /
      DATA B(86632), B(86633), B(86634) /    -8.71,  -14.45,    0.00 /
      DATA B(86935), B(86936), B(86937) /    -8.05,  -13.95,    0.00 /
      DATA B(87238), B(87239), B(87240) /    -8.03,  -13.99,    0.00 /
      DATA B(87541), B(87542), B(87543) /    -8.96,  -14.72,    0.00 /
      DATA B(87844), B(87845), B(87846) /    -8.95,  -14.77,    0.00 /
      DATA B(88147), B(88148), B(88149) /    -8.95,  -14.82,    0.00 /
      DATA B(88450), B(88451), B(88452) /    -8.94,  -14.87,    0.00 /
      DATA B(88753), B(88754), B(88755) /    -8.93,  -14.91,    0.00 /
      DATA B(89056), B(89057), B(89058) /    -8.93,  -14.96,    0.00 /
      DATA B(89359), B(89360), B(89361) /    -8.93,  -15.01,    0.00 /
      DATA B(89662), B(89663), B(89664) /    -8.92,  -15.06,    0.00 /
      DATA B(67849), B(67850), B(67851) /    -8.01,  -11.75,    0.00 /
      DATA B(68152), B(68153), B(68154) /    -8.00,  -11.87,    0.00 /
      DATA B(68455), B(68456), B(68457) /    -8.01,  -11.99,    0.00 /
      DATA B(68758), B(68759), B(68760) /    -8.01,  -12.09,    0.00 /
      DATA B(69061), B(69062), B(69063) /    -8.01,  -12.17,    0.00 /
      DATA B(69364), B(69365), B(69366) /    -8.02,  -12.24,    0.00 /
      DATA B(69667), B(69668), B(69669) /    -8.01,  -12.31,    0.00 /
      DATA B(69970), B(69971), B(69972) /    -8.01,  -12.36,    0.00 /
      DATA B(70273), B(70274), B(70275) /    -8.00,  -12.41,    0.00 /
      DATA B(70576), B(70577), B(70578) /    -7.99,  -12.47,    0.00 /
      DATA B(70879), B(70880), B(70881) /    -7.98,  -12.52,    0.00 /
      DATA B(71182), B(71183), B(71184) /    -7.97,  -12.58,    0.00 /
      DATA B(71485), B(71486), B(71487) /    -7.95,  -12.63,    0.00 /
      DATA B(71788), B(71789), B(71790) /    -7.94,  -12.69,    0.00 /
      DATA B(72091), B(72092), B(72093) /    -7.93,  -12.75,    0.00 /
      DATA B(72394), B(72395), B(72396) /    -7.93,  -12.82,    0.00 /
      DATA B(72697), B(72698), B(72699) /    -7.92,  -12.88,    0.00 /
      DATA B(73000), B(73001), B(73002) /    -7.91,  -12.95,    0.00 /
      DATA B(73303), B(73304), B(73305) /    -7.90,  -13.01,    0.00 /
      DATA B(73606), B(73607), B(73608) /    -7.90,  -13.08,    0.00 /
      DATA B(73909), B(73910), B(73911) /    -7.89,  -13.15,    0.00 /
      DATA B(74212), B(74213), B(74214) /    -7.89,  -13.23,    0.00 /
      DATA B(74515), B(74516), B(74517) /    -7.88,  -13.30,    0.00 /
      DATA B(74818), B(74819), B(74820) /    -7.88,  -13.37,    0.00 /
      DATA B(75121), B(75122), B(75123) /    -7.88,  -13.45,    0.00 /
      DATA B(75424), B(75425), B(75426) /    -7.87,  -13.53,    0.00 /
      DATA B(75727), B(75728), B(75729) /    -7.87,  -13.62,    0.00 /
      DATA B(76030), B(76031), B(76032) /    -7.86,  -13.71,    0.00 /
      DATA B(76333), B(76334), B(76335) /    -7.86,  -13.81,    0.00 /
      DATA B(76636), B(76637), B(76638) /    -8.52,  -13.70,    0.00 /
      DATA B(76939), B(76940), B(76941) /    -8.49,  -13.79,    0.00 /
      DATA B(77242), B(77243), B(77244) /    -8.45,  -13.89,    0.00 /
      DATA B(77545), B(77546), B(77547) /    -8.42,  -14.00,    0.00 /
      DATA B(77848), B(77849), B(77850) /    -8.38,  -14.12,    0.00 /
      DATA B(78151), B(78152), B(78153) /    -8.34,  -14.26,    0.00 /
      DATA B(78454), B(78455), B(78456) /    -8.31,  -14.39,    0.00 /
      DATA B(78757), B(78758), B(78759) /    -8.36,  -14.68,    0.00 /
      DATA B(79060), B(79061), B(79062) /    -8.43,  -17.18,    0.00 /
      DATA B(79363), B(79364), B(79365) /    -8.40,  -14.50,    0.00 /
      DATA B(79666), B(79667), B(79668) /    -8.38,  -14.46,    0.00 /
      DATA B(79969), B(79970), B(79971) /    -8.35,  -14.41,    0.00 /
      DATA B(80272), B(80273), B(80274) /    -8.32,  -14.38,    0.00 /
      DATA B(80575), B(80576), B(80577) /    -8.28,  -14.34,    0.00 /
      DATA B(80878), B(80879), B(80880) /    -8.23,  -14.33,    0.00 /
      DATA B(81181), B(81182), B(81183) /    -8.15,  -14.37,    0.00 /
      DATA B(81484), B(81485), B(81486) /    -8.05,  -14.51,    0.00 /
      DATA B(81787), B(81788), B(81789) /    -8.00,  -14.86,    0.00 /
      DATA B(82090), B(82091), B(82092) /    -8.19,  -15.20,    0.00 /
      DATA B(82393), B(82394), B(82395) /    -8.27,  -15.18,    0.00 /
      DATA B(82696), B(82697), B(82698) /    -8.36,  -15.14,    0.00 /
      DATA B(82999), B(83000), B(83001) /    -8.70,  -15.42,    0.00 /
      DATA B(83302), B(83303), B(83304) /    -9.24,  -15.55,    0.00 /
      DATA B(83605), B(83606), B(83607) /    -9.49,  -16.06,    0.00 /
      DATA B(83908), B(83909), B(83910) /    -9.47,  -16.07,    0.00 /
      DATA B(84211), B(84212), B(84213) /    -9.17,  -15.39,    0.00 /
      DATA B(84514), B(84515), B(84516) /    -8.82,  -14.79,    0.00 /
      DATA B(84817), B(84818), B(84819) /    -8.55,  -14.29,    0.00 /
      DATA B(85120), B(85121), B(85122) /    -8.64,  -13.81,    0.00 /
      DATA B(85423), B(85424), B(85425) /    -8.80,  -13.87,    0.00 /
      DATA B(85726), B(85727), B(85728) /    -8.81,  -14.22,    0.00 /
      DATA B(86029), B(86030), B(86031) /    -8.77,  -14.35,    0.00 /
      DATA B(86332), B(86333), B(86334) /    -8.72,  -14.43,    0.00 /
      DATA B(86635), B(86636), B(86637) /    -8.68,  -14.50,    0.00 /
      DATA B(86938), B(86939), B(86940) /    -7.98,  -13.98,    0.00 /
      DATA B(87241), B(87242), B(87243) /    -8.90,  -14.71,    0.00 /
      DATA B(87544), B(87545), B(87546) /    -8.88,  -14.75,    0.00 /
      DATA B(87847), B(87848), B(87849) /    -8.87,  -14.80,    0.00 /
      DATA B(88150), B(88151), B(88152) /    -8.87,  -14.85,    0.00 /
      DATA B(88453), B(88454), B(88455) /    -8.86,  -14.90,    0.00 /
      DATA B(88756), B(88757), B(88758) /    -8.85,  -14.95,    0.00 /
      DATA B(89059), B(89060), B(89061) /    -8.85,  -15.00,    0.00 /
      DATA B(89362), B(89363), B(89364) /    -8.85,  -15.04,    0.00 /
      DATA B(89665), B(89666), B(89667) /    -8.84,  -15.09,    0.00 /
      DATA B(67852), B(67853), B(67854) /    -7.92,  -11.73,    0.00 /
      DATA B(68155), B(68156), B(68157) /    -7.92,  -11.85,    0.00 /
      DATA B(68458), B(68459), B(68460) /    -7.92,  -11.95,    0.00 /
      DATA B(68761), B(68762), B(68763) /    -7.92,  -12.05,    0.00 /
      DATA B(69064), B(69065), B(69066) /    -7.93,  -12.13,    0.00 /
      DATA B(69367), B(69368), B(69369) /    -7.93,  -12.21,    0.00 /
      DATA B(69670), B(69671), B(69672) /    -7.93,  -12.27,    0.00 /
      DATA B(69973), B(69974), B(69975) /    -7.92,  -12.34,    0.00 /
      DATA B(70276), B(70277), B(70278) /    -7.92,  -12.39,    0.00 /
      DATA B(70579), B(70580), B(70581) /    -7.91,  -12.45,    0.00 /
      DATA B(70882), B(70883), B(70884) /    -7.90,  -12.51,    0.00 /
      DATA B(71185), B(71186), B(71187) /    -7.89,  -12.56,    0.00 /
      DATA B(71488), B(71489), B(71490) /    -7.88,  -12.62,    0.00 /
      DATA B(71791), B(71792), B(71793) /    -7.87,  -12.68,    0.00 /
      DATA B(72094), B(72095), B(72096) /    -7.86,  -12.74,    0.00 /
      DATA B(72397), B(72398), B(72399) /    -7.86,  -12.80,    0.00 /
      DATA B(72700), B(72701), B(72702) /    -7.85,  -12.87,    0.00 /
      DATA B(73003), B(73004), B(73005) /    -7.84,  -12.93,    0.00 /
      DATA B(73306), B(73307), B(73308) /    -7.84,  -13.00,    0.00 /
      DATA B(73609), B(73610), B(73611) /    -7.83,  -13.06,    0.00 /
      DATA B(73912), B(73913), B(73914) /    -7.83,  -13.13,    0.00 /
      DATA B(74215), B(74216), B(74217) /    -7.83,  -13.19,    0.00 /
      DATA B(74518), B(74519), B(74520) /    -7.82,  -13.26,    0.00 /
      DATA B(74821), B(74822), B(74823) /    -7.82,  -13.33,    0.00 /
      DATA B(75124), B(75125), B(75126) /    -7.82,  -13.40,    0.00 /
      DATA B(75427), B(75428), B(75429) /    -7.82,  -13.47,    0.00 /
      DATA B(75730), B(75731), B(75732) /    -7.81,  -13.54,    0.00 /
      DATA B(76033), B(76034), B(76035) /    -7.81,  -13.62,    0.00 /
      DATA B(76336), B(76337), B(76338) /    -7.81,  -13.69,    0.00 /
      DATA B(76639), B(76640), B(76641) /    -7.82,  -13.78,    0.00 /
      DATA B(76942), B(76943), B(76944) /    -7.82,  -13.85,    0.00 /
      DATA B(77245), B(77246), B(77247) /    -8.41,  -14.01,    0.00 /
      DATA B(77548), B(77549), B(77550) /    -8.38,  -14.08,    0.00 /
      DATA B(77851), B(77852), B(77853) /    -8.34,  -14.15,    0.00 /
      DATA B(78154), B(78155), B(78156) /    -8.31,  -14.23,    0.00 /
      DATA B(78457), B(78458), B(78459) /    -8.29,  -14.32,    0.00 /
      DATA B(78760), B(78761), B(78762) /    -8.29,  -14.38,    0.00 /
      DATA B(79063), B(79064), B(79065) /    -8.29,  -14.42,    0.00 /
      DATA B(79366), B(79367), B(79368) /    -8.28,  -14.43,    0.00 /
      DATA B(79669), B(79670), B(79671) /    -8.25,  -14.44,    0.00 /
      DATA B(79972), B(79973), B(79974) /    -8.23,  -14.44,    0.00 /
      DATA B(80275), B(80276), B(80277) /    -8.20,  -14.45,    0.00 /
      DATA B(80578), B(80579), B(80580) /    -8.16,  -14.46,    0.00 /
      DATA B(80881), B(80882), B(80883) /    -8.11,  -14.48,    0.00 /
      DATA B(81184), B(81185), B(81186) /    -8.06,  -14.52,    0.00 /
      DATA B(81487), B(81488), B(81489) /    -7.99,  -14.59,    0.00 /
      DATA B(81790), B(81791), B(81792) /    -7.94,  -14.74,    0.00 /
      DATA B(82093), B(82094), B(82095) /    -8.02,  -14.92,    0.00 /
      DATA B(82396), B(82397), B(82398) /    -8.09,  -14.90,    0.00 /
      DATA B(82699), B(82700), B(82701) /    -8.09,  -14.88,    0.00 /
      DATA B(83002), B(83003), B(83004) /    -8.17,  -14.95,    0.00 /
      DATA B(83305), B(83306), B(83307) /    -8.56,  -15.18,    0.00 /
      DATA B(83608), B(83609), B(83610) /    -9.31,  -16.06,    0.00 /
      DATA B(83911), B(83912), B(83913) /    -9.59,  -16.22,    0.00 /
      DATA B(84214), B(84215), B(84216) /    -9.60,  -15.83,    0.00 /
      DATA B(84517), B(84518), B(84519) /    -9.09,  -15.13,    0.00 /
      DATA B(84820), B(84821), B(84822) /    -8.51,  -14.46,    0.00 /
      DATA B(85123), B(85124), B(85125) /    -8.60,  -13.76,    0.00 /
      DATA B(85426), B(85427), B(85428) /    -8.75,  -13.76,    0.00 /
      DATA B(85729), B(85730), B(85731) /    -8.80,  -14.22,    0.00 /
      DATA B(86032), B(86033), B(86034) /    -8.74,  -14.38,    0.00 /
      DATA B(86335), B(86336), B(86337) /    -8.69,  -14.48,    0.00 /
      DATA B(86638), B(86639), B(86640) /    -8.65,  -14.54,    0.00 /
      DATA B(86941), B(86942), B(86943) /    -7.89,  -14.01,    0.00 /
      DATA B(87244), B(87245), B(87246) /    -8.82,  -14.74,    0.00 /
      DATA B(87547), B(87548), B(87549) /    -8.80,  -14.79,    0.00 /
      DATA B(87850), B(87851), B(87852) /    -8.79,  -14.83,    0.00 /
      DATA B(88153), B(88154), B(88155) /    -8.79,  -14.88,    0.00 /
      DATA B(88456), B(88457), B(88458) /    -8.78,  -14.93,    0.00 /
      DATA B(88759), B(88760), B(88761) /    -8.77,  -14.98,    0.00 /
      DATA B(89062), B(89063), B(89064) /    -8.77,  -15.03,    0.00 /
      DATA B(89365), B(89366), B(89367) /    -8.77,  -15.08,    0.00 /
      DATA B(89668), B(89669), B(89670) /    -8.76,  -15.13,    0.00 /
      DATA B(67855), B(67856), B(67857) /    -7.83,  -11.72,    0.00 /
      DATA B(68158), B(68159), B(68160) /    -7.83,  -11.83,    0.00 /
      DATA B(68461), B(68462), B(68463) /    -7.83,  -11.93,    0.00 /
      DATA B(68764), B(68765), B(68766) /    -7.84,  -12.02,    0.00 /
      DATA B(69067), B(69068), B(69069) /    -7.84,  -12.10,    0.00 /
      DATA B(69370), B(69371), B(69372) /    -7.84,  -12.18,    0.00 /
      DATA B(69673), B(69674), B(69675) /    -7.84,  -12.25,    0.00 /
      DATA B(69976), B(69977), B(69978) /    -7.84,  -12.31,    0.00 /
      DATA B(70279), B(70280), B(70281) /    -7.83,  -12.38,    0.00 /
      DATA B(70582), B(70583), B(70584) /    -7.82,  -12.44,    0.00 /
      DATA B(70885), B(70886), B(70887) /    -7.82,  -12.50,    0.00 /
      DATA B(71188), B(71189), B(71190) /    -7.81,  -12.56,    0.00 /
      DATA B(71491), B(71492), B(71493) /    -7.80,  -12.61,    0.00 /
      DATA B(71794), B(71795), B(71796) /    -7.80,  -12.68,    0.00 /
      DATA B(72097), B(72098), B(72099) /    -7.79,  -12.74,    0.00 /
      DATA B(72400), B(72401), B(72402) /    -7.78,  -12.80,    0.00 /
      DATA B(72703), B(72704), B(72705) /    -7.78,  -12.86,    0.00 /
      DATA B(73006), B(73007), B(73008) /    -7.77,  -12.92,    0.00 /
      DATA B(73309), B(73310), B(73311) /    -7.77,  -12.98,    0.00 /
      DATA B(73612), B(73613), B(73614) /    -7.76,  -13.05,    0.00 /
      DATA B(73915), B(73916), B(73917) /    -7.76,  -13.11,    0.00 /
      DATA B(74218), B(74219), B(74220) /    -7.76,  -13.17,    0.00 /
      DATA B(74521), B(74522), B(74523) /    -7.76,  -13.24,    0.00 /
      DATA B(74824), B(74825), B(74826) /    -7.76,  -13.30,    0.00 /
      DATA B(75127), B(75128), B(75129) /    -7.75,  -13.37,    0.00 /
      DATA B(75430), B(75431), B(75432) /    -7.75,  -13.43,    0.00 /
      DATA B(75733), B(75734), B(75735) /    -7.75,  -13.50,    0.00 /
      DATA B(76036), B(76037), B(76038) /    -7.75,  -13.56,    0.00 /
      DATA B(76339), B(76340), B(76341) /    -7.75,  -13.63,    0.00 /
      DATA B(76642), B(76643), B(76644) /    -7.76,  -13.70,    0.00 /
      DATA B(76945), B(76946), B(76947) /    -7.76,  -13.77,    0.00 /
      DATA B(77248), B(77249), B(77250) /    -7.76,  -13.84,    0.00 /
      DATA B(77551), B(77552), B(77553) /    -7.77,  -13.91,    0.00 /
      DATA B(77854), B(77855), B(77856) /    -7.77,  -13.98,    0.00 /
      DATA B(78157), B(78158), B(78159) /    -8.26,  -14.40,    0.00 /
      DATA B(78460), B(78461), B(78462) /    -8.23,  -14.46,    0.00 /
      DATA B(78763), B(78764), B(78765) /    -8.21,  -14.51,    0.00 /
      DATA B(79066), B(79067), B(79068) /    -8.20,  -14.55,    0.00 /
      DATA B(79369), B(79370), B(79371) /    -8.18,  -14.58,    0.00 /
      DATA B(79672), B(79673), B(79674) /    -8.15,  -14.61,    0.00 /
      DATA B(79975), B(79976), B(79977) /    -8.12,  -14.63,    0.00 /
      DATA B(80278), B(80279), B(80280) /    -8.09,  -14.65,    0.00 /
      DATA B(80581), B(80582), B(80583) /    -8.06,  -14.68,    0.00 /
      DATA B(80884), B(80885), B(80886) /    -8.02,  -14.71,    0.00 /
      DATA B(81187), B(81188), B(81189) /    -7.97,  -14.75,    0.00 /
      DATA B(81490), B(81491), B(81492) /    -7.93,  -14.80,    0.00 /
      DATA B(81793), B(81794), B(81795) /    -7.90,  -14.86,    0.00 /
      DATA B(82096), B(82097), B(82098) /    -7.90,  -14.93,    0.00 /
      DATA B(82399), B(82400), B(82401) /    -7.90,  -14.95,    0.00 /
      DATA B(82702), B(82703), B(82704) /    -7.88,  -14.95,    0.00 /
      DATA B(83005), B(83006), B(83007) /    -7.88,  -14.99,    0.00 /
      DATA B(83308), B(83309), B(83310) /    -7.90,  -15.09,    0.00 /
      DATA B(83611), B(83612), B(83613) /    -7.66,  -15.50,    0.00 /
      DATA B(83914), B(83915), B(83916) /    -8.33,  -13.86,    0.00 /
      DATA B(84217), B(84218), B(84219) /    -8.33,  -13.48,    0.00 /
      DATA B(84520), B(84521), B(84522) /    -7.86,  -12.76,    0.00 /
      DATA B(84823), B(84824), B(84825) /    -7.18,  -12.04,    0.00 /
      DATA B(85126), B(85127), B(85128) /    -8.68,  -13.77,    0.00 /
      DATA B(85429), B(85430), B(85431) /    -8.73,  -13.63,    0.00 /
      DATA B(85732), B(85733), B(85734) /    -8.79,  -14.21,    0.00 /
      DATA B(86035), B(86036), B(86037) /    -8.73,  -14.43,    0.00 /
      DATA B(86338), B(86339), B(86340) /    -8.66,  -14.52,    0.00 /
      DATA B(86641), B(86642), B(86643) /    -7.85,  -13.99,    0.00 /
      DATA B(86944), B(86945), B(86946) /    -8.76,  -14.72,    0.00 /
      DATA B(87247), B(87248), B(87249) /    -8.74,  -14.77,    0.00 /
      DATA B(87550), B(87551), B(87552) /    -8.72,  -14.82,    0.00 /
      DATA B(87853), B(87854), B(87855) /    -8.71,  -14.87,    0.00 /
      DATA B(88156), B(88157), B(88158) /    -8.70,  -14.91,    0.00 /
      DATA B(88459), B(88460), B(88461) /    -8.70,  -14.96,    0.00 /
      DATA B(88762), B(88763), B(88764) /    -8.69,  -15.01,    0.00 /
      DATA B(89065), B(89066), B(89067) /    -8.69,  -15.06,    0.00 /
      DATA B(89368), B(89369), B(89370) /    -8.68,  -15.11,    0.00 /
      DATA B(89671), B(89672), B(89673) /    -8.68,  -15.16,    0.00 /
      DATA B(67858), B(67859), B(67860) /    -7.75,  -11.71,    0.00 /
      DATA B(68161), B(68162), B(68163) /    -7.75,  -11.81,    0.00 /
      DATA B(68464), B(68465), B(68466) /    -7.75,  -11.91,    0.00 /
      DATA B(68767), B(68768), B(68769) /    -7.75,  -12.00,    0.00 /
      DATA B(69070), B(69071), B(69072) /    -7.75,  -12.08,    0.00 /
      DATA B(69373), B(69374), B(69375) /    -7.75,  -12.16,    0.00 /
      DATA B(69676), B(69677), B(69678) /    -7.75,  -12.23,    0.00 /
      DATA B(69979), B(69980), B(69981) /    -7.75,  -12.30,    0.00 /
      DATA B(70282), B(70283), B(70284) /    -7.75,  -12.36,    0.00 /
      DATA B(70585), B(70586), B(70587) /    -7.74,  -12.43,    0.00 /
      DATA B(70888), B(70889), B(70890) /    -7.74,  -12.49,    0.00 /
      DATA B(71191), B(71192), B(71193) /    -7.73,  -12.55,    0.00 /
      DATA B(71494), B(71495), B(71496) /    -7.73,  -12.61,    0.00 /
      DATA B(71797), B(71798), B(71799) /    -7.72,  -12.67,    0.00 /
      DATA B(72100), B(72101), B(72102) /    -7.71,  -12.73,    0.00 /
      DATA B(72403), B(72404), B(72405) /    -7.71,  -12.79,    0.00 /
      DATA B(72706), B(72707), B(72708) /    -7.70,  -12.85,    0.00 /
      DATA B(73009), B(73010), B(73011) /    -7.70,  -12.91,    0.00 /
      DATA B(73312), B(73313), B(73314) /    -7.70,  -12.98,    0.00 /
      DATA B(73615), B(73616), B(73617) /    -7.69,  -13.04,    0.00 /
      DATA B(73918), B(73919), B(73920) /    -7.69,  -13.10,    0.00 /
      DATA B(74221), B(74222), B(74223) /    -7.69,  -13.16,    0.00 /
      DATA B(74524), B(74525), B(74526) /    -7.69,  -13.22,    0.00 /
      DATA B(74827), B(74828), B(74829) /    -7.69,  -13.29,    0.00 /
      DATA B(75130), B(75131), B(75132) /    -7.69,  -13.35,    0.00 /
      DATA B(75433), B(75434), B(75435) /    -7.69,  -13.41,    0.00 /
      DATA B(75736), B(75737), B(75738) /    -7.69,  -13.47,    0.00 /
      DATA B(76039), B(76040), B(76041) /    -7.69,  -13.53,    0.00 /
      DATA B(76342), B(76343), B(76344) /    -7.69,  -13.60,    0.00 /
      DATA B(76645), B(76646), B(76647) /    -7.69,  -13.66,    0.00 /
      DATA B(76948), B(76949), B(76950) /    -7.69,  -13.72,    0.00 /
      DATA B(77251), B(77252), B(77253) /    -7.69,  -13.79,    0.00 /
      DATA B(77554), B(77555), B(77556) /    -7.70,  -13.85,    0.00 /
      DATA B(77857), B(77858), B(77859) /    -7.70,  -13.91,    0.00 /
      DATA B(78160), B(78161), B(78162) /    -7.71,  -13.97,    0.00 /
      DATA B(78463), B(78464), B(78465) /    -7.72,  -14.03,    0.00 /
      DATA B(78766), B(78767), B(78768) /    -7.73,  -14.09,    0.00 /
      DATA B(79069), B(79070), B(79071) /    -7.74,  -14.14,    0.00 /
      DATA B(79372), B(79373), B(79374) /    -7.75,  -14.19,    0.00 /
      DATA B(79675), B(79676), B(79677) /    -8.06,  -14.85,    0.00 /
      DATA B(79978), B(79979), B(79980) /    -8.03,  -14.88,    0.00 /
      DATA B(80281), B(80282), B(80283) /    -8.00,  -14.92,    0.00 /
      DATA B(80584), B(80585), B(80586) /    -7.97,  -14.95,    0.00 /
      DATA B(80887), B(80888), B(80889) /    -7.93,  -14.98,    0.00 /
      DATA B(81190), B(81191), B(81192) /    -7.89,  -15.02,    0.00 /
      DATA B(81493), B(81494), B(81495) /    -7.86,  -15.06,    0.00 /
      DATA B(81796), B(81797), B(81798) /    -7.83,  -15.10,    0.00 /
      DATA B(82099), B(82100), B(82101) /    -7.81,  -15.14,    0.00 /
      DATA B(82402), B(82403), B(82404) /    -7.79,  -15.16,    0.00 /
      DATA B(82705), B(82706), B(82707) /    -7.74,  -15.12,    0.00 /
      DATA B(83008), B(83009), B(83010) /    -7.71,  -15.14,    0.00 /
      DATA B(83311), B(83312), B(83313) /    -7.58,  -15.31,    0.00 /
      DATA B(83614), B(83615), B(83616) /    -7.51,  -15.31,    0.00 /
      DATA B(83917), B(83918), B(83919) /    -8.43,  -13.99,    0.00 /
      DATA B(84220), B(84221), B(84222) /    -8.32,  -13.72,    0.00 /
      DATA B(84523), B(84524), B(84525) /    -8.03,  -13.34,    0.00 /
      DATA B(84826), B(84827), B(84828) /    -7.45,  -12.64,    0.00 /
      DATA B(85129), B(85130), B(85131) /    -8.84,  -13.87,    0.00 /
      DATA B(85432), B(85433), B(85434) /    -8.75,  -13.47,    0.00 /
      DATA B(85735), B(85736), B(85737) /    -8.80,  -14.20,    0.00 /
      DATA B(86038), B(86039), B(86040) /    -8.70,  -14.48,    0.00 /
      DATA B(86341), B(86342), B(86343) /    -8.62,  -14.58,    0.00 /
      DATA B(86644), B(86645), B(86646) /    -8.71,  -14.71,    0.00 /
      DATA B(86947), B(86948), B(86949) /    -8.67,  -14.75,    0.00 /
      DATA B(87250), B(87251), B(87252) /    -8.65,  -14.80,    0.00 /
      DATA B(87553), B(87554), B(87555) /    -8.64,  -14.85,    0.00 /
      DATA B(87856), B(87857), B(87858) /    -8.63,  -14.90,    0.00 /
      DATA B(88159), B(88160), B(88161) /    -8.62,  -14.95,    0.00 /
      DATA B(88462), B(88463), B(88464) /    -8.62,  -14.99,    0.00 /
      DATA B(88765), B(88766), B(88767) /    -8.61,  -15.04,    0.00 /
      DATA B(89068), B(89069), B(89070) /    -8.61,  -15.09,    0.00 /
      DATA B(89371), B(89372), B(89373) /    -8.60,  -15.14,    0.00 /
      DATA B(89674), B(89675), B(89676) /    -8.60,  -15.19,    0.00 /
      DATA B(67861), B(67862), B(67863) /    -7.66,  -11.71,    0.00 /
      DATA B(68164), B(68165), B(68166) /    -7.66,  -11.80,    0.00 /
      DATA B(68467), B(68468), B(68469) /    -7.66,  -11.89,    0.00 /
      DATA B(68770), B(68771), B(68772) /    -7.66,  -11.98,    0.00 /
      DATA B(69073), B(69074), B(69075) /    -7.66,  -12.06,    0.00 /
      DATA B(69376), B(69377), B(69378) /    -7.66,  -12.14,    0.00 /
      DATA B(69679), B(69680), B(69681) /    -7.66,  -12.22,    0.00 /
      DATA B(69982), B(69983), B(69984) /    -7.66,  -12.28,    0.00 /
      DATA B(70285), B(70286), B(70287) /    -7.66,  -12.35,    0.00 /
      DATA B(70588), B(70589), B(70590) /    -7.66,  -12.42,    0.00 /
      DATA B(70891), B(70892), B(70893) /    -7.65,  -12.48,    0.00 /
      DATA B(71194), B(71195), B(71196) /    -7.65,  -12.54,    0.00 /
      DATA B(71497), B(71498), B(71499) /    -7.65,  -12.60,    0.00 /
      DATA B(71800), B(71801), B(71802) /    -7.64,  -12.67,    0.00 /
      DATA B(72103), B(72104), B(72105) /    -7.64,  -12.73,    0.00 /
      DATA B(72406), B(72407), B(72408) /    -7.63,  -12.79,    0.00 /
      DATA B(72709), B(72710), B(72711) /    -7.63,  -12.85,    0.00 /
      DATA B(73012), B(73013), B(73014) /    -7.63,  -12.91,    0.00 /
      DATA B(73315), B(73316), B(73317) /    -7.62,  -12.97,    0.00 /
      DATA B(73618), B(73619), B(73620) /    -7.62,  -13.03,    0.00 /
      DATA B(73921), B(73922), B(73923) /    -7.62,  -13.09,    0.00 /
      DATA B(74224), B(74225), B(74226) /    -7.62,  -13.16,    0.00 /
      DATA B(74527), B(74528), B(74529) /    -7.62,  -13.22,    0.00 /
      DATA B(74830), B(74831), B(74832) /    -7.61,  -13.28,    0.00 /
      DATA B(75133), B(75134), B(75135) /    -7.61,  -13.34,    0.00 /
      DATA B(75436), B(75437), B(75438) /    -7.61,  -13.40,    0.00 /
      DATA B(75739), B(75740), B(75741) /    -7.61,  -13.46,    0.00 /
      DATA B(76042), B(76043), B(76044) /    -7.61,  -13.52,    0.00 /
      DATA B(76345), B(76346), B(76347) /    -7.62,  -13.58,    0.00 /
      DATA B(76648), B(76649), B(76650) /    -7.62,  -13.64,    0.00 /
      DATA B(76951), B(76952), B(76953) /    -7.62,  -13.70,    0.00 /
      DATA B(77254), B(77255), B(77256) /    -7.62,  -13.76,    0.00 /
      DATA B(77557), B(77558), B(77559) /    -7.63,  -13.82,    0.00 /
      DATA B(77860), B(77861), B(77862) /    -7.63,  -13.88,    0.00 /
      DATA B(78163), B(78164), B(78165) /    -7.63,  -13.93,    0.00 /
      DATA B(78466), B(78467), B(78468) /    -7.64,  -13.99,    0.00 /
      DATA B(78769), B(78770), B(78771) /    -7.65,  -14.05,    0.00 /
      DATA B(79072), B(79073), B(79074) /    -7.65,  -14.10,    0.00 /
      DATA B(79375), B(79376), B(79377) /    -7.66,  -14.15,    0.00 /
      DATA B(79678), B(79679), B(79680) /    -7.67,  -14.20,    0.00 /
      DATA B(79981), B(79982), B(79983) /    -7.67,  -14.25,    0.00 /
      DATA B(80284), B(80285), B(80286) /    -7.68,  -14.30,    0.00 /
      DATA B(80587), B(80588), B(80589) /    -7.68,  -14.35,    0.00 /
      DATA B(80890), B(80891), B(80892) /    -7.68,  -14.39,    0.00 /
      DATA B(81193), B(81194), B(81195) /    -7.69,  -14.44,    0.00 /
      DATA B(81496), B(81497), B(81498) /    -7.69,  -14.49,    0.00 /
      DATA B(81799), B(81800), B(81801) /    -7.70,  -14.54,    0.00 /
      DATA B(82102), B(82103), B(82104) /    -7.72,  -14.57,    0.00 /
      DATA B(82405), B(82406), B(82407) /    -7.76,  -14.59,    0.00 /
      DATA B(82708), B(82709), B(82710) /    -7.89,  -14.52,    0.00 /
      DATA B(83011), B(83012), B(83013) /    -8.21,  -14.26,    0.00 /
      DATA B(83314), B(83315), B(83316) /    -8.42,  -14.28,    0.00 /
      DATA B(83617), B(83618), B(83619) /    -7.41,  -15.53,    0.00 /
      DATA B(83920), B(83921), B(83922) /    -8.41,  -14.09,    0.00 /
      DATA B(84223), B(84224), B(84225) /    -8.31,  -13.92,    0.00 /
      DATA B(84526), B(84527), B(84528) /    -8.11,  -13.69,    0.00 /
      DATA B(84829), B(84830), B(84831) /    -7.65,  -13.13,    0.00 /
      DATA B(85132), B(85133), B(85134) /    -9.04,  -14.01,    0.00 /
      DATA B(85435), B(85436), B(85437) /    -8.76,  -13.26,    0.00 /
      DATA B(85738), B(85739), B(85740) /    -8.77,  -14.23,    0.00 /
      DATA B(86041), B(86042), B(86043) /    -8.67,  -14.55,    0.00 /
      DATA B(86344), B(86345), B(86346) /    -8.62,  -14.66,    0.00 /
      DATA B(86647), B(86648), B(86649) /    -8.61,  -14.73,    0.00 /
      DATA B(86950), B(86951), B(86952) /    -8.58,  -14.78,    0.00 /
      DATA B(87253), B(87254), B(87255) /    -8.57,  -14.83,    0.00 /
      DATA B(87556), B(87557), B(87558) /    -8.56,  -14.88,    0.00 /
      DATA B(87859), B(87860), B(87861) /    -8.55,  -14.93,    0.00 /
      DATA B(88162), B(88163), B(88164) /    -8.54,  -14.98,    0.00 /
      DATA B(88465), B(88466), B(88467) /    -8.53,  -15.02,    0.00 /
      DATA B(88768), B(88769), B(88770) /    -8.53,  -15.07,    0.00 /
      DATA B(89071), B(89072), B(89073) /    -8.53,  -15.12,    0.00 /
      DATA B(89374), B(89375), B(89376) /    -8.52,  -15.17,    0.00 /
      DATA B(89677), B(89678), B(89679) /    -8.52,  -15.22,    0.00 /
      DATA B(67864), B(67865), B(67866) /    -7.58,  -11.71,    0.00 /
      DATA B(68167), B(68168), B(68169) /    -7.58,  -11.80,    0.00 /
      DATA B(68470), B(68471), B(68472) /    -7.58,  -11.89,    0.00 /
      DATA B(68773), B(68774), B(68775) /    -7.58,  -11.97,    0.00 /
      DATA B(69076), B(69077), B(69078) /    -7.58,  -12.05,    0.00 /
      DATA B(69379), B(69380), B(69381) /    -7.58,  -12.13,    0.00 /
      DATA B(69682), B(69683), B(69684) /    -7.58,  -12.20,    0.00 /
      DATA B(69985), B(69986), B(69987) /    -7.58,  -12.27,    0.00 /
      DATA B(70288), B(70289), B(70290) /    -7.58,  -12.34,    0.00 /
      DATA B(70591), B(70592), B(70593) /    -7.57,  -12.41,    0.00 /
      DATA B(70894), B(70895), B(70896) /    -7.57,  -12.47,    0.00 /
      DATA B(71197), B(71198), B(71199) /    -7.57,  -12.54,    0.00 /
      DATA B(71500), B(71501), B(71502) /    -7.57,  -12.60,    0.00 /
      DATA B(71803), B(71804), B(71805) /    -7.56,  -12.66,    0.00 /
      DATA B(72106), B(72107), B(72108) /    -7.56,  -12.72,    0.00 /
      DATA B(72409), B(72410), B(72411) /    -7.55,  -12.79,    0.00 /
      DATA B(72712), B(72713), B(72714) /    -7.55,  -12.85,    0.00 /
      DATA B(73015), B(73016), B(73017) /    -7.55,  -12.91,    0.00 /
      DATA B(73318), B(73319), B(73320) /    -7.55,  -12.97,    0.00 /
      DATA B(73621), B(73622), B(73623) /    -7.54,  -13.03,    0.00 /
      DATA B(73924), B(73925), B(73926) /    -7.54,  -13.09,    0.00 /
      DATA B(74227), B(74228), B(74229) /    -7.54,  -13.15,    0.00 /
      DATA B(74530), B(74531), B(74532) /    -7.54,  -13.21,    0.00 /
      DATA B(74833), B(74834), B(74835) /    -7.54,  -13.27,    0.00 /
      DATA B(75136), B(75137), B(75138) /    -7.54,  -13.33,    0.00 /
      DATA B(75439), B(75440), B(75441) /    -7.54,  -13.39,    0.00 /
      DATA B(75742), B(75743), B(75744) /    -7.54,  -13.45,    0.00 /
      DATA B(76045), B(76046), B(76047) /    -7.54,  -13.51,    0.00 /
      DATA B(76348), B(76349), B(76350) /    -7.54,  -13.57,    0.00 /
      DATA B(76651), B(76652), B(76653) /    -7.54,  -13.63,    0.00 /
      DATA B(76954), B(76955), B(76956) /    -7.55,  -13.69,    0.00 /
      DATA B(77257), B(77258), B(77259) /    -7.55,  -13.74,    0.00 /
      DATA B(77560), B(77561), B(77562) /    -7.55,  -13.80,    0.00 /
      DATA B(77863), B(77864), B(77865) /    -7.55,  -13.86,    0.00 /
      DATA B(78166), B(78167), B(78168) /    -7.56,  -13.91,    0.00 /
      DATA B(78469), B(78470), B(78471) /    -7.56,  -13.97,    0.00 /
      DATA B(78772), B(78773), B(78774) /    -7.57,  -14.03,    0.00 /
      DATA B(79075), B(79076), B(79077) /    -7.57,  -14.08,    0.00 /
      DATA B(79378), B(79379), B(79380) /    -7.58,  -14.13,    0.00 /
      DATA B(79681), B(79682), B(79683) /    -7.58,  -14.19,    0.00 /
      DATA B(79984), B(79985), B(79986) /    -7.59,  -14.24,    0.00 /
      DATA B(80287), B(80288), B(80289) /    -7.59,  -14.29,    0.00 /
      DATA B(80590), B(80591), B(80592) /    -7.60,  -14.33,    0.00 /
      DATA B(80893), B(80894), B(80895) /    -7.60,  -14.38,    0.00 /
      DATA B(81196), B(81197), B(81198) /    -7.61,  -14.43,    0.00 /
      DATA B(81499), B(81500), B(81501) /    -7.62,  -14.47,    0.00 /
      DATA B(81802), B(81803), B(81804) /    -7.63,  -14.52,    0.00 /
      DATA B(82105), B(82106), B(82107) /    -7.67,  -14.55,    0.00 /
      DATA B(82408), B(82409), B(82410) /    -7.77,  -14.53,    0.00 /
      DATA B(82711), B(82712), B(82713) /    -8.05,  -14.29,    0.00 /
      DATA B(83014), B(83015), B(83016) /    -8.24,  -14.26,    0.00 /
      DATA B(83317), B(83318), B(83319) /    -8.33,  -14.25,    0.00 /
      DATA B(83620), B(83621), B(83622) /    -8.36,  -14.23,    0.00 /
      DATA B(83923), B(83924), B(83925) /    -8.35,  -14.16,    0.00 /
      DATA B(84226), B(84227), B(84228) /    -8.30,  -14.06,    0.00 /
      DATA B(84529), B(84530), B(84531) /    -8.18,  -13.92,    0.00 /
      DATA B(84832), B(84833), B(84834) /    -7.86,  -13.56,    0.00 /
      DATA B(85135), B(85136), B(85137) /    -9.18,  -14.15,    0.00 /
      DATA B(85438), B(85439), B(85440) /    -8.64,  -12.97,    0.00 /
      DATA B(85741), B(85742), B(85743) /    -8.48,  -14.45,    0.00 /
      DATA B(86044), B(86045), B(86046) /    -8.55,  -14.62,    0.00 /
      DATA B(86347), B(86348), B(86349) /    -8.53,  -14.70,    0.00 /
      DATA B(86650), B(86651), B(86652) /    -8.51,  -14.76,    0.00 /
      DATA B(86953), B(86954), B(86955) /    -8.50,  -14.81,    0.00 /
      DATA B(87256), B(87257), B(87258) /    -8.48,  -14.86,    0.00 /
      DATA B(87559), B(87560), B(87561) /    -8.47,  -14.91,    0.00 /
      DATA B(87862), B(87863), B(87864) /    -8.46,  -14.96,    0.00 /
      DATA B(88165), B(88166), B(88167) /    -8.46,  -15.01,    0.00 /
      DATA B(88468), B(88469), B(88470) /    -8.45,  -15.06,    0.00 /
      DATA B(88771), B(88772), B(88773) /    -8.45,  -15.10,    0.00 /
      DATA B(89074), B(89075), B(89076) /    -8.44,  -15.15,    0.00 /
      DATA B(89377), B(89378), B(89379) /    -8.44,  -15.20,    0.00 /
      DATA B(89680), B(89681), B(89682) /    -8.44,  -15.25,    0.00 /
      DATA B(67867), B(67868), B(67869) /    -7.49,  -11.70,    0.00 /
      DATA B(68170), B(68171), B(68172) /    -7.49,  -11.79,    0.00 /
      DATA B(68473), B(68474), B(68475) /    -7.49,  -11.88,    0.00 /
      DATA B(68776), B(68777), B(68778) /    -7.49,  -11.96,    0.00 /
      DATA B(69079), B(69080), B(69081) /    -7.49,  -12.04,    0.00 /
      DATA B(69382), B(69383), B(69384) /    -7.49,  -12.12,    0.00 /
      DATA B(69685), B(69686), B(69687) /    -7.49,  -12.20,    0.00 /
      DATA B(69988), B(69989), B(69990) /    -7.49,  -12.27,    0.00 /
      DATA B(70291), B(70292), B(70293) /    -7.49,  -12.34,    0.00 /
      DATA B(70594), B(70595), B(70596) /    -7.49,  -12.40,    0.00 /
      DATA B(70897), B(70898), B(70899) /    -7.49,  -12.47,    0.00 /
      DATA B(71200), B(71201), B(71202) /    -7.49,  -12.53,    0.00 /
      DATA B(71503), B(71504), B(71505) /    -7.48,  -12.60,    0.00 /
      DATA B(71806), B(71807), B(71808) /    -7.48,  -12.66,    0.00 /
      DATA B(72109), B(72110), B(72111) /    -7.48,  -12.72,    0.00 /
      DATA B(72412), B(72413), B(72414) /    -7.48,  -12.79,    0.00 /
      DATA B(72715), B(72716), B(72717) /    -7.47,  -12.85,    0.00 /
      DATA B(73018), B(73019), B(73020) /    -7.47,  -12.91,    0.00 /
      DATA B(73321), B(73322), B(73323) /    -7.47,  -12.97,    0.00 /
      DATA B(73624), B(73625), B(73626) /    -7.47,  -13.03,    0.00 /
      DATA B(73927), B(73928), B(73929) /    -7.47,  -13.09,    0.00 /
      DATA B(74230), B(74231), B(74232) /    -7.47,  -13.15,    0.00 /
      DATA B(74533), B(74534), B(74535) /    -7.46,  -13.21,    0.00 /
      DATA B(74836), B(74837), B(74838) /    -7.46,  -13.27,    0.00 /
      DATA B(75139), B(75140), B(75141) /    -7.46,  -13.33,    0.00 /
      DATA B(75442), B(75443), B(75444) /    -7.46,  -13.39,    0.00 /
      DATA B(75745), B(75746), B(75747) /    -7.46,  -13.45,    0.00 /
      DATA B(76048), B(76049), B(76050) /    -7.46,  -13.51,    0.00 /
      DATA B(76351), B(76352), B(76353) /    -7.47,  -13.56,    0.00 /
      DATA B(76654), B(76655), B(76656) /    -7.47,  -13.62,    0.00 /
      DATA B(76957), B(76958), B(76959) /    -7.47,  -13.68,    0.00 /
      DATA B(77260), B(77261), B(77262) /    -7.47,  -13.74,    0.00 /
      DATA B(77563), B(77564), B(77565) /    -7.47,  -13.79,    0.00 /
      DATA B(77866), B(77867), B(77868) /    -7.48,  -13.85,    0.00 /
      DATA B(78169), B(78170), B(78171) /    -7.48,  -13.91,    0.00 /
      DATA B(78472), B(78473), B(78474) /    -7.48,  -13.96,    0.00 /
      DATA B(78775), B(78776), B(78777) /    -7.49,  -14.02,    0.00 /
      DATA B(79078), B(79079), B(79080) /    -7.49,  -14.07,    0.00 /
      DATA B(79381), B(79382), B(79383) /    -7.50,  -14.12,    0.00 /
      DATA B(79684), B(79685), B(79686) /    -7.50,  -14.18,    0.00 /
      DATA B(79987), B(79988), B(79989) /    -7.51,  -14.23,    0.00 /
      DATA B(80290), B(80291), B(80292) /    -7.51,  -14.28,    0.00 /
      DATA B(80593), B(80594), B(80595) /    -7.52,  -14.33,    0.00 /
      DATA B(80896), B(80897), B(80898) /    -7.52,  -14.38,    0.00 /
      DATA B(81199), B(81200), B(81201) /    -7.53,  -14.42,    0.00 /
      DATA B(81502), B(81503), B(81504) /    -7.55,  -14.47,    0.00 /
      DATA B(81805), B(81806), B(81807) /    -7.57,  -14.50,    0.00 /
      DATA B(82108), B(82109), B(82110) /    -7.63,  -14.52,    0.00 /
      DATA B(82411), B(82412), B(82413) /    -7.82,  -14.42,    0.00 /
      DATA B(82714), B(82715), B(82716) /    -8.06,  -14.29,    0.00 /
      DATA B(83017), B(83018), B(83019) /    -8.22,  -14.25,    0.00 /
      DATA B(83320), B(83321), B(83322) /    -8.27,  -14.25,    0.00 /
      DATA B(83623), B(83624), B(83625) /    -8.30,  -14.24,    0.00 /
      DATA B(83926), B(83927), B(83928) /    -8.30,  -14.21,    0.00 /
      DATA B(84229), B(84230), B(84231) /    -8.28,  -14.16,    0.00 /
      DATA B(84532), B(84533), B(84534) /    -8.24,  -14.08,    0.00 /
      DATA B(84835), B(84836), B(84837) /    -8.15,  -13.92,    0.00 /
      DATA B(85138), B(85139), B(85140) /    -7.41,  -12.62,    0.00 /
      DATA B(85441), B(85442), B(85443) /    -9.00,  -14.99,    0.00 /
      DATA B(85744), B(85745), B(85746) /    -8.63,  -14.69,    0.00 /
      DATA B(86047), B(86048), B(86049) /    -8.48,  -14.67,    0.00 /
      DATA B(86350), B(86351), B(86352) /    -8.44,  -14.73,    0.00 /
      DATA B(86653), B(86654), B(86655) /    -8.42,  -14.79,    0.00 /
      DATA B(86956), B(86957), B(86958) /    -8.41,  -14.84,    0.00 /
      DATA B(87259), B(87260), B(87261) /    -8.40,  -14.89,    0.00 /
      DATA B(87562), B(87563), B(87564) /    -8.39,  -14.94,    0.00 /
      DATA B(87865), B(87866), B(87867) /    -8.38,  -14.99,    0.00 /
      DATA B(88168), B(88169), B(88170) /    -8.37,  -15.04,    0.00 /
      DATA B(88471), B(88472), B(88473) /    -8.37,  -15.09,    0.00 /
      DATA B(88774), B(88775), B(88776) /    -8.37,  -15.13,    0.00 /
      DATA B(89077), B(89078), B(89079) /    -8.36,  -15.18,    0.00 /
      DATA B(89380), B(89381), B(89382) /    -8.36,  -15.23,    0.00 /
      DATA B(89683), B(89684), B(89685) /    -8.36,  -15.28,    0.00 /
      DATA B(67870), B(67871), B(67872) /    -7.41,  -11.71,    0.00 /
      DATA B(68173), B(68174), B(68175) /    -7.40,  -11.79,    0.00 /
      DATA B(68476), B(68477), B(68478) /    -7.40,  -11.88,    0.00 /
      DATA B(68779), B(68780), B(68781) /    -7.41,  -11.96,    0.00 /
      DATA B(69082), B(69083), B(69084) /    -7.41,  -12.04,    0.00 /
      DATA B(69385), B(69386), B(69387) /    -7.41,  -12.12,    0.00 /
      DATA B(69688), B(69689), B(69690) /    -7.41,  -12.19,    0.00 /
      DATA B(69991), B(69992), B(69993) /    -7.41,  -12.26,    0.00 /
      DATA B(70294), B(70295), B(70296) /    -7.41,  -12.33,    0.00 /
      DATA B(70597), B(70598), B(70599) /    -7.41,  -12.40,    0.00 /
      DATA B(70900), B(70901), B(70902) /    -7.40,  -12.47,    0.00 /
      DATA B(71203), B(71204), B(71205) /    -7.40,  -12.53,    0.00 /
      DATA B(71506), B(71507), B(71508) /    -7.40,  -12.60,    0.00 /
      DATA B(71809), B(71810), B(71811) /    -7.40,  -12.66,    0.00 /
      DATA B(72112), B(72113), B(72114) /    -7.40,  -12.72,    0.00 /
      DATA B(72415), B(72416), B(72417) /    -7.40,  -12.79,    0.00 /
      DATA B(72718), B(72719), B(72720) /    -7.39,  -12.85,    0.00 /
      DATA B(73021), B(73022), B(73023) /    -7.39,  -12.91,    0.00 /
      DATA B(73324), B(73325), B(73326) /    -7.39,  -12.97,    0.00 /
      DATA B(73627), B(73628), B(73629) /    -7.39,  -13.03,    0.00 /
      DATA B(73930), B(73931), B(73932) /    -7.39,  -13.09,    0.00 /
      DATA B(74233), B(74234), B(74235) /    -7.39,  -13.15,    0.00 /
      DATA B(74536), B(74537), B(74538) /    -7.39,  -13.21,    0.00 /
      DATA B(74839), B(74840), B(74841) /    -7.39,  -13.27,    0.00 /
      DATA B(75142), B(75143), B(75144) /    -7.39,  -13.33,    0.00 /
      DATA B(75445), B(75446), B(75447) /    -7.39,  -13.39,    0.00 /
      DATA B(75748), B(75749), B(75750) /    -7.39,  -13.45,    0.00 /
      DATA B(76051), B(76052), B(76053) /    -7.39,  -13.51,    0.00 /
      DATA B(76354), B(76355), B(76356) /    -7.39,  -13.56,    0.00 /
      DATA B(76657), B(76658), B(76659) /    -7.39,  -13.62,    0.00 /
      DATA B(76960), B(76961), B(76962) /    -7.39,  -13.68,    0.00 /
      DATA B(77263), B(77264), B(77265) /    -7.39,  -13.74,    0.00 /
      DATA B(77566), B(77567), B(77568) /    -7.39,  -13.79,    0.00 /
      DATA B(77869), B(77870), B(77871) /    -7.40,  -13.85,    0.00 /
      DATA B(78172), B(78173), B(78174) /    -7.40,  -13.90,    0.00 /
      DATA B(78475), B(78476), B(78477) /    -7.40,  -13.96,    0.00 /
      DATA B(78778), B(78779), B(78780) /    -7.41,  -14.02,    0.00 /
      DATA B(79081), B(79082), B(79083) /    -7.41,  -14.07,    0.00 /
      DATA B(79384), B(79385), B(79386) /    -7.42,  -14.12,    0.00 /
      DATA B(79687), B(79688), B(79689) /    -7.42,  -14.18,    0.00 /
      DATA B(79990), B(79991), B(79992) /    -7.42,  -14.23,    0.00 /
      DATA B(80293), B(80294), B(80295) /    -7.43,  -14.28,    0.00 /
      DATA B(80596), B(80597), B(80598) /    -7.44,  -14.33,    0.00 /
      DATA B(80899), B(80900), B(80901) /    -7.45,  -14.38,    0.00 /
      DATA B(81202), B(81203), B(81204) /    -7.46,  -14.43,    0.00 /
      DATA B(81505), B(81506), B(81507) /    -7.48,  -14.47,    0.00 /
      DATA B(81808), B(81809), B(81810) /    -7.52,  -14.50,    0.00 /
      DATA B(82111), B(82112), B(82113) /    -7.62,  -14.48,    0.00 /
      DATA B(82414), B(82415), B(82416) /    -7.90,  -14.26,    0.00 /
      DATA B(82717), B(82718), B(82719) /    -8.08,  -14.26,    0.00 /
      DATA B(83020), B(83021), B(83022) /    -8.17,  -14.25,    0.00 /
      DATA B(83323), B(83324), B(83325) /    -8.21,  -14.26,    0.00 /
      DATA B(83626), B(83627), B(83628) /    -8.23,  -14.26,    0.00 /
      DATA B(83929), B(83930), B(83931) /    -8.24,  -14.25,    0.00 /
      DATA B(84232), B(84233), B(84234) /    -8.24,  -14.23,    0.00 /
      DATA B(84535), B(84536), B(84537) /    -8.25,  -14.19,    0.00 /
      DATA B(84838), B(84839), B(84840) /    -8.30,  -14.11,    0.00 /
      DATA B(85141), B(85142), B(85143) /    -8.36,  -14.17,    0.00 /
      DATA B(85444), B(85445), B(85446) /    -8.59,  -14.84,    0.00 /
      DATA B(85747), B(85748), B(85749) /    -8.50,  -14.75,    0.00 /
      DATA B(86050), B(86051), B(86052) /    -8.40,  -14.73,    0.00 /
      DATA B(86353), B(86354), B(86355) /    -8.36,  -14.77,    0.00 /
      DATA B(86656), B(86657), B(86658) /    -8.33,  -14.82,    0.00 /
      DATA B(86959), B(86960), B(86961) /    -8.32,  -14.87,    0.00 /
      DATA B(87262), B(87263), B(87264) /    -8.31,  -14.92,    0.00 /
      DATA B(87565), B(87566), B(87567) /    -8.30,  -14.97,    0.00 /
      DATA B(87868), B(87869), B(87870) /    -8.30,  -15.02,    0.00 /
      DATA B(88171), B(88172), B(88173) /    -8.29,  -15.07,    0.00 /
      DATA B(88474), B(88475), B(88476) /    -8.29,  -15.12,    0.00 /
      DATA B(88777), B(88778), B(88779) /    -8.28,  -15.16,    0.00 /
      DATA B(89080), B(89081), B(89082) /    -8.28,  -15.21,    0.00 /
      DATA B(89383), B(89384), B(89385) /    -8.28,  -15.26,    0.00 /
      DATA B(89686), B(89687), B(89688) /    -8.27,  -15.31,    0.00 /
      DATA B(67873), B(67874), B(67875) /    -7.32,  -11.71,    0.00 /
      DATA B(68176), B(68177), B(68178) /    -7.32,  -11.79,    0.00 /
      DATA B(68479), B(68480), B(68481) /    -7.32,  -11.88,    0.00 /
      DATA B(68782), B(68783), B(68784) /    -7.32,  -11.96,    0.00 /
      DATA B(69085), B(69086), B(69087) /    -7.32,  -12.04,    0.00 /
      DATA B(69388), B(69389), B(69390) /    -7.32,  -12.11,    0.00 /
      DATA B(69691), B(69692), B(69693) /    -7.32,  -12.19,    0.00 /
      DATA B(69994), B(69995), B(69996) /    -7.32,  -12.26,    0.00 /
      DATA B(70297), B(70298), B(70299) /    -7.32,  -12.33,    0.00 /
      DATA B(70600), B(70601), B(70602) /    -7.32,  -12.40,    0.00 /
      DATA B(70903), B(70904), B(70905) /    -7.32,  -12.47,    0.00 /
      DATA B(71206), B(71207), B(71208) /    -7.32,  -12.53,    0.00 /
      DATA B(71509), B(71510), B(71511) /    -7.32,  -12.60,    0.00 /
      DATA B(71812), B(71813), B(71814) /    -7.32,  -12.66,    0.00 /
      DATA B(72115), B(72116), B(72117) /    -7.32,  -12.72,    0.00 /
      DATA B(72418), B(72419), B(72420) /    -7.31,  -12.79,    0.00 /
      DATA B(72721), B(72722), B(72723) /    -7.31,  -12.85,    0.00 /
      DATA B(73024), B(73025), B(73026) /    -7.31,  -12.91,    0.00 /
      DATA B(73327), B(73328), B(73329) /    -7.31,  -12.97,    0.00 /
      DATA B(73630), B(73631), B(73632) /    -7.31,  -13.03,    0.00 /
      DATA B(73933), B(73934), B(73935) /    -7.31,  -13.09,    0.00 /
      DATA B(74236), B(74237), B(74238) /    -7.31,  -13.16,    0.00 /
      DATA B(74539), B(74540), B(74541) /    -7.31,  -13.22,    0.00 /
      DATA B(74842), B(74843), B(74844) /    -7.31,  -13.27,    0.00 /
      DATA B(75145), B(75146), B(75147) /    -7.31,  -13.33,    0.00 /
      DATA B(75448), B(75449), B(75450) /    -7.31,  -13.39,    0.00 /
      DATA B(75751), B(75752), B(75753) /    -7.31,  -13.45,    0.00 /
      DATA B(76054), B(76055), B(76056) /    -7.31,  -13.51,    0.00 /
      DATA B(76357), B(76358), B(76359) /    -7.31,  -13.57,    0.00 /
      DATA B(76660), B(76661), B(76662) /    -7.31,  -13.62,    0.00 /
      DATA B(76963), B(76964), B(76965) /    -7.31,  -13.68,    0.00 /
      DATA B(77266), B(77267), B(77268) /    -7.31,  -13.74,    0.00 /
      DATA B(77569), B(77570), B(77571) /    -7.32,  -13.80,    0.00 /
      DATA B(77872), B(77873), B(77874) /    -7.32,  -13.85,    0.00 /
      DATA B(78175), B(78176), B(78177) /    -7.32,  -13.91,    0.00 /
      DATA B(78478), B(78479), B(78480) /    -7.32,  -13.96,    0.00 /
      DATA B(78781), B(78782), B(78783) /    -7.33,  -14.02,    0.00 /
      DATA B(79084), B(79085), B(79086) /    -7.33,  -14.07,    0.00 /
      DATA B(79387), B(79388), B(79389) /    -7.33,  -14.13,    0.00 /
      DATA B(79690), B(79691), B(79692) /    -7.34,  -14.18,    0.00 /
      DATA B(79993), B(79994), B(79995) /    -7.34,  -14.23,    0.00 /
      DATA B(80296), B(80297), B(80298) /    -7.35,  -14.29,    0.00 /
      DATA B(80599), B(80600), B(80601) /    -7.36,  -14.34,    0.00 /
      DATA B(80902), B(80903), B(80904) /    -7.37,  -14.38,    0.00 /
      DATA B(81205), B(81206), B(81207) /    -7.38,  -14.43,    0.00 /
      DATA B(81508), B(81509), B(81510) /    -7.41,  -14.47,    0.00 /
      DATA B(81811), B(81812), B(81813) /    -7.48,  -14.49,    0.00 /
      DATA B(82114), B(82115), B(82116) /    -7.66,  -14.41,    0.00 /
      DATA B(82417), B(82418), B(82419) /    -7.90,  -14.26,    0.00 /
      DATA B(82720), B(82721), B(82722) /    -8.06,  -14.25,    0.00 /
      DATA B(83023), B(83024), B(83025) /    -8.11,  -14.26,    0.00 /
      DATA B(83326), B(83327), B(83328) /    -8.14,  -14.27,    0.00 /
      DATA B(83629), B(83630), B(83631) /    -8.16,  -14.28,    0.00 /
      DATA B(83932), B(83933), B(83934) /    -8.17,  -14.29,    0.00 /
      DATA B(84235), B(84236), B(84237) /    -8.18,  -14.28,    0.00 /
      DATA B(84538), B(84539), B(84540) /    -8.20,  -14.27,    0.00 /
      DATA B(84841), B(84842), B(84843) /    -8.23,  -14.26,    0.00 /
      DATA B(85144), B(85145), B(85146) /    -8.22,  -14.39,    0.00 /
      DATA B(85447), B(85448), B(85449) /    -8.29,  -14.69,    0.00 /
      DATA B(85750), B(85751), B(85752) /    -8.32,  -14.75,    0.00 /
      DATA B(86053), B(86054), B(86055) /    -8.29,  -14.76,    0.00 /
      DATA B(86356), B(86357), B(86358) /    -8.26,  -14.80,    0.00 /
      DATA B(86659), B(86660), B(86661) /    -8.24,  -14.85,    0.00 /
      DATA B(86962), B(86963), B(86964) /    -8.23,  -14.90,    0.00 /
      DATA B(87265), B(87266), B(87267) /    -8.22,  -14.95,    0.00 /
      DATA B(87568), B(87569), B(87570) /    -8.22,  -15.00,    0.00 /
      DATA B(87871), B(87872), B(87873) /    -8.21,  -15.05,    0.00 /
      DATA B(88174), B(88175), B(88176) /    -8.21,  -15.09,    0.00 /
      DATA B(88477), B(88478), B(88479) /    -8.20,  -15.14,    0.00 /
      DATA B(88780), B(88781), B(88782) /    -8.20,  -15.19,    0.00 /
      DATA B(89083), B(89084), B(89085) /    -8.20,  -15.24,    0.00 /
      DATA B(89386), B(89387), B(89388) /    -8.19,  -15.29,    0.00 /
      DATA B(89689), B(89690), B(89691) /    -8.19,  -15.34,    0.00 /
      DATA B(67876), B(67877), B(67878) /    -7.23,  -11.71,    0.00 /
      DATA B(68179), B(68180), B(68181) /    -7.23,  -11.79,    0.00 /
      DATA B(68482), B(68483), B(68484) /    -7.23,  -11.88,    0.00 /
      DATA B(68785), B(68786), B(68787) /    -7.23,  -11.96,    0.00 /
      DATA B(69088), B(69089), B(69090) /    -7.23,  -12.03,    0.00 /
      DATA B(69391), B(69392), B(69393) /    -7.24,  -12.11,    0.00 /
      DATA B(69694), B(69695), B(69696) /    -7.24,  -12.18,    0.00 /
      DATA B(69997), B(69998), B(69999) /    -7.24,  -12.26,    0.00 /
      DATA B(70300), B(70301), B(70302) /    -7.24,  -12.33,    0.00 /
      DATA B(70603), B(70604), B(70605) /    -7.24,  -12.40,    0.00 /
      DATA B(70906), B(70907), B(70908) /    -7.24,  -12.47,    0.00 /
      DATA B(71209), B(71210), B(71211) /    -7.24,  -12.53,    0.00 /
      DATA B(71512), B(71513), B(71514) /    -7.24,  -12.60,    0.00 /
      DATA B(71815), B(71816), B(71817) /    -7.23,  -12.66,    0.00 /
      DATA B(72118), B(72119), B(72120) /    -7.23,  -12.73,    0.00 /
      DATA B(72421), B(72422), B(72423) /    -7.23,  -12.79,    0.00 /
      DATA B(72724), B(72725), B(72726) /    -7.23,  -12.85,    0.00 /
      DATA B(73027), B(73028), B(73029) /    -7.23,  -12.91,    0.00 /
      DATA B(73330), B(73331), B(73332) /    -7.23,  -12.98,    0.00 /
      DATA B(73633), B(73634), B(73635) /    -7.23,  -13.04,    0.00 /
      DATA B(73936), B(73937), B(73938) /    -7.23,  -13.10,    0.00 /
      DATA B(74239), B(74240), B(74241) /    -7.23,  -13.16,    0.00 /
      DATA B(74542), B(74543), B(74544) /    -7.23,  -13.22,    0.00 /
      DATA B(74845), B(74846), B(74847) /    -7.23,  -13.28,    0.00 /
      DATA B(75148), B(75149), B(75150) /    -7.23,  -13.34,    0.00 /
      DATA B(75451), B(75452), B(75453) /    -7.23,  -13.40,    0.00 /
      DATA B(75754), B(75755), B(75756) /    -7.23,  -13.46,    0.00 /
      DATA B(76057), B(76058), B(76059) /    -7.23,  -13.51,    0.00 /
      DATA B(76360), B(76361), B(76362) /    -7.23,  -13.57,    0.00 /
      DATA B(76663), B(76664), B(76665) /    -7.23,  -13.63,    0.00 /
      DATA B(76966), B(76967), B(76968) /    -7.23,  -13.69,    0.00 /
      DATA B(77269), B(77270), B(77271) /    -7.23,  -13.74,    0.00 /
      DATA B(77572), B(77573), B(77574) /    -7.23,  -13.80,    0.00 /
      DATA B(77875), B(77876), B(77877) /    -7.24,  -13.86,    0.00 /
      DATA B(78178), B(78179), B(78180) /    -7.24,  -13.91,    0.00 /
      DATA B(78481), B(78482), B(78483) /    -7.24,  -13.97,    0.00 /
      DATA B(78784), B(78785), B(78786) /    -7.25,  -14.02,    0.00 /
      DATA B(79087), B(79088), B(79089) /    -7.25,  -14.08,    0.00 /
      DATA B(79390), B(79391), B(79392) /    -7.25,  -14.13,    0.00 /
      DATA B(79693), B(79694), B(79695) /    -7.26,  -14.19,    0.00 /
      DATA B(79996), B(79997), B(79998) /    -7.26,  -14.24,    0.00 /
      DATA B(80299), B(80300), B(80301) /    -7.27,  -14.29,    0.00 /
      DATA B(80602), B(80603), B(80604) /    -7.28,  -14.34,    0.00 /
      DATA B(80905), B(80906), B(80907) /    -7.29,  -14.39,    0.00 /
      DATA B(81208), B(81209), B(81210) /    -7.32,  -14.43,    0.00 /
      DATA B(81511), B(81512), B(81513) /    -7.36,  -14.47,    0.00 /
      DATA B(81814), B(81815), B(81816) /    -7.46,  -14.46,    0.00 /
      DATA B(82117), B(82118), B(82119) /    -7.73,  -14.25,    0.00 /
      DATA B(82420), B(82421), B(82422) /    -7.92,  -14.25,    0.00 /
      DATA B(82723), B(82724), B(82725) /    -8.01,  -14.25,    0.00 /
      DATA B(83026), B(83027), B(83028) /    -8.05,  -14.27,    0.00 /
      DATA B(83329), B(83330), B(83331) /    -8.07,  -14.29,    0.00 /
      DATA B(83632), B(83633), B(83634) /    -8.09,  -14.31,    0.00 /
      DATA B(83935), B(83936), B(83937) /    -8.10,  -14.32,    0.00 /
      DATA B(84238), B(84239), B(84240) /    -8.11,  -14.33,    0.00 /
      DATA B(84541), B(84542), B(84543) /    -8.12,  -14.34,    0.00 /
      DATA B(84844), B(84845), B(84846) /    -8.13,  -14.37,    0.00 /
      DATA B(85147), B(85148), B(85149) /    -8.12,  -14.48,    0.00 /
      DATA B(85450), B(85451), B(85452) /    -8.15,  -14.65,    0.00 /
      DATA B(85753), B(85754), B(85755) /    -8.18,  -14.74,    0.00 /
      DATA B(86056), B(86057), B(86058) /    -8.18,  -14.78,    0.00 /
      DATA B(86359), B(86360), B(86361) /    -8.16,  -14.83,    0.00 /
      DATA B(86662), B(86663), B(86664) /    -8.15,  -14.87,    0.00 /
      DATA B(86965), B(86966), B(86967) /    -8.14,  -14.92,    0.00 /
      DATA B(87268), B(87269), B(87270) /    -8.14,  -14.97,    0.00 /
      DATA B(87571), B(87572), B(87573) /    -8.13,  -15.02,    0.00 /
      DATA B(87874), B(87875), B(87876) /    -8.13,  -15.07,    0.00 /
      DATA B(88177), B(88178), B(88179) /    -8.12,  -15.12,    0.00 /
      DATA B(88480), B(88481), B(88482) /    -8.12,  -15.17,    0.00 /
      DATA B(88783), B(88784), B(88785) /    -8.12,  -15.22,    0.00 /
      DATA B(89086), B(89087), B(89088) /    -8.11,  -15.27,    0.00 /
      DATA B(89389), B(89390), B(89391) /    -8.11,  -15.32,    0.00 /
      DATA B(89692), B(89693), B(89694) /    -8.11,  -15.37,    0.00 /
      DATA B(67879), B(67880), B(67881) /    -7.15,  -11.72,    0.00 /
      DATA B(68182), B(68183), B(68184) /    -7.15,  -11.80,    0.00 /
      DATA B(68485), B(68486), B(68487) /    -7.15,  -11.88,    0.00 /
      DATA B(68788), B(68789), B(68790) /    -7.15,  -11.96,    0.00 /
      DATA B(69091), B(69092), B(69093) /    -7.15,  -12.03,    0.00 /
      DATA B(69394), B(69395), B(69396) /    -7.15,  -12.11,    0.00 /
      DATA B(69697), B(69698), B(69699) /    -7.15,  -12.18,    0.00 /
      DATA B(70000), B(70001), B(70002) /    -7.15,  -12.26,    0.00 /
      DATA B(70303), B(70304), B(70305) /    -7.15,  -12.33,    0.00 /
      DATA B(70606), B(70607), B(70608) /    -7.15,  -12.40,    0.00 /
      DATA B(70909), B(70910), B(70911) /    -7.15,  -12.47,    0.00 /
      DATA B(71212), B(71213), B(71214) /    -7.15,  -12.53,    0.00 /
      DATA B(71515), B(71516), B(71517) /    -7.15,  -12.60,    0.00 /
      DATA B(71818), B(71819), B(71820) /    -7.15,  -12.66,    0.00 /
      DATA B(72121), B(72122), B(72123) /    -7.15,  -12.73,    0.00 /
      DATA B(72424), B(72425), B(72426) /    -7.15,  -12.79,    0.00 /
      DATA B(72727), B(72728), B(72729) /    -7.15,  -12.86,    0.00 /
      DATA B(73030), B(73031), B(73032) /    -7.15,  -12.92,    0.00 /
      DATA B(73333), B(73334), B(73335) /    -7.15,  -12.98,    0.00 /
      DATA B(73636), B(73637), B(73638) /    -7.15,  -13.04,    0.00 /
      DATA B(73939), B(73940), B(73941) /    -7.15,  -13.10,    0.00 /
      DATA B(74242), B(74243), B(74244) /    -7.15,  -13.16,    0.00 /
      DATA B(74545), B(74546), B(74547) /    -7.15,  -13.22,    0.00 /
      DATA B(74848), B(74849), B(74850) /    -7.15,  -13.28,    0.00 /
      DATA B(75151), B(75152), B(75153) /    -7.15,  -13.34,    0.00 /
      DATA B(75454), B(75455), B(75456) /    -7.15,  -13.40,    0.00 /
      DATA B(75757), B(75758), B(75759) /    -7.15,  -13.46,    0.00 /
      DATA B(76060), B(76061), B(76062) /    -7.15,  -13.52,    0.00 /
      DATA B(76363), B(76364), B(76365) /    -7.15,  -13.58,    0.00 /
      DATA B(76666), B(76667), B(76668) /    -7.15,  -13.64,    0.00 /
      DATA B(76969), B(76970), B(76971) /    -7.15,  -13.69,    0.00 /
      DATA B(77272), B(77273), B(77274) /    -7.15,  -13.75,    0.00 /
      DATA B(77575), B(77576), B(77577) /    -7.15,  -13.81,    0.00 /
      DATA B(77878), B(77879), B(77880) /    -7.16,  -13.86,    0.00 /
      DATA B(78181), B(78182), B(78183) /    -7.16,  -13.92,    0.00 /
      DATA B(78484), B(78485), B(78486) /    -7.16,  -13.98,    0.00 /
      DATA B(78787), B(78788), B(78789) /    -7.16,  -14.03,    0.00 /
      DATA B(79090), B(79091), B(79092) /    -7.17,  -14.09,    0.00 /
      DATA B(79393), B(79394), B(79395) /    -7.17,  -14.14,    0.00 /
      DATA B(79696), B(79697), B(79698) /    -7.18,  -14.20,    0.00 /
      DATA B(79999), B(80000), B(80001) /    -7.18,  -14.25,    0.00 /
      DATA B(80302), B(80303), B(80304) /    -7.19,  -14.30,    0.00 /
      DATA B(80605), B(80606), B(80607) /    -7.20,  -14.35,    0.00 /
      DATA B(80908), B(80909), B(80910) /    -7.22,  -14.40,    0.00 /
      DATA B(81211), B(81212), B(81213) /    -7.25,  -14.44,    0.00 /
      DATA B(81514), B(81515), B(81516) /    -7.31,  -14.47,    0.00 /
      DATA B(81817), B(81818), B(81819) /    -7.49,  -14.40,    0.00 /
      DATA B(82120), B(82121), B(82122) /    -7.74,  -14.22,    0.00 /
      DATA B(82423), B(82424), B(82425) /    -7.89,  -14.24,    0.00 /
      DATA B(82726), B(82727), B(82728) /    -7.95,  -14.26,    0.00 /
      DATA B(83029), B(83030), B(83031) /    -7.98,  -14.28,    0.00 /
      DATA B(83332), B(83333), B(83334) /    -8.00,  -14.31,    0.00 /
      DATA B(83635), B(83636), B(83637) /    -8.01,  -14.34,    0.00 /
      DATA B(83938), B(83939), B(83940) /    -8.02,  -14.36,    0.00 /
      DATA B(84241), B(84242), B(84243) /    -8.03,  -14.38,    0.00 /
      DATA B(84544), B(84545), B(84546) /    -8.04,  -14.41,    0.00 /
      DATA B(84847), B(84848), B(84849) /    -8.03,  -14.45,    0.00 /
      DATA B(85150), B(85151), B(85152) /    -8.03,  -14.54,    0.00 /
      DATA B(85453), B(85454), B(85455) /    -8.04,  -14.65,    0.00 /
      DATA B(85756), B(85757), B(85758) /    -8.06,  -14.74,    0.00 /
      DATA B(86059), B(86060), B(86061) /    -8.07,  -14.80,    0.00 /
      DATA B(86362), B(86363), B(86364) /    -8.07,  -14.85,    0.00 /
      DATA B(86665), B(86666), B(86667) /    -8.06,  -14.90,    0.00 /
      DATA B(86968), B(86969), B(86970) /    -8.05,  -14.95,    0.00 /
      DATA B(87271), B(87272), B(87273) /    -8.05,  -15.00,    0.00 /
      DATA B(87574), B(87575), B(87576) /    -8.04,  -15.05,    0.00 /
      DATA B(87877), B(87878), B(87879) /    -8.04,  -15.10,    0.00 /
      DATA B(88180), B(88181), B(88182) /    -8.04,  -15.15,    0.00 /
      DATA B(88483), B(88484), B(88485) /    -8.03,  -15.20,    0.00 /
      DATA B(88786), B(88787), B(88788) /    -8.03,  -15.25,    0.00 /
      DATA B(89089), B(89090), B(89091) /    -8.03,  -15.30,    0.00 /
      DATA B(89392), B(89393), B(89394) /    -8.03,  -15.35,    0.00 /
      DATA B(89695), B(89696), B(89697) /    -8.02,  -15.40,    0.00 /
      DATA B(67882), B(67883), B(67884) /    -7.06,  -11.72,    0.00 /
      DATA B(68185), B(68186), B(68187) /    -7.06,  -11.80,    0.00 /
      DATA B(68488), B(68489), B(68490) /    -7.06,  -11.88,    0.00 /
      DATA B(68791), B(68792), B(68793) /    -7.06,  -11.96,    0.00 /
      DATA B(69094), B(69095), B(69096) /    -7.06,  -12.04,    0.00 /
      DATA B(69397), B(69398), B(69399) /    -7.07,  -12.11,    0.00 /
      DATA B(69700), B(69701), B(69702) /    -7.07,  -12.19,    0.00 /
      DATA B(70003), B(70004), B(70005) /    -7.07,  -12.26,    0.00 /
      DATA B(70306), B(70307), B(70308) /    -7.07,  -12.33,    0.00 /
      DATA B(70609), B(70610), B(70611) /    -7.07,  -12.40,    0.00 /
      DATA B(70912), B(70913), B(70914) /    -7.07,  -12.47,    0.00 /
      DATA B(71215), B(71216), B(71217) /    -7.07,  -12.54,    0.00 /
      DATA B(71518), B(71519), B(71520) /    -7.07,  -12.60,    0.00 /
      DATA B(71821), B(71822), B(71823) /    -7.07,  -12.67,    0.00 /
      DATA B(72124), B(72125), B(72126) /    -7.07,  -12.73,    0.00 /
      DATA B(72427), B(72428), B(72429) /    -7.07,  -12.80,    0.00 /
      DATA B(72730), B(72731), B(72732) /    -7.07,  -12.86,    0.00 /
      DATA B(73033), B(73034), B(73035) /    -7.07,  -12.92,    0.00 /
      DATA B(73336), B(73337), B(73338) /    -7.07,  -12.98,    0.00 /
      DATA B(73639), B(73640), B(73641) /    -7.07,  -13.05,    0.00 /
      DATA B(73942), B(73943), B(73944) /    -7.07,  -13.11,    0.00 /
      DATA B(74245), B(74246), B(74247) /    -7.07,  -13.17,    0.00 /
      DATA B(74548), B(74549), B(74550) /    -7.07,  -13.23,    0.00 /
      DATA B(74851), B(74852), B(74853) /    -7.07,  -13.29,    0.00 /
      DATA B(75154), B(75155), B(75156) /    -7.07,  -13.35,    0.00 /
      DATA B(75457), B(75458), B(75459) /    -7.07,  -13.41,    0.00 /
      DATA B(75760), B(75761), B(75762) /    -7.07,  -13.47,    0.00 /
      DATA B(76063), B(76064), B(76065) /    -7.07,  -13.53,    0.00 /
      DATA B(76366), B(76367), B(76368) /    -7.07,  -13.59,    0.00 /
      DATA B(76669), B(76670), B(76671) /    -7.07,  -13.64,    0.00 /
      DATA B(76972), B(76973), B(76974) /    -7.07,  -13.70,    0.00 /
      DATA B(77275), B(77276), B(77277) /    -7.07,  -13.76,    0.00 /
      DATA B(77578), B(77579), B(77580) /    -7.07,  -13.82,    0.00 /
      DATA B(77881), B(77882), B(77883) /    -7.07,  -13.87,    0.00 /
      DATA B(78184), B(78185), B(78186) /    -7.08,  -13.93,    0.00 /
      DATA B(78487), B(78488), B(78489) /    -7.08,  -13.98,    0.00 /
      DATA B(78790), B(78791), B(78792) /    -7.08,  -14.04,    0.00 /
      DATA B(79093), B(79094), B(79095) /    -7.09,  -14.10,    0.00 /
      DATA B(79396), B(79397), B(79398) /    -7.09,  -14.15,    0.00 /
      DATA B(79699), B(79700), B(79701) /    -7.10,  -14.20,    0.00 /
      DATA B(80002), B(80003), B(80004) /    -7.10,  -14.26,    0.00 /
      DATA B(80305), B(80306), B(80307) /    -7.11,  -14.31,    0.00 /
      DATA B(80608), B(80609), B(80610) /    -7.13,  -14.36,    0.00 /
      DATA B(80911), B(80912), B(80913) /    -7.15,  -14.41,    0.00 /
      DATA B(81214), B(81215), B(81216) /    -7.19,  -14.45,    0.00 /
      DATA B(81517), B(81518), B(81519) /    -7.29,  -14.45,    0.00 /
      DATA B(81820), B(81821), B(81822) /    -7.56,  -14.26,    0.00 /
      DATA B(82123), B(82124), B(82125) /    -7.75,  -14.23,    0.00 /
      DATA B(82426), B(82427), B(82428) /    -7.84,  -14.24,    0.00 /
      DATA B(82729), B(82730), B(82731) /    -7.88,  -14.27,    0.00 /
      DATA B(83032), B(83033), B(83034) /    -7.91,  -14.30,    0.00 /
      DATA B(83335), B(83336), B(83337) /    -7.92,  -14.33,    0.00 /
      DATA B(83638), B(83639), B(83640) /    -7.93,  -14.36,    0.00 /
      DATA B(83941), B(83942), B(83943) /    -7.94,  -14.39,    0.00 /
      DATA B(84244), B(84245), B(84246) /    -7.95,  -14.42,    0.00 /
      DATA B(84547), B(84548), B(84549) /    -7.95,  -14.46,    0.00 /
      DATA B(84850), B(84851), B(84852) /    -7.95,  -14.51,    0.00 /
      DATA B(85153), B(85154), B(85155) /    -7.95,  -14.59,    0.00 /
      DATA B(85456), B(85457), B(85458) /    -7.95,  -14.68,    0.00 /
      DATA B(85759), B(85760), B(85761) /    -7.96,  -14.75,    0.00 /
      DATA B(86062), B(86063), B(86064) /    -7.97,  -14.82,    0.00 /
      DATA B(86365), B(86366), B(86367) /    -7.97,  -14.87,    0.00 /
      DATA B(86668), B(86669), B(86670) /    -7.97,  -14.92,    0.00 /
      DATA B(86971), B(86972), B(86973) /    -7.96,  -14.98,    0.00 /
      DATA B(87274), B(87275), B(87276) /    -7.96,  -15.03,    0.00 /
      DATA B(87577), B(87578), B(87579) /    -7.96,  -15.08,    0.00 /
      DATA B(87880), B(87881), B(87882) /    -7.96,  -15.13,    0.00 /
      DATA B(88183), B(88184), B(88185) /    -7.95,  -15.18,    0.00 /
      DATA B(88486), B(88487), B(88488) /    -7.95,  -15.23,    0.00 /
      DATA B(88789), B(88790), B(88791) /    -7.95,  -15.28,    0.00 /
      DATA B(89092), B(89093), B(89094) /    -7.95,  -15.33,    0.00 /
      DATA B(89395), B(89396), B(89397) /    -7.94,  -15.38,    0.00 /
      DATA B(89698), B(89699), B(89700) /    -7.94,  -15.43,    0.00 /
      DATA B(67885), B(67886), B(67887) /    -6.98,  -11.73,    0.00 /
      DATA B(68188), B(68189), B(68190) /    -6.98,  -11.81,    0.00 /
      DATA B(68491), B(68492), B(68493) /    -6.98,  -11.88,    0.00 /
      DATA B(68794), B(68795), B(68796) /    -6.98,  -11.96,    0.00 /
      DATA B(69097), B(69098), B(69099) /    -6.98,  -12.04,    0.00 /
      DATA B(69400), B(69401), B(69402) /    -6.98,  -12.11,    0.00 /
      DATA B(69703), B(69704), B(69705) /    -6.98,  -12.19,    0.00 /
      DATA B(70006), B(70007), B(70008) /    -6.98,  -12.26,    0.00 /
      DATA B(70309), B(70310), B(70311) /    -6.98,  -12.33,    0.00 /
      DATA B(70612), B(70613), B(70614) /    -6.98,  -12.40,    0.00 /
      DATA B(70915), B(70916), B(70917) /    -6.98,  -12.47,    0.00 /
      DATA B(71218), B(71219), B(71220) /    -6.98,  -12.54,    0.00 /
      DATA B(71521), B(71522), B(71523) /    -6.98,  -12.60,    0.00 /
      DATA B(71824), B(71825), B(71826) /    -6.98,  -12.67,    0.00 /
      DATA B(72127), B(72128), B(72129) /    -6.98,  -12.74,    0.00 /
      DATA B(72430), B(72431), B(72432) /    -6.98,  -12.80,    0.00 /
      DATA B(72733), B(72734), B(72735) /    -6.98,  -12.86,    0.00 /
      DATA B(73036), B(73037), B(73038) /    -6.98,  -12.93,    0.00 /
      DATA B(73339), B(73340), B(73341) /    -6.98,  -12.99,    0.00 /
      DATA B(73642), B(73643), B(73644) /    -6.98,  -13.05,    0.00 /
      DATA B(73945), B(73946), B(73947) /    -6.98,  -13.11,    0.00 /
      DATA B(74248), B(74249), B(74250) /    -6.98,  -13.18,    0.00 /
      DATA B(74551), B(74552), B(74553) /    -6.98,  -13.24,    0.00 /
      DATA B(74854), B(74855), B(74856) /    -6.98,  -13.30,    0.00 /
      DATA B(75157), B(75158), B(75159) /    -6.98,  -13.36,    0.00 /
      DATA B(75460), B(75461), B(75462) /    -6.98,  -13.42,    0.00 /
      DATA B(75763), B(75764), B(75765) /    -6.99,  -13.48,    0.00 /
      DATA B(76066), B(76067), B(76068) /    -6.99,  -13.54,    0.00 /
      DATA B(76369), B(76370), B(76371) /    -6.99,  -13.60,    0.00 /
      DATA B(76672), B(76673), B(76674) /    -6.99,  -13.65,    0.00 /
      DATA B(76975), B(76976), B(76977) /    -6.99,  -13.71,    0.00 /
      DATA B(77278), B(77279), B(77280) /    -6.99,  -13.77,    0.00 /
      DATA B(77581), B(77582), B(77583) /    -6.99,  -13.83,    0.00 /
      DATA B(77884), B(77885), B(77886) /    -6.99,  -13.88,    0.00 /
      DATA B(78187), B(78188), B(78189) /    -7.00,  -13.94,    0.00 /
      DATA B(78490), B(78491), B(78492) /    -7.00,  -13.99,    0.00 /
      DATA B(78793), B(78794), B(78795) /    -7.00,  -14.05,    0.00 /
      DATA B(79096), B(79097), B(79098) /    -7.01,  -14.11,    0.00 /
      DATA B(79399), B(79400), B(79401) /    -7.01,  -14.16,    0.00 /
      DATA B(79702), B(79703), B(79704) /    -7.02,  -14.22,    0.00 /
      DATA B(80005), B(80006), B(80007) /    -7.03,  -14.27,    0.00 /
      DATA B(80308), B(80309), B(80310) /    -7.04,  -14.32,    0.00 /
      DATA B(80611), B(80612), B(80613) /    -7.06,  -14.37,    0.00 /
      DATA B(80914), B(80915), B(80916) /    -7.09,  -14.42,    0.00 /
      DATA B(81217), B(81218), B(81219) /    -7.15,  -14.45,    0.00 /
      DATA B(81520), B(81521), B(81522) /    -7.32,  -14.40,    0.00 /
      DATA B(81823), B(81824), B(81825) /    -7.73,  -14.06,    0.00 /
      DATA B(82126), B(82127), B(82128) /    -7.72,  -14.22,    0.00 /
      DATA B(82429), B(82430), B(82431) /    -7.78,  -14.25,    0.00 /
      DATA B(82732), B(82733), B(82734) /    -7.81,  -14.29,    0.00 /
      DATA B(83035), B(83036), B(83037) /    -7.83,  -14.32,    0.00 /
      DATA B(83338), B(83339), B(83340) /    -7.84,  -14.36,    0.00 /
      DATA B(83641), B(83642), B(83643) /    -7.85,  -14.39,    0.00 /
      DATA B(83944), B(83945), B(83946) /    -7.86,  -14.43,    0.00 /
      DATA B(84247), B(84248), B(84249) /    -7.86,  -14.46,    0.00 /
      DATA B(84550), B(84551), B(84552) /    -7.86,  -14.51,    0.00 /
      DATA B(84853), B(84854), B(84855) /    -7.86,  -14.56,    0.00 /
      DATA B(85156), B(85157), B(85158) /    -7.86,  -14.63,    0.00 /
      DATA B(85459), B(85460), B(85461) /    -7.86,  -14.70,    0.00 /
      DATA B(85762), B(85763), B(85764) /    -7.87,  -14.77,    0.00 /
      DATA B(86065), B(86066), B(86067) /    -7.88,  -14.84,    0.00 /
      DATA B(86368), B(86369), B(86370) /    -7.88,  -14.90,    0.00 /
      DATA B(86671), B(86672), B(86673) /    -7.88,  -14.95,    0.00 /
      DATA B(86974), B(86975), B(86976) /    -7.88,  -15.00,    0.00 /
      DATA B(87277), B(87278), B(87279) /    -7.87,  -15.05,    0.00 /
      DATA B(87580), B(87581), B(87582) /    -7.87,  -15.10,    0.00 /
      DATA B(87883), B(87884), B(87885) /    -7.87,  -15.16,    0.00 /
      DATA B(88186), B(88187), B(88188) /    -7.87,  -15.21,    0.00 /
      DATA B(88489), B(88490), B(88491) /    -7.87,  -15.26,    0.00 /
      DATA B(88792), B(88793), B(88794) /    -7.86,  -15.31,    0.00 /
      DATA B(89095), B(89096), B(89097) /    -7.86,  -15.36,    0.00 /
      DATA B(89398), B(89399), B(89400) /    -7.86,  -15.41,    0.00 /
      DATA B(89701), B(89702), B(89703) /    -7.86,  -15.46,    0.00 /
      DATA B(67888), B(67889), B(67890) /    -6.89,  -11.73,    0.00 /
      DATA B(68191), B(68192), B(68193) /    -6.89,  -11.81,    0.00 /
      DATA B(68494), B(68495), B(68496) /    -6.89,  -11.89,    0.00 /
      DATA B(68797), B(68798), B(68799) /    -6.89,  -11.96,    0.00 /
      DATA B(69100), B(69101), B(69102) /    -6.90,  -12.04,    0.00 /
      DATA B(69403), B(69404), B(69405) /    -6.90,  -12.12,    0.00 /
      DATA B(69706), B(69707), B(69708) /    -6.90,  -12.19,    0.00 /
      DATA B(70009), B(70010), B(70011) /    -6.90,  -12.26,    0.00 /
      DATA B(70312), B(70313), B(70314) /    -6.90,  -12.33,    0.00 /
      DATA B(70615), B(70616), B(70617) /    -6.90,  -12.40,    0.00 /
      DATA B(70918), B(70919), B(70920) /    -6.90,  -12.47,    0.00 /
      DATA B(71221), B(71222), B(71223) /    -6.90,  -12.54,    0.00 /
      DATA B(71524), B(71525), B(71526) /    -6.90,  -12.61,    0.00 /
      DATA B(71827), B(71828), B(71829) /    -6.90,  -12.67,    0.00 /
      DATA B(72130), B(72131), B(72132) /    -6.90,  -12.74,    0.00 /
      DATA B(72433), B(72434), B(72435) /    -6.90,  -12.80,    0.00 /
      DATA B(72736), B(72737), B(72738) /    -6.90,  -12.87,    0.00 /
      DATA B(73039), B(73040), B(73041) /    -6.90,  -12.93,    0.00 /
      DATA B(73342), B(73343), B(73344) /    -6.90,  -12.99,    0.00 /
      DATA B(73645), B(73646), B(73647) /    -6.90,  -13.06,    0.00 /
      DATA B(73948), B(73949), B(73950) /    -6.90,  -13.12,    0.00 /
      DATA B(74251), B(74252), B(74253) /    -6.90,  -13.18,    0.00 /
      DATA B(74554), B(74555), B(74556) /    -6.90,  -13.24,    0.00 /
      DATA B(74857), B(74858), B(74859) /    -6.90,  -13.31,    0.00 /
      DATA B(75160), B(75161), B(75162) /    -6.90,  -13.37,    0.00 /
      DATA B(75463), B(75464), B(75465) /    -6.90,  -13.43,    0.00 /
      DATA B(75766), B(75767), B(75768) /    -6.90,  -13.49,    0.00 /
      DATA B(76069), B(76070), B(76071) /    -6.90,  -13.55,    0.00 /
      DATA B(76372), B(76373), B(76374) /    -6.90,  -13.60,    0.00 /
      DATA B(76675), B(76676), B(76677) /    -6.91,  -13.66,    0.00 /
      DATA B(76978), B(76979), B(76980) /    -6.91,  -13.72,    0.00 /
      DATA B(77281), B(77282), B(77283) /    -6.91,  -13.78,    0.00 /
      DATA B(77584), B(77585), B(77586) /    -6.91,  -13.84,    0.00 /
      DATA B(77887), B(77888), B(77889) /    -6.91,  -13.89,    0.00 /
      DATA B(78190), B(78191), B(78192) /    -6.91,  -13.95,    0.00 /
      DATA B(78493), B(78494), B(78495) /    -6.92,  -14.00,    0.00 /
      DATA B(78796), B(78797), B(78798) /    -6.92,  -14.06,    0.00 /
      DATA B(79099), B(79100), B(79101) /    -6.93,  -14.12,    0.00 /
      DATA B(79402), B(79403), B(79404) /    -6.93,  -14.17,    0.00 /
      DATA B(79705), B(79706), B(79707) /    -6.94,  -14.23,    0.00 /
      DATA B(80008), B(80009), B(80010) /    -6.95,  -14.28,    0.00 /
      DATA B(80311), B(80312), B(80313) /    -6.96,  -14.33,    0.00 /
      DATA B(80614), B(80615), B(80616) /    -6.99,  -14.38,    0.00 /
      DATA B(80917), B(80918), B(80919) /    -7.03,  -14.42,    0.00 /
      DATA B(81220), B(81221), B(81222) /    -7.13,  -14.44,    0.00 /
      DATA B(81523), B(81524), B(81525) /    -7.38,  -14.26,    0.00 /
      DATA B(81826), B(81827), B(81828) /    -7.58,  -14.21,    0.00 /
      DATA B(82129), B(82130), B(82131) /    -7.68,  -14.23,    0.00 /
      DATA B(82432), B(82433), B(82434) /    -7.72,  -14.26,    0.00 /
      DATA B(82735), B(82736), B(82737) /    -7.74,  -14.30,    0.00 /
      DATA B(83038), B(83039), B(83040) /    -7.75,  -14.34,    0.00 /
      DATA B(83341), B(83342), B(83343) /    -7.76,  -14.38,    0.00 /
      DATA B(83644), B(83645), B(83646) /    -7.77,  -14.42,    0.00 /
      DATA B(83947), B(83948), B(83949) /    -7.78,  -14.46,    0.00 /
      DATA B(84250), B(84251), B(84252) /    -7.78,  -14.50,    0.00 /
      DATA B(84553), B(84554), B(84555) /    -7.78,  -14.55,    0.00 /
      DATA B(84856), B(84857), B(84858) /    -7.78,  -14.60,    0.00 /
      DATA B(85159), B(85160), B(85161) /    -7.78,  -14.66,    0.00 /
      DATA B(85462), B(85463), B(85464) /    -7.78,  -14.73,    0.00 /
      DATA B(85765), B(85766), B(85767) /    -7.78,  -14.80,    0.00 /
      DATA B(86068), B(86069), B(86070) /    -7.79,  -14.86,    0.00 /
      DATA B(86371), B(86372), B(86373) /    -7.79,  -14.92,    0.00 /
      DATA B(86674), B(86675), B(86676) /    -7.79,  -14.97,    0.00 /
      DATA B(86977), B(86978), B(86979) /    -7.79,  -15.03,    0.00 /
      DATA B(87280), B(87281), B(87282) /    -7.79,  -15.08,    0.00 /
      DATA B(87583), B(87584), B(87585) /    -7.79,  -15.13,    0.00 /
      DATA B(87886), B(87887), B(87888) /    -7.78,  -15.18,    0.00 /
      DATA B(88189), B(88190), B(88191) /    -7.78,  -15.23,    0.00 /
      DATA B(88492), B(88493), B(88494) /    -7.78,  -15.28,    0.00 /
      DATA B(88795), B(88796), B(88797) /    -7.78,  -15.33,    0.00 /
      DATA B(89098), B(89099), B(89100) /    -7.78,  -15.38,    0.00 /
      DATA B(89401), B(89402), B(89403) /    -7.78,  -15.43,    0.00 /
      DATA B(89704), B(89705), B(89706) /    -7.77,  -15.48,    0.00 /
      DATA B(67891), B(67892), B(67893) /    -6.81,  -11.74,    0.00 /
      DATA B(68194), B(68195), B(68196) /    -6.81,  -11.82,    0.00 /
      DATA B(68497), B(68498), B(68499) /    -6.81,  -11.89,    0.00 /
      DATA B(68800), B(68801), B(68802) /    -6.81,  -11.97,    0.00 /
      DATA B(69103), B(69104), B(69105) /    -6.81,  -12.04,    0.00 /
      DATA B(69406), B(69407), B(69408) /    -6.81,  -12.12,    0.00 /
      DATA B(69709), B(69710), B(69711) /    -6.81,  -12.19,    0.00 /
      DATA B(70012), B(70013), B(70014) /    -6.81,  -12.26,    0.00 /
      DATA B(70315), B(70316), B(70317) /    -6.82,  -12.34,    0.00 /
      DATA B(70618), B(70619), B(70620) /    -6.82,  -12.41,    0.00 /
      DATA B(70921), B(70922), B(70923) /    -6.82,  -12.48,    0.00 /
      DATA B(71224), B(71225), B(71226) /    -6.82,  -12.54,    0.00 /
      DATA B(71527), B(71528), B(71529) /    -6.82,  -12.61,    0.00 /
      DATA B(71830), B(71831), B(71832) /    -6.82,  -12.68,    0.00 /
      DATA B(72133), B(72134), B(72135) /    -6.82,  -12.74,    0.00 /
      DATA B(72436), B(72437), B(72438) /    -6.82,  -12.81,    0.00 /
      DATA B(72739), B(72740), B(72741) /    -6.82,  -12.87,    0.00 /
      DATA B(73042), B(73043), B(73044) /    -6.82,  -12.93,    0.00 /
      DATA B(73345), B(73346), B(73347) /    -6.82,  -13.00,    0.00 /
      DATA B(73648), B(73649), B(73650) /    -6.82,  -13.06,    0.00 /
      DATA B(73951), B(73952), B(73953) /    -6.82,  -13.13,    0.00 /
      DATA B(74254), B(74255), B(74256) /    -6.82,  -13.19,    0.00 /
      DATA B(74557), B(74558), B(74559) /    -6.82,  -13.25,    0.00 /
      DATA B(74860), B(74861), B(74862) /    -6.82,  -13.31,    0.00 /
      DATA B(75163), B(75164), B(75165) /    -6.82,  -13.37,    0.00 /
      DATA B(75466), B(75467), B(75468) /    -6.82,  -13.43,    0.00 /
      DATA B(75769), B(75770), B(75771) /    -6.82,  -13.50,    0.00 /
      DATA B(76072), B(76073), B(76074) /    -6.82,  -13.55,    0.00 /
      DATA B(76375), B(76376), B(76377) /    -6.82,  -13.61,    0.00 /
      DATA B(76678), B(76679), B(76680) /    -6.82,  -13.67,    0.00 /
      DATA B(76981), B(76982), B(76983) /    -6.82,  -13.73,    0.00 /
      DATA B(77284), B(77285), B(77286) /    -6.83,  -13.79,    0.00 /
      DATA B(77587), B(77588), B(77589) /    -6.83,  -13.85,    0.00 /
      DATA B(77890), B(77891), B(77892) /    -6.83,  -13.90,    0.00 /
      DATA B(78193), B(78194), B(78195) /    -6.83,  -13.96,    0.00 /
      DATA B(78496), B(78497), B(78498) /    -6.84,  -14.01,    0.00 /
      DATA B(78799), B(78800), B(78801) /    -6.84,  -14.07,    0.00 /
      DATA B(79102), B(79103), B(79104) /    -6.85,  -14.13,    0.00 /
      DATA B(79405), B(79406), B(79407) /    -6.85,  -14.18,    0.00 /
      DATA B(79708), B(79709), B(79710) /    -6.86,  -14.24,    0.00 /
      DATA B(80011), B(80012), B(80013) /    -6.87,  -14.29,    0.00 /
      DATA B(80314), B(80315), B(80316) /    -6.89,  -14.34,    0.00 /
      DATA B(80617), B(80618), B(80619) /    -6.92,  -14.39,    0.00 /
      DATA B(80920), B(80921), B(80922) /    -6.98,  -14.43,    0.00 /
      DATA B(81223), B(81224), B(81225) /    -7.15,  -14.40,    0.00 /
      DATA B(81526), B(81527), B(81528) /    -7.38,  -14.20,    0.00 /
      DATA B(81829), B(81830), B(81831) /    -7.56,  -14.21,    0.00 /
      DATA B(82132), B(82133), B(82134) /    -7.62,  -14.24,    0.00 /
      DATA B(82435), B(82436), B(82437) /    -7.65,  -14.28,    0.00 /
      DATA B(82738), B(82739), B(82740) /    -7.66,  -14.32,    0.00 /
      DATA B(83041), B(83042), B(83043) /    -7.67,  -14.36,    0.00 /
      DATA B(83344), B(83345), B(83346) /    -7.68,  -14.41,    0.00 /
      DATA B(83647), B(83648), B(83649) /    -7.69,  -14.45,    0.00 /
      DATA B(83950), B(83951), B(83952) /    -7.69,  -14.49,    0.00 /
      DATA B(84253), B(84254), B(84255) /    -7.69,  -14.53,    0.00 /
      DATA B(84556), B(84557), B(84558) /    -7.69,  -14.58,    0.00 /
      DATA B(84859), B(84860), B(84861) /    -7.69,  -14.64,    0.00 /
      DATA B(85162), B(85163), B(85164) /    -7.69,  -14.70,    0.00 /
      DATA B(85465), B(85466), B(85467) /    -7.69,  -14.76,    0.00 /
      DATA B(85768), B(85769), B(85770) /    -7.69,  -14.82,    0.00 /
      DATA B(86071), B(86072), B(86073) /    -7.70,  -14.88,    0.00 /
      DATA B(86374), B(86375), B(86376) /    -7.70,  -14.94,    0.00 /
      DATA B(86677), B(86678), B(86679) /    -7.70,  -15.00,    0.00 /
      DATA B(86980), B(86981), B(86982) /    -7.70,  -15.05,    0.00 /
      DATA B(87283), B(87284), B(87285) /    -7.70,  -15.10,    0.00 /
      DATA B(87586), B(87587), B(87588) /    -7.70,  -15.16,    0.00 /
      DATA B(87889), B(87890), B(87891) /    -7.70,  -15.21,    0.00 /
      DATA B(88192), B(88193), B(88194) /    -7.70,  -15.26,    0.00 /
      DATA B(88495), B(88496), B(88497) /    -7.70,  -15.31,    0.00 /
      DATA B(88798), B(88799), B(88800) /    -7.69,  -15.36,    0.00 /
      DATA B(89101), B(89102), B(89103) /    -7.69,  -15.41,    0.00 /
      DATA B(89404), B(89405), B(89406) /    -7.69,  -15.46,    0.00 /
      DATA B(89707), B(89708), B(89709) /    -7.69,  -15.51,    0.00 /
      DATA B(67894), B(67895), B(67896) /    -6.72,  -11.74,    0.00 /
      DATA B(68197), B(68198), B(68199) /    -6.72,  -11.82,    0.00 /
      DATA B(68500), B(68501), B(68502) /    -6.73,  -11.90,    0.00 /
      DATA B(68803), B(68804), B(68805) /    -6.73,  -11.97,    0.00 /
      DATA B(69106), B(69107), B(69108) /    -6.73,  -12.05,    0.00 /
      DATA B(69409), B(69410), B(69411) /    -6.73,  -12.12,    0.00 /
      DATA B(69712), B(69713), B(69714) /    -6.73,  -12.19,    0.00 /
      DATA B(70015), B(70016), B(70017) /    -6.73,  -12.27,    0.00 /
      DATA B(70318), B(70319), B(70320) /    -6.73,  -12.34,    0.00 /
      DATA B(70621), B(70622), B(70623) /    -6.73,  -12.41,    0.00 /
      DATA B(70924), B(70925), B(70926) /    -6.73,  -12.48,    0.00 /
      DATA B(71227), B(71228), B(71229) /    -6.73,  -12.55,    0.00 /
      DATA B(71530), B(71531), B(71532) /    -6.73,  -12.62,    0.00 /
      DATA B(71833), B(71834), B(71835) /    -6.73,  -12.68,    0.00 /
      DATA B(72136), B(72137), B(72138) /    -6.73,  -12.75,    0.00 /
      DATA B(72439), B(72440), B(72441) /    -6.74,  -12.81,    0.00 /
      DATA B(72742), B(72743), B(72744) /    -6.74,  -12.87,    0.00 /
      DATA B(73045), B(73046), B(73047) /    -6.74,  -12.94,    0.00 /
      DATA B(73348), B(73349), B(73350) /    -6.74,  -13.00,    0.00 /
      DATA B(73651), B(73652), B(73653) /    -6.74,  -13.07,    0.00 /
      DATA B(73954), B(73955), B(73956) /    -6.74,  -13.13,    0.00 /
      DATA B(74257), B(74258), B(74259) /    -6.74,  -13.19,    0.00 /
      DATA B(74560), B(74561), B(74562) /    -6.74,  -13.26,    0.00 /
      DATA B(74863), B(74864), B(74865) /    -6.74,  -13.32,    0.00 /
      DATA B(75166), B(75167), B(75168) /    -6.74,  -13.38,    0.00 /
      DATA B(75469), B(75470), B(75471) /    -6.74,  -13.44,    0.00 /
      DATA B(75772), B(75773), B(75774) /    -6.74,  -13.50,    0.00 /
      DATA B(76075), B(76076), B(76077) /    -6.74,  -13.56,    0.00 /
      DATA B(76378), B(76379), B(76380) /    -6.74,  -13.62,    0.00 /
      DATA B(76681), B(76682), B(76683) /    -6.74,  -13.68,    0.00 /
      DATA B(76984), B(76985), B(76986) /    -6.74,  -13.74,    0.00 /
      DATA B(77287), B(77288), B(77289) /    -6.74,  -13.80,    0.00 /
      DATA B(77590), B(77591), B(77592) /    -6.75,  -13.85,    0.00 /
      DATA B(77893), B(77894), B(77895) /    -6.75,  -13.91,    0.00 /
      DATA B(78196), B(78197), B(78198) /    -6.75,  -13.97,    0.00 /
      DATA B(78499), B(78500), B(78501) /    -6.76,  -14.02,    0.00 /
      DATA B(78802), B(78803), B(78804) /    -6.76,  -14.08,    0.00 /
      DATA B(79105), B(79106), B(79107) /    -6.77,  -14.14,    0.00 /
      DATA B(79408), B(79409), B(79410) /    -6.77,  -14.19,    0.00 /
      DATA B(79711), B(79712), B(79713) /    -6.78,  -14.25,    0.00 /
      DATA B(80014), B(80015), B(80016) /    -6.80,  -14.30,    0.00 /
      DATA B(80317), B(80318), B(80319) /    -6.82,  -14.35,    0.00 /
      DATA B(80620), B(80621), B(80622) /    -6.86,  -14.40,    0.00 /
      DATA B(80923), B(80924), B(80925) /    -6.96,  -14.42,    0.00 /
      DATA B(81226), B(81227), B(81228) /    -7.20,  -14.27,    0.00 /
      DATA B(81529), B(81530), B(81531) /    -7.41,  -14.19,    0.00 /
      DATA B(81832), B(81833), B(81834) /    -7.51,  -14.21,    0.00 /
      DATA B(82135), B(82136), B(82137) /    -7.55,  -14.25,    0.00 /
      DATA B(82438), B(82439), B(82440) /    -7.57,  -14.30,    0.00 /
      DATA B(82741), B(82742), B(82743) /    -7.59,  -14.34,    0.00 /
      DATA B(83044), B(83045), B(83046) /    -7.59,  -14.39,    0.00 /
      DATA B(83347), B(83348), B(83349) /    -7.60,  -14.43,    0.00 /
      DATA B(83650), B(83651), B(83652) /    -7.61,  -14.47,    0.00 /
      DATA B(83953), B(83954), B(83955) /    -7.61,  -14.52,    0.00 /
      DATA B(84256), B(84257), B(84258) /    -7.61,  -14.57,    0.00 /
      DATA B(84559), B(84560), B(84561) /    -7.61,  -14.62,    0.00 /
      DATA B(84862), B(84863), B(84864) /    -7.61,  -14.67,    0.00 /
      DATA B(85165), B(85166), B(85167) /    -7.61,  -14.73,    0.00 /
      DATA B(85468), B(85469), B(85470) /    -7.61,  -14.79,    0.00 /
      DATA B(85771), B(85772), B(85773) /    -7.61,  -14.85,    0.00 /
      DATA B(86074), B(86075), B(86076) /    -7.61,  -14.91,    0.00 /
      DATA B(86377), B(86378), B(86379) /    -7.61,  -14.97,    0.00 /
      DATA B(86680), B(86681), B(86682) /    -7.61,  -15.02,    0.00 /
      DATA B(86983), B(86984), B(86985) /    -7.61,  -15.08,    0.00 /
      DATA B(87286), B(87287), B(87288) /    -7.61,  -15.13,    0.00 /
      DATA B(87589), B(87590), B(87591) /    -7.61,  -15.18,    0.00 /
      DATA B(87892), B(87893), B(87894) /    -7.61,  -15.23,    0.00 /
      DATA B(88195), B(88196), B(88197) /    -7.61,  -15.29,    0.00 /
      DATA B(88498), B(88499), B(88500) /    -7.61,  -15.34,    0.00 /
      DATA B(88801), B(88802), B(88803) /    -7.61,  -15.39,    0.00 /
      DATA B(89104), B(89105), B(89106) /    -7.61,  -15.44,    0.00 /
      DATA B(89407), B(89408), B(89409) /    -7.61,  -15.49,    0.00 /
      DATA B(89710), B(89711), B(89712) /    -7.61,  -15.54,    0.00 /
      DATA B(67897), B(67898), B(67899) /    -6.64,  -11.75,    0.00 /
      DATA B(68200), B(68201), B(68202) /    -6.64,  -11.83,    0.00 /
      DATA B(68503), B(68504), B(68505) /    -6.64,  -11.90,    0.00 /
      DATA B(68806), B(68807), B(68808) /    -6.64,  -11.97,    0.00 /
      DATA B(69109), B(69110), B(69111) /    -6.65,  -12.05,    0.00 /
      DATA B(69412), B(69413), B(69414) /    -6.65,  -12.12,    0.00 /
      DATA B(69715), B(69716), B(69717) /    -6.65,  -12.20,    0.00 /
      DATA B(70018), B(70019), B(70020) /    -6.65,  -12.27,    0.00 /
      DATA B(70321), B(70322), B(70323) /    -6.65,  -12.34,    0.00 /
      DATA B(70624), B(70625), B(70626) /    -6.65,  -12.41,    0.00 /
      DATA B(70927), B(70928), B(70929) /    -6.65,  -12.48,    0.00 /
      DATA B(71230), B(71231), B(71232) /    -6.65,  -12.55,    0.00 /
      DATA B(71533), B(71534), B(71535) /    -6.65,  -12.62,    0.00 /
      DATA B(71836), B(71837), B(71838) /    -6.65,  -12.69,    0.00 /
      DATA B(72139), B(72140), B(72141) /    -6.65,  -12.75,    0.00 /
      DATA B(72442), B(72443), B(72444) /    -6.65,  -12.81,    0.00 /
      DATA B(72745), B(72746), B(72747) /    -6.65,  -12.88,    0.00 /
      DATA B(73048), B(73049), B(73050) /    -6.66,  -12.94,    0.00 /
      DATA B(73351), B(73352), B(73353) /    -6.66,  -13.00,    0.00 /
      DATA B(73654), B(73655), B(73656) /    -6.66,  -13.07,    0.00 /
      DATA B(73957), B(73958), B(73959) /    -6.66,  -13.13,    0.00 /
      DATA B(74260), B(74261), B(74262) /    -6.66,  -13.20,    0.00 /
      DATA B(74563), B(74564), B(74565) /    -6.66,  -13.26,    0.00 /
      DATA B(74866), B(74867), B(74868) /    -6.66,  -13.33,    0.00 /
      DATA B(75169), B(75170), B(75171) /    -6.66,  -13.39,    0.00 /
      DATA B(75472), B(75473), B(75474) /    -6.66,  -13.45,    0.00 /
      DATA B(75775), B(75776), B(75777) /    -6.66,  -13.51,    0.00 /
      DATA B(76078), B(76079), B(76080) /    -6.66,  -13.57,    0.00 /
      DATA B(76381), B(76382), B(76383) /    -6.66,  -13.63,    0.00 /
      DATA B(76684), B(76685), B(76686) /    -6.66,  -13.69,    0.00 /
      DATA B(76987), B(76988), B(76989) /    -6.66,  -13.75,    0.00 /
      DATA B(77290), B(77291), B(77292) /    -6.66,  -13.81,    0.00 /
      DATA B(77593), B(77594), B(77595) /    -6.67,  -13.86,    0.00 /
      DATA B(77896), B(77897), B(77898) /    -6.67,  -13.92,    0.00 /
      DATA B(78199), B(78200), B(78201) /    -6.67,  -13.98,    0.00 /
      DATA B(78502), B(78503), B(78504) /    -6.68,  -14.03,    0.00 /
      DATA B(78805), B(78806), B(78807) /    -6.68,  -14.09,    0.00 /
      DATA B(79108), B(79109), B(79110) /    -6.69,  -14.14,    0.00 /
      DATA B(79411), B(79412), B(79413) /    -6.70,  -14.20,    0.00 /
      DATA B(79714), B(79715), B(79716) /    -6.71,  -14.25,    0.00 /
      DATA B(80017), B(80018), B(80019) /    -6.73,  -14.31,    0.00 /
      DATA B(80320), B(80321), B(80322) /    -6.76,  -14.36,    0.00 /
      DATA B(80623), B(80624), B(80625) /    -6.82,  -14.40,    0.00 /
      DATA B(80926), B(80927), B(80928) /    -6.98,  -14.39,    0.00 /
      DATA B(81229), B(81230), B(81231) /    -7.22,  -14.18,    0.00 /
      DATA B(81532), B(81533), B(81534) /    -7.39,  -14.18,    0.00 /
      DATA B(81835), B(81836), B(81837) /    -7.45,  -14.22,    0.00 /
      DATA B(82138), B(82139), B(82140) /    -7.48,  -14.27,    0.00 /
      DATA B(82441), B(82442), B(82443) /    -7.50,  -14.31,    0.00 /
      DATA B(82744), B(82745), B(82746) /    -7.51,  -14.36,    0.00 /
      DATA B(83047), B(83048), B(83049) /    -7.51,  -14.41,    0.00 /
      DATA B(83350), B(83351), B(83352) /    -7.52,  -14.45,    0.00 /
      DATA B(83653), B(83654), B(83655) /    -7.52,  -14.50,    0.00 /
      DATA B(83956), B(83957), B(83958) /    -7.52,  -14.55,    0.00 /
      DATA B(84259), B(84260), B(84261) /    -7.52,  -14.60,    0.00 /
      DATA B(84562), B(84563), B(84564) /    -7.52,  -14.65,    0.00 /
      DATA B(84865), B(84866), B(84867) /    -7.52,  -14.70,    0.00 /
      DATA B(85168), B(85169), B(85170) /    -7.52,  -14.76,    0.00 /
      DATA B(85471), B(85472), B(85473) /    -7.52,  -14.82,    0.00 /
      DATA B(85774), B(85775), B(85776) /    -7.52,  -14.88,    0.00 /
      DATA B(86077), B(86078), B(86079) /    -7.53,  -14.93,    0.00 /
      DATA B(86380), B(86381), B(86382) /    -7.53,  -14.99,    0.00 /
      DATA B(86683), B(86684), B(86685) /    -7.53,  -15.05,    0.00 /
      DATA B(86986), B(86987), B(86988) /    -7.53,  -15.10,    0.00 /
      DATA B(87289), B(87290), B(87291) /    -7.53,  -15.15,    0.00 /
      DATA B(87592), B(87593), B(87594) /    -7.53,  -15.21,    0.00 /
      DATA B(87895), B(87896), B(87897) /    -7.53,  -15.26,    0.00 /
      DATA B(88198), B(88199), B(88200) /    -7.53,  -15.31,    0.00 /
      DATA B(88501), B(88502), B(88503) /    -7.53,  -15.36,    0.00 /
      DATA B(88804), B(88805), B(88806) /    -7.52,  -15.41,    0.00 /
      DATA B(89107), B(89108), B(89109) /    -7.52,  -15.46,    0.00 /
      DATA B(89410), B(89411), B(89412) /    -7.52,  -15.51,    0.00 /
      DATA B(89713), B(89714), B(89715) /    -7.52,  -15.57,    0.00 /
      DATA B(67900), B(67901), B(67902) /    -6.56,  -11.75,    0.00 /
      DATA B(68203), B(68204), B(68205) /    -6.56,  -11.83,    0.00 /
      DATA B(68506), B(68507), B(68508) /    -6.56,  -11.90,    0.00 /
      DATA B(68809), B(68810), B(68811) /    -6.56,  -11.98,    0.00 /
      DATA B(69112), B(69113), B(69114) /    -6.56,  -12.05,    0.00 /
      DATA B(69415), B(69416), B(69417) /    -6.57,  -12.12,    0.00 /
      DATA B(69718), B(69719), B(69720) /    -6.57,  -12.20,    0.00 /
      DATA B(70021), B(70022), B(70023) /    -6.57,  -12.27,    0.00 /
      DATA B(70324), B(70325), B(70326) /    -6.57,  -12.34,    0.00 /
      DATA B(70627), B(70628), B(70629) /    -6.57,  -12.41,    0.00 /
      DATA B(70930), B(70931), B(70932) /    -6.57,  -12.48,    0.00 /
      DATA B(71233), B(71234), B(71235) /    -6.57,  -12.55,    0.00 /
      DATA B(71536), B(71537), B(71538) /    -6.57,  -12.62,    0.00 /
      DATA B(71839), B(71840), B(71841) /    -6.57,  -12.69,    0.00 /
      DATA B(72142), B(72143), B(72144) /    -6.57,  -12.75,    0.00 /
      DATA B(72445), B(72446), B(72447) /    -6.57,  -12.81,    0.00 /
      DATA B(72748), B(72749), B(72750) /    -6.57,  -12.87,    0.00 /
      DATA B(73051), B(73052), B(73053) /    -6.58,  -12.94,    0.00 /
      DATA B(73354), B(73355), B(73356) /    -6.58,  -13.00,    0.00 /
      DATA B(73657), B(73658), B(73659) /    -6.58,  -13.07,    0.00 /
      DATA B(73960), B(73961), B(73962) /    -6.58,  -13.14,    0.00 /
      DATA B(74263), B(74264), B(74265) /    -6.58,  -13.20,    0.00 /
      DATA B(74566), B(74567), B(74568) /    -6.58,  -13.27,    0.00 /
      DATA B(74869), B(74870), B(74871) /    -6.58,  -13.33,    0.00 /
      DATA B(75172), B(75173), B(75174) /    -6.58,  -13.40,    0.00 /
      DATA B(75475), B(75476), B(75477) /    -6.58,  -13.46,    0.00 /
      DATA B(75778), B(75779), B(75780) /    -6.58,  -13.52,    0.00 /
      DATA B(76081), B(76082), B(76083) /    -6.58,  -13.58,    0.00 /
      DATA B(76384), B(76385), B(76386) /    -6.58,  -13.64,    0.00 /
      DATA B(76687), B(76688), B(76689) /    -6.58,  -13.70,    0.00 /
      DATA B(76990), B(76991), B(76992) /    -6.58,  -13.76,    0.00 /
      DATA B(77293), B(77294), B(77295) /    -6.58,  -13.82,    0.00 /
      DATA B(77596), B(77597), B(77598) /    -6.59,  -13.87,    0.00 /
      DATA B(77899), B(77900), B(77901) /    -6.59,  -13.93,    0.00 /
      DATA B(78202), B(78203), B(78204) /    -6.59,  -13.98,    0.00 /
      DATA B(78505), B(78506), B(78507) /    -6.60,  -14.04,    0.00 /
      DATA B(78808), B(78809), B(78810) /    -6.60,  -14.10,    0.00 /
      DATA B(79111), B(79112), B(79113) /    -6.61,  -14.15,    0.00 /
      DATA B(79414), B(79415), B(79416) /    -6.62,  -14.21,    0.00 /
      DATA B(79717), B(79718), B(79719) /    -6.64,  -14.26,    0.00 /
      DATA B(80020), B(80021), B(80022) /    -6.66,  -14.31,    0.00 /
      DATA B(80323), B(80324), B(80325) /    -6.70,  -14.36,    0.00 /
      DATA B(80626), B(80627), B(80628) /    -6.80,  -14.39,    0.00 /
      DATA B(80929), B(80930), B(80931) /    -7.04,  -14.26,    0.00 /
      DATA B(81232), B(81233), B(81234) /    -7.24,  -14.16,    0.00 /
      DATA B(81535), B(81536), B(81537) /    -7.35,  -14.19,    0.00 /
      DATA B(81838), B(81839), B(81840) /    -7.39,  -14.24,    0.00 /
      DATA B(82141), B(82142), B(82143) /    -7.41,  -14.29,    0.00 /
      DATA B(82444), B(82445), B(82446) /    -7.42,  -14.33,    0.00 /
      DATA B(82747), B(82748), B(82749) /    -7.43,  -14.38,    0.00 /
      DATA B(83050), B(83051), B(83052) /    -7.43,  -14.43,    0.00 /
      DATA B(83353), B(83354), B(83355) /    -7.44,  -14.48,    0.00 /
      DATA B(83656), B(83657), B(83658) /    -7.44,  -14.53,    0.00 /
      DATA B(83959), B(83960), B(83961) /    -7.44,  -14.57,    0.00 /
      DATA B(84262), B(84263), B(84264) /    -7.44,  -14.62,    0.00 /
      DATA B(84565), B(84566), B(84567) /    -7.44,  -14.68,    0.00 /
      DATA B(84868), B(84869), B(84870) /    -7.44,  -14.73,    0.00 /
      DATA B(85171), B(85172), B(85173) /    -7.44,  -14.79,    0.00 /
      DATA B(85474), B(85475), B(85476) /    -7.44,  -14.84,    0.00 /
      DATA B(85777), B(85778), B(85779) /    -7.44,  -14.90,    0.00 /
      DATA B(86080), B(86081), B(86082) /    -7.44,  -14.96,    0.00 /
      DATA B(86383), B(86384), B(86385) /    -7.44,  -15.02,    0.00 /
      DATA B(86686), B(86687), B(86688) /    -7.44,  -15.07,    0.00 /
      DATA B(86989), B(86990), B(86991) /    -7.44,  -15.13,    0.00 /
      DATA B(87292), B(87293), B(87294) /    -7.44,  -15.18,    0.00 /
      DATA B(87595), B(87596), B(87597) /    -7.44,  -15.23,    0.00 /
      DATA B(87898), B(87899), B(87900) /    -7.44,  -15.28,    0.00 /
      DATA B(88201), B(88202), B(88203) /    -7.44,  -15.34,    0.00 /
      DATA B(88504), B(88505), B(88506) /    -7.44,  -15.39,    0.00 /
      DATA B(88807), B(88808), B(88809) /    -7.44,  -15.44,    0.00 /
      DATA B(89110), B(89111), B(89112) /    -7.44,  -15.49,    0.00 /
      DATA B(89413), B(89414), B(89415) /    -7.44,  -15.54,    0.00 /
      DATA B(89716), B(89717), B(89718) /    -7.44,  -15.59,    0.00 /
      DATA B(67903), B(67904), B(67905) /    -6.48,  -11.76,    0.00 /
      DATA B(68206), B(68207), B(68208) /    -6.48,  -11.83,    0.00 /
      DATA B(68509), B(68510), B(68511) /    -6.48,  -11.90,    0.00 /
      DATA B(68812), B(68813), B(68814) /    -6.49,  -11.98,    0.00 /
      DATA B(69115), B(69116), B(69117) /    -6.49,  -12.05,    0.00 /
      DATA B(69418), B(69419), B(69420) /    -6.49,  -12.12,    0.00 /
      DATA B(69721), B(69722), B(69723) /    -6.49,  -12.19,    0.00 /
      DATA B(70024), B(70025), B(70026) /    -6.49,  -12.27,    0.00 /
      DATA B(70327), B(70328), B(70329) /    -6.49,  -12.34,    0.00 /
      DATA B(70630), B(70631), B(70632) /    -6.49,  -12.41,    0.00 /
      DATA B(70933), B(70934), B(70935) /    -6.50,  -12.49,    0.00 /
      DATA B(71236), B(71237), B(71238) /    -6.50,  -12.56,    0.00 /
      DATA B(71539), B(71540), B(71541) /    -6.50,  -12.62,    0.00 /
      DATA B(71842), B(71843), B(71844) /    -6.50,  -12.69,    0.00 /
      DATA B(72145), B(72146), B(72147) /    -6.50,  -12.75,    0.00 /
      DATA B(72448), B(72449), B(72450) /    -6.50,  -12.81,    0.00 /
      DATA B(72751), B(72752), B(72753) /    -6.50,  -12.86,    0.00 /
      DATA B(73054), B(73055), B(73056) /    -6.51,  -12.92,    0.00 /
      DATA B(73357), B(73358), B(73359) /    -6.51,  -12.99,    0.00 /
      DATA B(73660), B(73661), B(73662) /    -6.51,  -13.07,    0.00 /
      DATA B(73963), B(73964), B(73965) /    -6.51,  -13.14,    0.00 /
      DATA B(74266), B(74267), B(74268) /    -6.50,  -13.21,    0.00 /
      DATA B(74569), B(74570), B(74571) /    -6.50,  -13.28,    0.00 /
      DATA B(74872), B(74873), B(74874) /    -6.50,  -13.34,    0.00 /
      DATA B(75175), B(75176), B(75177) /    -6.50,  -13.40,    0.00 /
      DATA B(75478), B(75479), B(75480) /    -6.50,  -13.47,    0.00 /
      DATA B(75781), B(75782), B(75783) /    -6.50,  -13.53,    0.00 /
      DATA B(76084), B(76085), B(76086) /    -6.50,  -13.59,    0.00 /
      DATA B(76387), B(76388), B(76389) /    -6.50,  -13.65,    0.00 /
      DATA B(76690), B(76691), B(76692) /    -6.50,  -13.71,    0.00 /
      DATA B(76993), B(76994), B(76995) /    -6.50,  -13.77,    0.00 /
      DATA B(77296), B(77297), B(77298) /    -6.50,  -13.82,    0.00 /
      DATA B(77599), B(77600), B(77601) /    -6.51,  -13.88,    0.00 /
      DATA B(77902), B(77903), B(77904) /    -6.51,  -13.93,    0.00 /
      DATA B(78205), B(78206), B(78207) /    -6.52,  -13.99,    0.00 /
      DATA B(78508), B(78509), B(78510) /    -6.53,  -14.04,    0.00 /
      DATA B(78811), B(78812), B(78813) /    -6.53,  -14.10,    0.00 /
      DATA B(79114), B(79115), B(79116) /    -6.54,  -14.15,    0.00 /
      DATA B(79417), B(79418), B(79419) /    -6.55,  -14.21,    0.00 /
      DATA B(79720), B(79721), B(79722) /    -6.57,  -14.26,    0.00 /
      DATA B(80023), B(80024), B(80025) /    -6.60,  -14.30,    0.00 /
      DATA B(80326), B(80327), B(80328) /    -6.67,  -14.34,    0.00 /
      DATA B(80629), B(80630), B(80631) /    -6.83,  -14.35,    0.00 /
      DATA B(80932), B(80933), B(80934) /    -7.07,  -14.15,    0.00 /
      DATA B(81235), B(81236), B(81237) /    -7.23,  -14.16,    0.00 /
      DATA B(81538), B(81539), B(81540) /    -7.29,  -14.20,    0.00 /
      DATA B(81841), B(81842), B(81843) /    -7.31,  -14.25,    0.00 /
      DATA B(82144), B(82145), B(82146) /    -7.33,  -14.30,    0.00 /
      DATA B(82447), B(82448), B(82449) /    -7.34,  -14.35,    0.00 /
      DATA B(82750), B(82751), B(82752) /    -7.35,  -14.40,    0.00 /
      DATA B(83053), B(83054), B(83055) /    -7.35,  -14.45,    0.00 /
      DATA B(83356), B(83357), B(83358) /    -7.35,  -14.50,    0.00 /
      DATA B(83659), B(83660), B(83661) /    -7.35,  -14.55,    0.00 /
      DATA B(83962), B(83963), B(83964) /    -7.36,  -14.60,    0.00 /
      DATA B(84265), B(84266), B(84267) /    -7.36,  -14.65,    0.00 /
      DATA B(84568), B(84569), B(84570) /    -7.36,  -14.70,    0.00 /
      DATA B(84871), B(84872), B(84873) /    -7.36,  -14.76,    0.00 /
      DATA B(85174), B(85175), B(85176) /    -7.35,  -14.81,    0.00 /
      DATA B(85477), B(85478), B(85479) /    -7.35,  -14.87,    0.00 /
      DATA B(85780), B(85781), B(85782) /    -7.35,  -14.93,    0.00 /
      DATA B(86083), B(86084), B(86085) /    -7.36,  -14.98,    0.00 /
      DATA B(86386), B(86387), B(86388) /    -7.36,  -15.04,    0.00 /
      DATA B(86689), B(86690), B(86691) /    -7.36,  -15.10,    0.00 /
      DATA B(86992), B(86993), B(86994) /    -7.36,  -15.15,    0.00 /
      DATA B(87295), B(87296), B(87297) /    -7.36,  -15.20,    0.00 /
      DATA B(87598), B(87599), B(87600) /    -7.36,  -15.26,    0.00 /
      DATA B(87901), B(87902), B(87903) /    -7.36,  -15.31,    0.00 /
      DATA B(88204), B(88205), B(88206) /    -7.36,  -15.36,    0.00 /
      DATA B(88507), B(88508), B(88509) /    -7.36,  -15.41,    0.00 /
      DATA B(88810), B(88811), B(88812) /    -7.35,  -15.46,    0.00 /
      DATA B(89113), B(89114), B(89115) /    -7.35,  -15.52,    0.00 /
      DATA B(89416), B(89417), B(89418) /    -7.35,  -15.57,    0.00 /
      DATA B(89719), B(89720), B(89721) /    -7.35,  -15.62,    0.00 /
      DATA B(67906), B(67907), B(67908) /    -6.40,  -11.76,    0.00 /
      DATA B(68209), B(68210), B(68211) /    -6.41,  -11.83,    0.00 /
      DATA B(68512), B(68513), B(68514) /    -6.41,  -11.90,    0.00 /
      DATA B(68815), B(68816), B(68817) /    -6.41,  -11.97,    0.00 /
      DATA B(69118), B(69119), B(69120) /    -6.42,  -12.04,    0.00 /
      DATA B(69421), B(69422), B(69423) /    -6.42,  -12.11,    0.00 /
      DATA B(69724), B(69725), B(69726) /    -6.42,  -12.19,    0.00 /
      DATA B(70027), B(70028), B(70029) /    -6.42,  -12.26,    0.00 /
      DATA B(70330), B(70331), B(70332) /    -6.42,  -12.34,    0.00 /
      DATA B(70633), B(70634), B(70635) /    -6.42,  -12.41,    0.00 /
      DATA B(70936), B(70937), B(70938) /    -6.42,  -12.48,    0.00 /
      DATA B(71239), B(71240), B(71241) /    -6.43,  -12.55,    0.00 /
      DATA B(71542), B(71543), B(71544) /    -6.43,  -12.63,    0.00 /
      DATA B(71845), B(71846), B(71847) /    -6.43,  -12.69,    0.00 /
      DATA B(72148), B(72149), B(72150) /    -6.43,  -12.75,    0.00 /
      DATA B(72451), B(72452), B(72453) /    -6.43,  -12.80,    0.00 /
      DATA B(72754), B(72755), B(72756) /    -6.44,  -12.82,    0.00 /
      DATA B(73057), B(73058), B(73059) /    -6.46,  -12.88,    0.00 /
      DATA B(73360), B(73361), B(73362) /    -6.45,  -12.98,    0.00 /
      DATA B(73663), B(73664), B(73665) /    -6.44,  -13.06,    0.00 /
      DATA B(73966), B(73967), B(73968) /    -6.44,  -13.14,    0.00 /
      DATA B(74269), B(74270), B(74271) /    -6.43,  -13.21,    0.00 /
      DATA B(74572), B(74573), B(74574) /    -6.42,  -13.28,    0.00 /
      DATA B(74875), B(74876), B(74877) /    -6.42,  -13.35,    0.00 /
      DATA B(75178), B(75179), B(75180) /    -6.42,  -13.41,    0.00 /
      DATA B(75481), B(75482), B(75483) /    -6.42,  -13.47,    0.00 /
      DATA B(75784), B(75785), B(75786) /    -6.42,  -13.54,    0.00 /
      DATA B(76087), B(76088), B(76089) /    -6.42,  -13.60,    0.00 /
      DATA B(76390), B(76391), B(76392) /    -6.42,  -13.66,    0.00 /
      DATA B(76693), B(76694), B(76695) /    -6.42,  -13.72,    0.00 /
      DATA B(76996), B(76997), B(76998) /    -6.43,  -13.77,    0.00 /
      DATA B(77299), B(77300), B(77301) /    -6.43,  -13.83,    0.00 /
      DATA B(77602), B(77603), B(77604) /    -6.44,  -13.88,    0.00 /
      DATA B(77905), B(77906), B(77907) /    -6.44,  -13.93,    0.00 /
      DATA B(78208), B(78209), B(78210) /    -6.45,  -13.98,    0.00 /
      DATA B(78511), B(78512), B(78513) /    -6.46,  -14.04,    0.00 /
      DATA B(78814), B(78815), B(78816) /    -6.47,  -14.10,    0.00 /
      DATA B(79117), B(79118), B(79119) /    -6.48,  -14.15,    0.00 /
      DATA B(79420), B(79421), B(79422) /    -6.50,  -14.20,    0.00 /
      DATA B(79723), B(79724), B(79725) /    -6.53,  -14.24,    0.00 /
      DATA B(80026), B(80027), B(80028) /    -6.57,  -14.27,    0.00 /
      DATA B(80329), B(80330), B(80331) /    -6.68,  -14.29,    0.00 /
      DATA B(80632), B(80633), B(80634) /    -6.91,  -14.22,    0.00 /
      DATA B(80935), B(80936), B(80937) /    -7.10,  -14.13,    0.00 /
      DATA B(81238), B(81239), B(81240) /    -7.19,  -14.17,    0.00 /
      DATA B(81541), B(81542), B(81543) /    -7.22,  -14.22,    0.00 /
      DATA B(81844), B(81845), B(81846) /    -7.24,  -14.27,    0.00 /
      DATA B(82147), B(82148), B(82149) /    -7.25,  -14.32,    0.00 /
      DATA B(82450), B(82451), B(82452) /    -7.26,  -14.37,    0.00 /
      DATA B(82753), B(82754), B(82755) /    -7.26,  -14.43,    0.00 /
      DATA B(83056), B(83057), B(83058) /    -7.27,  -14.48,    0.00 /
      DATA B(83359), B(83360), B(83361) /    -7.27,  -14.53,    0.00 /
      DATA B(83662), B(83663), B(83664) /    -7.27,  -14.58,    0.00 /
      DATA B(83965), B(83966), B(83967) /    -7.27,  -14.63,    0.00 /
      DATA B(84268), B(84269), B(84270) /    -7.27,  -14.68,    0.00 /
      DATA B(84571), B(84572), B(84573) /    -7.27,  -14.73,    0.00 /
      DATA B(84874), B(84875), B(84876) /    -7.27,  -14.79,    0.00 /
      DATA B(85177), B(85178), B(85179) /    -7.27,  -14.84,    0.00 /
      DATA B(85480), B(85481), B(85482) /    -7.27,  -14.90,    0.00 /
      DATA B(85783), B(85784), B(85785) /    -7.27,  -14.95,    0.00 /
      DATA B(86086), B(86087), B(86088) /    -7.27,  -15.01,    0.00 /
      DATA B(86389), B(86390), B(86391) /    -7.27,  -15.06,    0.00 /
      DATA B(86692), B(86693), B(86694) /    -7.27,  -15.12,    0.00 /
      DATA B(86995), B(86996), B(86997) /    -7.27,  -15.17,    0.00 /
      DATA B(87298), B(87299), B(87300) /    -7.27,  -15.23,    0.00 /
      DATA B(87601), B(87602), B(87603) /    -7.27,  -15.28,    0.00 /
      DATA B(87904), B(87905), B(87906) /    -7.27,  -15.33,    0.00 /
      DATA B(88207), B(88208), B(88209) /    -7.27,  -15.39,    0.00 /
      DATA B(88510), B(88511), B(88512) /    -7.27,  -15.44,    0.00 /
      DATA B(88813), B(88814), B(88815) /    -7.27,  -15.49,    0.00 /
      DATA B(89116), B(89117), B(89118) /    -7.27,  -15.54,    0.00 /
      DATA B(89419), B(89420), B(89421) /    -7.27,  -15.59,    0.00 /
      DATA B(89722), B(89723), B(89724) /    -7.27,  -15.64,    0.00 /
      DATA B(67909), B(67910), B(67911) /    -6.35,  -11.75,    0.00 /
      DATA B(68212), B(68213), B(68214) /    -6.35,  -11.82,    0.00 /
      DATA B(68515), B(68516), B(68517) /    -6.35,  -11.89,    0.00 /
      DATA B(68818), B(68819), B(68820) /    -6.36,  -11.95,    0.00 /
      DATA B(69121), B(69122), B(69123) /    -6.36,  -12.02,    0.00 /
      DATA B(69424), B(69425), B(69426) /    -6.36,  -12.09,    0.00 /
      DATA B(69727), B(69728), B(69729) /    -6.36,  -12.17,    0.00 /
      DATA B(70030), B(70031), B(70032) /    -6.36,  -12.25,    0.00 /
      DATA B(70333), B(70334), B(70335) /    -6.36,  -12.33,    0.00 /
      DATA B(70636), B(70637), B(70638) /    -6.36,  -12.40,    0.00 /
      DATA B(70939), B(70940), B(70941) /    -6.36,  -12.47,    0.00 /
      DATA B(71242), B(71243), B(71244) /    -6.37,  -12.55,    0.00 /
      DATA B(71545), B(71546), B(71547) /    -6.37,  -12.62,    0.00 /
      DATA B(71848), B(71849), B(71850) /    -6.38,  -12.69,    0.00 /
      DATA B(72151), B(72152), B(72153) /    -6.40,  -12.74,    0.00 /
      DATA B(72454), B(72455), B(72456) /    -6.45,  -12.77,    0.00 /
      DATA B(72757), B(72758), B(72759) /    -6.47,  -12.73,    0.00 /
      DATA B(73060), B(73061), B(73062) /    -6.49,  -12.80,    0.00 /
      DATA B(73363), B(73364), B(73365) /    -6.43,  -12.94,    0.00 /
      DATA B(73666), B(73667), B(73668) /    -6.39,  -13.04,    0.00 /
      DATA B(73969), B(73970), B(73971) /    -6.37,  -13.13,    0.00 /
      DATA B(74272), B(74273), B(74274) /    -6.36,  -13.21,    0.00 /
      DATA B(74575), B(74576), B(74577) /    -6.35,  -13.28,    0.00 /
      DATA B(74878), B(74879), B(74880) /    -6.35,  -13.35,    0.00 /
      DATA B(75181), B(75182), B(75183) /    -6.35,  -13.41,    0.00 /
      DATA B(75484), B(75485), B(75486) /    -6.35,  -13.48,    0.00 /
      DATA B(75787), B(75788), B(75789) /    -6.35,  -13.54,    0.00 /
      DATA B(76090), B(76091), B(76092) /    -6.35,  -13.60,    0.00 /
      DATA B(76393), B(76394), B(76395) /    -6.35,  -13.66,    0.00 /
      DATA B(76696), B(76697), B(76698) /    -6.36,  -13.72,    0.00 /
      DATA B(76999), B(77000), B(77001) /    -6.36,  -13.78,    0.00 /
      DATA B(77302), B(77303), B(77304) /    -6.37,  -13.82,    0.00 /
      DATA B(77605), B(77606), B(77607) /    -6.38,  -13.86,    0.00 /
      DATA B(77908), B(77909), B(77910) /    -6.40,  -13.91,    0.00 /
      DATA B(78211), B(78212), B(78213) /    -6.41,  -13.96,    0.00 /
      DATA B(78514), B(78515), B(78516) /    -6.42,  -14.02,    0.00 /
      DATA B(78817), B(78818), B(78819) /    -6.44,  -14.08,    0.00 /
      DATA B(79120), B(79121), B(79122) /    -6.46,  -14.12,    0.00 /
      DATA B(79423), B(79424), B(79425) /    -6.50,  -14.16,    0.00 /
      DATA B(79726), B(79727), B(79728) /    -6.57,  -14.18,    0.00 /
      DATA B(80029), B(80030), B(80031) /    -6.68,  -14.19,    0.00 /
      DATA B(80332), B(80333), B(80334) /    -6.85,  -14.18,    0.00 /
      DATA B(80635), B(80636), B(80637) /    -7.00,  -14.16,    0.00 /
      DATA B(80938), B(80939), B(80940) /    -7.10,  -14.13,    0.00 /
      DATA B(81241), B(81242), B(81243) /    -7.14,  -14.18,    0.00 /
      DATA B(81544), B(81545), B(81546) /    -7.15,  -14.24,    0.00 /
      DATA B(81847), B(81848), B(81849) /    -7.17,  -14.29,    0.00 /
      DATA B(82150), B(82151), B(82152) /    -7.17,  -14.34,    0.00 /
      DATA B(82453), B(82454), B(82455) /    -7.18,  -14.40,    0.00 /
      DATA B(82756), B(82757), B(82758) /    -7.18,  -14.45,    0.00 /
      DATA B(83059), B(83060), B(83061) /    -7.18,  -14.50,    0.00 /
      DATA B(83362), B(83363), B(83364) /    -7.19,  -14.55,    0.00 /
      DATA B(83665), B(83666), B(83667) /    -7.19,  -14.60,    0.00 /
      DATA B(83968), B(83969), B(83970) /    -7.19,  -14.65,    0.00 /
      DATA B(84271), B(84272), B(84273) /    -7.19,  -14.70,    0.00 /
      DATA B(84574), B(84575), B(84576) /    -7.19,  -14.76,    0.00 /
      DATA B(84877), B(84878), B(84879) /    -7.19,  -14.81,    0.00 /
      DATA B(85180), B(85181), B(85182) /    -7.19,  -14.87,    0.00 /
      DATA B(85483), B(85484), B(85485) /    -7.19,  -14.92,    0.00 /
      DATA B(85786), B(85787), B(85788) /    -7.19,  -14.98,    0.00 /
      DATA B(86089), B(86090), B(86091) /    -7.19,  -15.03,    0.00 /
      DATA B(86392), B(86393), B(86394) /    -7.19,  -15.09,    0.00 /
      DATA B(86695), B(86696), B(86697) /    -7.19,  -15.14,    0.00 /
      DATA B(86998), B(86999), B(87000) /    -7.19,  -15.20,    0.00 /
      DATA B(87301), B(87302), B(87303) /    -7.19,  -15.25,    0.00 /
      DATA B(87604), B(87605), B(87606) /    -7.19,  -15.31,    0.00 /
      DATA B(87907), B(87908), B(87909) /    -7.19,  -15.36,    0.00 /
      DATA B(88210), B(88211), B(88212) /    -7.19,  -15.41,    0.00 /
      DATA B(88513), B(88514), B(88515) /    -7.18,  -15.46,    0.00 /
      DATA B(88816), B(88817), B(88818) /    -7.18,  -15.51,    0.00 /
      DATA B(89119), B(89120), B(89121) /    -7.18,  -15.57,    0.00 /
      DATA B(89422), B(89423), B(89424) /    -7.18,  -15.62,    0.00 /
      DATA B(89725), B(89726), B(89727) /    -7.18,  -15.67,    0.00 /
      DATA B(67912), B(67913), B(67914) /    -6.33,  -11.71,    0.00 /
      DATA B(68215), B(68216), B(68217) /    -6.34,  -11.78,    0.00 /
      DATA B(68518), B(68519), B(68520) /    -6.36,  -11.84,    0.00 /
      DATA B(68821), B(68822), B(68823) /    -6.37,  -11.90,    0.00 /
      DATA B(69124), B(69125), B(69126) /    -6.37,  -11.96,    0.00 /
      DATA B(69427), B(69428), B(69429) /    -6.37,  -12.03,    0.00 /
      DATA B(69730), B(69731), B(69732) /    -6.35,  -12.12,    0.00 /
      DATA B(70033), B(70034), B(70035) /    -6.34,  -12.21,    0.00 /
      DATA B(70336), B(70337), B(70338) /    -6.33,  -12.29,    0.00 /
      DATA B(70639), B(70640), B(70641) /    -6.33,  -12.37,    0.00 /
      DATA B(70942), B(70943), B(70944) /    -6.33,  -12.45,    0.00 /
      DATA B(71245), B(71246), B(71247) /    -6.34,  -12.52,    0.00 /
      DATA B(71548), B(71549), B(71550) /    -6.36,  -12.60,    0.00 /
      DATA B(71851), B(71852), B(71853) /    -6.41,  -12.66,    0.00 /
      DATA B(72154), B(72155), B(72156) /    -6.53,  -12.66,    0.00 /
      DATA B(72457), B(72458), B(72459) /    -6.70,  -12.64,    0.00 /
      DATA B(72760), B(72761), B(72762) /    -6.71,  -12.72,    0.00 /
      DATA B(73063), B(73064), B(73065) /    -6.61,  -12.81,    0.00 /
      DATA B(73366), B(73367), B(73368) /    -6.49,  -12.86,    0.00 /
      DATA B(73669), B(73670), B(73671) /    -6.38,  -13.00,    0.00 /
      DATA B(73972), B(73973), B(73974) /    -6.33,  -13.11,    0.00 /
      DATA B(74275), B(74276), B(74277) /    -6.30,  -13.20,    0.00 /
      DATA B(74578), B(74579), B(74580) /    -6.29,  -13.28,    0.00 /
      DATA B(74881), B(74882), B(74883) /    -6.28,  -13.35,    0.00 /
      DATA B(75184), B(75185), B(75186) /    -6.28,  -13.41,    0.00 /
      DATA B(75487), B(75488), B(75489) /    -6.28,  -13.48,    0.00 /
      DATA B(75790), B(75791), B(75792) /    -6.28,  -13.54,    0.00 /
      DATA B(76093), B(76094), B(76095) /    -6.28,  -13.60,    0.00 /
      DATA B(76396), B(76397), B(76398) /    -6.29,  -13.66,    0.00 /
      DATA B(76699), B(76700), B(76701) /    -6.30,  -13.72,    0.00 /
      DATA B(77002), B(77003), B(77004) /    -6.32,  -13.77,    0.00 /
      DATA B(77305), B(77306), B(77307) /    -6.35,  -13.80,    0.00 /
      DATA B(77608), B(77609), B(77610) /    -6.39,  -13.81,    0.00 /
      DATA B(77911), B(77912), B(77913) /    -6.43,  -13.84,    0.00 /
      DATA B(78214), B(78215), B(78216) /    -6.45,  -13.89,    0.00 /
      DATA B(78517), B(78518), B(78519) /    -6.47,  -13.95,    0.00 /
      DATA B(78820), B(78821), B(78822) /    -6.51,  -14.01,    0.00 /
      DATA B(79123), B(79124), B(79125) /    -6.58,  -14.05,    0.00 /
      DATA B(79426), B(79427), B(79428) /    -6.71,  -14.07,    0.00 /
      DATA B(79729), B(79730), B(79731) /    -6.84,  -14.09,    0.00 /
      DATA B(80032), B(80033), B(80034) /    -6.92,  -14.10,    0.00 /
      DATA B(80335), B(80336), B(80337) /    -7.00,  -14.11,    0.00 /
      DATA B(80638), B(80639), B(80640) /    -7.04,  -14.10,    0.00 /
      DATA B(80941), B(80942), B(80943) /    -7.06,  -14.15,    0.00 /
      DATA B(81244), B(81245), B(81246) /    -7.07,  -14.20,    0.00 /
      DATA B(81547), B(81548), B(81549) /    -7.08,  -14.26,    0.00 /
      DATA B(81850), B(81851), B(81852) /    -7.09,  -14.31,    0.00 /
      DATA B(82153), B(82154), B(82155) /    -7.09,  -14.36,    0.00 /
      DATA B(82456), B(82457), B(82458) /    -7.10,  -14.42,    0.00 /
      DATA B(82759), B(82760), B(82761) /    -7.10,  -14.47,    0.00 /
      DATA B(83062), B(83063), B(83064) /    -7.10,  -14.52,    0.00 /
      DATA B(83365), B(83366), B(83367) /    -7.10,  -14.57,    0.00 /
      DATA B(83668), B(83669), B(83670) /    -7.10,  -14.62,    0.00 /
      DATA B(83971), B(83972), B(83973) /    -7.10,  -14.68,    0.00 /
      DATA B(84274), B(84275), B(84276) /    -7.10,  -14.73,    0.00 /
      DATA B(84577), B(84578), B(84579) /    -7.10,  -14.78,    0.00 /
      DATA B(84880), B(84881), B(84882) /    -7.10,  -14.84,    0.00 /
      DATA B(85183), B(85184), B(85185) /    -7.10,  -14.89,    0.00 /
      DATA B(85486), B(85487), B(85488) /    -7.10,  -14.95,    0.00 /
      DATA B(85789), B(85790), B(85791) /    -7.10,  -15.00,    0.00 /
      DATA B(86092), B(86093), B(86094) /    -7.10,  -15.06,    0.00 /
      DATA B(86395), B(86396), B(86397) /    -7.10,  -15.11,    0.00 /
      DATA B(86698), B(86699), B(86700) /    -7.10,  -15.17,    0.00 /
      DATA B(87001), B(87002), B(87003) /    -7.10,  -15.22,    0.00 /
      DATA B(87304), B(87305), B(87306) /    -7.10,  -15.28,    0.00 /
      DATA B(87607), B(87608), B(87609) /    -7.10,  -15.33,    0.00 /
      DATA B(87910), B(87911), B(87912) /    -7.10,  -15.38,    0.00 /
      DATA B(88213), B(88214), B(88215) /    -7.10,  -15.43,    0.00 /
      DATA B(88516), B(88517), B(88518) /    -7.10,  -15.49,    0.00 /
      DATA B(88819), B(88820), B(88821) /    -7.10,  -15.54,    0.00 /
      DATA B(89122), B(89123), B(89124) /    -7.10,  -15.59,    0.00 /
      DATA B(89425), B(89426), B(89427) /    -7.10,  -15.64,    0.00 /
      DATA B(89728), B(89729), B(89730) /    -7.10,  -15.69,    0.00 /
      DATA B(67915), B(67916), B(67917) /    -6.52,  -11.64,    0.00 /
      DATA B(68218), B(68219), B(68220) /    -6.57,  -11.71,    0.00 /
      DATA B(68521), B(68522), B(68523) /    -6.61,  -11.78,    0.00 /
      DATA B(68824), B(68825), B(68826) /    -6.64,  -11.85,    0.00 /
      DATA B(69127), B(69128), B(69129) /    -6.64,  -11.92,    0.00 /
      DATA B(69430), B(69431), B(69432) /    -6.60,  -12.01,    0.00 /
      DATA B(69733), B(69734), B(69735) /    -6.53,  -12.07,    0.00 /
      DATA B(70036), B(70037), B(70038) /    -6.47,  -12.14,    0.00 /
      DATA B(70339), B(70340), B(70341) /    -6.42,  -12.22,    0.00 /
      DATA B(70642), B(70643), B(70644) /    -6.40,  -12.30,    0.00 /
      DATA B(70945), B(70946), B(70947) /    -6.40,  -12.37,    0.00 /
      DATA B(71248), B(71249), B(71250) /    -6.42,  -12.44,    0.00 /
      DATA B(71551), B(71552), B(71553) /    -6.49,  -12.53,    0.00 /
      DATA B(71854), B(71855), B(71856) /    -6.65,  -12.53,    0.00 /
      DATA B(72157), B(72158), B(72159) /    -6.78,  -12.53,    0.00 /
      DATA B(72460), B(72461), B(72462) /    -6.82,  -12.58,    0.00 /
      DATA B(72763), B(72764), B(72765) /    -6.81,  -12.67,    0.00 /
      DATA B(73066), B(73067), B(73068) /    -6.73,  -12.80,    0.00 /
      DATA B(73369), B(73370), B(73371) /    -6.59,  -12.91,    0.00 /
      DATA B(73672), B(73673), B(73674) /    -6.45,  -12.94,    0.00 /
      DATA B(73975), B(73976), B(73977) /    -6.33,  -13.08,    0.00 /
      DATA B(74278), B(74279), B(74280) /    -6.26,  -13.18,    0.00 /
      DATA B(74581), B(74582), B(74583) /    -6.24,  -13.26,    0.00 /
      DATA B(74884), B(74885), B(74886) /    -6.23,  -13.33,    0.00 /
      DATA B(75187), B(75188), B(75189) /    -6.22,  -13.41,    0.00 /
      DATA B(75490), B(75491), B(75492) /    -6.22,  -13.47,    0.00 /
      DATA B(75793), B(75794), B(75795) /    -6.22,  -13.53,    0.00 /
      DATA B(76096), B(76097), B(76098) /    -6.24,  -13.59,    0.00 /
      DATA B(76399), B(76400), B(76401) /    -6.26,  -13.65,    0.00 /
      DATA B(76702), B(76703), B(76704) /    -6.29,  -13.69,    0.00 /
      DATA B(77005), B(77006), B(77007) /    -6.37,  -13.72,    0.00 /
      DATA B(77308), B(77309), B(77310) /    -6.51,  -13.72,    0.00 /
      DATA B(77611), B(77612), B(77613) /    -6.65,  -13.71,    0.00 /
      DATA B(77914), B(77915), B(77916) /    -6.70,  -13.80,    0.00 /
      DATA B(78217), B(78218), B(78219) /    -6.72,  -13.86,    0.00 /
      DATA B(78520), B(78521), B(78522) /    -6.74,  -13.91,    0.00 /
      DATA B(78823), B(78824), B(78825) /    -6.79,  -13.96,    0.00 /
      DATA B(79126), B(79127), B(79128) /    -6.84,  -13.97,    0.00 /
      DATA B(79429), B(79430), B(79431) /    -6.89,  -13.99,    0.00 /
      DATA B(79732), B(79733), B(79734) /    -6.92,  -14.02,    0.00 /
      DATA B(80035), B(80036), B(80037) /    -6.95,  -14.06,    0.00 /
      DATA B(80338), B(80339), B(80340) /    -6.97,  -14.09,    0.00 /
      DATA B(80641), B(80642), B(80643) /    -6.99,  -14.12,    0.00 /
      DATA B(80944), B(80945), B(80946) /    -6.99,  -14.17,    0.00 /
      DATA B(81247), B(81248), B(81249) /    -7.00,  -14.22,    0.00 /
      DATA B(81550), B(81551), B(81552) /    -7.00,  -14.28,    0.00 /
      DATA B(81853), B(81854), B(81855) /    -7.01,  -14.33,    0.00 /
      DATA B(82156), B(82157), B(82158) /    -7.01,  -14.38,    0.00 /
      DATA B(82459), B(82460), B(82461) /    -7.01,  -14.44,    0.00 /
      DATA B(82762), B(82763), B(82764) /    -7.01,  -14.49,    0.00 /
      DATA B(83065), B(83066), B(83067) /    -7.02,  -14.54,    0.00 /
      DATA B(83368), B(83369), B(83370) /    -7.02,  -14.59,    0.00 /
      DATA B(83671), B(83672), B(83673) /    -7.02,  -14.65,    0.00 /
      DATA B(83974), B(83975), B(83976) /    -7.02,  -14.70,    0.00 /
      DATA B(84277), B(84278), B(84279) /    -7.02,  -14.75,    0.00 /
      DATA B(84580), B(84581), B(84582) /    -7.02,  -14.81,    0.00 /
      DATA B(84883), B(84884), B(84885) /    -7.02,  -14.86,    0.00 /
      DATA B(85186), B(85187), B(85188) /    -7.02,  -14.92,    0.00 /
      DATA B(85489), B(85490), B(85491) /    -7.02,  -14.97,    0.00 /
      DATA B(85792), B(85793), B(85794) /    -7.02,  -15.03,    0.00 /
      DATA B(86095), B(86096), B(86097) /    -7.02,  -15.08,    0.00 /
      DATA B(86398), B(86399), B(86400) /    -7.02,  -15.14,    0.00 /
      DATA B(86701), B(86702), B(86703) /    -7.02,  -15.19,    0.00 /
      DATA B(87004), B(87005), B(87006) /    -7.02,  -15.25,    0.00 /
      DATA B(87307), B(87308), B(87309) /    -7.02,  -15.30,    0.00 /
      DATA B(87610), B(87611), B(87612) /    -7.02,  -15.35,    0.00 /
      DATA B(87913), B(87914), B(87915) /    -7.01,  -15.41,    0.00 /
      DATA B(88216), B(88217), B(88218) /    -7.01,  -15.46,    0.00 /
      DATA B(88519), B(88520), B(88521) /    -7.01,  -15.51,    0.00 /
      DATA B(88822), B(88823), B(88824) /    -7.01,  -15.56,    0.00 /
      DATA B(89125), B(89126), B(89127) /    -7.01,  -15.61,    0.00 /
      DATA B(89428), B(89429), B(89430) /    -7.01,  -15.67,    0.00 /
      DATA B(89731), B(89732), B(89733) /    -7.01,  -15.72,    0.00 /
      DATA B(67918), B(67919), B(67920) /    -6.76,  -11.58,    0.00 /
      DATA B(68221), B(68222), B(68223) /    -6.77,  -11.64,    0.00 /
      DATA B(68524), B(68525), B(68526) /    -6.78,  -11.71,    0.00 /
      DATA B(68827), B(68828), B(68829) /    -6.78,  -11.78,    0.00 /
      DATA B(69130), B(69131), B(69132) /    -6.78,  -11.86,    0.00 /
      DATA B(69433), B(69434), B(69435) /    -6.76,  -11.95,    0.00 /
      DATA B(69736), B(69737), B(69738) /    -6.75,  -12.04,    0.00 /
      DATA B(70039), B(70040), B(70041) /    -6.72,  -12.13,    0.00 /
      DATA B(70342), B(70343), B(70344) /    -6.94,  -12.06,    0.00 /
      DATA B(70645), B(70646), B(70647) /    -6.69,  -12.28,    0.00 /
      DATA B(70948), B(70949), B(70950) /    -6.70,  -12.34,    0.00 /
      DATA B(71251), B(71252), B(71253) /    -6.71,  -12.40,    0.00 /
      DATA B(71554), B(71555), B(71556) /    -6.96,  -12.31,    0.00 /
      DATA B(71857), B(71858), B(71859) /    -6.80,  -12.45,    0.00 /
      DATA B(72160), B(72161), B(72162) /    -6.81,  -12.50,    0.00 /
      DATA B(72463), B(72464), B(72465) /    -6.81,  -12.57,    0.00 /
      DATA B(72766), B(72767), B(72768) /    -6.80,  -12.65,    0.00 /
      DATA B(73069), B(73070), B(73071) /    -6.77,  -12.75,    0.00 /
      DATA B(73372), B(73373), B(73374) /    -6.70,  -12.88,    0.00 /
      DATA B(73675), B(73676), B(73677) /    -6.56,  -13.00,    0.00 /
      DATA B(73978), B(73979), B(73980) /    -6.42,  -13.03,    0.00 /
      DATA B(74281), B(74282), B(74283) /    -6.29,  -13.13,    0.00 /
      DATA B(74584), B(74585), B(74586) /    -6.24,  -13.21,    0.00 /
      DATA B(74887), B(74888), B(74889) /    -6.21,  -13.29,    0.00 /
      DATA B(75190), B(75191), B(75192) /    -6.20,  -13.38,    0.00 /
      DATA B(75493), B(75494), B(75495) /    -6.20,  -13.44,    0.00 /
      DATA B(75796), B(75797), B(75798) /    -6.22,  -13.50,    0.00 /
      DATA B(76099), B(76100), B(76101) /    -6.25,  -13.54,    0.00 /
      DATA B(76402), B(76403), B(76404) /    -6.33,  -13.59,    0.00 /
      DATA B(76705), B(76706), B(76707) /    -6.47,  -13.60,    0.00 /
      DATA B(77008), B(77009), B(77010) /    -6.64,  -13.59,    0.00 /
      DATA B(77311), B(77312), B(77313) /    -6.74,  -13.61,    0.00 /
      DATA B(77614), B(77615), B(77616) /    -6.78,  -13.66,    0.00 /
      DATA B(77917), B(77918), B(77919) /    -6.80,  -13.73,    0.00 /
      DATA B(78220), B(78221), B(78222) /    -6.82,  -13.79,    0.00 /
      DATA B(78523), B(78524), B(78525) /    -6.83,  -13.84,    0.00 /
      DATA B(78826), B(78827), B(78828) /    -6.85,  -13.88,    0.00 /
      DATA B(79129), B(79130), B(79131) /    -6.86,  -13.92,    0.00 /
      DATA B(79432), B(79433), B(79434) /    -6.88,  -13.96,    0.00 /
      DATA B(79735), B(79736), B(79737) /    -6.89,  -14.01,    0.00 /
      DATA B(80038), B(80039), B(80040) /    -6.90,  -14.05,    0.00 /
      DATA B(80341), B(80342), B(80343) /    -6.91,  -14.09,    0.00 /
      DATA B(80644), B(80645), B(80646) /    -6.91,  -14.14,    0.00 /
      DATA B(80947), B(80948), B(80949) /    -6.92,  -14.19,    0.00 /
      DATA B(81250), B(81251), B(81252) /    -6.92,  -14.24,    0.00 /
      DATA B(81553), B(81554), B(81555) /    -6.92,  -14.30,    0.00 /
      DATA B(81856), B(81857), B(81858) /    -6.93,  -14.35,    0.00 /
      DATA B(82159), B(82160), B(82161) /    -6.93,  -14.40,    0.00 /
      DATA B(82462), B(82463), B(82464) /    -6.93,  -14.46,    0.00 /
      DATA B(82765), B(82766), B(82767) /    -6.93,  -14.51,    0.00 /
      DATA B(83068), B(83069), B(83070) /    -6.93,  -14.56,    0.00 /
      DATA B(83371), B(83372), B(83373) /    -6.93,  -14.62,    0.00 /
      DATA B(83674), B(83675), B(83676) /    -6.93,  -14.67,    0.00 /
      DATA B(83977), B(83978), B(83979) /    -6.93,  -14.72,    0.00 /
      DATA B(84280), B(84281), B(84282) /    -6.93,  -14.78,    0.00 /
      DATA B(84583), B(84584), B(84585) /    -6.93,  -14.83,    0.00 /
      DATA B(84886), B(84887), B(84888) /    -6.93,  -14.89,    0.00 /
      DATA B(85189), B(85190), B(85191) /    -6.93,  -14.94,    0.00 /
      DATA B(85492), B(85493), B(85494) /    -6.93,  -15.00,    0.00 /
      DATA B(85795), B(85796), B(85797) /    -6.93,  -15.05,    0.00 /
      DATA B(86098), B(86099), B(86100) /    -6.93,  -15.11,    0.00 /
      DATA B(86401), B(86402), B(86403) /    -6.93,  -15.16,    0.00 /
      DATA B(86704), B(86705), B(86706) /    -6.93,  -15.21,    0.00 /
      DATA B(87007), B(87008), B(87009) /    -6.93,  -15.27,    0.00 /
      DATA B(87310), B(87311), B(87312) /    -6.93,  -15.32,    0.00 /
      DATA B(87613), B(87614), B(87615) /    -6.93,  -15.38,    0.00 /
      DATA B(87916), B(87917), B(87918) /    -6.93,  -15.43,    0.00 /
      DATA B(88219), B(88220), B(88221) /    -6.93,  -15.48,    0.00 /
      DATA B(88522), B(88523), B(88524) /    -6.93,  -15.53,    0.00 /
      DATA B(88825), B(88826), B(88827) /    -6.93,  -15.59,    0.00 /
      DATA B(89128), B(89129), B(89130) /    -6.93,  -15.64,    0.00 /
      DATA B(89431), B(89432), B(89433) /    -6.93,  -15.69,    0.00 /
      DATA B(89734), B(89735), B(89736) /    -6.93,  -15.74,    0.00 /
      DATA B(67921), B(67922), B(67923) /    -6.76,  -11.54,    0.00 /
      DATA B(68224), B(68225), B(68226) /    -6.76,  -11.61,    0.00 /
      DATA B(68527), B(68528), B(68529) /    -6.76,  -11.68,    0.00 /
      DATA B(68830), B(68831), B(68832) /    -6.76,  -11.76,    0.00 /
      DATA B(69133), B(69134), B(69135) /    -6.76,  -11.83,    0.00 /
      DATA B(69436), B(69437), B(69438) /    -6.76,  -11.91,    0.00 /
      DATA B(69739), B(69740), B(69741) /    -6.75,  -11.99,    0.00 /
      DATA B(70042), B(70043), B(70044) /    -6.75,  -12.07,    0.00 /
      DATA B(70345), B(70346), B(70347) /    -6.75,  -12.14,    0.00 /
      DATA B(70648), B(70649), B(70650) /    -6.75,  -12.21,    0.00 /
      DATA B(70951), B(70952), B(70953) /    -6.75,  -12.27,    0.00 /
      DATA B(71254), B(71255), B(71256) /    -6.76,  -12.33,    0.00 /
      DATA B(71557), B(71558), B(71559) /    -6.77,  -12.38,    0.00 /
      DATA B(71860), B(71861), B(71862) /    -6.77,  -12.44,    0.00 /
      DATA B(72163), B(72164), B(72165) /    -6.77,  -12.50,    0.00 /
      DATA B(72466), B(72467), B(72468) /    -6.77,  -12.57,    0.00 /
      DATA B(72769), B(72770), B(72771) /    -6.76,  -12.64,    0.00 /
      DATA B(73072), B(73073), B(73074) /    -6.74,  -12.73,    0.00 /
      DATA B(73375), B(73376), B(73377) /    -6.71,  -12.83,    0.00 /
      DATA B(73678), B(73679), B(73680) /    -6.66,  -12.95,    0.00 /
      DATA B(73981), B(73982), B(73983) /    -6.58,  -13.10,    0.00 /
      DATA B(74284), B(74285), B(74286) /    -6.50,  -13.13,    0.00 /
      DATA B(74587), B(74588), B(74589) /    -6.41,  -13.17,    0.00 /
      DATA B(74890), B(74891), B(74892) /    -6.35,  -13.23,    0.00 /
      DATA B(75193), B(75194), B(75195) /    -6.32,  -13.31,    0.00 /
      DATA B(75496), B(75497), B(75498) /    -6.34,  -13.37,    0.00 /
      DATA B(75799), B(75800), B(75801) /    -6.42,  -13.42,    0.00 /
      DATA B(76102), B(76103), B(76104) /    -6.51,  -13.46,    0.00 /
      DATA B(76405), B(76406), B(76407) /    -6.61,  -13.50,    0.00 /
      DATA B(76708), B(76709), B(76710) /    -6.69,  -13.49,    0.00 /
      DATA B(77011), B(77012), B(77013) /    -6.73,  -13.53,    0.00 /
      DATA B(77314), B(77315), B(77316) /    -6.75,  -13.58,    0.00 /
      DATA B(77617), B(77618), B(77619) /    -6.77,  -13.64,    0.00 /
      DATA B(77920), B(77921), B(77922) /    -6.78,  -13.70,    0.00 /
      DATA B(78223), B(78224), B(78225) /    -6.79,  -13.76,    0.00 /
      DATA B(78526), B(78527), B(78528) /    -6.79,  -13.81,    0.00 /
      DATA B(78829), B(78830), B(78831) /    -6.80,  -13.86,    0.00 /
      DATA B(79132), B(79133), B(79134) /    -6.81,  -13.91,    0.00 /
      DATA B(79435), B(79436), B(79437) /    -6.82,  -13.96,    0.00 /
      DATA B(79738), B(79739), B(79740) /    -6.82,  -14.01,    0.00 /
      DATA B(80041), B(80042), B(80043) /    -6.83,  -14.06,    0.00 /
      DATA B(80344), B(80345), B(80346) /    -6.83,  -14.11,    0.00 /
      DATA B(80647), B(80648), B(80649) /    -6.84,  -14.16,    0.00 /
      DATA B(80950), B(80951), B(80952) /    -6.84,  -14.21,    0.00 /
      DATA B(81253), B(81254), B(81255) /    -6.84,  -14.26,    0.00 /
      DATA B(81556), B(81557), B(81558) /    -6.84,  -14.32,    0.00 /
      DATA B(81859), B(81860), B(81861) /    -6.84,  -14.37,    0.00 /
      DATA B(82162), B(82163), B(82164) /    -6.85,  -14.42,    0.00 /
      DATA B(82465), B(82466), B(82467) /    -6.85,  -14.48,    0.00 /
      DATA B(82768), B(82769), B(82770) /    -6.85,  -14.53,    0.00 /
      DATA B(83071), B(83072), B(83073) /    -6.85,  -14.59,    0.00 /
      DATA B(83374), B(83375), B(83376) /    -6.85,  -14.64,    0.00 /
      DATA B(83677), B(83678), B(83679) /    -6.85,  -14.69,    0.00 /
      DATA B(83980), B(83981), B(83982) /    -6.85,  -14.75,    0.00 /
      DATA B(84283), B(84284), B(84285) /    -6.85,  -14.80,    0.00 /
      DATA B(84586), B(84587), B(84588) /    -6.85,  -14.85,    0.00 /
      DATA B(84889), B(84890), B(84891) /    -6.85,  -14.91,    0.00 /
      DATA B(85192), B(85193), B(85194) /    -6.85,  -14.96,    0.00 /
      DATA B(85495), B(85496), B(85497) /    -6.85,  -15.02,    0.00 /
      DATA B(85798), B(85799), B(85800) /    -6.85,  -15.07,    0.00 /
      DATA B(86101), B(86102), B(86103) /    -6.85,  -15.13,    0.00 /
      DATA B(86404), B(86405), B(86406) /    -6.84,  -15.18,    0.00 /
      DATA B(86707), B(86708), B(86709) /    -6.84,  -15.24,    0.00 /
      DATA B(87010), B(87011), B(87012) /    -6.84,  -15.29,    0.00 /
      DATA B(87313), B(87314), B(87315) /    -6.84,  -15.35,    0.00 /
      DATA B(87616), B(87617), B(87618) /    -6.84,  -15.40,    0.00 /
      DATA B(87919), B(87920), B(87921) /    -6.84,  -15.45,    0.00 /
      DATA B(88222), B(88223), B(88224) /    -6.84,  -15.51,    0.00 /
      DATA B(88525), B(88526), B(88527) /    -6.84,  -15.56,    0.00 /
      DATA B(88828), B(88829), B(88830) /    -6.84,  -15.61,    0.00 /
      DATA B(89131), B(89132), B(89133) /    -6.84,  -15.66,    0.00 /
      DATA B(89434), B(89435), B(89436) /    -6.84,  -15.71,    0.00 /
      DATA B(89737), B(89738), B(89739) /    -6.84,  -15.77,    0.00 /
      DATA B(67924), B(67925), B(67926) /    -6.71,  -11.53,    0.00 /
      DATA B(68227), B(68228), B(68229) /    -6.71,  -11.60,    0.00 /
      DATA B(68530), B(68531), B(68532) /    -6.71,  -11.68,    0.00 /
      DATA B(68833), B(68834), B(68835) /    -6.71,  -11.75,    0.00 /
      DATA B(69136), B(69137), B(69138) /    -6.70,  -11.82,    0.00 /
      DATA B(69439), B(69440), B(69441) /    -6.70,  -11.90,    0.00 /
      DATA B(69742), B(69743), B(69744) /    -6.70,  -11.97,    0.00 /
      DATA B(70045), B(70046), B(70047) /    -6.70,  -12.05,    0.00 /
      DATA B(70348), B(70349), B(70350) /    -6.70,  -12.12,    0.00 /
      DATA B(70651), B(70652), B(70653) /    -6.70,  -12.19,    0.00 /
      DATA B(70954), B(70955), B(70956) /    -6.71,  -12.25,    0.00 /
      DATA B(71257), B(71258), B(71259) /    -6.71,  -12.31,    0.00 /
      DATA B(71560), B(71561), B(71562) /    -6.71,  -12.37,    0.00 /
      DATA B(71863), B(71864), B(71865) /    -6.71,  -12.44,    0.00 /
      DATA B(72166), B(72167), B(72168) /    -6.71,  -12.50,    0.00 /
      DATA B(72469), B(72470), B(72471) /    -6.71,  -12.57,    0.00 /
      DATA B(72772), B(72773), B(72774) /    -6.70,  -12.64,    0.00 /
      DATA B(73075), B(73076), B(73077) /    -6.69,  -12.72,    0.00 /
      DATA B(73378), B(73379), B(73380) /    -6.68,  -12.80,    0.00 /
      DATA B(73681), B(73682), B(73683) /    -6.66,  -12.89,    0.00 /
      DATA B(73984), B(73985), B(73986) /    -6.65,  -12.99,    0.00 /
      DATA B(74287), B(74288), B(74289) /    -6.63,  -13.07,    0.00 /
      DATA B(74590), B(74591), B(74592) /    -6.61,  -13.15,    0.00 /
      DATA B(74893), B(74894), B(74895) /    -6.58,  -13.22,    0.00 /
      DATA B(75196), B(75197), B(75198) /    -6.80,  -13.13,    0.00 /
      DATA B(75499), B(75500), B(75501) /    -6.60,  -13.31,    0.00 /
      DATA B(75802), B(75803), B(75804) /    -6.63,  -13.35,    0.00 /
      DATA B(76105), B(76106), B(76107) /    -6.65,  -13.39,    0.00 /
      DATA B(76408), B(76409), B(76410) /    -6.67,  -13.43,    0.00 /
      DATA B(76711), B(76712), B(76713) /    -6.69,  -13.47,    0.00 /
      DATA B(77014), B(77015), B(77016) /    -6.70,  -13.52,    0.00 /
      DATA B(77317), B(77318), B(77319) /    -6.71,  -13.57,    0.00 /
      DATA B(77620), B(77621), B(77622) /    -6.71,  -13.63,    0.00 /
      DATA B(77923), B(77924), B(77925) /    -6.72,  -13.69,    0.00 /
      DATA B(78226), B(78227), B(78228) /    -6.73,  -13.75,    0.00 /
      DATA B(78529), B(78530), B(78531) /    -6.73,  -13.81,    0.00 /
      DATA B(78832), B(78833), B(78834) /    -6.74,  -13.86,    0.00 /
      DATA B(79135), B(79136), B(79137) /    -6.74,  -13.91,    0.00 /
      DATA B(79438), B(79439), B(79440) /    -6.74,  -13.97,    0.00 /
      DATA B(79741), B(79742), B(79743) /    -6.75,  -14.02,    0.00 /
      DATA B(80044), B(80045), B(80046) /    -6.75,  -14.07,    0.00 /
      DATA B(80347), B(80348), B(80349) /    -6.75,  -14.12,    0.00 /
      DATA B(80650), B(80651), B(80652) /    -6.76,  -14.17,    0.00 /
      DATA B(80953), B(80954), B(80955) /    -6.76,  -14.23,    0.00 /
      DATA B(81256), B(81257), B(81258) /    -6.76,  -14.28,    0.00 /
      DATA B(81559), B(81560), B(81561) /    -6.76,  -14.34,    0.00 /
      DATA B(81862), B(81863), B(81864) /    -6.76,  -14.39,    0.00 /
      DATA B(82165), B(82166), B(82167) /    -6.76,  -14.44,    0.00 /
      DATA B(82468), B(82469), B(82470) /    -6.76,  -14.50,    0.00 /
      DATA B(82771), B(82772), B(82773) /    -6.76,  -14.55,    0.00 /
      DATA B(83074), B(83075), B(83076) /    -6.76,  -14.61,    0.00 /
      DATA B(83377), B(83378), B(83379) /    -6.76,  -14.66,    0.00 /
      DATA B(83680), B(83681), B(83682) /    -6.76,  -14.72,    0.00 /
      DATA B(83983), B(83984), B(83985) /    -6.76,  -14.77,    0.00 /
      DATA B(84286), B(84287), B(84288) /    -6.76,  -14.82,    0.00 /
      DATA B(84589), B(84590), B(84591) /    -6.76,  -14.88,    0.00 /
      DATA B(84892), B(84893), B(84894) /    -6.76,  -14.93,    0.00 /
      DATA B(85195), B(85196), B(85197) /    -6.76,  -14.99,    0.00 /
      DATA B(85498), B(85499), B(85500) /    -6.76,  -15.04,    0.00 /
      DATA B(85801), B(85802), B(85803) /    -6.76,  -15.10,    0.00 /
      DATA B(86104), B(86105), B(86106) /    -6.76,  -15.15,    0.00 /
      DATA B(86407), B(86408), B(86409) /    -6.76,  -15.21,    0.00 /
      DATA B(86710), B(86711), B(86712) /    -6.76,  -15.26,    0.00 /
      DATA B(87013), B(87014), B(87015) /    -6.76,  -15.32,    0.00 /
      DATA B(87316), B(87317), B(87318) /    -6.76,  -15.37,    0.00 /
      DATA B(87619), B(87620), B(87621) /    -6.76,  -15.42,    0.00 /
      DATA B(87922), B(87923), B(87924) /    -6.76,  -15.48,    0.00 /
      DATA B(88225), B(88226), B(88227) /    -6.76,  -15.53,    0.00 /
      DATA B(88528), B(88529), B(88530) /    -6.76,  -15.58,    0.00 /
      DATA B(88831), B(88832), B(88833) /    -6.76,  -15.63,    0.00 /
      DATA B(89134), B(89135), B(89136) /    -6.76,  -15.69,    0.00 /
      DATA B(89437), B(89438), B(89439) /    -6.76,  -15.74,    0.00 /
      DATA B(89740), B(89741), B(89742) /    -6.76,  -15.79,    0.00 /
      DATA B(67927), B(67928), B(67929) /    -6.64,  -11.53,    0.00 /
      DATA B(68230), B(68231), B(68232) /    -6.64,  -11.60,    0.00 /
      DATA B(68533), B(68534), B(68535) /    -6.64,  -11.68,    0.00 /
      DATA B(68836), B(68837), B(68838) /    -6.64,  -11.75,    0.00 /
      DATA B(69139), B(69140), B(69141) /    -6.64,  -11.82,    0.00 /
      DATA B(69442), B(69443), B(69444) /    -6.63,  -11.90,    0.00 /
      DATA B(69745), B(69746), B(69747) /    -6.63,  -11.97,    0.00 /
      DATA B(70048), B(70049), B(70050) /    -6.64,  -12.04,    0.00 /
      DATA B(70351), B(70352), B(70353) /    -6.64,  -12.11,    0.00 /
      DATA B(70654), B(70655), B(70656) /    -6.64,  -12.18,    0.00 /
      DATA B(70957), B(70958), B(70959) /    -6.64,  -12.25,    0.00 /
      DATA B(71260), B(71261), B(71262) /    -6.64,  -12.31,    0.00 /
      DATA B(71563), B(71564), B(71565) /    -6.64,  -12.38,    0.00 /
      DATA B(71866), B(71867), B(71868) /    -6.64,  -12.44,    0.00 /
      DATA B(72169), B(72170), B(72171) /    -6.64,  -12.51,    0.00 /
      DATA B(72472), B(72473), B(72474) /    -6.63,  -12.58,    0.00 /
      DATA B(72775), B(72776), B(72777) /    -6.63,  -12.65,    0.00 /
      DATA B(73078), B(73079), B(73080) /    -6.63,  -12.72,    0.00 /
      DATA B(73381), B(73382), B(73383) /    -6.62,  -12.80,    0.00 /
      DATA B(73684), B(73685), B(73686) /    -6.62,  -12.87,    0.00 /
      DATA B(73987), B(73988), B(73989) /    -6.61,  -12.95,    0.00 /
      DATA B(74290), B(74291), B(74292) /    -6.61,  -13.02,    0.00 /
      DATA B(74593), B(74594), B(74595) /    -6.61,  -13.09,    0.00 /
      DATA B(74896), B(74897), B(74898) /    -6.60,  -13.15,    0.00 /
      DATA B(75199), B(75200), B(75201) /    -6.61,  -13.21,    0.00 /
      DATA B(75502), B(75503), B(75504) /    -6.61,  -13.26,    0.00 /
      DATA B(75805), B(75806), B(75807) /    -6.62,  -13.31,    0.00 /
      DATA B(76108), B(76109), B(76110) /    -6.62,  -13.36,    0.00 /
      DATA B(76411), B(76412), B(76413) /    -6.63,  -13.41,    0.00 /
      DATA B(76714), B(76715), B(76716) /    -6.64,  -13.47,    0.00 /
      DATA B(77017), B(77018), B(77019) /    -6.64,  -13.52,    0.00 /
      DATA B(77320), B(77321), B(77322) /    -6.64,  -13.58,    0.00 /
      DATA B(77623), B(77624), B(77625) /    -6.65,  -13.64,    0.00 /
      DATA B(77926), B(77927), B(77928) /    -6.65,  -13.70,    0.00 /
      DATA B(78229), B(78230), B(78231) /    -6.65,  -13.76,    0.00 /
      DATA B(78532), B(78533), B(78534) /    -6.66,  -13.81,    0.00 /
      DATA B(78835), B(78836), B(78837) /    -6.66,  -13.87,    0.00 /
      DATA B(79138), B(79139), B(79140) /    -6.66,  -13.92,    0.00 /
      DATA B(79441), B(79442), B(79443) /    -6.67,  -13.98,    0.00 /
      DATA B(79744), B(79745), B(79746) /    -6.67,  -14.03,    0.00 /
      DATA B(80047), B(80048), B(80049) /    -6.67,  -14.08,    0.00 /
      DATA B(80350), B(80351), B(80352) /    -6.67,  -14.14,    0.00 /
      DATA B(80653), B(80654), B(80655) /    -6.67,  -14.19,    0.00 /
      DATA B(80956), B(80957), B(80958) /    -6.67,  -14.25,    0.00 /
      DATA B(81259), B(81260), B(81261) /    -6.68,  -14.30,    0.00 /
      DATA B(81562), B(81563), B(81564) /    -6.68,  -14.36,    0.00 /
      DATA B(81865), B(81866), B(81867) /    -6.68,  -14.41,    0.00 /
      DATA B(82168), B(82169), B(82170) /    -6.68,  -14.46,    0.00 /
      DATA B(82471), B(82472), B(82473) /    -6.68,  -14.52,    0.00 /
      DATA B(82774), B(82775), B(82776) /    -6.68,  -14.57,    0.00 /
      DATA B(83077), B(83078), B(83079) /    -6.68,  -14.63,    0.00 /
      DATA B(83380), B(83381), B(83382) /    -6.68,  -14.68,    0.00 /
      DATA B(83683), B(83684), B(83685) /    -6.68,  -14.74,    0.00 /
      DATA B(83986), B(83987), B(83988) /    -6.68,  -14.79,    0.00 /
      DATA B(84289), B(84290), B(84291) /    -6.68,  -14.85,    0.00 /
      DATA B(84592), B(84593), B(84594) /    -6.68,  -14.90,    0.00 /
      DATA B(84895), B(84896), B(84897) /    -6.68,  -14.96,    0.00 /
      DATA B(85198), B(85199), B(85200) /    -6.68,  -15.01,    0.00 /
      DATA B(85501), B(85502), B(85503) /    -6.68,  -15.06,    0.00 /
      DATA B(85804), B(85805), B(85806) /    -6.67,  -15.12,    0.00 /
      DATA B(86107), B(86108), B(86109) /    -6.67,  -15.17,    0.00 /
      DATA B(86410), B(86411), B(86412) /    -6.67,  -15.23,    0.00 /
      DATA B(86713), B(86714), B(86715) /    -6.67,  -15.28,    0.00 /
      DATA B(87016), B(87017), B(87018) /    -6.67,  -15.34,    0.00 /
      DATA B(87319), B(87320), B(87321) /    -6.67,  -15.39,    0.00 /
      DATA B(87622), B(87623), B(87624) /    -6.67,  -15.45,    0.00 /
      DATA B(87925), B(87926), B(87927) /    -6.67,  -15.50,    0.00 /
      DATA B(88228), B(88229), B(88230) /    -6.67,  -15.55,    0.00 /
      DATA B(88531), B(88532), B(88533) /    -6.67,  -15.60,    0.00 /
      DATA B(88834), B(88835), B(88836) /    -6.67,  -15.66,    0.00 /
      DATA B(89137), B(89138), B(89139) /    -6.67,  -15.71,    0.00 /
      DATA B(89440), B(89441), B(89442) /    -6.67,  -15.76,    0.00 /
      DATA B(89743), B(89744), B(89745) /    -6.67,  -15.81,    0.00 /
      DATA B(67930), B(67931), B(67932) /    -6.57,  -11.54,    0.00 /
      DATA B(68233), B(68234), B(68235) /    -6.56,  -11.61,    0.00 /
      DATA B(68536), B(68537), B(68538) /    -6.56,  -11.68,    0.00 /
      DATA B(68839), B(68840), B(68841) /    -6.56,  -11.75,    0.00 /
      DATA B(69142), B(69143), B(69144) /    -6.56,  -11.83,    0.00 /
      DATA B(69445), B(69446), B(69447) /    -6.56,  -11.90,    0.00 /
      DATA B(69748), B(69749), B(69750) /    -6.56,  -11.97,    0.00 /
      DATA B(70051), B(70052), B(70053) /    -6.56,  -12.04,    0.00 /
      DATA B(70354), B(70355), B(70356) /    -6.56,  -12.11,    0.00 /
      DATA B(70657), B(70658), B(70659) /    -6.56,  -12.18,    0.00 /
      DATA B(70960), B(70961), B(70962) /    -6.56,  -12.25,    0.00 /
      DATA B(71263), B(71264), B(71265) /    -6.56,  -12.32,    0.00 /
      DATA B(71566), B(71567), B(71568) /    -6.56,  -12.38,    0.00 /
      DATA B(71869), B(71870), B(71871) /    -6.56,  -12.45,    0.00 /
      DATA B(72172), B(72173), B(72174) /    -6.56,  -12.52,    0.00 /
      DATA B(72475), B(72476), B(72477) /    -6.56,  -12.58,    0.00 /
      DATA B(72778), B(72779), B(72780) /    -6.56,  -12.65,    0.00 /
      DATA B(73081), B(73082), B(73083) /    -6.55,  -12.72,    0.00 /
      DATA B(73384), B(73385), B(73386) /    -6.55,  -12.80,    0.00 /
      DATA B(73687), B(73688), B(73689) /    -6.55,  -12.87,    0.00 /
      DATA B(73990), B(73991), B(73992) /    -6.55,  -12.94,    0.00 /
      DATA B(74293), B(74294), B(74295) /    -6.55,  -13.01,    0.00 /
      DATA B(74596), B(74597), B(74598) /    -6.55,  -13.07,    0.00 /
      DATA B(74899), B(74900), B(74901) /    -6.55,  -13.13,    0.00 /
      DATA B(75202), B(75203), B(75204) /    -6.55,  -13.19,    0.00 /
      DATA B(75505), B(75506), B(75507) /    -6.56,  -13.25,    0.00 /
      DATA B(75808), B(75809), B(75810) /    -6.56,  -13.30,    0.00 /
      DATA B(76111), B(76112), B(76113) /    -6.56,  -13.36,    0.00 /
      DATA B(76414), B(76415), B(76416) /    -6.56,  -13.42,    0.00 /
      DATA B(76717), B(76718), B(76719) /    -6.57,  -13.47,    0.00 /
      DATA B(77020), B(77021), B(77022) /    -6.57,  -13.53,    0.00 /
      DATA B(77323), B(77324), B(77325) /    -6.57,  -13.59,    0.00 /
      DATA B(77626), B(77627), B(77628) /    -6.57,  -13.65,    0.00 /
      DATA B(77929), B(77930), B(77931) /    -6.57,  -13.71,    0.00 /
      DATA B(78232), B(78233), B(78234) /    -6.58,  -13.76,    0.00 /
      DATA B(78535), B(78536), B(78537) /    -6.58,  -13.82,    0.00 /
      DATA B(78838), B(78839), B(78840) /    -6.58,  -13.88,    0.00 /
      DATA B(79141), B(79142), B(79143) /    -6.58,  -13.94,    0.00 /
      DATA B(79444), B(79445), B(79446) /    -6.59,  -13.99,    0.00 /
      DATA B(79747), B(79748), B(79749) /    -6.59,  -14.05,    0.00 /
      DATA B(80050), B(80051), B(80052) /    -6.59,  -14.10,    0.00 /
      DATA B(80353), B(80354), B(80355) /    -6.59,  -14.15,    0.00 /
      DATA B(80656), B(80657), B(80658) /    -6.59,  -14.21,    0.00 /
      DATA B(80959), B(80960), B(80961) /    -6.59,  -14.26,    0.00 /
      DATA B(81262), B(81263), B(81264) /    -6.59,  -14.32,    0.00 /
      DATA B(81565), B(81566), B(81567) /    -6.59,  -14.37,    0.00 /
      DATA B(81868), B(81869), B(81870) /    -6.59,  -14.43,    0.00 /
      DATA B(82171), B(82172), B(82173) /    -6.59,  -14.48,    0.00 /
      DATA B(82474), B(82475), B(82476) /    -6.59,  -14.54,    0.00 /
      DATA B(82777), B(82778), B(82779) /    -6.59,  -14.59,    0.00 /
      DATA B(83080), B(83081), B(83082) /    -6.59,  -14.65,    0.00 /
      DATA B(83383), B(83384), B(83385) /    -6.59,  -14.70,    0.00 /
      DATA B(83686), B(83687), B(83688) /    -6.59,  -14.76,    0.00 /
      DATA B(83989), B(83990), B(83991) /    -6.59,  -14.81,    0.00 /
      DATA B(84292), B(84293), B(84294) /    -6.59,  -14.87,    0.00 /
      DATA B(84595), B(84596), B(84597) /    -6.59,  -14.92,    0.00 /
      DATA B(84898), B(84899), B(84900) /    -6.59,  -14.98,    0.00 /
      DATA B(85201), B(85202), B(85203) /    -6.59,  -15.03,    0.00 /
      DATA B(85504), B(85505), B(85506) /    -6.59,  -15.09,    0.00 /
      DATA B(85807), B(85808), B(85809) /    -6.59,  -15.14,    0.00 /
      DATA B(86110), B(86111), B(86112) /    -6.59,  -15.20,    0.00 /
      DATA B(86413), B(86414), B(86415) /    -6.59,  -15.25,    0.00 /
      DATA B(86716), B(86717), B(86718) /    -6.59,  -15.31,    0.00 /
      DATA B(87019), B(87020), B(87021) /    -6.59,  -15.36,    0.00 /
      DATA B(87322), B(87323), B(87324) /    -6.59,  -15.41,    0.00 /
      DATA B(87625), B(87626), B(87627) /    -6.59,  -15.47,    0.00 /
      DATA B(87928), B(87929), B(87930) /    -6.59,  -15.52,    0.00 /
      DATA B(88231), B(88232), B(88233) /    -6.59,  -15.57,    0.00 /
      DATA B(88534), B(88535), B(88536) /    -6.59,  -15.63,    0.00 /
      DATA B(88837), B(88838), B(88839) /    -6.59,  -15.68,    0.00 /
      DATA B(89140), B(89141), B(89142) /    -6.59,  -15.73,    0.00 /
      DATA B(89443), B(89444), B(89445) /    -6.58,  -15.78,    0.00 /
      DATA B(89746), B(89747), B(89748) /    -6.58,  -15.84,    0.00 /
      DATA B(67933), B(67934), B(67935) /    -6.49,  -11.54,    0.00 /
      DATA B(68236), B(68237), B(68238) /    -6.48,  -11.61,    0.00 /
      DATA B(68539), B(68540), B(68541) /    -6.48,  -11.69,    0.00 /
      DATA B(68842), B(68843), B(68844) /    -6.48,  -11.76,    0.00 /
      DATA B(69145), B(69146), B(69147) /    -6.48,  -11.83,    0.00 /
      DATA B(69448), B(69449), B(69450) /    -6.48,  -11.90,    0.00 /
      DATA B(69751), B(69752), B(69753) /    -6.48,  -11.98,    0.00 /
      DATA B(70054), B(70055), B(70056) /    -6.48,  -12.05,    0.00 /
      DATA B(70357), B(70358), B(70359) /    -6.48,  -12.12,    0.00 /
      DATA B(70660), B(70661), B(70662) /    -6.48,  -12.19,    0.00 /
      DATA B(70963), B(70964), B(70965) /    -6.48,  -12.25,    0.00 /
      DATA B(71266), B(71267), B(71268) /    -6.48,  -12.32,    0.00 /
      DATA B(71569), B(71570), B(71571) /    -6.48,  -12.39,    0.00 /
      DATA B(71872), B(71873), B(71874) /    -6.48,  -12.46,    0.00 /
      DATA B(72175), B(72176), B(72177) /    -6.48,  -12.52,    0.00 /
      DATA B(72478), B(72479), B(72480) /    -6.48,  -12.59,    0.00 /
      DATA B(72781), B(72782), B(72783) /    -6.48,  -12.66,    0.00 /
      DATA B(73084), B(73085), B(73086) /    -6.48,  -12.73,    0.00 /
      DATA B(73387), B(73388), B(73389) /    -6.48,  -12.80,    0.00 /
      DATA B(73690), B(73691), B(73692) /    -6.48,  -12.87,    0.00 /
      DATA B(73993), B(73994), B(73995) /    -6.48,  -12.94,    0.00 /
      DATA B(74296), B(74297), B(74298) /    -6.48,  -13.00,    0.00 /
      DATA B(74599), B(74600), B(74601) /    -6.48,  -13.07,    0.00 /
      DATA B(74902), B(74903), B(74904) /    -6.48,  -13.13,    0.00 /
      DATA B(75205), B(75206), B(75207) /    -6.48,  -13.19,    0.00 /
      DATA B(75508), B(75509), B(75510) /    -6.48,  -13.25,    0.00 /
      DATA B(75811), B(75812), B(75813) /    -6.49,  -13.31,    0.00 /
      DATA B(76114), B(76115), B(76116) /    -6.49,  -13.37,    0.00 /
      DATA B(76417), B(76418), B(76419) /    -6.49,  -13.42,    0.00 /
      DATA B(76720), B(76721), B(76722) /    -6.49,  -13.48,    0.00 /
      DATA B(77023), B(77024), B(77025) /    -6.49,  -13.54,    0.00 /
      DATA B(77326), B(77327), B(77328) /    -6.49,  -13.60,    0.00 /
      DATA B(77629), B(77630), B(77631) /    -6.49,  -13.66,    0.00 /
      DATA B(77932), B(77933), B(77934) /    -6.49,  -13.72,    0.00 /
      DATA B(78235), B(78236), B(78237) /    -6.50,  -13.78,    0.00 /
      DATA B(78538), B(78539), B(78540) /    -6.50,  -13.83,    0.00 /
      DATA B(78841), B(78842), B(78843) /    -6.50,  -13.89,    0.00 /
      DATA B(79144), B(79145), B(79146) /    -6.50,  -13.95,    0.00 /
      DATA B(79447), B(79448), B(79449) /    -6.50,  -14.00,    0.00 /
      DATA B(79750), B(79751), B(79752) /    -6.50,  -14.06,    0.00 /
      DATA B(80053), B(80054), B(80055) /    -6.50,  -14.12,    0.00 /
      DATA B(80356), B(80357), B(80358) /    -6.51,  -14.17,    0.00 /
      DATA B(80659), B(80660), B(80661) /    -6.51,  -14.23,    0.00 /
      DATA B(80962), B(80963), B(80964) /    -6.51,  -14.28,    0.00 /
      DATA B(81265), B(81266), B(81267) /    -6.51,  -14.34,    0.00 /
      DATA B(81568), B(81569), B(81570) /    -6.51,  -14.39,    0.00 /
      DATA B(81871), B(81872), B(81873) /    -6.51,  -14.45,    0.00 /
      DATA B(82174), B(82175), B(82176) /    -6.51,  -14.50,    0.00 /
      DATA B(82477), B(82478), B(82479) /    -6.51,  -14.56,    0.00 /
      DATA B(82780), B(82781), B(82782) /    -6.51,  -14.61,    0.00 /
      DATA B(83083), B(83084), B(83085) /    -6.51,  -14.67,    0.00 /
      DATA B(83386), B(83387), B(83388) /    -6.51,  -14.72,    0.00 /
      DATA B(83689), B(83690), B(83691) /    -6.51,  -14.78,    0.00 /
      DATA B(83992), B(83993), B(83994) /    -6.51,  -14.83,    0.00 /
      DATA B(84295), B(84296), B(84297) /    -6.51,  -14.89,    0.00 /
      DATA B(84598), B(84599), B(84600) /    -6.51,  -14.94,    0.00 /
      DATA B(84901), B(84902), B(84903) /    -6.51,  -15.00,    0.00 /
      DATA B(85204), B(85205), B(85206) /    -6.50,  -15.05,    0.00 /
      DATA B(85507), B(85508), B(85509) /    -6.50,  -15.11,    0.00 /
      DATA B(85810), B(85811), B(85812) /    -6.50,  -15.16,    0.00 /
      DATA B(86113), B(86114), B(86115) /    -6.50,  -15.22,    0.00 /
      DATA B(86416), B(86417), B(86418) /    -6.50,  -15.27,    0.00 /
      DATA B(86719), B(86720), B(86721) /    -6.50,  -15.33,    0.00 /
      DATA B(87022), B(87023), B(87024) /    -6.50,  -15.38,    0.00 /
      DATA B(87325), B(87326), B(87327) /    -6.50,  -15.44,    0.00 /
      DATA B(87628), B(87629), B(87630) /    -6.50,  -15.49,    0.00 /
      DATA B(87931), B(87932), B(87933) /    -6.50,  -15.54,    0.00 /
      DATA B(88234), B(88235), B(88236) /    -6.50,  -15.60,    0.00 /
      DATA B(88537), B(88538), B(88539) /    -6.50,  -15.65,    0.00 /
      DATA B(88840), B(88841), B(88842) /    -6.50,  -15.70,    0.00 /
      DATA B(89143), B(89144), B(89145) /    -6.50,  -15.75,    0.00 /
      DATA B(89446), B(89447), B(89448) /    -6.50,  -15.81,    0.00 /
      DATA B(89749), B(89750), B(89751) /    -6.50,  -15.86,    0.00 /
      DATA B(67936), B(67937), B(67938) /    -6.40,  -11.55,    0.00 /
      DATA B(68239), B(68240), B(68241) /    -6.40,  -11.62,    0.00 /
      DATA B(68542), B(68543), B(68544) /    -6.40,  -11.70,    0.00 /
      DATA B(68845), B(68846), B(68847) /    -6.40,  -11.77,    0.00 /
      DATA B(69148), B(69149), B(69150) /    -6.40,  -11.84,    0.00 /
      DATA B(69451), B(69452), B(69453) /    -6.40,  -11.91,    0.00 /
      DATA B(69754), B(69755), B(69756) /    -6.40,  -11.98,    0.00 /
      DATA B(70057), B(70058), B(70059) /    -6.40,  -12.05,    0.00 /
      DATA B(70360), B(70361), B(70362) /    -6.40,  -12.12,    0.00 /
      DATA B(70663), B(70664), B(70665) /    -6.40,  -12.19,    0.00 /
      DATA B(70966), B(70967), B(70968) /    -6.40,  -12.26,    0.00 /
      DATA B(71269), B(71270), B(71271) /    -6.40,  -12.33,    0.00 /
      DATA B(71572), B(71573), B(71574) /    -6.40,  -12.40,    0.00 /
      DATA B(71875), B(71876), B(71877) /    -6.40,  -12.47,    0.00 /
      DATA B(72178), B(72179), B(72180) /    -6.40,  -12.53,    0.00 /
      DATA B(72481), B(72482), B(72483) /    -6.40,  -12.60,    0.00 /
      DATA B(72784), B(72785), B(72786) /    -6.40,  -12.67,    0.00 /
      DATA B(73087), B(73088), B(73089) /    -6.40,  -12.74,    0.00 /
      DATA B(73390), B(73391), B(73392) /    -6.40,  -12.81,    0.00 /
      DATA B(73693), B(73694), B(73695) /    -6.40,  -12.87,    0.00 /
      DATA B(73996), B(73997), B(73998) /    -6.40,  -12.94,    0.00 /
      DATA B(74299), B(74300), B(74301) /    -6.40,  -13.01,    0.00 /
      DATA B(74602), B(74603), B(74604) /    -6.40,  -13.07,    0.00 /
      DATA B(74905), B(74906), B(74907) /    -6.40,  -13.13,    0.00 /
      DATA B(75208), B(75209), B(75210) /    -6.40,  -13.19,    0.00 /
      DATA B(75511), B(75512), B(75513) /    -6.41,  -13.25,    0.00 /
      DATA B(75814), B(75815), B(75816) /    -6.41,  -13.31,    0.00 /
      DATA B(76117), B(76118), B(76119) /    -6.41,  -13.37,    0.00 /
      DATA B(76420), B(76421), B(76422) /    -6.41,  -13.43,    0.00 /
      DATA B(76723), B(76724), B(76725) /    -6.41,  -13.49,    0.00 /
      DATA B(77026), B(77027), B(77028) /    -6.41,  -13.55,    0.00 /
      DATA B(77329), B(77330), B(77331) /    -6.41,  -13.61,    0.00 /
      DATA B(77632), B(77633), B(77634) /    -6.41,  -13.67,    0.00 /
      DATA B(77935), B(77936), B(77937) /    -6.41,  -13.73,    0.00 /
      DATA B(78238), B(78239), B(78240) /    -6.41,  -13.79,    0.00 /
      DATA B(78541), B(78542), B(78543) /    -6.41,  -13.85,    0.00 /
      DATA B(78844), B(78845), B(78846) /    -6.42,  -13.91,    0.00 /
      DATA B(79147), B(79148), B(79149) /    -6.42,  -13.96,    0.00 /
      DATA B(79450), B(79451), B(79452) /    -6.42,  -14.02,    0.00 /
      DATA B(79753), B(79754), B(79755) /    -6.42,  -14.08,    0.00 /
      DATA B(80056), B(80057), B(80058) /    -6.42,  -14.13,    0.00 /
      DATA B(80359), B(80360), B(80361) /    -6.42,  -14.19,    0.00 /
      DATA B(80662), B(80663), B(80664) /    -6.42,  -14.24,    0.00 /
      DATA B(80965), B(80966), B(80967) /    -6.42,  -14.30,    0.00 /
      DATA B(81268), B(81269), B(81270) /    -6.42,  -14.36,    0.00 /
      DATA B(81571), B(81572), B(81573) /    -6.42,  -14.41,    0.00 /
      DATA B(81874), B(81875), B(81876) /    -6.42,  -14.47,    0.00 /
      DATA B(82177), B(82178), B(82179) /    -6.42,  -14.52,    0.00 /
      DATA B(82480), B(82481), B(82482) /    -6.42,  -14.58,    0.00 /
      DATA B(82783), B(82784), B(82785) /    -6.42,  -14.63,    0.00 /
      DATA B(83086), B(83087), B(83088) /    -6.42,  -14.69,    0.00 /
      DATA B(83389), B(83390), B(83391) /    -6.42,  -14.75,    0.00 /
      DATA B(83692), B(83693), B(83694) /    -6.42,  -14.80,    0.00 /
      DATA B(83995), B(83996), B(83997) /    -6.42,  -14.86,    0.00 /
      DATA B(84298), B(84299), B(84300) /    -6.42,  -14.91,    0.00 /
      DATA B(84601), B(84602), B(84603) /    -6.42,  -14.97,    0.00 /
      DATA B(84904), B(84905), B(84906) /    -6.42,  -15.02,    0.00 /
      DATA B(85207), B(85208), B(85209) /    -6.42,  -15.08,    0.00 /
      DATA B(85510), B(85511), B(85512) /    -6.42,  -15.13,    0.00 /
      DATA B(85813), B(85814), B(85815) /    -6.42,  -15.19,    0.00 /
      DATA B(86116), B(86117), B(86118) /    -6.42,  -15.24,    0.00 /
      DATA B(86419), B(86420), B(86421) /    -6.42,  -15.29,    0.00 /
      DATA B(86722), B(86723), B(86724) /    -6.42,  -15.35,    0.00 /
      DATA B(87025), B(87026), B(87027) /    -6.42,  -15.40,    0.00 /
      DATA B(87328), B(87329), B(87330) /    -6.42,  -15.46,    0.00 /
      DATA B(87631), B(87632), B(87633) /    -6.42,  -15.51,    0.00 /
      DATA B(87934), B(87935), B(87936) /    -6.41,  -15.57,    0.00 /
      DATA B(88237), B(88238), B(88239) /    -6.41,  -15.62,    0.00 /
      DATA B(88540), B(88541), B(88542) /    -6.41,  -15.67,    0.00 /
      DATA B(88843), B(88844), B(88845) /    -6.41,  -15.72,    0.00 /
      DATA B(89146), B(89147), B(89148) /    -6.41,  -15.78,    0.00 /
      DATA B(89449), B(89450), B(89451) /    -6.41,  -15.83,    0.00 /
      DATA B(89752), B(89753), B(89754) /    -6.41,  -15.88,    0.00 /
      DATA B(67939), B(67940), B(67941) /    -6.32,  -11.56,    0.00 /
      DATA B(68242), B(68243), B(68244) /    -6.32,  -11.63,    0.00 /
      DATA B(68545), B(68546), B(68547) /    -6.32,  -11.70,    0.00 /
      DATA B(68848), B(68849), B(68850) /    -6.32,  -11.78,    0.00 /
      DATA B(69151), B(69152), B(69153) /    -6.32,  -11.85,    0.00 /
      DATA B(69454), B(69455), B(69456) /    -6.32,  -11.92,    0.00 /
      DATA B(69757), B(69758), B(69759) /    -6.32,  -11.99,    0.00 /
      DATA B(70060), B(70061), B(70062) /    -6.32,  -12.06,    0.00 /
      DATA B(70363), B(70364), B(70365) /    -6.32,  -12.13,    0.00 /
      DATA B(70666), B(70667), B(70668) /    -6.32,  -12.20,    0.00 /
      DATA B(70969), B(70970), B(70971) /    -6.32,  -12.27,    0.00 /
      DATA B(71272), B(71273), B(71274) /    -6.32,  -12.34,    0.00 /
      DATA B(71575), B(71576), B(71577) /    -6.32,  -12.41,    0.00 /
      DATA B(71878), B(71879), B(71880) /    -6.32,  -12.48,    0.00 /
      DATA B(72181), B(72182), B(72183) /    -6.32,  -12.54,    0.00 /
      DATA B(72484), B(72485), B(72486) /    -6.32,  -12.61,    0.00 /
      DATA B(72787), B(72788), B(72789) /    -6.32,  -12.68,    0.00 /
      DATA B(73090), B(73091), B(73092) /    -6.32,  -12.75,    0.00 /
      DATA B(73393), B(73394), B(73395) /    -6.32,  -12.81,    0.00 /
      DATA B(73696), B(73697), B(73698) /    -6.32,  -12.88,    0.00 /
      DATA B(73999), B(74000), B(74001) /    -6.32,  -12.95,    0.00 /
      DATA B(74302), B(74303), B(74304) /    -6.32,  -13.01,    0.00 /
      DATA B(74605), B(74606), B(74607) /    -6.32,  -13.08,    0.00 /
      DATA B(74908), B(74909), B(74910) /    -6.32,  -13.14,    0.00 /
      DATA B(75211), B(75212), B(75213) /    -6.32,  -13.20,    0.00 /
      DATA B(75514), B(75515), B(75516) /    -6.32,  -13.26,    0.00 /
      DATA B(75817), B(75818), B(75819) /    -6.32,  -13.32,    0.00 /
      DATA B(76120), B(76121), B(76122) /    -6.33,  -13.38,    0.00 /
      DATA B(76423), B(76424), B(76425) /    -6.33,  -13.44,    0.00 /
      DATA B(76726), B(76727), B(76728) /    -6.33,  -13.50,    0.00 /
      DATA B(77029), B(77030), B(77031) /    -6.33,  -13.56,    0.00 /
      DATA B(77332), B(77333), B(77334) /    -6.33,  -13.62,    0.00 /
      DATA B(77635), B(77636), B(77637) /    -6.33,  -13.68,    0.00 /
      DATA B(77938), B(77939), B(77940) /    -6.33,  -13.74,    0.00 /
      DATA B(78241), B(78242), B(78243) /    -6.33,  -13.80,    0.00 /
      DATA B(78544), B(78545), B(78546) /    -6.33,  -13.86,    0.00 /
      DATA B(78847), B(78848), B(78849) /    -6.33,  -13.92,    0.00 /
      DATA B(79150), B(79151), B(79152) /    -6.33,  -13.98,    0.00 /
      DATA B(79453), B(79454), B(79455) /    -6.33,  -14.03,    0.00 /
      DATA B(79756), B(79757), B(79758) /    -6.33,  -14.09,    0.00 /
      DATA B(80059), B(80060), B(80061) /    -6.34,  -14.15,    0.00 /
      DATA B(80362), B(80363), B(80364) /    -6.34,  -14.21,    0.00 /
      DATA B(80665), B(80666), B(80667) /    -6.34,  -14.26,    0.00 /
      DATA B(80968), B(80969), B(80970) /    -6.34,  -14.32,    0.00 /
      DATA B(81271), B(81272), B(81273) /    -6.34,  -14.37,    0.00 /
      DATA B(81574), B(81575), B(81576) /    -6.34,  -14.43,    0.00 /
      DATA B(81877), B(81878), B(81879) /    -6.34,  -14.49,    0.00 /
      DATA B(82180), B(82181), B(82182) /    -6.34,  -14.54,    0.00 /
      DATA B(82483), B(82484), B(82485) /    -6.34,  -14.60,    0.00 /
      DATA B(82786), B(82787), B(82788) /    -6.34,  -14.65,    0.00 /
      DATA B(83089), B(83090), B(83091) /    -6.34,  -14.71,    0.00 /
      DATA B(83392), B(83393), B(83394) /    -6.34,  -14.77,    0.00 /
      DATA B(83695), B(83696), B(83697) /    -6.34,  -14.82,    0.00 /
      DATA B(83998), B(83999), B(84000) /    -6.33,  -14.88,    0.00 /
      DATA B(84301), B(84302), B(84303) /    -6.33,  -14.93,    0.00 /
      DATA B(84604), B(84605), B(84606) /    -6.33,  -14.99,    0.00 /
      DATA B(84907), B(84908), B(84909) /    -6.33,  -15.04,    0.00 /
      DATA B(85210), B(85211), B(85212) /    -6.33,  -15.10,    0.00 /
      DATA B(85513), B(85514), B(85515) /    -6.33,  -15.15,    0.00 /
      DATA B(85816), B(85817), B(85818) /    -6.33,  -15.21,    0.00 /
      DATA B(86119), B(86120), B(86121) /    -6.33,  -15.26,    0.00 /
      DATA B(86422), B(86423), B(86424) /    -6.33,  -15.32,    0.00 /
      DATA B(86725), B(86726), B(86727) /    -6.33,  -15.37,    0.00 /
      DATA B(87028), B(87029), B(87030) /    -6.33,  -15.43,    0.00 /
      DATA B(87331), B(87332), B(87333) /    -6.33,  -15.48,    0.00 /
      DATA B(87634), B(87635), B(87636) /    -6.33,  -15.53,    0.00 /
      DATA B(87937), B(87938), B(87939) /    -6.33,  -15.59,    0.00 /
      DATA B(88240), B(88241), B(88242) /    -6.33,  -15.64,    0.00 /
      DATA B(88543), B(88544), B(88545) /    -6.33,  -15.69,    0.00 /
      DATA B(88846), B(88847), B(88848) /    -6.33,  -15.75,    0.00 /
      DATA B(89149), B(89150), B(89151) /    -6.33,  -15.80,    0.00 /
      DATA B(89452), B(89453), B(89454) /    -6.33,  -15.85,    0.00 /
      DATA B(89755), B(89756), B(89757) /    -6.33,  -15.90,    0.00 /
      DATA B(67942), B(67943), B(67944) /    -6.24,  -11.57,    0.00 /
      DATA B(68245), B(68246), B(68247) /    -6.24,  -11.64,    0.00 /
      DATA B(68548), B(68549), B(68550) /    -6.24,  -11.71,    0.00 /
      DATA B(68851), B(68852), B(68853) /    -6.23,  -11.78,    0.00 /
      DATA B(69154), B(69155), B(69156) /    -6.23,  -11.86,    0.00 /
      DATA B(69457), B(69458), B(69459) /    -6.23,  -11.93,    0.00 /
      DATA B(69760), B(69761), B(69762) /    -6.23,  -12.00,    0.00 /
      DATA B(70063), B(70064), B(70065) /    -6.23,  -12.07,    0.00 /
      DATA B(70366), B(70367), B(70368) /    -6.23,  -12.14,    0.00 /
      DATA B(70669), B(70670), B(70671) /    -6.23,  -12.21,    0.00 /
      DATA B(70972), B(70973), B(70974) /    -6.23,  -12.28,    0.00 /
      DATA B(71275), B(71276), B(71277) /    -6.23,  -12.35,    0.00 /
      DATA B(71578), B(71579), B(71580) /    -6.23,  -12.42,    0.00 /
      DATA B(71881), B(71882), B(71883) /    -6.23,  -12.49,    0.00 /
      DATA B(72184), B(72185), B(72186) /    -6.23,  -12.55,    0.00 /
      DATA B(72487), B(72488), B(72489) /    -6.23,  -12.62,    0.00 /
      DATA B(72790), B(72791), B(72792) /    -6.23,  -12.69,    0.00 /
      DATA B(73093), B(73094), B(73095) /    -6.23,  -12.76,    0.00 /
      DATA B(73396), B(73397), B(73398) /    -6.24,  -12.82,    0.00 /
      DATA B(73699), B(73700), B(73701) /    -6.24,  -12.89,    0.00 /
      DATA B(74002), B(74003), B(74004) /    -6.24,  -12.96,    0.00 /
      DATA B(74305), B(74306), B(74307) /    -6.24,  -13.02,    0.00 /
      DATA B(74608), B(74609), B(74610) /    -6.24,  -13.08,    0.00 /
      DATA B(74911), B(74912), B(74913) /    -6.24,  -13.15,    0.00 /
      DATA B(75214), B(75215), B(75216) /    -6.24,  -13.21,    0.00 /
      DATA B(75517), B(75518), B(75519) /    -6.24,  -13.27,    0.00 /
      DATA B(75820), B(75821), B(75822) /    -6.24,  -13.33,    0.00 /
      DATA B(76123), B(76124), B(76125) /    -6.24,  -13.39,    0.00 /
      DATA B(76426), B(76427), B(76428) /    -6.24,  -13.46,    0.00 /
      DATA B(76729), B(76730), B(76731) /    -6.24,  -13.52,    0.00 /
      DATA B(77032), B(77033), B(77034) /    -6.24,  -13.58,    0.00 /
      DATA B(77335), B(77336), B(77337) /    -6.24,  -13.64,    0.00 /
      DATA B(77638), B(77639), B(77640) /    -6.24,  -13.70,    0.00 /
      DATA B(77941), B(77942), B(77943) /    -6.25,  -13.76,    0.00 /
      DATA B(78244), B(78245), B(78246) /    -6.25,  -13.82,    0.00 /
      DATA B(78547), B(78548), B(78549) /    -6.25,  -13.88,    0.00 /
      DATA B(78850), B(78851), B(78852) /    -6.25,  -13.93,    0.00 /
      DATA B(79153), B(79154), B(79155) /    -6.25,  -13.99,    0.00 /
      DATA B(79456), B(79457), B(79458) /    -6.25,  -14.05,    0.00 /
      DATA B(79759), B(79760), B(79761) /    -6.25,  -14.11,    0.00 /
      DATA B(80062), B(80063), B(80064) /    -6.25,  -14.17,    0.00 /
      DATA B(80365), B(80366), B(80367) /    -6.25,  -14.22,    0.00 /
      DATA B(80668), B(80669), B(80670) /    -6.25,  -14.28,    0.00 /
      DATA B(80971), B(80972), B(80973) /    -6.25,  -14.34,    0.00 /
      DATA B(81274), B(81275), B(81276) /    -6.25,  -14.39,    0.00 /
      DATA B(81577), B(81578), B(81579) /    -6.25,  -14.45,    0.00 /
      DATA B(81880), B(81881), B(81882) /    -6.25,  -14.51,    0.00 /
      DATA B(82183), B(82184), B(82185) /    -6.25,  -14.56,    0.00 /
      DATA B(82486), B(82487), B(82488) /    -6.25,  -14.62,    0.00 /
      DATA B(82789), B(82790), B(82791) /    -6.25,  -14.67,    0.00 /
      DATA B(83092), B(83093), B(83094) /    -6.25,  -14.73,    0.00 /
      DATA B(83395), B(83396), B(83397) /    -6.25,  -14.78,    0.00 /
      DATA B(83698), B(83699), B(83700) /    -6.25,  -14.84,    0.00 /
      DATA B(84001), B(84002), B(84003) /    -6.25,  -14.90,    0.00 /
      DATA B(84304), B(84305), B(84306) /    -6.25,  -14.95,    0.00 /
      DATA B(84607), B(84608), B(84609) /    -6.25,  -15.01,    0.00 /
      DATA B(84910), B(84911), B(84912) /    -6.25,  -15.06,    0.00 /
      DATA B(85213), B(85214), B(85215) /    -6.25,  -15.12,    0.00 /
      DATA B(85516), B(85517), B(85518) /    -6.25,  -15.17,    0.00 /
      DATA B(85819), B(85820), B(85821) /    -6.25,  -15.23,    0.00 /
      DATA B(86122), B(86123), B(86124) /    -6.24,  -15.28,    0.00 /
      DATA B(86425), B(86426), B(86427) /    -6.24,  -15.34,    0.00 /
      DATA B(86728), B(86729), B(86730) /    -6.24,  -15.39,    0.00 /
      DATA B(87031), B(87032), B(87033) /    -6.24,  -15.45,    0.00 /
      DATA B(87334), B(87335), B(87336) /    -6.24,  -15.50,    0.00 /
      DATA B(87637), B(87638), B(87639) /    -6.24,  -15.55,    0.00 /
      DATA B(87940), B(87941), B(87942) /    -6.24,  -15.61,    0.00 /
      DATA B(88243), B(88244), B(88245) /    -6.24,  -15.66,    0.00 /
      DATA B(88546), B(88547), B(88548) /    -6.24,  -15.71,    0.00 /
      DATA B(88849), B(88850), B(88851) /    -6.24,  -15.77,    0.00 /
      DATA B(89152), B(89153), B(89154) /    -6.24,  -15.82,    0.00 /
      DATA B(89455), B(89456), B(89457) /    -6.24,  -15.87,    0.00 /
      DATA B(89758), B(89759), B(89760) /    -6.24,  -15.92,    0.00 /
      DATA B(67945), B(67946), B(67947) /    -6.15,  -11.58,    0.00 /
      DATA B(68248), B(68249), B(68250) /    -6.15,  -11.65,    0.00 /
      DATA B(68551), B(68552), B(68553) /    -6.15,  -11.72,    0.00 /
      DATA B(68854), B(68855), B(68856) /    -6.15,  -11.79,    0.00 /
      DATA B(69157), B(69158), B(69159) /    -6.15,  -11.87,    0.00 /
      DATA B(69460), B(69461), B(69462) /    -6.15,  -11.94,    0.00 /
      DATA B(69763), B(69764), B(69765) /    -6.15,  -12.01,    0.00 /
      DATA B(70066), B(70067), B(70068) /    -6.15,  -12.08,    0.00 /
      DATA B(70369), B(70370), B(70371) /    -6.15,  -12.15,    0.00 /
      DATA B(70672), B(70673), B(70674) /    -6.15,  -12.22,    0.00 /
      DATA B(70975), B(70976), B(70977) /    -6.15,  -12.29,    0.00 /
      DATA B(71278), B(71279), B(71280) /    -6.15,  -12.36,    0.00 /
      DATA B(71581), B(71582), B(71583) /    -6.15,  -12.43,    0.00 /
      DATA B(71884), B(71885), B(71886) /    -6.15,  -12.50,    0.00 /
      DATA B(72187), B(72188), B(72189) /    -6.15,  -12.56,    0.00 /
      DATA B(72490), B(72491), B(72492) /    -6.15,  -12.63,    0.00 /
      DATA B(72793), B(72794), B(72795) /    -6.15,  -12.70,    0.00 /
      DATA B(73096), B(73097), B(73098) /    -6.15,  -12.77,    0.00 /
      DATA B(73399), B(73400), B(73401) /    -6.15,  -12.83,    0.00 /
      DATA B(73702), B(73703), B(73704) /    -6.15,  -12.90,    0.00 /
      DATA B(74005), B(74006), B(74007) /    -6.15,  -12.96,    0.00 /
      DATA B(74308), B(74309), B(74310) /    -6.15,  -13.03,    0.00 /
      DATA B(74611), B(74612), B(74613) /    -6.15,  -13.09,    0.00 /
      DATA B(74914), B(74915), B(74916) /    -6.16,  -13.16,    0.00 /
      DATA B(75217), B(75218), B(75219) /    -6.16,  -13.22,    0.00 /
      DATA B(75520), B(75521), B(75522) /    -6.16,  -13.28,    0.00 /
      DATA B(75823), B(75824), B(75825) /    -6.16,  -13.35,    0.00 /
      DATA B(76126), B(76127), B(76128) /    -6.16,  -13.41,    0.00 /
      DATA B(76429), B(76430), B(76431) /    -6.16,  -13.47,    0.00 /
      DATA B(76732), B(76733), B(76734) /    -6.16,  -13.53,    0.00 /
      DATA B(77035), B(77036), B(77037) /    -6.16,  -13.59,    0.00 /
      DATA B(77338), B(77339), B(77340) /    -6.16,  -13.65,    0.00 /
      DATA B(77641), B(77642), B(77643) /    -6.16,  -13.71,    0.00 /
      DATA B(77944), B(77945), B(77946) /    -6.16,  -13.77,    0.00 /
      DATA B(78247), B(78248), B(78249) /    -6.16,  -13.83,    0.00 /
      DATA B(78550), B(78551), B(78552) /    -6.16,  -13.89,    0.00 /
      DATA B(78853), B(78854), B(78855) /    -6.16,  -13.95,    0.00 /
      DATA B(79156), B(79157), B(79158) /    -6.16,  -14.01,    0.00 /
      DATA B(79459), B(79460), B(79461) /    -6.16,  -14.07,    0.00 /
      DATA B(79762), B(79763), B(79764) /    -6.16,  -14.12,    0.00 /
      DATA B(80065), B(80066), B(80067) /    -6.16,  -14.18,    0.00 /
      DATA B(80368), B(80369), B(80370) /    -6.16,  -14.24,    0.00 /
      DATA B(80671), B(80672), B(80673) /    -6.16,  -14.30,    0.00 /
      DATA B(80974), B(80975), B(80976) /    -6.16,  -14.35,    0.00 /
      DATA B(81277), B(81278), B(81279) /    -6.16,  -14.41,    0.00 /
      DATA B(81580), B(81581), B(81582) /    -6.16,  -14.47,    0.00 /
      DATA B(81883), B(81884), B(81885) /    -6.16,  -14.52,    0.00 /
      DATA B(82186), B(82187), B(82188) /    -6.16,  -14.58,    0.00 /
      DATA B(82489), B(82490), B(82491) /    -6.16,  -14.64,    0.00 /
      DATA B(82792), B(82793), B(82794) /    -6.16,  -14.69,    0.00 /
      DATA B(83095), B(83096), B(83097) /    -6.16,  -14.75,    0.00 /
      DATA B(83398), B(83399), B(83400) /    -6.16,  -14.80,    0.00 /
      DATA B(83701), B(83702), B(83703) /    -6.16,  -14.86,    0.00 /
      DATA B(84004), B(84005), B(84006) /    -6.16,  -14.92,    0.00 /
      DATA B(84307), B(84308), B(84309) /    -6.16,  -14.97,    0.00 /
      DATA B(84610), B(84611), B(84612) /    -6.16,  -15.03,    0.00 /
      DATA B(84913), B(84914), B(84915) /    -6.16,  -15.08,    0.00 /
      DATA B(85216), B(85217), B(85218) /    -6.16,  -15.14,    0.00 /
      DATA B(85519), B(85520), B(85521) /    -6.16,  -15.19,    0.00 /
      DATA B(85822), B(85823), B(85824) /    -6.16,  -15.25,    0.00 /
      DATA B(86125), B(86126), B(86127) /    -6.16,  -15.30,    0.00 /
      DATA B(86428), B(86429), B(86430) /    -6.16,  -15.36,    0.00 /
      DATA B(86731), B(86732), B(86733) /    -6.16,  -15.41,    0.00 /
      DATA B(87034), B(87035), B(87036) /    -6.16,  -15.47,    0.00 /
      DATA B(87337), B(87338), B(87339) /    -6.16,  -15.52,    0.00 /
      DATA B(87640), B(87641), B(87642) /    -6.16,  -15.58,    0.00 /
      DATA B(87943), B(87944), B(87945) /    -6.16,  -15.63,    0.00 /
      DATA B(88246), B(88247), B(88248) /    -6.16,  -15.68,    0.00 /
      DATA B(88549), B(88550), B(88551) /    -6.16,  -15.74,    0.00 /
      DATA B(88852), B(88853), B(88854) /    -6.16,  -15.79,    0.00 /
      DATA B(89155), B(89156), B(89157) /    -6.15,  -15.84,    0.00 /
      DATA B(89458), B(89459), B(89460) /    -6.15,  -15.89,    0.00 /
      DATA B(89761), B(89762), B(89763) /    -6.15,  -15.95,    0.00 /
      DATA B(67948), B(67949), B(67950) /    -6.07,  -11.59,    0.00 /
      DATA B(68251), B(68252), B(68253) /    -6.07,  -11.66,    0.00 /
      DATA B(68554), B(68555), B(68556) /    -6.07,  -11.73,    0.00 /
      DATA B(68857), B(68858), B(68859) /    -6.07,  -11.80,    0.00 /
      DATA B(69160), B(69161), B(69162) /    -6.07,  -11.88,    0.00 /
      DATA B(69463), B(69464), B(69465) /    -6.07,  -11.95,    0.00 /
      DATA B(69766), B(69767), B(69768) /    -6.07,  -12.02,    0.00 /
      DATA B(70069), B(70070), B(70071) /    -6.07,  -12.09,    0.00 /
      DATA B(70372), B(70373), B(70374) /    -6.07,  -12.16,    0.00 /
      DATA B(70675), B(70676), B(70677) /    -6.07,  -12.23,    0.00 /
      DATA B(70978), B(70979), B(70980) /    -6.07,  -12.30,    0.00 /
      DATA B(71281), B(71282), B(71283) /    -6.07,  -12.37,    0.00 /
      DATA B(71584), B(71585), B(71586) /    -6.07,  -12.44,    0.00 /
      DATA B(71887), B(71888), B(71889) /    -6.07,  -12.51,    0.00 /
      DATA B(72190), B(72191), B(72192) /    -6.07,  -12.57,    0.00 /
      DATA B(72493), B(72494), B(72495) /    -6.07,  -12.64,    0.00 /
      DATA B(72796), B(72797), B(72798) /    -6.07,  -12.71,    0.00 /
      DATA B(73099), B(73100), B(73101) /    -6.07,  -12.78,    0.00 /
      DATA B(73402), B(73403), B(73404) /    -6.07,  -12.84,    0.00 /
      DATA B(73705), B(73706), B(73707) /    -6.07,  -12.91,    0.00 /
      DATA B(74008), B(74009), B(74010) /    -6.07,  -12.97,    0.00 /
      DATA B(74311), B(74312), B(74313) /    -6.07,  -13.04,    0.00 /
      DATA B(74614), B(74615), B(74616) /    -6.07,  -13.10,    0.00 /
      DATA B(74917), B(74918), B(74919) /    -6.07,  -13.17,    0.00 /
      DATA B(75220), B(75221), B(75222) /    -6.07,  -13.23,    0.00 /
      DATA B(75523), B(75524), B(75525) /    -6.07,  -13.29,    0.00 /
      DATA B(75826), B(75827), B(75828) /    -6.07,  -13.36,    0.00 /
      DATA B(76129), B(76130), B(76131) /    -6.07,  -13.42,    0.00 /
      DATA B(76432), B(76433), B(76434) /    -6.07,  -13.48,    0.00 /
      DATA B(76735), B(76736), B(76737) /    -6.07,  -13.54,    0.00 /
      DATA B(77038), B(77039), B(77040) /    -6.07,  -13.60,    0.00 /
      DATA B(77341), B(77342), B(77343) /    -6.07,  -13.66,    0.00 /
      DATA B(77644), B(77645), B(77646) /    -6.08,  -13.72,    0.00 /
      DATA B(77947), B(77948), B(77949) /    -6.08,  -13.78,    0.00 /
      DATA B(78250), B(78251), B(78252) /    -6.08,  -13.84,    0.00 /
      DATA B(78553), B(78554), B(78555) /    -6.08,  -13.90,    0.00 /
      DATA B(78856), B(78857), B(78858) /    -6.08,  -13.96,    0.00 /
      DATA B(79159), B(79160), B(79161) /    -6.08,  -14.02,    0.00 /
      DATA B(79462), B(79463), B(79464) /    -6.08,  -14.08,    0.00 /
      DATA B(79765), B(79766), B(79767) /    -6.08,  -14.14,    0.00 /
      DATA B(80068), B(80069), B(80070) /    -6.08,  -14.20,    0.00 /
      DATA B(80371), B(80372), B(80373) /    -6.08,  -14.26,    0.00 /
      DATA B(80674), B(80675), B(80676) /    -6.08,  -14.31,    0.00 /
      DATA B(80977), B(80978), B(80979) /    -6.08,  -14.37,    0.00 /
      DATA B(81280), B(81281), B(81282) /    -6.08,  -14.43,    0.00 /
      DATA B(81583), B(81584), B(81585) /    -6.08,  -14.48,    0.00 /
      DATA B(81886), B(81887), B(81888) /    -6.08,  -14.54,    0.00 /
      DATA B(82189), B(82190), B(82191) /    -6.08,  -14.60,    0.00 /
      DATA B(82492), B(82493), B(82494) /    -6.08,  -14.65,    0.00 /
      DATA B(82795), B(82796), B(82797) /    -6.08,  -14.71,    0.00 /
      DATA B(83098), B(83099), B(83100) /    -6.08,  -14.77,    0.00 /
      DATA B(83401), B(83402), B(83403) /    -6.08,  -14.82,    0.00 /
      DATA B(83704), B(83705), B(83706) /    -6.08,  -14.88,    0.00 /
      DATA B(84007), B(84008), B(84009) /    -6.08,  -14.94,    0.00 /
      DATA B(84310), B(84311), B(84312) /    -6.08,  -14.99,    0.00 /
      DATA B(84613), B(84614), B(84615) /    -6.07,  -15.05,    0.00 /
      DATA B(84916), B(84917), B(84918) /    -6.07,  -15.10,    0.00 /
      DATA B(85219), B(85220), B(85221) /    -6.07,  -15.16,    0.00 /
      DATA B(85522), B(85523), B(85524) /    -6.07,  -15.21,    0.00 /
      DATA B(85825), B(85826), B(85827) /    -6.07,  -15.27,    0.00 /
      DATA B(86128), B(86129), B(86130) /    -6.07,  -15.32,    0.00 /
      DATA B(86431), B(86432), B(86433) /    -6.07,  -15.38,    0.00 /
      DATA B(86734), B(86735), B(86736) /    -6.07,  -15.43,    0.00 /
      DATA B(87037), B(87038), B(87039) /    -6.07,  -15.49,    0.00 /
      DATA B(87340), B(87341), B(87342) /    -6.07,  -15.54,    0.00 /
      DATA B(87643), B(87644), B(87645) /    -6.07,  -15.60,    0.00 /
      DATA B(87946), B(87947), B(87948) /    -6.07,  -15.65,    0.00 /
      DATA B(88249), B(88250), B(88251) /    -6.07,  -15.70,    0.00 /
      DATA B(88552), B(88553), B(88554) /    -6.07,  -15.76,    0.00 /
      DATA B(88855), B(88856), B(88857) /    -6.07,  -15.81,    0.00 /
      DATA B(89158), B(89159), B(89160) /    -6.07,  -15.86,    0.00 /
      DATA B(89461), B(89462), B(89463) /    -6.07,  -15.91,    0.00 /
      DATA B(89764), B(89765), B(89766) /    -6.07,  -15.97,    0.00 /
      DATA B(67951), B(67952), B(67953) /    -5.98,  -11.59,    0.00 /
      DATA B(68254), B(68255), B(68256) /    -5.98,  -11.67,    0.00 /
      DATA B(68557), B(68558), B(68559) /    -5.98,  -11.74,    0.00 /
      DATA B(68860), B(68861), B(68862) /    -5.98,  -11.81,    0.00 /
      DATA B(69163), B(69164), B(69165) /    -5.98,  -11.89,    0.00 /
      DATA B(69466), B(69467), B(69468) /    -5.98,  -11.96,    0.00 /
      DATA B(69769), B(69770), B(69771) /    -5.98,  -12.03,    0.00 /
      DATA B(70072), B(70073), B(70074) /    -5.98,  -12.10,    0.00 /
      DATA B(70375), B(70376), B(70377) /    -5.98,  -12.17,    0.00 /
      DATA B(70678), B(70679), B(70680) /    -5.98,  -12.24,    0.00 /
      DATA B(70981), B(70982), B(70983) /    -5.98,  -12.31,    0.00 /
      DATA B(71284), B(71285), B(71286) /    -5.98,  -12.38,    0.00 /
      DATA B(71587), B(71588), B(71589) /    -5.98,  -12.45,    0.00 /
      DATA B(71890), B(71891), B(71892) /    -5.98,  -12.52,    0.00 /
      DATA B(72193), B(72194), B(72195) /    -5.98,  -12.58,    0.00 /
      DATA B(72496), B(72497), B(72498) /    -5.98,  -12.65,    0.00 /
      DATA B(72799), B(72800), B(72801) /    -5.98,  -12.72,    0.00 /
      DATA B(73102), B(73103), B(73104) /    -5.98,  -12.79,    0.00 /
      DATA B(73405), B(73406), B(73407) /    -5.98,  -12.85,    0.00 /
      DATA B(73708), B(73709), B(73710) /    -5.98,  -12.92,    0.00 /
      DATA B(74011), B(74012), B(74013) /    -5.98,  -12.99,    0.00 /
      DATA B(74314), B(74315), B(74316) /    -5.98,  -13.05,    0.00 /
      DATA B(74617), B(74618), B(74619) /    -5.98,  -13.12,    0.00 /
      DATA B(74920), B(74921), B(74922) /    -5.99,  -13.18,    0.00 /
      DATA B(75223), B(75224), B(75225) /    -5.99,  -13.24,    0.00 /
      DATA B(75526), B(75527), B(75528) /    -5.99,  -13.31,    0.00 /
      DATA B(75829), B(75830), B(75831) /    -5.99,  -13.37,    0.00 /
      DATA B(76132), B(76133), B(76134) /    -5.99,  -13.43,    0.00 /
      DATA B(76435), B(76436), B(76437) /    -5.99,  -13.49,    0.00 /
      DATA B(76738), B(76739), B(76740) /    -5.99,  -13.55,    0.00 /
      DATA B(77041), B(77042), B(77043) /    -5.99,  -13.62,    0.00 /
      DATA B(77344), B(77345), B(77346) /    -5.99,  -13.68,    0.00 /
      DATA B(77647), B(77648), B(77649) /    -5.99,  -13.74,    0.00 /
      DATA B(77950), B(77951), B(77952) /    -5.99,  -13.80,    0.00 /
      DATA B(78253), B(78254), B(78255) /    -5.99,  -13.86,    0.00 /
      DATA B(78556), B(78557), B(78558) /    -5.99,  -13.92,    0.00 /
      DATA B(78859), B(78860), B(78861) /    -5.99,  -13.98,    0.00 /
      DATA B(79162), B(79163), B(79164) /    -5.99,  -14.04,    0.00 /
      DATA B(79465), B(79466), B(79467) /    -5.99,  -14.10,    0.00 /
      DATA B(79768), B(79769), B(79770) /    -5.99,  -14.16,    0.00 /
      DATA B(80071), B(80072), B(80073) /    -5.99,  -14.21,    0.00 /
      DATA B(80374), B(80375), B(80376) /    -5.99,  -14.27,    0.00 /
      DATA B(80677), B(80678), B(80679) /    -5.99,  -14.33,    0.00 /
      DATA B(80980), B(80981), B(80982) /    -5.99,  -14.39,    0.00 /
      DATA B(81283), B(81284), B(81285) /    -5.99,  -14.45,    0.00 /
      DATA B(81586), B(81587), B(81588) /    -5.99,  -14.50,    0.00 /
      DATA B(81889), B(81890), B(81891) /    -5.99,  -14.56,    0.00 /
      DATA B(82192), B(82193), B(82194) /    -5.99,  -14.62,    0.00 /
      DATA B(82495), B(82496), B(82497) /    -5.99,  -14.67,    0.00 /
      DATA B(82798), B(82799), B(82800) /    -5.99,  -14.73,    0.00 /
      DATA B(83101), B(83102), B(83103) /    -5.99,  -14.79,    0.00 /
      DATA B(83404), B(83405), B(83406) /    -5.99,  -14.84,    0.00 /
      DATA B(83707), B(83708), B(83709) /    -5.99,  -14.90,    0.00 /
      DATA B(84010), B(84011), B(84012) /    -5.99,  -14.95,    0.00 /
      DATA B(84313), B(84314), B(84315) /    -5.99,  -15.01,    0.00 /
      DATA B(84616), B(84617), B(84618) /    -5.99,  -15.07,    0.00 /
      DATA B(84919), B(84920), B(84921) /    -5.99,  -15.12,    0.00 /
      DATA B(85222), B(85223), B(85224) /    -5.99,  -15.18,    0.00 /
      DATA B(85525), B(85526), B(85527) /    -5.99,  -15.23,    0.00 /
      DATA B(85828), B(85829), B(85830) /    -5.99,  -15.29,    0.00 /
      DATA B(86131), B(86132), B(86133) /    -5.99,  -15.34,    0.00 /
      DATA B(86434), B(86435), B(86436) /    -5.99,  -15.40,    0.00 /
      DATA B(86737), B(86738), B(86739) /    -5.98,  -15.45,    0.00 /
      DATA B(87040), B(87041), B(87042) /    -5.98,  -15.51,    0.00 /
      DATA B(87343), B(87344), B(87345) /    -5.98,  -15.56,    0.00 /
      DATA B(87646), B(87647), B(87648) /    -5.98,  -15.62,    0.00 /
      DATA B(87949), B(87950), B(87951) /    -5.98,  -15.67,    0.00 /
      DATA B(88252), B(88253), B(88254) /    -5.98,  -15.72,    0.00 /
      DATA B(88555), B(88556), B(88557) /    -5.98,  -15.78,    0.00 /
      DATA B(88858), B(88859), B(88860) /    -5.98,  -15.83,    0.00 /
      DATA B(89161), B(89162), B(89163) /    -5.98,  -15.88,    0.00 /
      DATA B(89464), B(89465), B(89466) /    -5.98,  -15.94,    0.00 /
      DATA B(89767), B(89768), B(89769) /    -5.98,  -15.99,    0.00 /
      DATA B(67954), B(67955), B(67956) /    -5.89,  -11.60,    0.00 /
      DATA B(68257), B(68258), B(68259) /    -5.89,  -11.68,    0.00 /
      DATA B(68560), B(68561), B(68562) /    -5.89,  -11.75,    0.00 /
      DATA B(68863), B(68864), B(68865) /    -5.89,  -11.82,    0.00 /
      DATA B(69166), B(69167), B(69168) /    -5.89,  -11.90,    0.00 /
      DATA B(69469), B(69470), B(69471) /    -5.89,  -11.97,    0.00 /
      DATA B(69772), B(69773), B(69774) /    -5.89,  -12.04,    0.00 /
      DATA B(70075), B(70076), B(70077) /    -5.89,  -12.11,    0.00 /
      DATA B(70378), B(70379), B(70380) /    -5.89,  -12.18,    0.00 /
      DATA B(70681), B(70682), B(70683) /    -5.89,  -12.25,    0.00 /
      DATA B(70984), B(70985), B(70986) /    -5.89,  -12.32,    0.00 /
      DATA B(71287), B(71288), B(71289) /    -5.89,  -12.39,    0.00 /
      DATA B(71590), B(71591), B(71592) /    -5.90,  -12.46,    0.00 /
      DATA B(71893), B(71894), B(71895) /    -5.90,  -12.53,    0.00 /
      DATA B(72196), B(72197), B(72198) /    -5.90,  -12.59,    0.00 /
      DATA B(72499), B(72500), B(72501) /    -5.90,  -12.66,    0.00 /
      DATA B(72802), B(72803), B(72804) /    -5.90,  -12.73,    0.00 /
      DATA B(73105), B(73106), B(73107) /    -5.90,  -12.80,    0.00 /
      DATA B(73408), B(73409), B(73410) /    -5.90,  -12.86,    0.00 /
      DATA B(73711), B(73712), B(73713) /    -5.90,  -12.93,    0.00 /
      DATA B(74014), B(74015), B(74016) /    -5.90,  -13.00,    0.00 /
      DATA B(74317), B(74318), B(74319) /    -5.90,  -13.06,    0.00 /
      DATA B(74620), B(74621), B(74622) /    -5.90,  -13.13,    0.00 /
      DATA B(74923), B(74924), B(74925) /    -5.90,  -13.19,    0.00 /
      DATA B(75226), B(75227), B(75228) /    -5.90,  -13.25,    0.00 /
      DATA B(75529), B(75530), B(75531) /    -5.90,  -13.32,    0.00 /
      DATA B(75832), B(75833), B(75834) /    -5.90,  -13.38,    0.00 /
      DATA B(76135), B(76136), B(76137) /    -5.90,  -13.44,    0.00 /
      DATA B(76438), B(76439), B(76440) /    -5.90,  -13.51,    0.00 /
      DATA B(76741), B(76742), B(76743) /    -5.90,  -13.57,    0.00 /
      DATA B(77044), B(77045), B(77046) /    -5.90,  -13.63,    0.00 /
      DATA B(77347), B(77348), B(77349) /    -5.90,  -13.69,    0.00 /
      DATA B(77650), B(77651), B(77652) /    -5.90,  -13.75,    0.00 /
      DATA B(77953), B(77954), B(77955) /    -5.90,  -13.81,    0.00 /
      DATA B(78256), B(78257), B(78258) /    -5.90,  -13.87,    0.00 /
      DATA B(78559), B(78560), B(78561) /    -5.90,  -13.93,    0.00 /
      DATA B(78862), B(78863), B(78864) /    -5.90,  -13.99,    0.00 /
      DATA B(79165), B(79166), B(79167) /    -5.90,  -14.05,    0.00 /
      DATA B(79468), B(79469), B(79470) /    -5.91,  -14.11,    0.00 /
      DATA B(79771), B(79772), B(79773) /    -5.91,  -14.17,    0.00 /
      DATA B(80074), B(80075), B(80076) /    -5.91,  -14.23,    0.00 /
      DATA B(80377), B(80378), B(80379) /    -5.91,  -14.29,    0.00 /
      DATA B(80680), B(80681), B(80682) /    -5.91,  -14.35,    0.00 /
      DATA B(80983), B(80984), B(80985) /    -5.91,  -14.40,    0.00 /
      DATA B(81286), B(81287), B(81288) /    -5.91,  -14.46,    0.00 /
      DATA B(81589), B(81590), B(81591) /    -5.91,  -14.52,    0.00 /
      DATA B(81892), B(81893), B(81894) /    -5.90,  -14.58,    0.00 /
      DATA B(82195), B(82196), B(82197) /    -5.90,  -14.63,    0.00 /
      DATA B(82498), B(82499), B(82500) /    -5.90,  -14.69,    0.00 /
      DATA B(82801), B(82802), B(82803) /    -5.90,  -14.75,    0.00 /
      DATA B(83104), B(83105), B(83106) /    -5.90,  -14.80,    0.00 /
      DATA B(83407), B(83408), B(83409) /    -5.90,  -14.86,    0.00 /
      DATA B(83710), B(83711), B(83712) /    -5.90,  -14.92,    0.00 /
      DATA B(84013), B(84014), B(84015) /    -5.90,  -14.97,    0.00 /
      DATA B(84316), B(84317), B(84318) /    -5.90,  -15.03,    0.00 /
      DATA B(84619), B(84620), B(84621) /    -5.90,  -15.09,    0.00 /
      DATA B(84922), B(84923), B(84924) /    -5.90,  -15.14,    0.00 /
      DATA B(85225), B(85226), B(85227) /    -5.90,  -15.20,    0.00 /
      DATA B(85528), B(85529), B(85530) /    -5.90,  -15.25,    0.00 /
      DATA B(85831), B(85832), B(85833) /    -5.90,  -15.31,    0.00 /
      DATA B(86134), B(86135), B(86136) /    -5.90,  -15.36,    0.00 /
      DATA B(86437), B(86438), B(86439) /    -5.90,  -15.42,    0.00 /
      DATA B(86740), B(86741), B(86742) /    -5.90,  -15.47,    0.00 /
      DATA B(87043), B(87044), B(87045) /    -5.90,  -15.53,    0.00 /
      DATA B(87346), B(87347), B(87348) /    -5.90,  -15.58,    0.00 /
      DATA B(87649), B(87650), B(87651) /    -5.90,  -15.64,    0.00 /
      DATA B(87952), B(87953), B(87954) /    -5.90,  -15.69,    0.00 /
      DATA B(88255), B(88256), B(88257) /    -5.90,  -15.74,    0.00 /
      DATA B(88558), B(88559), B(88560) /    -5.90,  -15.80,    0.00 /
      DATA B(88861), B(88862), B(88863) /    -5.90,  -15.85,    0.00 /
      DATA B(89164), B(89165), B(89166) /    -5.89,  -15.90,    0.00 /
      DATA B(89467), B(89468), B(89469) /    -5.89,  -15.96,    0.00 /
      DATA B(89770), B(89771), B(89772) /    -5.89,  -16.01,    0.00 /
      DATA B(67957), B(67958), B(67959) /    -5.81,  -11.61,    0.00 /
      DATA B(68260), B(68261), B(68262) /    -5.81,  -11.69,    0.00 /
      DATA B(68563), B(68564), B(68565) /    -5.81,  -11.76,    0.00 /
      DATA B(68866), B(68867), B(68868) /    -5.81,  -11.83,    0.00 /
      DATA B(69169), B(69170), B(69171) /    -5.81,  -11.91,    0.00 /
      DATA B(69472), B(69473), B(69474) /    -5.81,  -11.98,    0.00 /
      DATA B(69775), B(69776), B(69777) /    -5.81,  -12.05,    0.00 /
      DATA B(70078), B(70079), B(70080) /    -5.81,  -12.12,    0.00 /
      DATA B(70381), B(70382), B(70383) /    -5.81,  -12.19,    0.00 /
      DATA B(70684), B(70685), B(70686) /    -5.81,  -12.26,    0.00 /
      DATA B(70987), B(70988), B(70989) /    -5.81,  -12.33,    0.00 /
      DATA B(71290), B(71291), B(71292) /    -5.81,  -12.40,    0.00 /
      DATA B(71593), B(71594), B(71595) /    -5.81,  -12.47,    0.00 /
      DATA B(71896), B(71897), B(71898) /    -5.81,  -12.54,    0.00 /
      DATA B(72199), B(72200), B(72201) /    -5.81,  -12.61,    0.00 /
      DATA B(72502), B(72503), B(72504) /    -5.81,  -12.67,    0.00 /
      DATA B(72805), B(72806), B(72807) /    -5.81,  -12.74,    0.00 /
      DATA B(73108), B(73109), B(73110) /    -5.81,  -12.81,    0.00 /
      DATA B(73411), B(73412), B(73413) /    -5.81,  -12.87,    0.00 /
      DATA B(73714), B(73715), B(73716) /    -5.81,  -12.94,    0.00 /
      DATA B(74017), B(74018), B(74019) /    -5.81,  -13.01,    0.00 /
      DATA B(74320), B(74321), B(74322) /    -5.81,  -13.07,    0.00 /
      DATA B(74623), B(74624), B(74625) /    -5.81,  -13.14,    0.00 /
      DATA B(74926), B(74927), B(74928) /    -5.81,  -13.20,    0.00 /
      DATA B(75229), B(75230), B(75231) /    -5.81,  -13.27,    0.00 /
      DATA B(75532), B(75533), B(75534) /    -5.81,  -13.33,    0.00 /
      DATA B(75835), B(75836), B(75837) /    -5.82,  -13.39,    0.00 /
      DATA B(76138), B(76139), B(76140) /    -5.82,  -13.46,    0.00 /
      DATA B(76441), B(76442), B(76443) /    -5.82,  -13.52,    0.00 /
      DATA B(76744), B(76745), B(76746) /    -5.82,  -13.58,    0.00 /
      DATA B(77047), B(77048), B(77049) /    -5.82,  -13.64,    0.00 /
      DATA B(77350), B(77351), B(77352) /    -5.82,  -13.70,    0.00 /
      DATA B(77653), B(77654), B(77655) /    -5.82,  -13.77,    0.00 /
      DATA B(77956), B(77957), B(77958) /    -5.82,  -13.83,    0.00 /
      DATA B(78259), B(78260), B(78261) /    -5.82,  -13.89,    0.00 /
      DATA B(78562), B(78563), B(78564) /    -5.82,  -13.95,    0.00 /
      DATA B(78865), B(78866), B(78867) /    -5.82,  -14.01,    0.00 /
      DATA B(79168), B(79169), B(79170) /    -5.82,  -14.07,    0.00 /
      DATA B(79471), B(79472), B(79473) /    -5.82,  -14.13,    0.00 /
      DATA B(79774), B(79775), B(79776) /    -5.82,  -14.19,    0.00 /
      DATA B(80077), B(80078), B(80079) /    -5.82,  -14.25,    0.00 /
      DATA B(80380), B(80381), B(80382) /    -5.82,  -14.30,    0.00 /
      DATA B(80683), B(80684), B(80685) /    -5.82,  -14.36,    0.00 /
      DATA B(80986), B(80987), B(80988) /    -5.82,  -14.42,    0.00 /
      DATA B(81289), B(81290), B(81291) /    -5.82,  -14.48,    0.00 /
      DATA B(81592), B(81593), B(81594) /    -5.82,  -14.54,    0.00 /
      DATA B(81895), B(81896), B(81897) /    -5.82,  -14.59,    0.00 /
      DATA B(82198), B(82199), B(82200) /    -5.82,  -14.65,    0.00 /
      DATA B(82501), B(82502), B(82503) /    -5.82,  -14.71,    0.00 /
      DATA B(82804), B(82805), B(82806) /    -5.82,  -14.77,    0.00 /
      DATA B(83107), B(83108), B(83109) /    -5.82,  -14.82,    0.00 /
      DATA B(83410), B(83411), B(83412) /    -5.82,  -14.88,    0.00 /
      DATA B(83713), B(83714), B(83715) /    -5.82,  -14.94,    0.00 /
      DATA B(84016), B(84017), B(84018) /    -5.82,  -14.99,    0.00 /
      DATA B(84319), B(84320), B(84321) /    -5.81,  -15.05,    0.00 /
      DATA B(84622), B(84623), B(84624) /    -5.81,  -15.10,    0.00 /
      DATA B(84925), B(84926), B(84927) /    -5.81,  -15.16,    0.00 /
      DATA B(85228), B(85229), B(85230) /    -5.81,  -15.22,    0.00 /
      DATA B(85531), B(85532), B(85533) /    -5.81,  -15.27,    0.00 /
      DATA B(85834), B(85835), B(85836) /    -5.81,  -15.33,    0.00 /
      DATA B(86137), B(86138), B(86139) /    -5.81,  -15.38,    0.00 /
      DATA B(86440), B(86441), B(86442) /    -5.81,  -15.44,    0.00 /
      DATA B(86743), B(86744), B(86745) /    -5.81,  -15.49,    0.00 /
      DATA B(87046), B(87047), B(87048) /    -5.81,  -15.55,    0.00 /
      DATA B(87349), B(87350), B(87351) /    -5.81,  -15.60,    0.00 /
      DATA B(87652), B(87653), B(87654) /    -5.81,  -15.66,    0.00 /
      DATA B(87955), B(87956), B(87957) /    -5.81,  -15.71,    0.00 /
      DATA B(88258), B(88259), B(88260) /    -5.81,  -15.76,    0.00 /
      DATA B(88561), B(88562), B(88563) /    -5.81,  -15.82,    0.00 /
      DATA B(88864), B(88865), B(88866) /    -5.81,  -15.87,    0.00 /
      DATA B(89167), B(89168), B(89169) /    -5.81,  -15.92,    0.00 /
      DATA B(89470), B(89471), B(89472) /    -5.81,  -15.98,    0.00 /
      DATA B(89773), B(89774), B(89775) /    -5.81,  -16.03,    0.00 /
      DATA B(67960), B(67961), B(67962) /    -5.72,  -11.62,    0.00 /
      DATA B(68263), B(68264), B(68265) /    -5.72,  -11.70,    0.00 /
      DATA B(68566), B(68567), B(68568) /    -5.72,  -11.77,    0.00 /
      DATA B(68869), B(68870), B(68871) /    -5.72,  -11.84,    0.00 /
      DATA B(69172), B(69173), B(69174) /    -5.72,  -11.92,    0.00 /
      DATA B(69475), B(69476), B(69477) /    -5.72,  -11.99,    0.00 /
      DATA B(69778), B(69779), B(69780) /    -5.72,  -12.06,    0.00 /
      DATA B(70081), B(70082), B(70083) /    -5.72,  -12.13,    0.00 /
      DATA B(70384), B(70385), B(70386) /    -5.72,  -12.20,    0.00 /
      DATA B(70687), B(70688), B(70689) /    -5.72,  -12.27,    0.00 /
      DATA B(70990), B(70991), B(70992) /    -5.72,  -12.34,    0.00 /
      DATA B(71293), B(71294), B(71295) /    -5.72,  -12.41,    0.00 /
      DATA B(71596), B(71597), B(71598) /    -5.72,  -12.48,    0.00 /
      DATA B(71899), B(71900), B(71901) /    -5.72,  -12.55,    0.00 /
      DATA B(72202), B(72203), B(72204) /    -5.72,  -12.62,    0.00 /
      DATA B(72505), B(72506), B(72507) /    -5.72,  -12.68,    0.00 /
      DATA B(72808), B(72809), B(72810) /    -5.72,  -12.75,    0.00 /
      DATA B(73111), B(73112), B(73113) /    -5.72,  -12.82,    0.00 /
      DATA B(73414), B(73415), B(73416) /    -5.72,  -12.89,    0.00 /
      DATA B(73717), B(73718), B(73719) /    -5.73,  -12.95,    0.00 /
      DATA B(74020), B(74021), B(74022) /    -5.73,  -13.02,    0.00 /
      DATA B(74323), B(74324), B(74325) /    -5.73,  -13.08,    0.00 /
      DATA B(74626), B(74627), B(74628) /    -5.73,  -13.15,    0.00 /
      DATA B(74929), B(74930), B(74931) /    -5.73,  -13.21,    0.00 /
      DATA B(75232), B(75233), B(75234) /    -5.73,  -13.28,    0.00 /
      DATA B(75535), B(75536), B(75537) /    -5.73,  -13.34,    0.00 /
      DATA B(75838), B(75839), B(75840) /    -5.73,  -13.41,    0.00 /
      DATA B(76141), B(76142), B(76143) /    -5.73,  -13.47,    0.00 /
      DATA B(76444), B(76445), B(76446) /    -5.73,  -13.53,    0.00 /
      DATA B(76747), B(76748), B(76749) /    -5.73,  -13.59,    0.00 /
      DATA B(77050), B(77051), B(77052) /    -5.73,  -13.66,    0.00 /
      DATA B(77353), B(77354), B(77355) /    -5.73,  -13.72,    0.00 /
      DATA B(77656), B(77657), B(77658) /    -5.73,  -13.78,    0.00 /
      DATA B(77959), B(77960), B(77961) /    -5.73,  -13.84,    0.00 /
      DATA B(78262), B(78263), B(78264) /    -5.73,  -13.90,    0.00 /
      DATA B(78565), B(78566), B(78567) /    -5.73,  -13.96,    0.00 /
      DATA B(78868), B(78869), B(78870) /    -5.73,  -14.02,    0.00 /
      DATA B(79171), B(79172), B(79173) /    -5.73,  -14.08,    0.00 /
      DATA B(79474), B(79475), B(79476) /    -5.73,  -14.14,    0.00 /
      DATA B(79777), B(79778), B(79779) /    -5.73,  -14.20,    0.00 /
      DATA B(80080), B(80081), B(80082) /    -5.73,  -14.26,    0.00 /
      DATA B(80383), B(80384), B(80385) /    -5.73,  -14.32,    0.00 /
      DATA B(80686), B(80687), B(80688) /    -5.73,  -14.38,    0.00 /
      DATA B(80989), B(80990), B(80991) /    -5.73,  -14.44,    0.00 /
      DATA B(81292), B(81293), B(81294) /    -5.73,  -14.50,    0.00 /
      DATA B(81595), B(81596), B(81597) /    -5.73,  -14.55,    0.00 /
      DATA B(81898), B(81899), B(81900) /    -5.73,  -14.61,    0.00 /
      DATA B(82201), B(82202), B(82203) /    -5.73,  -14.67,    0.00 /
      DATA B(82504), B(82505), B(82506) /    -5.73,  -14.73,    0.00 /
      DATA B(82807), B(82808), B(82809) /    -5.73,  -14.78,    0.00 /
      DATA B(83110), B(83111), B(83112) /    -5.73,  -14.84,    0.00 /
      DATA B(83413), B(83414), B(83415) /    -5.73,  -14.90,    0.00 /
      DATA B(83716), B(83717), B(83718) /    -5.73,  -14.95,    0.00 /
      DATA B(84019), B(84020), B(84021) /    -5.73,  -15.01,    0.00 /
      DATA B(84322), B(84323), B(84324) /    -5.73,  -15.07,    0.00 /
      DATA B(84625), B(84626), B(84627) /    -5.73,  -15.12,    0.00 /
      DATA B(84928), B(84929), B(84930) /    -5.73,  -15.18,    0.00 /
      DATA B(85231), B(85232), B(85233) /    -5.73,  -15.23,    0.00 /
      DATA B(85534), B(85535), B(85536) /    -5.73,  -15.29,    0.00 /
      DATA B(85837), B(85838), B(85839) /    -5.73,  -15.35,    0.00 /
      DATA B(86140), B(86141), B(86142) /    -5.73,  -15.40,    0.00 /
      DATA B(86443), B(86444), B(86445) /    -5.72,  -15.46,    0.00 /
      DATA B(86746), B(86747), B(86748) /    -5.72,  -15.51,    0.00 /
      DATA B(87049), B(87050), B(87051) /    -5.72,  -15.57,    0.00 /
      DATA B(87352), B(87353), B(87354) /    -5.72,  -15.62,    0.00 /
      DATA B(87655), B(87656), B(87657) /    -5.72,  -15.68,    0.00 /
      DATA B(87958), B(87959), B(87960) /    -5.72,  -15.73,    0.00 /
      DATA B(88261), B(88262), B(88263) /    -5.72,  -15.78,    0.00 /
      DATA B(88564), B(88565), B(88566) /    -5.72,  -15.84,    0.00 /
      DATA B(88867), B(88868), B(88869) /    -5.72,  -15.89,    0.00 /
      DATA B(89170), B(89171), B(89172) /    -5.72,  -15.94,    0.00 /
      DATA B(89473), B(89474), B(89475) /    -5.72,  -16.00,    0.00 /
      DATA B(89776), B(89777), B(89778) /    -5.72,  -16.05,    0.00 /
      DATA B(67963), B(67964), B(67965) /    -5.64,  -11.63,    0.00 /
      DATA B(68266), B(68267), B(68268) /    -5.64,  -11.71,    0.00 /
      DATA B(68569), B(68570), B(68571) /    -5.64,  -11.78,    0.00 /
      DATA B(68872), B(68873), B(68874) /    -5.64,  -11.85,    0.00 /
      DATA B(69175), B(69176), B(69177) /    -5.64,  -11.93,    0.00 /
      DATA B(69478), B(69479), B(69480) /    -5.64,  -12.00,    0.00 /
      DATA B(69781), B(69782), B(69783) /    -5.64,  -12.07,    0.00 /
      DATA B(70084), B(70085), B(70086) /    -5.64,  -12.14,    0.00 /
      DATA B(70387), B(70388), B(70389) /    -5.64,  -12.21,    0.00 /
      DATA B(70690), B(70691), B(70692) /    -5.64,  -12.28,    0.00 /
      DATA B(70993), B(70994), B(70995) /    -5.64,  -12.35,    0.00 /
      DATA B(71296), B(71297), B(71298) /    -5.64,  -12.42,    0.00 /
      DATA B(71599), B(71600), B(71601) /    -5.64,  -12.49,    0.00 /
      DATA B(71902), B(71903), B(71904) /    -5.64,  -12.56,    0.00 /
      DATA B(72205), B(72206), B(72207) /    -5.64,  -12.63,    0.00 /
      DATA B(72508), B(72509), B(72510) /    -5.64,  -12.69,    0.00 /
      DATA B(72811), B(72812), B(72813) /    -5.64,  -12.76,    0.00 /
      DATA B(73114), B(73115), B(73116) /    -5.64,  -12.83,    0.00 /
      DATA B(73417), B(73418), B(73419) /    -5.64,  -12.90,    0.00 /
      DATA B(73720), B(73721), B(73722) /    -5.64,  -12.96,    0.00 /
      DATA B(74023), B(74024), B(74025) /    -5.64,  -13.03,    0.00 /
      DATA B(74326), B(74327), B(74328) /    -5.64,  -13.10,    0.00 /
      DATA B(74629), B(74630), B(74631) /    -5.64,  -13.16,    0.00 /
      DATA B(74932), B(74933), B(74934) /    -5.64,  -13.23,    0.00 /
      DATA B(75235), B(75236), B(75237) /    -5.64,  -13.29,    0.00 /
      DATA B(75538), B(75539), B(75540) /    -5.64,  -13.35,    0.00 /
      DATA B(75841), B(75842), B(75843) /    -5.64,  -13.42,    0.00 /
      DATA B(76144), B(76145), B(76146) /    -5.64,  -13.48,    0.00 /
      DATA B(76447), B(76448), B(76449) /    -5.64,  -13.54,    0.00 /
      DATA B(76750), B(76751), B(76752) /    -5.64,  -13.61,    0.00 /
      DATA B(77053), B(77054), B(77055) /    -5.64,  -13.67,    0.00 /
      DATA B(77356), B(77357), B(77358) /    -5.64,  -13.73,    0.00 /
      DATA B(77659), B(77660), B(77661) /    -5.64,  -13.79,    0.00 /
      DATA B(77962), B(77963), B(77964) /    -5.64,  -13.85,    0.00 /
      DATA B(78265), B(78266), B(78267) /    -5.64,  -13.92,    0.00 /
      DATA B(78568), B(78569), B(78570) /    -5.64,  -13.98,    0.00 /
      DATA B(78871), B(78872), B(78873) /    -5.64,  -14.04,    0.00 /
      DATA B(79174), B(79175), B(79176) /    -5.64,  -14.10,    0.00 /
      DATA B(79477), B(79478), B(79479) /    -5.64,  -14.16,    0.00 /
      DATA B(79780), B(79781), B(79782) /    -5.64,  -14.22,    0.00 /
      DATA B(80083), B(80084), B(80085) /    -5.64,  -14.28,    0.00 /
      DATA B(80386), B(80387), B(80388) /    -5.64,  -14.34,    0.00 /
      DATA B(80689), B(80690), B(80691) /    -5.64,  -14.39,    0.00 /
      DATA B(80992), B(80993), B(80994) /    -5.64,  -14.45,    0.00 /
      DATA B(81295), B(81296), B(81297) /    -5.64,  -14.51,    0.00 /
      DATA B(81598), B(81599), B(81600) /    -5.64,  -14.57,    0.00 /
      DATA B(81901), B(81902), B(81903) /    -5.64,  -14.63,    0.00 /
      DATA B(82204), B(82205), B(82206) /    -5.64,  -14.69,    0.00 /
      DATA B(82507), B(82508), B(82509) /    -5.64,  -14.74,    0.00 /
      DATA B(82810), B(82811), B(82812) /    -5.64,  -14.80,    0.00 /
      DATA B(83113), B(83114), B(83115) /    -5.64,  -14.86,    0.00 /
      DATA B(83416), B(83417), B(83418) /    -5.64,  -14.91,    0.00 /
      DATA B(83719), B(83720), B(83721) /    -5.64,  -14.97,    0.00 /
      DATA B(84022), B(84023), B(84024) /    -5.64,  -15.03,    0.00 /
      DATA B(84325), B(84326), B(84327) /    -5.64,  -15.08,    0.00 /
      DATA B(84628), B(84629), B(84630) /    -5.64,  -15.14,    0.00 /
      DATA B(84931), B(84932), B(84933) /    -5.64,  -15.20,    0.00 /
      DATA B(85234), B(85235), B(85236) /    -5.64,  -15.25,    0.00 /
      DATA B(85537), B(85538), B(85539) /    -5.64,  -15.31,    0.00 /
      DATA B(85840), B(85841), B(85842) /    -5.64,  -15.36,    0.00 /
      DATA B(86143), B(86144), B(86145) /    -5.64,  -15.42,    0.00 /
      DATA B(86446), B(86447), B(86448) /    -5.64,  -15.48,    0.00 /
      DATA B(86749), B(86750), B(86751) /    -5.64,  -15.53,    0.00 /
      DATA B(87052), B(87053), B(87054) /    -5.64,  -15.59,    0.00 /
      DATA B(87355), B(87356), B(87357) /    -5.64,  -15.64,    0.00 /
      DATA B(87658), B(87659), B(87660) /    -5.64,  -15.69,    0.00 /
      DATA B(87961), B(87962), B(87963) /    -5.64,  -15.75,    0.00 /
      DATA B(88264), B(88265), B(88266) /    -5.63,  -15.80,    0.00 /
      DATA B(88567), B(88568), B(88569) /    -5.63,  -15.86,    0.00 /
      DATA B(88870), B(88871), B(88872) /    -5.63,  -15.91,    0.00 /
      DATA B(89173), B(89174), B(89175) /    -5.63,  -15.96,    0.00 /
      DATA B(89476), B(89477), B(89478) /    -5.63,  -16.01,    0.00 /
      DATA B(89779), B(89780), B(89781) /    -5.63,  -16.07,    0.00 /
      DATA B(67966), B(67967), B(67968) /    -5.55,  -11.64,    0.00 /
      DATA B(68269), B(68270), B(68271) /    -5.55,  -11.72,    0.00 /
      DATA B(68572), B(68573), B(68574) /    -5.55,  -11.79,    0.00 /
      DATA B(68875), B(68876), B(68877) /    -5.55,  -11.86,    0.00 /
      DATA B(69178), B(69179), B(69180) /    -5.55,  -11.94,    0.00 /
      DATA B(69481), B(69482), B(69483) /    -5.55,  -12.01,    0.00 /
      DATA B(69784), B(69785), B(69786) /    -5.55,  -12.08,    0.00 /
      DATA B(70087), B(70088), B(70089) /    -5.55,  -12.15,    0.00 /
      DATA B(70390), B(70391), B(70392) /    -5.55,  -12.22,    0.00 /
      DATA B(70693), B(70694), B(70695) /    -5.55,  -12.29,    0.00 /
      DATA B(70996), B(70997), B(70998) /    -5.55,  -12.36,    0.00 /
      DATA B(71299), B(71300), B(71301) /    -5.55,  -12.43,    0.00 /
      DATA B(71602), B(71603), B(71604) /    -5.55,  -12.50,    0.00 /
      DATA B(71905), B(71906), B(71907) /    -5.55,  -12.57,    0.00 /
      DATA B(72208), B(72209), B(72210) /    -5.55,  -12.64,    0.00 /
      DATA B(72511), B(72512), B(72513) /    -5.55,  -12.71,    0.00 /
      DATA B(72814), B(72815), B(72816) /    -5.55,  -12.77,    0.00 /
      DATA B(73117), B(73118), B(73119) /    -5.55,  -12.84,    0.00 /
      DATA B(73420), B(73421), B(73422) /    -5.55,  -12.91,    0.00 /
      DATA B(73723), B(73724), B(73725) /    -5.55,  -12.97,    0.00 /
      DATA B(74026), B(74027), B(74028) /    -5.55,  -13.04,    0.00 /
      DATA B(74329), B(74330), B(74331) /    -5.55,  -13.11,    0.00 /
      DATA B(74632), B(74633), B(74634) /    -5.55,  -13.17,    0.00 /
      DATA B(74935), B(74936), B(74937) /    -5.55,  -13.24,    0.00 /
      DATA B(75238), B(75239), B(75240) /    -5.55,  -13.30,    0.00 /
      DATA B(75541), B(75542), B(75543) /    -5.55,  -13.37,    0.00 /
      DATA B(75844), B(75845), B(75846) /    -5.55,  -13.43,    0.00 /
      DATA B(76147), B(76148), B(76149) /    -5.56,  -13.49,    0.00 /
      DATA B(76450), B(76451), B(76452) /    -5.56,  -13.56,    0.00 /
      DATA B(76753), B(76754), B(76755) /    -5.56,  -13.62,    0.00 /
      DATA B(77056), B(77057), B(77058) /    -5.56,  -13.68,    0.00 /
      DATA B(77359), B(77360), B(77361) /    -5.56,  -13.74,    0.00 /
      DATA B(77662), B(77663), B(77664) /    -5.56,  -13.81,    0.00 /
      DATA B(77965), B(77966), B(77967) /    -5.56,  -13.87,    0.00 /
      DATA B(78268), B(78269), B(78270) /    -5.56,  -13.93,    0.00 /
      DATA B(78571), B(78572), B(78573) /    -5.56,  -13.99,    0.00 /
      DATA B(78874), B(78875), B(78876) /    -5.56,  -14.05,    0.00 /
      DATA B(79177), B(79178), B(79179) /    -5.56,  -14.11,    0.00 /
      DATA B(79480), B(79481), B(79482) /    -5.56,  -14.17,    0.00 /
      DATA B(79783), B(79784), B(79785) /    -5.56,  -14.23,    0.00 /
      DATA B(80086), B(80087), B(80088) /    -5.56,  -14.29,    0.00 /
      DATA B(80389), B(80390), B(80391) /    -5.56,  -14.35,    0.00 /
      DATA B(80692), B(80693), B(80694) /    -5.56,  -14.41,    0.00 /
      DATA B(80995), B(80996), B(80997) /    -5.56,  -14.47,    0.00 /
      DATA B(81298), B(81299), B(81300) /    -5.56,  -14.53,    0.00 /
      DATA B(81601), B(81602), B(81603) /    -5.56,  -14.59,    0.00 /
      DATA B(81904), B(81905), B(81906) /    -5.56,  -14.64,    0.00 /
      DATA B(82207), B(82208), B(82209) /    -5.56,  -14.70,    0.00 /
      DATA B(82510), B(82511), B(82512) /    -5.56,  -14.76,    0.00 /
      DATA B(82813), B(82814), B(82815) /    -5.56,  -14.82,    0.00 /
      DATA B(83116), B(83117), B(83118) /    -5.56,  -14.88,    0.00 /
      DATA B(83419), B(83420), B(83421) /    -5.55,  -14.93,    0.00 /
      DATA B(83722), B(83723), B(83724) /    -5.55,  -14.99,    0.00 /
      DATA B(84025), B(84026), B(84027) /    -5.55,  -15.05,    0.00 /
      DATA B(84328), B(84329), B(84330) /    -5.55,  -15.10,    0.00 /
      DATA B(84631), B(84632), B(84633) /    -5.55,  -15.16,    0.00 /
      DATA B(84934), B(84935), B(84936) /    -5.55,  -15.22,    0.00 /
      DATA B(85237), B(85238), B(85239) /    -5.55,  -15.27,    0.00 /
      DATA B(85540), B(85541), B(85542) /    -5.55,  -15.33,    0.00 /
      DATA B(85843), B(85844), B(85845) /    -5.55,  -15.38,    0.00 /
      DATA B(86146), B(86147), B(86148) /    -5.55,  -15.44,    0.00 /
      DATA B(86449), B(86450), B(86451) /    -5.55,  -15.49,    0.00 /
      DATA B(86752), B(86753), B(86754) /    -5.55,  -15.55,    0.00 /
      DATA B(87055), B(87056), B(87057) /    -5.55,  -15.60,    0.00 /
      DATA B(87358), B(87359), B(87360) /    -5.55,  -15.66,    0.00 /
      DATA B(87661), B(87662), B(87663) /    -5.55,  -15.71,    0.00 /
      DATA B(87964), B(87965), B(87966) /    -5.55,  -15.77,    0.00 /
      DATA B(88267), B(88268), B(88269) /    -5.55,  -15.82,    0.00 /
      DATA B(88570), B(88571), B(88572) /    -5.55,  -15.87,    0.00 /
      DATA B(88873), B(88874), B(88875) /    -5.55,  -15.93,    0.00 /
      DATA B(89176), B(89177), B(89178) /    -5.55,  -15.98,    0.00 /
      DATA B(89479), B(89480), B(89481) /    -5.55,  -16.03,    0.00 /
      DATA B(89782), B(89783), B(89784) /    -5.55,  -16.09,    0.00 /
      DATA B(67969), B(67970), B(67971) /    -5.46,  -11.65,    0.00 /
      DATA B(68272), B(68273), B(68274) /    -5.46,  -11.73,    0.00 /
      DATA B(68575), B(68576), B(68577) /    -5.46,  -11.80,    0.00 /
      DATA B(68878), B(68879), B(68880) /    -5.46,  -11.87,    0.00 /
      DATA B(69181), B(69182), B(69183) /    -5.46,  -11.95,    0.00 /
      DATA B(69484), B(69485), B(69486) /    -5.46,  -12.02,    0.00 /
      DATA B(69787), B(69788), B(69789) /    -5.46,  -12.09,    0.00 /
      DATA B(70090), B(70091), B(70092) /    -5.46,  -12.16,    0.00 /
      DATA B(70393), B(70394), B(70395) /    -5.46,  -12.23,    0.00 /
      DATA B(70696), B(70697), B(70698) /    -5.46,  -12.30,    0.00 /
      DATA B(70999), B(71000), B(71001) /    -5.46,  -12.37,    0.00 /
      DATA B(71302), B(71303), B(71304) /    -5.46,  -12.44,    0.00 /
      DATA B(71605), B(71606), B(71607) /    -5.46,  -12.51,    0.00 /
      DATA B(71908), B(71909), B(71910) /    -5.46,  -12.58,    0.00 /
      DATA B(72211), B(72212), B(72213) /    -5.46,  -12.65,    0.00 /
      DATA B(72514), B(72515), B(72516) /    -5.46,  -12.72,    0.00 /
      DATA B(72817), B(72818), B(72819) /    -5.46,  -12.78,    0.00 /
      DATA B(73120), B(73121), B(73122) /    -5.46,  -12.85,    0.00 /
      DATA B(73423), B(73424), B(73425) /    -5.46,  -12.92,    0.00 /
      DATA B(73726), B(73727), B(73728) /    -5.47,  -12.99,    0.00 /
      DATA B(74029), B(74030), B(74031) /    -5.47,  -13.05,    0.00 /
      DATA B(74332), B(74333), B(74334) /    -5.47,  -13.12,    0.00 /
      DATA B(74635), B(74636), B(74637) /    -5.47,  -13.18,    0.00 /
      DATA B(74938), B(74939), B(74940) /    -5.47,  -13.25,    0.00 /
      DATA B(75241), B(75242), B(75243) /    -5.47,  -13.31,    0.00 /
      DATA B(75544), B(75545), B(75546) /    -5.47,  -13.38,    0.00 /
      DATA B(75847), B(75848), B(75849) /    -5.47,  -13.44,    0.00 /
      DATA B(76150), B(76151), B(76152) /    -5.47,  -13.51,    0.00 /
      DATA B(76453), B(76454), B(76455) /    -5.47,  -13.57,    0.00 /
      DATA B(76756), B(76757), B(76758) /    -5.47,  -13.63,    0.00 /
      DATA B(77059), B(77060), B(77061) /    -5.47,  -13.70,    0.00 /
      DATA B(77362), B(77363), B(77364) /    -5.47,  -13.76,    0.00 /
      DATA B(77665), B(77666), B(77667) /    -5.47,  -13.82,    0.00 /
      DATA B(77968), B(77969), B(77970) /    -5.47,  -13.88,    0.00 /
      DATA B(78271), B(78272), B(78273) /    -5.47,  -13.94,    0.00 /
      DATA B(78574), B(78575), B(78576) /    -5.47,  -14.00,    0.00 /
      DATA B(78877), B(78878), B(78879) /    -5.47,  -14.07,    0.00 /
      DATA B(79180), B(79181), B(79182) /    -5.47,  -14.13,    0.00 /
      DATA B(79483), B(79484), B(79485) /    -5.47,  -14.19,    0.00 /
      DATA B(79786), B(79787), B(79788) /    -5.47,  -14.25,    0.00 /
      DATA B(80089), B(80090), B(80091) /    -5.47,  -14.31,    0.00 /
      DATA B(80392), B(80393), B(80394) /    -5.47,  -14.37,    0.00 /
      DATA B(80695), B(80696), B(80697) /    -5.47,  -14.43,    0.00 /
      DATA B(80998), B(80999), B(81000) /    -5.47,  -14.48,    0.00 /
      DATA B(81301), B(81302), B(81303) /    -5.47,  -14.54,    0.00 /
      DATA B(81604), B(81605), B(81606) /    -5.47,  -14.60,    0.00 /
      DATA B(81907), B(81908), B(81909) /    -5.47,  -14.66,    0.00 /
      DATA B(82210), B(82211), B(82212) /    -5.47,  -14.72,    0.00 /
      DATA B(82513), B(82514), B(82515) /    -5.47,  -14.78,    0.00 /
      DATA B(82816), B(82817), B(82818) /    -5.47,  -14.83,    0.00 /
      DATA B(83119), B(83120), B(83121) /    -5.47,  -14.89,    0.00 /
      DATA B(83422), B(83423), B(83424) /    -5.47,  -14.95,    0.00 /
      DATA B(83725), B(83726), B(83727) /    -5.47,  -15.01,    0.00 /
      DATA B(84028), B(84029), B(84030) /    -5.47,  -15.06,    0.00 /
      DATA B(84331), B(84332), B(84333) /    -5.47,  -15.12,    0.00 /
      DATA B(84634), B(84635), B(84636) /    -5.47,  -15.18,    0.00 /
      DATA B(84937), B(84938), B(84939) /    -5.47,  -15.23,    0.00 /
      DATA B(85240), B(85241), B(85242) /    -5.46,  -15.29,    0.00 /
      DATA B(85543), B(85544), B(85545) /    -5.46,  -15.35,    0.00 /
      DATA B(85846), B(85847), B(85848) /    -5.46,  -15.40,    0.00 /
      DATA B(86149), B(86150), B(86151) /    -5.46,  -15.46,    0.00 /
      DATA B(86452), B(86453), B(86454) /    -5.46,  -15.51,    0.00 /
      DATA B(86755), B(86756), B(86757) /    -5.46,  -15.57,    0.00 /
      DATA B(87058), B(87059), B(87060) /    -5.46,  -15.62,    0.00 /
      DATA B(87361), B(87362), B(87363) /    -5.46,  -15.68,    0.00 /
      DATA B(87664), B(87665), B(87666) /    -5.46,  -15.73,    0.00 /
      DATA B(87967), B(87968), B(87969) /    -5.46,  -15.79,    0.00 /
      DATA B(88270), B(88271), B(88272) /    -5.46,  -15.84,    0.00 /
      DATA B(88573), B(88574), B(88575) /    -5.46,  -15.89,    0.00 /
      DATA B(88876), B(88877), B(88878) /    -5.46,  -15.95,    0.00 /
      DATA B(89179), B(89180), B(89181) /    -5.46,  -16.00,    0.00 /
      DATA B(89482), B(89483), B(89484) /    -5.46,  -16.05,    0.00 /
      DATA B(89785), B(89786), B(89787) /    -5.46,  -16.11,    0.00 /
      DATA B(67972), B(67973), B(67974) /    -5.37,  -11.66,    0.00 /
      DATA B(68275), B(68276), B(68277) /    -5.37,  -11.74,    0.00 /
      DATA B(68578), B(68579), B(68580) /    -5.37,  -11.81,    0.00 /
      DATA B(68881), B(68882), B(68883) /    -5.37,  -11.88,    0.00 /
      DATA B(69184), B(69185), B(69186) /    -5.37,  -11.96,    0.00 /
      DATA B(69487), B(69488), B(69489) /    -5.37,  -12.03,    0.00 /
      DATA B(69790), B(69791), B(69792) /    -5.37,  -12.10,    0.00 /
      DATA B(70093), B(70094), B(70095) /    -5.37,  -12.17,    0.00 /
      DATA B(70396), B(70397), B(70398) /    -5.37,  -12.24,    0.00 /
      DATA B(70699), B(70700), B(70701) /    -5.37,  -12.31,    0.00 /
      DATA B(71002), B(71003), B(71004) /    -5.38,  -12.38,    0.00 /
      DATA B(71305), B(71306), B(71307) /    -5.38,  -12.45,    0.00 /
      DATA B(71608), B(71609), B(71610) /    -5.38,  -12.52,    0.00 /
      DATA B(71911), B(71912), B(71913) /    -5.38,  -12.59,    0.00 /
      DATA B(72214), B(72215), B(72216) /    -5.38,  -12.66,    0.00 /
      DATA B(72517), B(72518), B(72519) /    -5.38,  -12.73,    0.00 /
      DATA B(72820), B(72821), B(72822) /    -5.38,  -12.79,    0.00 /
      DATA B(73123), B(73124), B(73125) /    -5.38,  -12.86,    0.00 /
      DATA B(73426), B(73427), B(73428) /    -5.38,  -12.93,    0.00 /
      DATA B(73729), B(73730), B(73731) /    -5.38,  -13.00,    0.00 /
      DATA B(74032), B(74033), B(74034) /    -5.38,  -13.06,    0.00 /
      DATA B(74335), B(74336), B(74337) /    -5.38,  -13.13,    0.00 /
      DATA B(74638), B(74639), B(74640) /    -5.38,  -13.20,    0.00 /
      DATA B(74941), B(74942), B(74943) /    -5.38,  -13.26,    0.00 /
      DATA B(75244), B(75245), B(75246) /    -5.38,  -13.33,    0.00 /
      DATA B(75547), B(75548), B(75549) /    -5.38,  -13.39,    0.00 /
      DATA B(75850), B(75851), B(75852) /    -5.38,  -13.45,    0.00 /
      DATA B(76153), B(76154), B(76155) /    -5.38,  -13.52,    0.00 /
      DATA B(76456), B(76457), B(76458) /    -5.38,  -13.58,    0.00 /
      DATA B(76759), B(76760), B(76761) /    -5.38,  -13.65,    0.00 /
      DATA B(77062), B(77063), B(77064) /    -5.38,  -13.71,    0.00 /
      DATA B(77365), B(77366), B(77367) /    -5.38,  -13.77,    0.00 /
      DATA B(77668), B(77669), B(77670) /    -5.38,  -13.83,    0.00 /
      DATA B(77971), B(77972), B(77973) /    -5.38,  -13.90,    0.00 /
      DATA B(78274), B(78275), B(78276) /    -5.38,  -13.96,    0.00 /
      DATA B(78577), B(78578), B(78579) /    -5.38,  -14.02,    0.00 /
      DATA B(78880), B(78881), B(78882) /    -5.38,  -14.08,    0.00 /
      DATA B(79183), B(79184), B(79185) /    -5.38,  -14.14,    0.00 /
      DATA B(79486), B(79487), B(79488) /    -5.38,  -14.20,    0.00 /
      DATA B(79789), B(79790), B(79791) /    -5.38,  -14.26,    0.00 /
      DATA B(80092), B(80093), B(80094) /    -5.38,  -14.32,    0.00 /
      DATA B(80395), B(80396), B(80397) /    -5.38,  -14.38,    0.00 /
      DATA B(80698), B(80699), B(80700) /    -5.38,  -14.44,    0.00 /
      DATA B(81001), B(81002), B(81003) /    -5.38,  -14.50,    0.00 /
      DATA B(81304), B(81305), B(81306) /    -5.38,  -14.56,    0.00 /
      DATA B(81607), B(81608), B(81609) /    -5.38,  -14.62,    0.00 /
      DATA B(81910), B(81911), B(81912) /    -5.38,  -14.68,    0.00 /
      DATA B(82213), B(82214), B(82215) /    -5.38,  -14.73,    0.00 /
      DATA B(82516), B(82517), B(82518) /    -5.38,  -14.79,    0.00 /
      DATA B(82819), B(82820), B(82821) /    -5.38,  -14.85,    0.00 /
      DATA B(83122), B(83123), B(83124) /    -5.38,  -14.91,    0.00 /
      DATA B(83425), B(83426), B(83427) /    -5.38,  -14.97,    0.00 /
      DATA B(83728), B(83729), B(83730) /    -5.38,  -15.02,    0.00 /
      DATA B(84031), B(84032), B(84033) /    -5.38,  -15.08,    0.00 /
      DATA B(84334), B(84335), B(84336) /    -5.38,  -15.14,    0.00 /
      DATA B(84637), B(84638), B(84639) /    -5.38,  -15.19,    0.00 /
      DATA B(84940), B(84941), B(84942) /    -5.38,  -15.25,    0.00 /
      DATA B(85243), B(85244), B(85245) /    -5.38,  -15.31,    0.00 /
      DATA B(85546), B(85547), B(85548) /    -5.38,  -15.36,    0.00 /
      DATA B(85849), B(85850), B(85851) /    -5.38,  -15.42,    0.00 /
      DATA B(86152), B(86153), B(86154) /    -5.38,  -15.47,    0.00 /
      DATA B(86455), B(86456), B(86457) /    -5.38,  -15.53,    0.00 /
      DATA B(86758), B(86759), B(86760) /    -5.37,  -15.59,    0.00 /
      DATA B(87061), B(87062), B(87063) /    -5.37,  -15.64,    0.00 /
      DATA B(87364), B(87365), B(87366) /    -5.37,  -15.69,    0.00 /
      DATA B(87667), B(87668), B(87669) /    -5.37,  -15.75,    0.00 /
      DATA B(87970), B(87971), B(87972) /    -5.37,  -15.80,    0.00 /
      DATA B(88273), B(88274), B(88275) /    -5.37,  -15.86,    0.00 /
      DATA B(88576), B(88577), B(88578) /    -5.37,  -15.91,    0.00 /
      DATA B(88879), B(88880), B(88881) /    -5.37,  -15.97,    0.00 /
      DATA B(89182), B(89183), B(89184) /    -5.37,  -16.02,    0.00 /
      DATA B(89485), B(89486), B(89487) /    -5.37,  -16.07,    0.00 /
      DATA B(89788), B(89789), B(89790) /    -5.37,  -16.12,    0.00 /
      DATA B(67975), B(67976), B(67977) /    -5.29,  -11.67,    0.00 /
      DATA B(68278), B(68279), B(68280) /    -5.29,  -11.75,    0.00 /
      DATA B(68581), B(68582), B(68583) /    -5.29,  -11.82,    0.00 /
      DATA B(68884), B(68885), B(68886) /    -5.29,  -11.89,    0.00 /
      DATA B(69187), B(69188), B(69189) /    -5.29,  -11.96,    0.00 /
      DATA B(69490), B(69491), B(69492) /    -5.29,  -12.04,    0.00 /
      DATA B(69793), B(69794), B(69795) /    -5.29,  -12.11,    0.00 /
      DATA B(70096), B(70097), B(70098) /    -5.29,  -12.18,    0.00 /
      DATA B(70399), B(70400), B(70401) /    -5.29,  -12.25,    0.00 /
      DATA B(70702), B(70703), B(70704) /    -5.29,  -12.32,    0.00 /
      DATA B(71005), B(71006), B(71007) /    -5.29,  -12.39,    0.00 /
      DATA B(71308), B(71309), B(71310) /    -5.29,  -12.46,    0.00 /
      DATA B(71611), B(71612), B(71613) /    -5.29,  -12.53,    0.00 /
      DATA B(71914), B(71915), B(71916) /    -5.29,  -12.60,    0.00 /
      DATA B(72217), B(72218), B(72219) /    -5.29,  -12.67,    0.00 /
      DATA B(72520), B(72521), B(72522) /    -5.29,  -12.74,    0.00 /
      DATA B(72823), B(72824), B(72825) /    -5.29,  -12.81,    0.00 /
      DATA B(73126), B(73127), B(73128) /    -5.29,  -12.87,    0.00 /
      DATA B(73429), B(73430), B(73431) /    -5.29,  -12.94,    0.00 /
      DATA B(73732), B(73733), B(73734) /    -5.29,  -13.01,    0.00 /
      DATA B(74035), B(74036), B(74037) /    -5.29,  -13.07,    0.00 /
      DATA B(74338), B(74339), B(74340) /    -5.29,  -13.14,    0.00 /
      DATA B(74641), B(74642), B(74643) /    -5.29,  -13.21,    0.00 /
      DATA B(74944), B(74945), B(74946) /    -5.29,  -13.27,    0.00 /
      DATA B(75247), B(75248), B(75249) /    -5.29,  -13.34,    0.00 /
      DATA B(75550), B(75551), B(75552) /    -5.29,  -13.40,    0.00 /
      DATA B(75853), B(75854), B(75855) /    -5.29,  -13.47,    0.00 /
      DATA B(76156), B(76157), B(76158) /    -5.29,  -13.53,    0.00 /
      DATA B(76459), B(76460), B(76461) /    -5.29,  -13.59,    0.00 /
      DATA B(76762), B(76763), B(76764) /    -5.29,  -13.66,    0.00 /
      DATA B(77065), B(77066), B(77067) /    -5.29,  -13.72,    0.00 /
      DATA B(77368), B(77369), B(77370) /    -5.29,  -13.78,    0.00 /
      DATA B(77671), B(77672), B(77673) /    -5.29,  -13.85,    0.00 /
      DATA B(77974), B(77975), B(77976) /    -5.29,  -13.91,    0.00 /
      DATA B(78277), B(78278), B(78279) /    -5.29,  -13.97,    0.00 /
      DATA B(78580), B(78581), B(78582) /    -5.29,  -14.03,    0.00 /
      DATA B(78883), B(78884), B(78885) /    -5.29,  -14.09,    0.00 /
      DATA B(79186), B(79187), B(79188) /    -5.29,  -14.15,    0.00 /
      DATA B(79489), B(79490), B(79491) /    -5.29,  -14.22,    0.00 /
      DATA B(79792), B(79793), B(79794) /    -5.29,  -14.28,    0.00 /
      DATA B(80095), B(80096), B(80097) /    -5.29,  -14.34,    0.00 /
      DATA B(80398), B(80399), B(80400) /    -5.29,  -14.40,    0.00 /
      DATA B(80701), B(80702), B(80703) /    -5.29,  -14.46,    0.00 /
      DATA B(81004), B(81005), B(81006) /    -5.29,  -14.52,    0.00 /
      DATA B(81307), B(81308), B(81309) /    -5.29,  -14.57,    0.00 /
      DATA B(81610), B(81611), B(81612) /    -5.29,  -14.63,    0.00 /
      DATA B(81913), B(81914), B(81915) /    -5.29,  -14.69,    0.00 /
      DATA B(82216), B(82217), B(82218) /    -5.29,  -14.75,    0.00 /
      DATA B(82519), B(82520), B(82521) /    -5.29,  -14.81,    0.00 /
      DATA B(82822), B(82823), B(82824) /    -5.29,  -14.87,    0.00 /
      DATA B(83125), B(83126), B(83127) /    -5.29,  -14.92,    0.00 /
      DATA B(83428), B(83429), B(83430) /    -5.29,  -14.98,    0.00 /
      DATA B(83731), B(83732), B(83733) /    -5.29,  -15.04,    0.00 /
      DATA B(84034), B(84035), B(84036) /    -5.29,  -15.10,    0.00 /
      DATA B(84337), B(84338), B(84339) /    -5.29,  -15.15,    0.00 /
      DATA B(84640), B(84641), B(84642) /    -5.29,  -15.21,    0.00 /
      DATA B(84943), B(84944), B(84945) /    -5.29,  -15.27,    0.00 /
      DATA B(85246), B(85247), B(85248) /    -5.29,  -15.32,    0.00 /
      DATA B(85549), B(85550), B(85551) /    -5.29,  -15.38,    0.00 /
      DATA B(85852), B(85853), B(85854) /    -5.29,  -15.44,    0.00 /
      DATA B(86155), B(86156), B(86157) /    -5.29,  -15.49,    0.00 /
      DATA B(86458), B(86459), B(86460) /    -5.29,  -15.55,    0.00 /
      DATA B(86761), B(86762), B(86763) /    -5.29,  -15.60,    0.00 /
      DATA B(87064), B(87065), B(87066) /    -5.29,  -15.66,    0.00 /
      DATA B(87367), B(87368), B(87369) /    -5.29,  -15.71,    0.00 /
      DATA B(87670), B(87671), B(87672) /    -5.29,  -15.77,    0.00 /
      DATA B(87973), B(87974), B(87975) /    -5.29,  -15.82,    0.00 /
      DATA B(88276), B(88277), B(88278) /    -5.29,  -15.88,    0.00 /
      DATA B(88579), B(88580), B(88581) /    -5.28,  -15.93,    0.00 /
      DATA B(88882), B(88883), B(88884) /    -5.28,  -15.98,    0.00 /
      DATA B(89185), B(89186), B(89187) /    -5.28,  -16.04,    0.00 /
      DATA B(89488), B(89489), B(89490) /    -5.28,  -16.09,    0.00 /
      DATA B(89791), B(89792), B(89793) /    -5.28,  -16.14,    0.00 /
      DATA B(67978), B(67979), B(67980) /    -5.20,  -11.68,    0.00 /
      DATA B(68281), B(68282), B(68283) /    -5.20,  -11.76,    0.00 /
      DATA B(68584), B(68585), B(68586) /    -5.20,  -11.83,    0.00 /
      DATA B(68887), B(68888), B(68889) /    -5.20,  -11.90,    0.00 /
      DATA B(69190), B(69191), B(69192) /    -5.20,  -11.97,    0.00 /
      DATA B(69493), B(69494), B(69495) /    -5.20,  -12.05,    0.00 /
      DATA B(69796), B(69797), B(69798) /    -5.20,  -12.12,    0.00 /
      DATA B(70099), B(70100), B(70101) /    -5.20,  -12.19,    0.00 /
      DATA B(70402), B(70403), B(70404) /    -5.20,  -12.26,    0.00 /
      DATA B(70705), B(70706), B(70707) /    -5.20,  -12.33,    0.00 /
      DATA B(71008), B(71009), B(71010) /    -5.20,  -12.40,    0.00 /
      DATA B(71311), B(71312), B(71313) /    -5.20,  -12.47,    0.00 /
      DATA B(71614), B(71615), B(71616) /    -5.20,  -12.54,    0.00 /
      DATA B(71917), B(71918), B(71919) /    -5.20,  -12.61,    0.00 /
      DATA B(72220), B(72221), B(72222) /    -5.20,  -12.68,    0.00 /
      DATA B(72523), B(72524), B(72525) /    -5.20,  -12.75,    0.00 /
      DATA B(72826), B(72827), B(72828) /    -5.20,  -12.82,    0.00 /
      DATA B(73129), B(73130), B(73131) /    -5.20,  -12.88,    0.00 /
      DATA B(73432), B(73433), B(73434) /    -5.20,  -12.95,    0.00 /
      DATA B(73735), B(73736), B(73737) /    -5.20,  -13.02,    0.00 /
      DATA B(74038), B(74039), B(74040) /    -5.20,  -13.09,    0.00 /
      DATA B(74341), B(74342), B(74343) /    -5.20,  -13.15,    0.00 /
      DATA B(74644), B(74645), B(74646) /    -5.20,  -13.22,    0.00 /
      DATA B(74947), B(74948), B(74949) /    -5.20,  -13.28,    0.00 /
      DATA B(75250), B(75251), B(75252) /    -5.20,  -13.35,    0.00 /
      DATA B(75553), B(75554), B(75555) /    -5.21,  -13.41,    0.00 /
      DATA B(75856), B(75857), B(75858) /    -5.21,  -13.48,    0.00 /
      DATA B(76159), B(76160), B(76161) /    -5.21,  -13.54,    0.00 /
      DATA B(76462), B(76463), B(76464) /    -5.21,  -13.61,    0.00 /
      DATA B(76765), B(76766), B(76767) /    -5.21,  -13.67,    0.00 /
      DATA B(77068), B(77069), B(77070) /    -5.21,  -13.73,    0.00 /
      DATA B(77371), B(77372), B(77373) /    -5.21,  -13.80,    0.00 /
      DATA B(77674), B(77675), B(77676) /    -5.21,  -13.86,    0.00 /
      DATA B(77977), B(77978), B(77979) /    -5.21,  -13.92,    0.00 /
      DATA B(78280), B(78281), B(78282) /    -5.21,  -13.98,    0.00 /
      DATA B(78583), B(78584), B(78585) /    -5.21,  -14.05,    0.00 /
      DATA B(78886), B(78887), B(78888) /    -5.21,  -14.11,    0.00 /
      DATA B(79189), B(79190), B(79191) /    -5.21,  -14.17,    0.00 /
      DATA B(79492), B(79493), B(79494) /    -5.21,  -14.23,    0.00 /
      DATA B(79795), B(79796), B(79797) /    -5.21,  -14.29,    0.00 /
      DATA B(80098), B(80099), B(80100) /    -5.21,  -14.35,    0.00 /
      DATA B(80401), B(80402), B(80403) /    -5.21,  -14.41,    0.00 /
      DATA B(80704), B(80705), B(80706) /    -5.21,  -14.47,    0.00 /
      DATA B(81007), B(81008), B(81009) /    -5.21,  -14.53,    0.00 /
      DATA B(81310), B(81311), B(81312) /    -5.21,  -14.59,    0.00 /
      DATA B(81613), B(81614), B(81615) /    -5.21,  -14.65,    0.00 /
      DATA B(81916), B(81917), B(81918) /    -5.21,  -14.71,    0.00 /
      DATA B(82219), B(82220), B(82221) /    -5.21,  -14.77,    0.00 /
      DATA B(82522), B(82523), B(82524) /    -5.21,  -14.82,    0.00 /
      DATA B(82825), B(82826), B(82827) /    -5.20,  -14.88,    0.00 /
      DATA B(83128), B(83129), B(83130) /    -5.20,  -14.94,    0.00 /
      DATA B(83431), B(83432), B(83433) /    -5.20,  -15.00,    0.00 /
      DATA B(83734), B(83735), B(83736) /    -5.20,  -15.06,    0.00 /
      DATA B(84037), B(84038), B(84039) /    -5.20,  -15.11,    0.00 /
      DATA B(84340), B(84341), B(84342) /    -5.20,  -15.17,    0.00 /
      DATA B(84643), B(84644), B(84645) /    -5.20,  -15.23,    0.00 /
      DATA B(84946), B(84947), B(84948) /    -5.20,  -15.28,    0.00 /
      DATA B(85249), B(85250), B(85251) /    -5.20,  -15.34,    0.00 /
      DATA B(85552), B(85553), B(85554) /    -5.20,  -15.40,    0.00 /
      DATA B(85855), B(85856), B(85857) /    -5.20,  -15.45,    0.00 /
      DATA B(86158), B(86159), B(86160) /    -5.20,  -15.51,    0.00 /
      DATA B(86461), B(86462), B(86463) /    -5.20,  -15.56,    0.00 /
      DATA B(86764), B(86765), B(86766) /    -5.20,  -15.62,    0.00 /
      DATA B(87067), B(87068), B(87069) /    -5.20,  -15.68,    0.00 /
      DATA B(87370), B(87371), B(87372) /    -5.20,  -15.73,    0.00 /
      DATA B(87673), B(87674), B(87675) /    -5.20,  -15.78,    0.00 /
      DATA B(87976), B(87977), B(87978) /    -5.20,  -15.84,    0.00 /
      DATA B(88279), B(88280), B(88281) /    -5.20,  -15.89,    0.00 /
      DATA B(88582), B(88583), B(88584) /    -5.20,  -15.95,    0.00 /
      DATA B(88885), B(88886), B(88887) /    -5.20,  -16.00,    0.00 /
      DATA B(89188), B(89189), B(89190) /    -5.20,  -16.05,    0.00 /
      DATA B(89491), B(89492), B(89493) /    -5.20,  -16.11,    0.00 /
      DATA B(89794), B(89795), B(89796) /    -5.20,  -16.16,    0.00 /
      DATA B(67981), B(67982), B(67983) /    -5.11,  -11.69,    0.00 /
      DATA B(68284), B(68285), B(68286) /    -5.11,  -11.77,    0.00 /
      DATA B(68587), B(68588), B(68589) /    -5.11,  -11.84,    0.00 /
      DATA B(68890), B(68891), B(68892) /    -5.11,  -11.91,    0.00 /
      DATA B(69193), B(69194), B(69195) /    -5.11,  -11.98,    0.00 /
      DATA B(69496), B(69497), B(69498) /    -5.11,  -12.06,    0.00 /
      DATA B(69799), B(69800), B(69801) /    -5.11,  -12.13,    0.00 /
      DATA B(70102), B(70103), B(70104) /    -5.11,  -12.20,    0.00 /
      DATA B(70405), B(70406), B(70407) /    -5.11,  -12.27,    0.00 /
      DATA B(70708), B(70709), B(70710) /    -5.11,  -12.34,    0.00 /
      DATA B(71011), B(71012), B(71013) /    -5.11,  -12.41,    0.00 /
      DATA B(71314), B(71315), B(71316) /    -5.11,  -12.48,    0.00 /
      DATA B(71617), B(71618), B(71619) /    -5.11,  -12.55,    0.00 /
      DATA B(71920), B(71921), B(71922) /    -5.11,  -12.62,    0.00 /
      DATA B(72223), B(72224), B(72225) /    -5.11,  -12.69,    0.00 /
      DATA B(72526), B(72527), B(72528) /    -5.11,  -12.76,    0.00 /
      DATA B(72829), B(72830), B(72831) /    -5.11,  -12.83,    0.00 /
      DATA B(73132), B(73133), B(73134) /    -5.11,  -12.89,    0.00 /
      DATA B(73435), B(73436), B(73437) /    -5.12,  -12.96,    0.00 /
      DATA B(73738), B(73739), B(73740) /    -5.12,  -13.03,    0.00 /
      DATA B(74041), B(74042), B(74043) /    -5.12,  -13.10,    0.00 /
      DATA B(74344), B(74345), B(74346) /    -5.12,  -13.16,    0.00 /
      DATA B(74647), B(74648), B(74649) /    -5.12,  -13.23,    0.00 /
      DATA B(74950), B(74951), B(74952) /    -5.12,  -13.30,    0.00 /
      DATA B(75253), B(75254), B(75255) /    -5.12,  -13.36,    0.00 /
      DATA B(75556), B(75557), B(75558) /    -5.12,  -13.43,    0.00 /
      DATA B(75859), B(75860), B(75861) /    -5.12,  -13.49,    0.00 /
      DATA B(76162), B(76163), B(76164) /    -5.12,  -13.56,    0.00 /
      DATA B(76465), B(76466), B(76467) /    -5.12,  -13.62,    0.00 /
      DATA B(76768), B(76769), B(76770) /    -5.12,  -13.68,    0.00 /
      DATA B(77071), B(77072), B(77073) /    -5.12,  -13.75,    0.00 /
      DATA B(77374), B(77375), B(77376) /    -5.12,  -13.81,    0.00 /
      DATA B(77677), B(77678), B(77679) /    -5.12,  -13.87,    0.00 /
      DATA B(77980), B(77981), B(77982) /    -5.12,  -13.94,    0.00 /
      DATA B(78283), B(78284), B(78285) /    -5.12,  -14.00,    0.00 /
      DATA B(78586), B(78587), B(78588) /    -5.12,  -14.06,    0.00 /
      DATA B(78889), B(78890), B(78891) /    -5.12,  -14.12,    0.00 /
      DATA B(79192), B(79193), B(79194) /    -5.12,  -14.18,    0.00 /
      DATA B(79495), B(79496), B(79497) /    -5.12,  -14.24,    0.00 /
      DATA B(79798), B(79799), B(79800) /    -5.12,  -14.30,    0.00 /
      DATA B(80101), B(80102), B(80103) /    -5.12,  -14.36,    0.00 /
      DATA B(80404), B(80405), B(80406) /    -5.12,  -14.43,    0.00 /
      DATA B(80707), B(80708), B(80709) /    -5.12,  -14.49,    0.00 /
      DATA B(81010), B(81011), B(81012) /    -5.12,  -14.54,    0.00 /
      DATA B(81313), B(81314), B(81315) /    -5.12,  -14.60,    0.00 /
      DATA B(81616), B(81617), B(81618) /    -5.12,  -14.66,    0.00 /
      DATA B(81919), B(81920), B(81921) /    -5.12,  -14.72,    0.00 /
      DATA B(82222), B(82223), B(82224) /    -5.12,  -14.78,    0.00 /
      DATA B(82525), B(82526), B(82527) /    -5.12,  -14.84,    0.00 /
      DATA B(82828), B(82829), B(82830) /    -5.12,  -14.90,    0.00 /
      DATA B(83131), B(83132), B(83133) /    -5.12,  -14.96,    0.00 /
      DATA B(83434), B(83435), B(83436) /    -5.12,  -15.01,    0.00 /
      DATA B(83737), B(83738), B(83739) /    -5.12,  -15.07,    0.00 /
      DATA B(84040), B(84041), B(84042) /    -5.12,  -15.13,    0.00 /
      DATA B(84343), B(84344), B(84345) /    -5.12,  -15.19,    0.00 /
      DATA B(84646), B(84647), B(84648) /    -5.11,  -15.24,    0.00 /
      DATA B(84949), B(84950), B(84951) /    -5.11,  -15.30,    0.00 /
      DATA B(85252), B(85253), B(85254) /    -5.11,  -15.36,    0.00 /
      DATA B(85555), B(85556), B(85557) /    -5.11,  -15.41,    0.00 /
      DATA B(85858), B(85859), B(85860) /    -5.11,  -15.47,    0.00 /
      DATA B(86161), B(86162), B(86163) /    -5.11,  -15.53,    0.00 /
      DATA B(86464), B(86465), B(86466) /    -5.11,  -15.58,    0.00 /
      DATA B(86767), B(86768), B(86769) /    -5.11,  -15.64,    0.00 /
      DATA B(87070), B(87071), B(87072) /    -5.11,  -15.69,    0.00 /
      DATA B(87373), B(87374), B(87375) /    -5.11,  -15.75,    0.00 /
      DATA B(87676), B(87677), B(87678) /    -5.11,  -15.80,    0.00 /
      DATA B(87979), B(87980), B(87981) /    -5.11,  -15.86,    0.00 /
      DATA B(88282), B(88283), B(88284) /    -5.11,  -15.91,    0.00 /
      DATA B(88585), B(88586), B(88587) /    -5.11,  -15.96,    0.00 /
      DATA B(88888), B(88889), B(88890) /    -5.11,  -16.02,    0.00 /
      DATA B(89191), B(89192), B(89193) /    -5.11,  -16.07,    0.00 /
      DATA B(89494), B(89495), B(89496) /    -5.11,  -16.13,    0.00 /
      DATA B(89797), B(89798), B(89799) /    -5.11,  -16.18,    0.00 /
      DATA B(67984), B(67985), B(67986) /    -5.02,  -11.70,    0.00 /
      DATA B(68287), B(68288), B(68289) /    -5.02,  -11.78,    0.00 /
      DATA B(68590), B(68591), B(68592) /    -5.02,  -11.85,    0.00 /
      DATA B(68893), B(68894), B(68895) /    -5.02,  -11.92,    0.00 /
      DATA B(69196), B(69197), B(69198) /    -5.02,  -11.99,    0.00 /
      DATA B(69499), B(69500), B(69501) /    -5.02,  -12.07,    0.00 /
      DATA B(69802), B(69803), B(69804) /    -5.02,  -12.14,    0.00 /
      DATA B(70105), B(70106), B(70107) /    -5.02,  -12.21,    0.00 /
      DATA B(70408), B(70409), B(70410) /    -5.02,  -12.28,    0.00 /
      DATA B(70711), B(70712), B(70713) /    -5.02,  -12.35,    0.00 /
      DATA B(71014), B(71015), B(71016) /    -5.03,  -12.42,    0.00 /
      DATA B(71317), B(71318), B(71319) /    -5.03,  -12.49,    0.00 /
      DATA B(71620), B(71621), B(71622) /    -5.03,  -12.56,    0.00 /
      DATA B(71923), B(71924), B(71925) /    -5.03,  -12.63,    0.00 /
      DATA B(72226), B(72227), B(72228) /    -5.03,  -12.70,    0.00 /
      DATA B(72529), B(72530), B(72531) /    -5.03,  -12.77,    0.00 /
      DATA B(72832), B(72833), B(72834) /    -5.03,  -12.84,    0.00 /
      DATA B(73135), B(73136), B(73137) /    -5.03,  -12.91,    0.00 /
      DATA B(73438), B(73439), B(73440) /    -5.03,  -12.97,    0.00 /
      DATA B(73741), B(73742), B(73743) /    -5.03,  -13.04,    0.00 /
      DATA B(74044), B(74045), B(74046) /    -5.03,  -13.11,    0.00 /
      DATA B(74347), B(74348), B(74349) /    -5.03,  -13.17,    0.00 /
      DATA B(74650), B(74651), B(74652) /    -5.03,  -13.24,    0.00 /
      DATA B(74953), B(74954), B(74955) /    -5.03,  -13.31,    0.00 /
      DATA B(75256), B(75257), B(75258) /    -5.03,  -13.37,    0.00 /
      DATA B(75559), B(75560), B(75561) /    -5.03,  -13.44,    0.00 /
      DATA B(75862), B(75863), B(75864) /    -5.03,  -13.50,    0.00 /
      DATA B(76165), B(76166), B(76167) /    -5.03,  -13.57,    0.00 /
      DATA B(76468), B(76469), B(76470) /    -5.03,  -13.63,    0.00 /
      DATA B(76771), B(76772), B(76773) /    -5.03,  -13.70,    0.00 /
      DATA B(77074), B(77075), B(77076) /    -5.03,  -13.76,    0.00 /
      DATA B(77377), B(77378), B(77379) /    -5.03,  -13.82,    0.00 /
      DATA B(77680), B(77681), B(77682) /    -5.03,  -13.89,    0.00 /
      DATA B(77983), B(77984), B(77985) /    -5.03,  -13.95,    0.00 /
      DATA B(78286), B(78287), B(78288) /    -5.03,  -14.01,    0.00 /
      DATA B(78589), B(78590), B(78591) /    -5.03,  -14.07,    0.00 /
      DATA B(78892), B(78893), B(78894) /    -5.03,  -14.13,    0.00 /
      DATA B(79195), B(79196), B(79197) /    -5.03,  -14.20,    0.00 /
      DATA B(79498), B(79499), B(79500) /    -5.03,  -14.26,    0.00 /
      DATA B(79801), B(79802), B(79803) /    -5.03,  -14.32,    0.00 /
      DATA B(80104), B(80105), B(80106) /    -5.03,  -14.38,    0.00 /
      DATA B(80407), B(80408), B(80409) /    -5.03,  -14.44,    0.00 /
      DATA B(80710), B(80711), B(80712) /    -5.03,  -14.50,    0.00 /
      DATA B(81013), B(81014), B(81015) /    -5.03,  -14.56,    0.00 /
      DATA B(81316), B(81317), B(81318) /    -5.03,  -14.62,    0.00 /
      DATA B(81619), B(81620), B(81621) /    -5.03,  -14.68,    0.00 /
      DATA B(81922), B(81923), B(81924) /    -5.03,  -14.74,    0.00 /
      DATA B(82225), B(82226), B(82227) /    -5.03,  -14.80,    0.00 /
      DATA B(82528), B(82529), B(82530) /    -5.03,  -14.86,    0.00 /
      DATA B(82831), B(82832), B(82833) /    -5.03,  -14.91,    0.00 /
      DATA B(83134), B(83135), B(83136) /    -5.03,  -14.97,    0.00 /
      DATA B(83437), B(83438), B(83439) /    -5.03,  -15.03,    0.00 /
      DATA B(83740), B(83741), B(83742) /    -5.03,  -15.09,    0.00 /
      DATA B(84043), B(84044), B(84045) /    -5.03,  -15.15,    0.00 /
      DATA B(84346), B(84347), B(84348) /    -5.03,  -15.20,    0.00 /
      DATA B(84649), B(84650), B(84651) /    -5.03,  -15.26,    0.00 /
      DATA B(84952), B(84953), B(84954) /    -5.03,  -15.32,    0.00 /
      DATA B(85255), B(85256), B(85257) /    -5.03,  -15.37,    0.00 /
      DATA B(85558), B(85559), B(85560) /    -5.03,  -15.43,    0.00 /
      DATA B(85861), B(85862), B(85863) /    -5.03,  -15.49,    0.00 /
      DATA B(86164), B(86165), B(86166) /    -5.02,  -15.54,    0.00 /
      DATA B(86467), B(86468), B(86469) /    -5.02,  -15.60,    0.00 /
      DATA B(86770), B(86771), B(86772) /    -5.02,  -15.65,    0.00 /
      DATA B(87073), B(87074), B(87075) /    -5.02,  -15.71,    0.00 /
      DATA B(87376), B(87377), B(87378) /    -5.02,  -15.76,    0.00 /
      DATA B(87679), B(87680), B(87681) /    -5.02,  -15.82,    0.00 /
      DATA B(87982), B(87983), B(87984) /    -5.02,  -15.87,    0.00 /
      DATA B(88285), B(88286), B(88287) /    -5.02,  -15.93,    0.00 /
      DATA B(88588), B(88589), B(88590) /    -5.02,  -15.98,    0.00 /
      DATA B(88891), B(88892), B(88893) /    -5.02,  -16.04,    0.00 /
      DATA B(89194), B(89195), B(89196) /    -5.02,  -16.09,    0.00 /
      DATA B(89497), B(89498), B(89499) /    -5.02,  -16.14,    0.00 /
      DATA B(89800), B(89801), B(89802) /    -5.02,  -16.20,    0.00 /
      DATA B(67987), B(67988), B(67989) /    -4.94,  -11.71,    0.00 /
      DATA B(68290), B(68291), B(68292) /    -4.94,  -11.78,    0.00 /
      DATA B(68593), B(68594), B(68595) /    -4.94,  -11.86,    0.00 /
      DATA B(68896), B(68897), B(68898) /    -4.94,  -11.93,    0.00 /
      DATA B(69199), B(69200), B(69201) /    -4.94,  -12.00,    0.00 /
      DATA B(69502), B(69503), B(69504) /    -4.94,  -12.08,    0.00 /
      DATA B(69805), B(69806), B(69807) /    -4.94,  -12.15,    0.00 /
      DATA B(70108), B(70109), B(70110) /    -4.94,  -12.22,    0.00 /
      DATA B(70411), B(70412), B(70413) /    -4.94,  -12.29,    0.00 /
      DATA B(70714), B(70715), B(70716) /    -4.94,  -12.36,    0.00 /
      DATA B(71017), B(71018), B(71019) /    -4.94,  -12.43,    0.00 /
      DATA B(71320), B(71321), B(71322) /    -4.94,  -12.50,    0.00 /
      DATA B(71623), B(71624), B(71625) /    -4.94,  -12.57,    0.00 /
      DATA B(71926), B(71927), B(71928) /    -4.94,  -12.64,    0.00 /
      DATA B(72229), B(72230), B(72231) /    -4.94,  -12.71,    0.00 /
      DATA B(72532), B(72533), B(72534) /    -4.94,  -12.78,    0.00 /
      DATA B(72835), B(72836), B(72837) /    -4.94,  -12.85,    0.00 /
      DATA B(73138), B(73139), B(73140) /    -4.94,  -12.92,    0.00 /
      DATA B(73441), B(73442), B(73443) /    -4.94,  -12.98,    0.00 /
      DATA B(73744), B(73745), B(73746) /    -4.94,  -13.05,    0.00 /
      DATA B(74047), B(74048), B(74049) /    -4.94,  -13.12,    0.00 /
      DATA B(74350), B(74351), B(74352) /    -4.94,  -13.18,    0.00 /
      DATA B(74653), B(74654), B(74655) /    -4.94,  -13.25,    0.00 /
      DATA B(74956), B(74957), B(74958) /    -4.94,  -13.32,    0.00 /
      DATA B(75259), B(75260), B(75261) /    -4.94,  -13.38,    0.00 /
      DATA B(75562), B(75563), B(75564) /    -4.94,  -13.45,    0.00 /
      DATA B(75865), B(75866), B(75867) /    -4.94,  -13.51,    0.00 /
      DATA B(76168), B(76169), B(76170) /    -4.94,  -13.58,    0.00 /
      DATA B(76471), B(76472), B(76473) /    -4.94,  -13.64,    0.00 /
      DATA B(76774), B(76775), B(76776) /    -4.94,  -13.71,    0.00 /
      DATA B(77077), B(77078), B(77079) /    -4.94,  -13.77,    0.00 /
      DATA B(77380), B(77381), B(77382) /    -4.94,  -13.83,    0.00 /
      DATA B(77683), B(77684), B(77685) /    -4.94,  -13.90,    0.00 /
      DATA B(77986), B(77987), B(77988) /    -4.94,  -13.96,    0.00 /
      DATA B(78289), B(78290), B(78291) /    -4.94,  -14.02,    0.00 /
      DATA B(78592), B(78593), B(78594) /    -4.94,  -14.09,    0.00 /
      DATA B(78895), B(78896), B(78897) /    -4.94,  -14.15,    0.00 /
      DATA B(79198), B(79199), B(79200) /    -4.94,  -14.21,    0.00 /
      DATA B(79501), B(79502), B(79503) /    -4.94,  -14.27,    0.00 /
      DATA B(79804), B(79805), B(79806) /    -4.94,  -14.33,    0.00 /
      DATA B(80107), B(80108), B(80109) /    -4.94,  -14.39,    0.00 /
      DATA B(80410), B(80411), B(80412) /    -4.94,  -14.45,    0.00 /
      DATA B(80713), B(80714), B(80715) /    -4.94,  -14.51,    0.00 /
      DATA B(81016), B(81017), B(81018) /    -4.94,  -14.57,    0.00 /
      DATA B(81319), B(81320), B(81321) /    -4.94,  -14.63,    0.00 /
      DATA B(81622), B(81623), B(81624) /    -4.94,  -14.69,    0.00 /
      DATA B(81925), B(81926), B(81927) /    -4.94,  -14.75,    0.00 /
      DATA B(82228), B(82229), B(82230) /    -4.94,  -14.81,    0.00 /
      DATA B(82531), B(82532), B(82533) /    -4.94,  -14.87,    0.00 /
      DATA B(82834), B(82835), B(82836) /    -4.94,  -14.93,    0.00 /
      DATA B(83137), B(83138), B(83139) /    -4.94,  -14.99,    0.00 /
      DATA B(83440), B(83441), B(83442) /    -4.94,  -15.05,    0.00 /
      DATA B(83743), B(83744), B(83745) /    -4.94,  -15.10,    0.00 /
      DATA B(84046), B(84047), B(84048) /    -4.94,  -15.16,    0.00 /
      DATA B(84349), B(84350), B(84351) /    -4.94,  -15.22,    0.00 /
      DATA B(84652), B(84653), B(84654) /    -4.94,  -15.28,    0.00 /
      DATA B(84955), B(84956), B(84957) /    -4.94,  -15.33,    0.00 /
      DATA B(85258), B(85259), B(85260) /    -4.94,  -15.39,    0.00 /
      DATA B(85561), B(85562), B(85563) /    -4.94,  -15.45,    0.00 /
      DATA B(85864), B(85865), B(85866) /    -4.94,  -15.50,    0.00 /
      DATA B(86167), B(86168), B(86169) /    -4.94,  -15.56,    0.00 /
      DATA B(86470), B(86471), B(86472) /    -4.94,  -15.61,    0.00 /
      DATA B(86773), B(86774), B(86775) /    -4.94,  -15.67,    0.00 /
      DATA B(87076), B(87077), B(87078) /    -4.94,  -15.73,    0.00 /
      DATA B(87379), B(87380), B(87381) /    -4.93,  -15.78,    0.00 /
      DATA B(87682), B(87683), B(87684) /    -4.93,  -15.84,    0.00 /
      DATA B(87985), B(87986), B(87987) /    -4.93,  -15.89,    0.00 /
      DATA B(88288), B(88289), B(88290) /    -4.93,  -15.94,    0.00 /
      DATA B(88591), B(88592), B(88593) /    -4.93,  -16.00,    0.00 /
      DATA B(88894), B(88895), B(88896) /    -4.93,  -16.05,    0.00 /
      DATA B(89197), B(89198), B(89199) /    -4.93,  -16.11,    0.00 /
      DATA B(89500), B(89501), B(89502) /    -4.93,  -16.16,    0.00 /
      DATA B(89803), B(89804), B(89805) /    -4.93,  -16.21,    0.00 /
      DATA B(67990), B(67991), B(67992) /    -4.85,  -11.72,    0.00 /
      DATA B(68293), B(68294), B(68295) /    -4.85,  -11.79,    0.00 /
      DATA B(68596), B(68597), B(68598) /    -4.85,  -11.87,    0.00 /
      DATA B(68899), B(68900), B(68901) /    -4.85,  -11.94,    0.00 /
      DATA B(69202), B(69203), B(69204) /    -4.85,  -12.01,    0.00 /
      DATA B(69505), B(69506), B(69507) /    -4.85,  -12.09,    0.00 /
      DATA B(69808), B(69809), B(69810) /    -4.85,  -12.16,    0.00 /
      DATA B(70111), B(70112), B(70113) /    -4.85,  -12.23,    0.00 /
      DATA B(70414), B(70415), B(70416) /    -4.85,  -12.30,    0.00 /
      DATA B(70717), B(70718), B(70719) /    -4.85,  -12.37,    0.00 /
      DATA B(71020), B(71021), B(71022) /    -4.85,  -12.44,    0.00 /
      DATA B(71323), B(71324), B(71325) /    -4.85,  -12.51,    0.00 /
      DATA B(71626), B(71627), B(71628) /    -4.85,  -12.58,    0.00 /
      DATA B(71929), B(71930), B(71931) /    -4.85,  -12.65,    0.00 /
      DATA B(72232), B(72233), B(72234) /    -4.85,  -12.72,    0.00 /
      DATA B(72535), B(72536), B(72537) /    -4.85,  -12.79,    0.00 /
      DATA B(72838), B(72839), B(72840) /    -4.85,  -12.86,    0.00 /
      DATA B(73141), B(73142), B(73143) /    -4.85,  -12.93,    0.00 /
      DATA B(73444), B(73445), B(73446) /    -4.85,  -12.99,    0.00 /
      DATA B(73747), B(73748), B(73749) /    -4.85,  -13.06,    0.00 /
      DATA B(74050), B(74051), B(74052) /    -4.85,  -13.13,    0.00 /
      DATA B(74353), B(74354), B(74355) /    -4.85,  -13.20,    0.00 /
      DATA B(74656), B(74657), B(74658) /    -4.85,  -13.26,    0.00 /
      DATA B(74959), B(74960), B(74961) /    -4.85,  -13.33,    0.00 /
      DATA B(75262), B(75263), B(75264) /    -4.85,  -13.39,    0.00 /
      DATA B(75565), B(75566), B(75567) /    -4.85,  -13.46,    0.00 /
      DATA B(75868), B(75869), B(75870) /    -4.85,  -13.53,    0.00 /
      DATA B(76171), B(76172), B(76173) /    -4.85,  -13.59,    0.00 /
      DATA B(76474), B(76475), B(76476) /    -4.85,  -13.65,    0.00 /
      DATA B(76777), B(76778), B(76779) /    -4.85,  -13.72,    0.00 /
      DATA B(77080), B(77081), B(77082) /    -4.85,  -13.78,    0.00 /
      DATA B(77383), B(77384), B(77385) /    -4.85,  -13.85,    0.00 /
      DATA B(77686), B(77687), B(77688) /    -4.85,  -13.91,    0.00 /
      DATA B(77989), B(77990), B(77991) /    -4.85,  -13.97,    0.00 /
      DATA B(78292), B(78293), B(78294) /    -4.85,  -14.04,    0.00 /
      DATA B(78595), B(78596), B(78597) /    -4.85,  -14.10,    0.00 /
      DATA B(78898), B(78899), B(78900) /    -4.85,  -14.16,    0.00 /
      DATA B(79201), B(79202), B(79203) /    -4.85,  -14.22,    0.00 /
      DATA B(79504), B(79505), B(79506) /    -4.85,  -14.28,    0.00 /
      DATA B(79807), B(79808), B(79809) /    -4.85,  -14.35,    0.00 /
      DATA B(80110), B(80111), B(80112) /    -4.85,  -14.41,    0.00 /
      DATA B(80413), B(80414), B(80415) /    -4.85,  -14.47,    0.00 /
      DATA B(80716), B(80717), B(80718) /    -4.85,  -14.53,    0.00 /
      DATA B(81019), B(81020), B(81021) /    -4.85,  -14.59,    0.00 /
      DATA B(81322), B(81323), B(81324) /    -4.85,  -14.65,    0.00 /
      DATA B(81625), B(81626), B(81627) /    -4.85,  -14.71,    0.00 /
      DATA B(81928), B(81929), B(81930) /    -4.85,  -14.77,    0.00 /
      DATA B(82231), B(82232), B(82233) /    -4.85,  -14.83,    0.00 /
      DATA B(82534), B(82535), B(82536) /    -4.85,  -14.88,    0.00 /
      DATA B(82837), B(82838), B(82839) /    -4.85,  -14.94,    0.00 /
      DATA B(83140), B(83141), B(83142) /    -4.85,  -15.00,    0.00 /
      DATA B(83443), B(83444), B(83445) /    -4.85,  -15.06,    0.00 /
      DATA B(83746), B(83747), B(83748) /    -4.85,  -15.12,    0.00 /
      DATA B(84049), B(84050), B(84051) /    -4.85,  -15.18,    0.00 /
      DATA B(84352), B(84353), B(84354) /    -4.85,  -15.23,    0.00 /
      DATA B(84655), B(84656), B(84657) /    -4.85,  -15.29,    0.00 /
      DATA B(84958), B(84959), B(84960) /    -4.85,  -15.35,    0.00 /
      DATA B(85261), B(85262), B(85263) /    -4.85,  -15.41,    0.00 /
      DATA B(85564), B(85565), B(85566) /    -4.85,  -15.46,    0.00 /
      DATA B(85867), B(85868), B(85869) /    -4.85,  -15.52,    0.00 /
      DATA B(86170), B(86171), B(86172) /    -4.85,  -15.57,    0.00 /
      DATA B(86473), B(86474), B(86475) /    -4.85,  -15.63,    0.00 /
      DATA B(86776), B(86777), B(86778) /    -4.85,  -15.69,    0.00 /
      DATA B(87079), B(87080), B(87081) /    -4.85,  -15.74,    0.00 /
      DATA B(87382), B(87383), B(87384) /    -4.85,  -15.80,    0.00 /
      DATA B(87685), B(87686), B(87687) /    -4.85,  -15.85,    0.00 /
      DATA B(87988), B(87989), B(87990) /    -4.85,  -15.91,    0.00 /
      DATA B(88291), B(88292), B(88293) /    -4.85,  -15.96,    0.00 /
      DATA B(88594), B(88595), B(88596) /    -4.85,  -16.02,    0.00 /
      DATA B(88897), B(88898), B(88899) /    -4.84,  -16.07,    0.00 /
      DATA B(89200), B(89201), B(89202) /    -4.84,  -16.12,    0.00 /
      DATA B(89503), B(89504), B(89505) /    -4.84,  -16.18,    0.00 /
      DATA B(89806), B(89807), B(89808) /    -4.84,  -16.23,    0.00 /
      DATA GRDLX( 5) / 197.00000000000 /,
     *     GRDUX( 5) / 229.00000000000 /,
     *     GRDLY( 5) /  55.00000000000 /,
     *     GRDUY( 5) /  66.00000000000 /,
     *     ICNTX( 5) / 32 /,
     *     ICNTY( 5) / 11 /,
     *     NBASE( 5) /89808 /
      DATA B(89809), B(89810), B(89811) /    -2.97,   -3.31,    0.00 /
      DATA B(89908), B(89909), B(89910) /    -8.96,   -1.23,    0.00 /
      DATA B(90007), B(90008), B(90009) /   -17.94,    1.80,    0.00 /
      DATA B(90106), B(90107), B(90108) /   -28.51,    5.17,    0.00 /
      DATA B(90205), B(90206), B(90207) /   -39.77,    8.35,    0.00 /
      DATA B(90304), B(90305), B(90306) /   -51.01,   10.86,    0.00 /
      DATA B(90403), B(90404), B(90405) /   -61.66,   12.32,    0.00 /
      DATA B(90502), B(90503), B(90504) /   -71.25,   12.55,    0.00 /
      DATA B(90601), B(90602), B(90603) /   -79.43,   11.67,    0.00 /
      DATA B(90700), B(90701), B(90702) /   -85.89,   10.10,    0.00 /
      DATA B(90799), B(90800), B(90801) /   -90.36,    8.48,    0.00 /
      DATA B(90898), B(90899), B(90900) /   -92.71,    7.43,    0.00 /
      DATA B(89812), B(89813), B(89814) /    -4.89,   -2.71,    0.00 /
      DATA B(89911), B(89912), B(89913) /    -9.99,   -0.91,    0.00 /
      DATA B(90010), B(90011), B(90012) /   -18.40,    1.95,    0.00 /
      DATA B(90109), B(90110), B(90111) /   -28.62,    5.23,    0.00 /
      DATA B(90208), B(90209), B(90210) /   -39.65,    8.37,    0.00 /
      DATA B(90307), B(90308), B(90309) /   -50.72,   10.85,    0.00 /
      DATA B(90406), B(90407), B(90408) /   -61.25,   12.28,    0.00 /
      DATA B(90505), B(90506), B(90507) /   -70.77,   12.45,    0.00 /
      DATA B(90604), B(90605), B(90606) /   -78.91,   11.48,    0.00 /
      DATA B(90703), B(90704), B(90705) /   -85.35,    9.80,    0.00 /
      DATA B(90802), B(90803), B(90804) /   -89.83,    8.08,    0.00 /
      DATA B(90901), B(90902), B(90903) /   -92.16,    6.97,    0.00 /
      DATA B(89815), B(89816), B(89817) /    -6.82,   -2.16,    0.00 /
      DATA B(89914), B(89915), B(89916) /   -11.16,   -0.59,    0.00 /
      DATA B(90013), B(90014), B(90015) /   -18.87,    2.11,    0.00 /
      DATA B(90112), B(90113), B(90114) /   -28.63,    5.32,    0.00 /
      DATA B(90211), B(90212), B(90213) /   -39.35,    8.45,    0.00 /
      DATA B(90310), B(90311), B(90312) /   -50.20,   10.96,    0.00 /
      DATA B(90409), B(90410), B(90411) /   -60.56,   12.36,    0.00 /
      DATA B(90508), B(90509), B(90510) /   -69.97,   12.41,    0.00 /
      DATA B(90607), B(90608), B(90609) /   -78.06,   11.20,    0.00 /
      DATA B(90706), B(90707), B(90708) /   -84.50,    9.21,    0.00 /
      DATA B(90805), B(90806), B(90807) /   -89.00,    7.20,    0.00 /
      DATA B(90904), B(90905), B(90906) /   -91.35,    5.95,    0.00 /
      DATA B(89818), B(89819), B(89820) /    -8.11,   -1.86,    0.00 /
      DATA B(89917), B(89918), B(89919) /   -11.93,   -0.42,    0.00 /
      DATA B(90016), B(90017), B(90018) /   -19.07,    2.17,    0.00 /
      DATA B(90115), B(90116), B(90117) /   -28.38,    5.37,    0.00 /
      DATA B(90214), B(90215), B(90216) /   -38.76,    8.57,    0.00 /
      DATA B(90313), B(90314), B(90315) /   -49.35,   11.16,    0.00 /
      DATA B(90412), B(90413), B(90414) /   -59.51,   12.56,    0.00 /
      DATA B(90511), B(90512), B(90513) /   -68.79,   12.43,    0.00 /
      DATA B(90610), B(90611), B(90612) /   -76.84,   10.82,    0.00 /
      DATA B(90709), B(90710), B(90711) /   -83.31,    8.31,    0.00 /
      DATA B(90808), B(90809), B(90810) /   -87.87,    5.83,    0.00 /
      DATA B(90907), B(90908), B(90909) /   -90.26,    4.33,    0.00 /
      DATA B(89821), B(89822), B(89823) /    -8.40,   -1.92,    0.00 /
      DATA B(89920), B(89921), B(89922) /   -11.91,   -0.54,    0.00 /
      DATA B(90019), B(90020), B(90021) /   -18.67,    2.02,    0.00 /
      DATA B(90118), B(90119), B(90120) /   -27.65,    5.29,    0.00 /
      DATA B(90217), B(90218), B(90219) /   -37.75,    8.66,    0.00 /
      DATA B(90316), B(90317), B(90318) /   -48.08,   11.42,    0.00 /
      DATA B(90415), B(90416), B(90417) /   -58.03,   12.87,    0.00 /
      DATA B(90514), B(90515), B(90516) /   -67.17,   12.53,    0.00 /
      DATA B(90613), B(90614), B(90615) /   -75.19,   10.38,    0.00 /
      DATA B(90712), B(90713), B(90714) /   -81.72,    7.10,    0.00 /
      DATA B(90811), B(90812), B(90813) /   -86.39,    3.91,    0.00 /
      DATA B(90910), B(90911), B(90912) /   -88.85,    2.03,    0.00 /
      DATA B(89824), B(89825), B(89826) /    -7.45,   -2.40,    0.00 /
      DATA B(89923), B(89924), B(89925) /   -10.83,   -1.02,    0.00 /
      DATA B(90022), B(90023), B(90024) /   -17.44,    1.58,    0.00 /
      DATA B(90121), B(90122), B(90123) /   -26.26,    5.00,    0.00 /
      DATA B(90220), B(90221), B(90222) /   -36.18,    8.63,    0.00 /
      DATA B(90319), B(90320), B(90321) /   -46.28,   11.70,    0.00 /
      DATA B(90418), B(90419), B(90420) /   -56.00,   13.31,    0.00 /
      DATA B(90517), B(90518), B(90519) /   -64.99,   12.75,    0.00 /
      DATA B(90616), B(90617), B(90618) /   -73.01,    9.89,    0.00 /
      DATA B(90715), B(90716), B(90717) /   -79.69,    5.57,    0.00 /
      DATA B(90814), B(90815), B(90816) /   -84.52,    1.39,    0.00 /
      DATA B(90913), B(90914), B(90915) /   -87.09,   -1.01,    0.00 /
      DATA B(89827), B(89828), B(89829) /    -5.08,   -3.32,    0.00 /
      DATA B(89926), B(89927), B(89928) /    -8.47,   -1.92,    0.00 /
      DATA B(90025), B(90026), B(90027) /   -15.16,    0.76,    0.00 /
      DATA B(90124), B(90125), B(90126) /   -24.05,    4.39,    0.00 /
      DATA B(90223), B(90224), B(90225) /   -33.90,    8.40,    0.00 /
      DATA B(90322), B(90323), B(90324) /   -43.81,   11.93,    0.00 /
      DATA B(90421), B(90422), B(90423) /   -53.29,   13.87,    0.00 /
      DATA B(90520), B(90521), B(90522) /   -62.14,   13.15,    0.00 /
      DATA B(90619), B(90620), B(90621) /   -70.21,    9.40,    0.00 /
      DATA B(90718), B(90719), B(90720) /   -77.13,    3.68,    0.00 /
      DATA B(90817), B(90818), B(90819) /   -82.22,   -1.81,    0.00 /
      DATA B(90916), B(90917), B(90918) /   -84.94,   -4.89,    0.00 /
      DATA B(89830), B(89831), B(89832) /    -1.16,   -4.64,    0.00 /
      DATA B(89929), B(89930), B(89931) /    -4.68,   -3.21,    0.00 /
      DATA B(90028), B(90029), B(90030) /   -11.67,   -0.47,    0.00 /
      DATA B(90127), B(90128), B(90129) /   -20.87,    3.38,    0.00 /
      DATA B(90226), B(90227), B(90228) /   -30.77,    7.85,    0.00 /
      DATA B(90325), B(90326), B(90327) /   -40.54,   12.01,    0.00 /
      DATA B(90424), B(90425), B(90426) /   -49.78,   14.51,    0.00 /
      DATA B(90523), B(90524), B(90525) /   -58.45,   13.76,    0.00 /
      DATA B(90622), B(90623), B(90624) /   -66.67,    8.95,    0.00 /
      DATA B(90721), B(90722), B(90723) /   -73.98,    1.42,    0.00 /
      DATA B(90820), B(90821), B(90822) /   -79.44,   -5.76,    0.00 /
      DATA B(90919), B(90920), B(90921) /   -82.34,   -9.69,    0.00 /
      DATA B(89833), B(89834), B(89835) /     4.31,   -6.27,    0.00 /
      DATA B(89932), B(89933), B(89934) /     0.62,   -4.86,    0.00 /
      DATA B(90031), B(90032), B(90033) /    -6.82,   -2.12,    0.00 /
      DATA B(90130), B(90131), B(90132) /   -16.62,    1.90,    0.00 /
      DATA B(90229), B(90230), B(90231) /   -26.63,    6.84,    0.00 /
      DATA B(90328), B(90329), B(90330) /   -36.32,   11.77,    0.00 /
      DATA B(90427), B(90428), B(90429) /   -45.31,   15.14,    0.00 /
      DATA B(90526), B(90527), B(90528) /   -53.76,   14.65,    0.00 /
      DATA B(90625), B(90626), B(90627) /   -62.25,    8.59,    0.00 /
      DATA B(90724), B(90725), B(90726) /   -70.20,   -1.28,    0.00 /
      DATA B(90823), B(90824), B(90825) /   -76.13,  -10.53,    0.00 /
      DATA B(90922), B(90923), B(90924) /   -79.21,  -15.42,    0.00 /
      DATA B(89836), B(89837), B(89838) /    11.07,   -8.06,    0.00 /
      DATA B(89935), B(89936), B(89937) /     7.39,   -6.71,    0.00 /
      DATA B(90034), B(90035), B(90036) /    -0.40,   -4.12,    0.00 /
      DATA B(90133), B(90134), B(90135) /   -11.17,   -0.06,    0.00 /
      DATA B(90232), B(90233), B(90234) /   -21.19,    5.24,    0.00 /
      DATA B(90331), B(90332), B(90333) /   -30.98,   10.91,    0.00 /
      DATA B(90430), B(90431), B(90432) /   -39.75,   15.50,    0.00 /
      DATA B(90529), B(90530), B(90531) /   -47.82,   15.83,    0.00 /
      DATA B(90628), B(90629), B(90630) /   -56.84,    8.34,    0.00 /
      DATA B(90727), B(90728), B(90729) /   -65.78,   -4.55,    0.00 /
      DATA B(90826), B(90827), B(90828) /   -72.26,  -16.16,    0.00 /
      DATA B(90925), B(90926), B(90927) /   -75.41,  -21.96,    0.00 /
      DATA B(89839), B(89840), B(89841) /    18.53,   -9.80,    0.00 /
      DATA B(89938), B(89939), B(89940) /    15.25,   -8.56,    0.00 /
      DATA B(90037), B(90038), B(90039) /     7.96,   -6.28,    0.00 /
      DATA B(90136), B(90137), B(90138) /    -4.18,   -2.37,    0.00 /
      DATA B(90235), B(90236), B(90237) /   -13.99,    3.01,    0.00 /
      DATA B(90334), B(90335), B(90336) /   -24.42,    9.05,    0.00 /
      DATA B(90433), B(90434), B(90435) /   -32.99,   15.06,    0.00 /
      DATA B(90532), B(90533), B(90534) /   -40.34,   17.26,    0.00 /
      DATA B(90631), B(90632), B(90633) /   -50.40,    8.09,    0.00 /
      DATA B(90730), B(90731), B(90732) /   -60.84,   -8.64,    0.00 /
      DATA B(90829), B(90830), B(90831) /   -67.80,  -22.63,    0.00 /
      DATA B(90928), B(90929), B(90930) /   -70.72,  -28.90,    0.00 /
      DATA B(89842), B(89843), B(89844) /    25.76,  -11.32,    0.00 /
      DATA B(89941), B(89942), B(89943) /    22.98,  -10.14,    0.00 /
      DATA B(90040), B(90041), B(90042) /    18.01,   -8.17,    0.00 /
      DATA B(90139), B(90140), B(90141) /     6.98,   -4.67,    0.00 /
      DATA B(90238), B(90239), B(90240) /    -5.33,    0.36,    0.00 /
      DATA B(90337), B(90338), B(90339) /   -16.45,    5.74,    0.00 /
      DATA B(90436), B(90437), B(90438) /   -24.74,   12.68,    0.00 /
      DATA B(90535), B(90536), B(90537) /   -30.98,   18.62,    0.00 /
      DATA B(90634), B(90635), B(90636) /   -43.14,    7.38,    0.00 /
      DATA B(90733), B(90734), B(90735) /   -55.68,  -14.03,    0.00 /
      DATA B(90832), B(90833), B(90834) /   -62.68,  -29.68,    0.00 /
      DATA B(90931), B(90932), B(90933) /   -64.69,  -35.30,    0.00 /
      DATA B(89845), B(89846), B(89847) /    31.82,  -12.57,    0.00 /
      DATA B(89944), B(89945), B(89946) /    29.33,  -11.35,    0.00 /
      DATA B(90043), B(90044), B(90045) /    24.30,   -9.22,    0.00 /
      DATA B(90142), B(90143), B(90144) /    15.04,   -6.01,    0.00 /
      DATA B(90241), B(90242), B(90243) /     3.92,   -2.26,    0.00 /
      DATA B(90340), B(90341), B(90342) /    -6.46,    1.06,    0.00 /
      DATA B(90439), B(90440), B(90441) /   -13.53,    6.39,    0.00 /
      DATA B(90538), B(90539), B(90540) /   -20.08,   18.70,    0.00 /
      DATA B(90637), B(90638), B(90639) /   -35.88,    4.81,    0.00 /
      DATA B(90736), B(90737), B(90738) /   -50.78,  -21.32,    0.00 /
      DATA B(90835), B(90836), B(90837) /   -56.69,  -36.55,    0.00 /
      DATA B(90934), B(90935), B(90936) /   -56.60,  -39.41,    0.00 /
      DATA B(89848), B(89849), B(89850) /    36.20,  -13.66,    0.00 /
      DATA B(89947), B(89948), B(89949) /    33.76,  -12.32,    0.00 /
      DATA B(90046), B(90047), B(90048) /    28.95,   -9.99,    0.00 /
      DATA B(90145), B(90146), B(90147) /    21.33,   -6.92,    0.00 /
      DATA B(90244), B(90245), B(90246) /    12.38,   -4.22,    0.00 /
      DATA B(90343), B(90344), B(90345) /     4.56,   -3.41,    0.00 /
      DATA B(90442), B(90443), B(90444) /     0.14,   -4.01,    0.00 /
      DATA B(90541), B(90542), B(90543) /   -10.85,   11.20,    0.00 /
      DATA B(90640), B(90641), B(90642) /   -30.21,   -2.85,    0.00 /
      DATA B(90739), B(90740), B(90741) /   -46.42,  -30.13,    0.00 /
      DATA B(90838), B(90839), B(90840) /   -49.23,  -41.46,    0.00 /
      DATA B(90937), B(90938), B(90939) /   -45.39,  -38.43,    0.00 /
      DATA B(89851), B(89852), B(89853) /    38.81,  -14.82,    0.00 /
      DATA B(89950), B(89951), B(89952) /    36.49,  -13.36,    0.00 /
      DATA B(90049), B(90050), B(90051) /    32.20,  -10.82,    0.00 /
      DATA B(90148), B(90149), B(90150) /    26.02,   -7.60,    0.00 /
      DATA B(90247), B(90248), B(90249) /    19.10,   -5.10,    0.00 /
      DATA B(90346), B(90347), B(90348) /    13.13,   -5.98,    0.00 /
      DATA B(90445), B(90446), B(90447) /     7.56,   -8.83,    0.00 /
      DATA B(90544), B(90545), B(90546) /    -5.79,   -1.95,    0.00 /
      DATA B(90643), B(90644), B(90645) /   -26.21,  -13.44,    0.00 /
      DATA B(90742), B(90743), B(90744) /   -42.03,  -37.50,    0.00 /
      DATA B(90841), B(90842), B(90843) /   -38.74,  -40.58,    0.00 /
      DATA B(90940), B(90941), B(90942) /   -30.00,  -29.03,    0.00 /
      DATA B(89854), B(89855), B(89856) /    39.78,  -16.27,    0.00 /
      DATA B(89953), B(89954), B(89955) /    37.68,  -14.76,    0.00 /
      DATA B(90052), B(90053), B(90054) /    33.99,  -12.10,    0.00 /
      DATA B(90151), B(90152), B(90153) /    28.98,   -8.57,    0.00 /
      DATA B(90250), B(90251), B(90252) /    23.45,   -5.22,    0.00 /
      DATA B(90349), B(90350), B(90351) /    18.27,   -5.77,    0.00 /
      DATA B(90448), B(90449), B(90450) /    12.11,  -13.74,    0.00 /
      DATA B(90547), B(90548), B(90549) /    -1.76,   -9.84,    0.00 /
      DATA B(90646), B(90647), B(90648) /   -21.48,  -17.16,    0.00 /
      DATA B(90745), B(90746), B(90747) /   -35.50,  -37.18,    0.00 /
      DATA B(90844), B(90845), B(90846) /   -20.93,  -25.02,    0.00 /
      DATA B(90943), B(90944), B(90945) /   -11.05,  -10.03,    0.00 /
      DATA B(89857), B(89858), B(89859) /    39.28,  -18.13,    0.00 /
      DATA B(89956), B(89957), B(89958) /    37.45,  -16.69,    0.00 /
      DATA B(90055), B(90056), B(90057) /    34.30,  -14.16,    0.00 /
      DATA B(90154), B(90155), B(90156) /    30.14,  -10.60,    0.00 /
      DATA B(90253), B(90254), B(90255) /    25.46,   -6.45,    0.00 /
      DATA B(90352), B(90353), B(90354) /    20.47,   -3.35,    0.00 /
      DATA B(90451), B(90452), B(90453) /    15.30,  -19.45,    0.00 /
      DATA B(90550), B(90551), B(90552) /     2.27,  -10.44,    0.00 /
      DATA B(90649), B(90650), B(90651) /   -15.39,  -10.68,    0.00 /
      DATA B(90748), B(90749), B(90750) /   -22.30,  -20.54,    0.00 /
      DATA B(90847), B(90848), B(90849) /    17.78,   32.08,    0.00 /
      DATA B(90946), B(90947), B(90948) /     3.11,    6.43,    0.00 /
      DATA B(89860), B(89861), B(89862) /    37.49,  -20.33,    0.00 /
      DATA B(89959), B(89960), B(89961) /    35.91,  -19.11,    0.00 /
      DATA B(90058), B(90059), B(90060) /    33.22,  -17.10,    0.00 /
      DATA B(90157), B(90158), B(90159) /    29.65,  -14.23,    0.00 /
      DATA B(90256), B(90257), B(90258) /    25.49,  -10.52,    0.00 /
      DATA B(90355), B(90356), B(90357) /    20.90,   -7.71,    0.00 /
      DATA B(90454), B(90455), B(90456) /    15.73,  -17.58,    0.00 /
      DATA B(90553), B(90554), B(90555) /     5.52,   -5.48,    0.00 /
      DATA B(90652), B(90653), B(90654) /    -9.92,    1.48,    0.00 /
      DATA B(90751), B(90752), B(90753) /    -9.38,   -0.37,    0.00 /
      DATA B(90850), B(90851), B(90852) /    13.15,   25.21,    0.00 /
      DATA B(90949), B(90950), B(90951) /     5.83,    9.15,    0.00 /
      DATA B(89863), B(89864), B(89865) /    34.61,  -22.60,    0.00 /
      DATA B(89962), B(89963), B(89964) /    33.25,  -21.73,    0.00 /
      DATA B(90061), B(90062), B(90063) /    30.92,  -20.61,    0.00 /
      DATA B(90160), B(90161), B(90162) /    27.76,  -19.18,    0.00 /
      DATA B(90259), B(90260), B(90261) /    23.95,  -17.39,    0.00 /
      DATA B(90358), B(90359), B(90360) /    19.56,  -16.15,    0.00 /
      DATA B(90457), B(90458), B(90459) /    13.97,  -15.59,    0.00 /
      DATA B(90556), B(90557), B(90558) /     4.51,   -2.25,    0.00 /
      DATA B(90655), B(90656), B(90657) /    -6.51,    7.38,    0.00 /
      DATA B(90754), B(90755), B(90756) /    -6.15,    4.73,    0.00 /
      DATA B(90853), B(90854), B(90855) /     0.97,    7.33,    0.00 /
      DATA B(90952), B(90953), B(90954) /    -2.54,   -3.26,    0.00 /
      DATA B(89866), B(89867), B(89868) /    30.86,  -24.53,    0.00 /
      DATA B(89965), B(89966), B(89967) /    29.70,  -24.06,    0.00 /
      DATA B(90064), B(90065), B(90066) /    27.65,  -23.98,    0.00 /
      DATA B(90163), B(90164), B(90165) /    24.81,  -24.31,    0.00 /
      DATA B(90262), B(90263), B(90264) /    21.24,  -24.97,    0.00 /
      DATA B(90361), B(90362), B(90363) /    16.88,  -24.62,    0.00 /
      DATA B(90460), B(90461), B(90462) /    11.29,  -18.01,    0.00 /
      DATA B(90559), B(90560), B(90561) /     3.25,   -4.95,    0.00 /
      DATA B(90658), B(90659), B(90660) /    -4.89,    3.57,    0.00 /
      DATA B(90757), B(90758), B(90759) /    -7.25,    1.17,    0.00 /
      DATA B(90856), B(90857), B(90858) /    -7.57,   -5.26,    0.00 /
      DATA B(90955), B(90956), B(90957) /   -10.34,  -13.79,    0.00 /
      DATA B(89869), B(89870), B(89871) /    26.48,  -25.62,    0.00 /
      DATA B(89968), B(89969), B(89970) /    25.50,  -25.51,    0.00 /
      DATA B(90067), B(90068), B(90069) /    23.72,  -26.34,    0.00 /
      DATA B(90166), B(90167), B(90168) /    21.18,  -28.15,    0.00 /
      DATA B(90265), B(90266), B(90267) /    17.86,  -30.73,    0.00 /
      DATA B(90364), B(90365), B(90366) /    13.61,  -32.35,    0.00 /
      DATA B(90463), B(90464), B(90465) /     8.57,  -22.35,    0.00 /
      DATA B(90562), B(90563), B(90564) /     1.91,   -9.90,    0.00 /
      DATA B(90661), B(90662), B(90663) /    -4.79,   -2.70,    0.00 /
      DATA B(90760), B(90761), B(90762) /    -8.90,   -4.69,    0.00 /
      DATA B(90859), B(90860), B(90861) /   -11.80,  -11.93,    0.00 /
      DATA B(90958), B(90959), B(90960) /   -14.47,  -18.71,    0.00 /
      DATA B(89872), B(89873), B(89874) /    21.73,  -25.47,    0.00 /
      DATA B(89971), B(89972), B(89973) /    20.92,  -25.60,    0.00 /
      DATA B(90070), B(90071), B(90072) /    19.40,  -26.96,    0.00 /
      DATA B(90169), B(90170), B(90171) /    17.22,  -29.52,    0.00 /
      DATA B(90268), B(90269), B(90270) /    14.31,  -32.85,    0.00 /
      DATA B(90367), B(90368), B(90369) /    10.54,  -34.86,    0.00 /
      DATA B(90466), B(90467), B(90468) /     6.21,  -25.10,    0.00 /
      DATA B(90565), B(90566), B(90567) /     0.66,  -14.27,    0.00 /
      DATA B(90664), B(90665), B(90666) /    -5.18,   -8.34,    0.00 /
      DATA B(90763), B(90764), B(90765) /    -9.92,   -9.71,    0.00 /
      DATA B(90862), B(90863), B(90864) /   -13.64,  -15.57,    0.00 /
      DATA B(90961), B(90962), B(90963) /   -16.20,  -20.58,    0.00 /
      DATA B(89875), B(89876), B(89877) /    16.87,  -23.89,    0.00 /
      DATA B(89974), B(89975), B(89976) /    16.23,  -24.09,    0.00 /
      DATA B(90073), B(90074), B(90075) /    14.97,  -25.51,    0.00 /
      DATA B(90172), B(90173), B(90174) /    13.20,  -28.05,    0.00 /
      DATA B(90271), B(90272), B(90273) /    10.92,  -30.94,    0.00 /
      DATA B(90370), B(90371), B(90372) /     8.00,  -31.39,    0.00 /
      DATA B(90469), B(90470), B(90471) /     4.39,  -24.74,    0.00 /
      DATA B(90568), B(90569), B(90570) /    -0.26,  -16.58,    0.00 /
      DATA B(90667), B(90668), B(90669) /    -5.42,  -12.09,    0.00 /
      DATA B(90766), B(90767), B(90768) /   -10.17,  -12.99,    0.00 /
      DATA B(90865), B(90866), B(90867) /   -14.00,  -17.25,    0.00 /
      DATA B(90964), B(90965), B(90966) /   -16.38,  -20.75,    0.00 /
      DATA B(89878), B(89879), B(89880) /    12.17,  -20.93,    0.00 /
      DATA B(89977), B(89978), B(89979) /    11.66,  -21.04,    0.00 /
      DATA B(90076), B(90077), B(90078) /    10.65,  -22.12,    0.00 /
      DATA B(90175), B(90176), B(90177) /     9.34,  -24.04,    0.00 /
      DATA B(90274), B(90275), B(90276) /     7.81,  -26.02,    0.00 /
      DATA B(90373), B(90374), B(90375) /     5.87,  -25.93,    0.00 /
      DATA B(90472), B(90473), B(90474) /     3.14,  -21.84,    0.00 /
      DATA B(90571), B(90572), B(90573) /    -0.70,  -16.57,    0.00 /
      DATA B(90670), B(90671), B(90672) /    -5.26,  -13.67,    0.00 /
      DATA B(90769), B(90770), B(90771) /    -9.74,  -14.45,    0.00 /
      DATA B(90868), B(90869), B(90870) /   -13.39,  -17.50,    0.00 /
      DATA B(90967), B(90968), B(90969) /   -15.56,  -19.88,    0.00 /
      DATA B(89881), B(89882), B(89883) /     7.88,  -16.90,    0.00 /
      DATA B(89980), B(89981), B(89982) /     7.46,  -16.78,    0.00 /
      DATA B(90079), B(90080), B(90081) /     6.62,  -17.22,    0.00 /
      DATA B(90178), B(90179), B(90180) /     5.73,  -18.25,    0.00 /
      DATA B(90277), B(90278), B(90279) /     5.05,  -19.42,    0.00 /
      DATA B(90376), B(90377), B(90378) /     4.22,  -19.42,    0.00 /
      DATA B(90475), B(90476), B(90477) /     2.48,  -17.36,    0.00 /
      DATA B(90574), B(90575), B(90576) /    -0.62,  -14.64,    0.00 /
      DATA B(90673), B(90674), B(90675) /    -4.65,  -13.35,    0.00 /
      DATA B(90772), B(90773), B(90774) /    -8.79,  -14.35,    0.00 /
      DATA B(90871), B(90872), B(90873) /   -12.18,  -16.68,    0.00 /
      DATA B(90970), B(90971), B(90972) /   -14.13,  -18.33,    0.00 /
      DATA B(89884), B(89885), B(89886) /     4.27,  -12.31,    0.00 /
      DATA B(89983), B(89984), B(89985) /     3.88,  -11.88,    0.00 /
      DATA B(90082), B(90083), B(90084) /     3.08,  -11.50,    0.00 /
      DATA B(90181), B(90182), B(90183) /     2.49,  -11.51,    0.00 /
      DATA B(90280), B(90281), B(90282) /     2.68,  -12.05,    0.00 /
      DATA B(90379), B(90380), B(90381) /     3.10,  -12.43,    0.00 /
      DATA B(90478), B(90479), B(90480) /     2.41,  -12.00,    0.00 /
      DATA B(90577), B(90578), B(90579) /    -0.05,  -11.40,    0.00 /
      DATA B(90676), B(90677), B(90678) /    -3.68,  -11.62,    0.00 /
      DATA B(90775), B(90776), B(90777) /    -7.49,  -13.08,    0.00 /
      DATA B(90874), B(90875), B(90876) /   -10.61,  -15.09,    0.00 /
      DATA B(90973), B(90974), B(90975) /   -12.38,  -16.32,    0.00 /
      DATA B(89887), B(89888), B(89889) /     1.56,   -7.76,    0.00 /
      DATA B(89986), B(89987), B(89988) /     1.14,   -6.98,    0.00 /
      DATA B(90085), B(90086), B(90087) /     0.26,   -5.71,    0.00 /
      DATA B(90184), B(90185), B(90186) /    -0.27,   -4.60,    0.00 /
      DATA B(90283), B(90284), B(90285) /     0.76,   -4.68,    0.00 /
      DATA B(90382), B(90383), B(90384) /     2.56,   -5.53,    0.00 /
      DATA B(90481), B(90482), B(90483) /     2.93,   -6.37,    0.00 /
      DATA B(90580), B(90581), B(90582) /     0.87,   -7.49,    0.00 /
      DATA B(90679), B(90680), B(90681) /    -2.49,   -9.04,    0.00 /
      DATA B(90778), B(90779), B(90780) /    -6.03,  -11.05,    0.00 /
      DATA B(90877), B(90878), B(90879) /    -8.90,  -13.02,    0.00 /
      DATA B(90976), B(90977), B(90978) /   -10.50,  -14.07,    0.00 /
      DATA B(89890), B(89891), B(89892) /    -0.10,   -3.83,    0.00 /
      DATA B(89989), B(89990), B(89991) /    -0.57,   -2.71,    0.00 /
      DATA B(90088), B(90089), B(90090) /    -1.52,   -0.65,    0.00 /
      DATA B(90187), B(90188), B(90189) /    -2.29,    1.63,    0.00 /
      DATA B(90286), B(90287), B(90288) /    -0.52,    1.89,    0.00 /
      DATA B(90385), B(90386), B(90387) /     2.58,    0.62,    0.00 /
      DATA B(90484), B(90485), B(90486) /     3.87,   -1.03,    0.00 /
      DATA B(90583), B(90584), B(90585) /     1.90,   -3.51,    0.00 /
      DATA B(90682), B(90683), B(90684) /    -1.27,   -6.13,    0.00 /
      DATA B(90781), B(90782), B(90783) /    -4.56,   -8.67,    0.00 /
      DATA B(90880), B(90881), B(90882) /    -7.22,  -10.74,    0.00 /
      DATA B(90979), B(90980), B(90981) /    -8.68,  -11.75,    0.00 /
      DATA B(89893), B(89894), B(89895) /    -0.65,   -0.97,    0.00 /
      DATA B(89992), B(89993), B(89994) /    -1.18,    0.48,    0.00 /
      DATA B(90091), B(90092), B(90093) /    -2.11,    3.10,    0.00 /
      DATA B(90190), B(90191), B(90192) /    -2.55,    5.81,    0.00 /
      DATA B(90289), B(90290), B(90291) /    -0.58,    6.52,    0.00 /
      DATA B(90388), B(90389), B(90390) /     2.83,    5.44,    0.00 /
      DATA B(90487), B(90488), B(90489) /     4.63,    3.41,    0.00 /
      DATA B(90586), B(90587), B(90588) /     2.71,    0.04,    0.00 /
      DATA B(90685), B(90686), B(90687) /    -0.19,   -3.30,    0.00 /
      DATA B(90784), B(90785), B(90786) /    -3.23,   -6.28,    0.00 /
      DATA B(90883), B(90884), B(90885) /    -5.68,   -8.51,    0.00 /
      DATA B(90982), B(90983), B(90984) /    -7.02,   -9.54,    0.00 /
      DATA B(89896), B(89897), B(89898) /    -0.22,    0.61,    0.00 /
      DATA B(89995), B(89996), B(89997) /    -0.87,    2.42,    0.00 /
      DATA B(90094), B(90095), B(90096) /    -1.74,    5.46,    0.00 /
      DATA B(90193), B(90194), B(90195) /    -1.79,    8.31,    0.00 /
      DATA B(90292), B(90293), B(90294) /     0.01,    9.45,    0.00 /
      DATA B(90391), B(90392), B(90393) /     2.85,    8.66,    0.00 /
      DATA B(90490), B(90491), B(90492) /     4.38,    6.39,    0.00 /
      DATA B(90589), B(90590), B(90591) /     3.16,    2.87,    0.00 /
      DATA B(90688), B(90689), B(90690) /     0.64,   -0.86,    0.00 /
      DATA B(90787), B(90788), B(90789) /    -2.12,   -4.14,    0.00 /
      DATA B(90886), B(90887), B(90888) /    -4.39,   -6.53,    0.00 /
      DATA B(90985), B(90986), B(90987) /    -5.63,   -7.62,    0.00 /
      DATA B(89899), B(89900), B(89901) /     0.91,    0.93,    0.00 /
      DATA B(89998), B(89999), B(90000) /     0.01,    3.24,    0.00 /
      DATA B(90097), B(90098), B(90099) /    -0.92,    6.73,    0.00 /
      DATA B(90196), B(90197), B(90198) /    -0.87,    9.81,    0.00 /
      DATA B(90295), B(90296), B(90297) /     0.64,   11.27,    0.00 /
      DATA B(90394), B(90395), B(90396) /     2.85,   10.73,    0.00 /
      DATA B(90493), B(90494), B(90495) /     4.10,    8.45,    0.00 /
      DATA B(90592), B(90593), B(90594) /     3.33,    4.92,    0.00 /
      DATA B(90691), B(90692), B(90693) /     1.21,    1.03,    0.00 /
      DATA B(90790), B(90791), B(90792) /    -1.29,   -2.44,    0.00 /
      DATA B(90889), B(90890), B(90891) /    -3.41,   -4.95,    0.00 /
      DATA B(90988), B(90989), B(90990) /    -4.57,   -6.10,    0.00 /
      DATA B(89902), B(89903), B(89904) /     2.31,    0.29,    0.00 /
      DATA B(90001), B(90002), B(90003) /     0.97,    3.35,    0.00 /
      DATA B(90100), B(90101), B(90102) /    -0.14,    7.33,    0.00 /
      DATA B(90199), B(90200), B(90201) /    -0.17,   10.69,    0.00 /
      DATA B(90298), B(90299), B(90300) /     1.09,   12.39,    0.00 /
      DATA B(90397), B(90398), B(90399) /     2.90,   12.03,    0.00 /
      DATA B(90496), B(90497), B(90498) /     3.96,    9.80,    0.00 /
      DATA B(90595), B(90596), B(90597) /     3.42,    6.27,    0.00 /
      DATA B(90694), B(90695), B(90696) /     1.57,    2.31,    0.00 /
      DATA B(90793), B(90794), B(90795) /    -0.76,   -1.29,    0.00 /
      DATA B(90892), B(90893), B(90894) /    -2.78,   -3.89,    0.00 /
      DATA B(90991), B(90992), B(90993) /    -3.89,   -5.08,    0.00 /
      DATA B(89905), B(89906), B(89907) /     3.26,   -0.46,    0.00 /
      DATA B(90004), B(90005), B(90006) /     1.55,    3.19,    0.00 /
      DATA B(90103), B(90104), B(90105) /     0.23,    7.58,    0.00 /
      DATA B(90202), B(90203), B(90204) /     0.12,   11.19,    0.00 /
      DATA B(90301), B(90302), B(90303) /     1.29,   13.04,    0.00 /
      DATA B(90400), B(90401), B(90402) /     2.99,   12.77,    0.00 /
      DATA B(90499), B(90500), B(90501) /     4.00,   10.55,    0.00 /
      DATA B(90598), B(90599), B(90600) /     3.53,    6.98,    0.00 /
      DATA B(90697), B(90698), B(90699) /     1.77,    2.94,    0.00 /
      DATA B(90796), B(90797), B(90798) /    -0.51,   -0.75,    0.00 /
      DATA B(90895), B(90896), B(90897) /    -2.51,   -3.41,    0.00 /
      DATA B(90994), B(90995), B(90996) /    -3.62,   -4.65,    0.00 /
   
      END

      BLOCK DATA INITEQ
      IMPLICIT DOUBLE PRECISION (A-H, O-Z)
      IMPLICIT INTEGER*4 (I-N)
      parameter (NDLOC = 1990)
      COMMON /QPARM/ STRIKE(NDLOC), HL(NDLOC), EQLAT(NDLOC),
     *   EQLON(NDLOC), SSLIP(NDLOC), DSLIP(NDLOC), DIP(NDLOC),
     *   DEPTH(NDLOC), WIDTH(NDLOC), EQLATR(50), EQLONR(50),
     *   EQRAD(50), ITEQK(50), NLOC(50), NFP(50), NUMEQ 

      DATA EQLATR(  1)  /0.5712986241E+00/
     *   EQLONR(  1)  /0.2015855286E+01/
     *   EQRAD(  1)   /0.2000000000E+06/
     *   ITEQK(  1)   /    42865920/
     *   NLOC(  1)    /   1/
     *   NFP(  1)     /   5/
      DATA STRIKE(   1) /0.2495820830E+01/
     *    HL(   1) /0.1100000000E+05/
     *    EQLAT(   1) /0.5685458908E+00/
     *    EQLON(   1) /0.2011428957E+01/
     *    SSLIP(   1) /0.2610000000E+01/
     *    DSLIP(   1) /0.6300000000E-01/
     *    DIP(   1) /0.1308996939E+01/
     *    DEPTH(   1) /0.0000000000E+00/
     *    WIDTH(   1) /0.1000000000E+05/
      DATA STRIKE(   2) /0.2495820830E+01/
     *    HL(   2) /0.4000000000E+04/
     *    EQLAT(   2) /0.5704317190E+00/
     *    EQLON(   2) /0.2013106392E+01/
     *    SSLIP(   2) /0.4331000000E+01/
     *    DSLIP(   2) /0.2535000000E+01/
     *    DIP(   2) /0.1308996939E+01/
     *    DEPTH(   2) /0.0000000000E+00/
     *    WIDTH(   2) /0.1000000000E+05/
      DATA STRIKE(   3) /0.2495820830E+01/
     *    HL(   3) /0.4000000000E+04/
     *    EQLAT(   3) /0.5714886904E+00/
     *    EQLON(   3) /0.2014003317E+01/
     *    SSLIP(   3) /0.1323000000E+01/
     *    DSLIP(   3) /-.1008000000E+01/
     *    DIP(   3) /0.1308996939E+01/
     *    DEPTH(   3) /0.0000000000E+00/
     *    WIDTH(   3) /0.1000000000E+05/
      DATA STRIKE(   4) /0.2495820830E+01/
     *    HL(   4) /0.1000000000E+05/
     *    EQLAT(   4) /0.5731999857E+00/
     *    EQLON(   4) /0.2015574114E+01/
     *    SSLIP(   4) /0.1033000000E+01/
     *    DSLIP(   4) /0.1830000000E+00/
     *    DIP(   4) /0.1308996939E+01/
     *    DEPTH(   4) /0.0000000000E+00/
     *    WIDTH(   4) /0.1000000000E+05/
      DATA STRIKE(   5) /0.6230825430E+01/
     *    HL(   5) /0.6000000000E+04/
     *    EQLAT(   5) /0.5745768760E+00/
     *    EQLON(   5) /0.2015637120E+01/
     *    SSLIP(   5) /0.1800000000E-01/
     *    DSLIP(   5) /0.3110000000E+00/
     *    DIP(   5) /0.1570796327E+01/
     *    DEPTH(   5) /0.0000000000E+00/
     *    WIDTH(   5) /0.1000000000E+05/
      DATA EQLATR(  2)  /0.5753826945E+00/
     *   EQLONR(  2)  /0.2024581932E+01/
     *   EQRAD(  2)   /0.2000000000E+06/
     *   ITEQK(  2)   /    44140320/
     *   NLOC(  2)    /   6/
     *   NFP(  2)     /   1/
      DATA STRIKE(   6) /0.5410520681E+01/
     *    HL(   6) /0.1500000000E+05/
     *    EQLAT(   6) /0.5773549166E+00/
     *    EQLON(   6) /0.2026690814E+01/
     *    SSLIP(   6) /0.4150000000E+00/
     *    DSLIP(   6) /-.1440000000E+00/
     *    DIP(   6) /0.1570796327E+01/
     *    DEPTH(   6) /0.0000000000E+00/
     *    WIDTH(   6) /0.1000000000E+05/
      DATA EQLATR(  3)  /0.5808979349E+00/
     *   EQLONR(  3)  /0.2027775885E+01/
     *   EQRAD(  3)   /0.2000000000E+06/
     *   ITEQK(  3)   /    50140800/
     *   NLOC(  3)    /   7/
     *   NFP(  3)     /   1/
      DATA STRIKE(   7) /0.5480333851E+01/
     *    HL(   7) /0.1500000000E+05/
     *    EQLAT(   7) /0.5816309732E+00/
     *    EQLON(   7) /0.2028523409E+01/
     *    SSLIP(   7) /0.3280000000E+00/
     *    DSLIP(   7) /-.3940000000E+00/
     *    DIP(   7) /0.1570796327E+01/
     *    DEPTH(   7) /0.0000000000E+00/
     *    WIDTH(   7) /0.1000000000E+05/
      DATA EQLATR(  4)  /0.5792747787E+00/
     *   EQLONR(  4)  /0.2026827647E+01/
     *   EQRAD(  4)   /0.2000000000E+06/
     *   ITEQK(  4)   /    57535200/
     *   NLOC(  4)    /   8/
     *   NFP(  4)     /   1/
      DATA STRIKE(   8) /0.2443460953E+01/
     *    HL(   8) /0.1500000000E+05/
     *    EQLAT(   8) /0.5783293339E+00/
     *    EQLON(   8) /0.2026079948E+01/
     *    SSLIP(   8) /0.8930000000E+00/
     *    DSLIP(   8) /0.3800000000E+00/
     *    DIP(   8) /0.1448623279E+01/
     *    DEPTH(   8) /0.1000000000E+04/
     *    WIDTH(   8) /0.9000000000E+04/
      DATA EQLATR(  5)  /0.5692159227E+00/
     *   EQLONR(  5)  /0.2012681754E+01/
     *   EQRAD(  5)   /0.2000000000E+06/
     *   ITEQK(  5)   /    63591840/
     *   NLOC(  5)    /   9/
     *   NFP(  5)     /   1/
      DATA STRIKE(   9) /0.2495820830E+01/
     *    HL(   9) /0.2000000000E+05/
     *    EQLAT(   9) /0.5721238157E+00/
     *    EQLON(   9) /0.2014517142E+01/
     *    SSLIP(   9) /0.6480000000E+00/
     *    DSLIP(   9) /0.3950000000E+00/
     *    DIP(   9) /0.1570796327E+01/
     *    DEPTH(   9) /0.0000000000E+00/
     *    WIDTH(   9) /0.1000000000E+05/
      DATA EQLATR(  6)  /0.5998173040E+00/
     *   EQLONR(  6)  /0.2087117079E+01/
     *   EQRAD(  6)   /0.2000000000E+06/
     *   ITEQK(  6)   /    43453440/
     *   NLOC(  6)    /  10/
     *   NFP(  6)     /   1/
      DATA STRIKE(  10) /0.1815142422E+01/
     *    HL(  10) /0.1250000000E+05/
     *    EQLAT(  10) /0.5993460651E+00/
     *    EQLON(  10) /0.2083835860E+01/
     *    SSLIP(  10) /0.0000000000E+00/
     *    DSLIP(  10) /0.0000000000E+00/
     *    DIP(  10) /0.5235987756E+00/
     *    DEPTH(  10) /0.1500000000E+04/
     *    WIDTH(  10) /0.1300000000E+05/
      DATA EQLATR(  7)  /0.6005882160E+00/
     *   EQLONR(  7)  /0.2066481528E+01/
     *   EQRAD(  7)   /0.2000000000E+06/
     *   ITEQK(  7)   /    59027040/
     *   NLOC(  7)    /  11/
     *   NFP(  7)     /   4/
      DATA STRIKE(  11) /0.1919862177E+01/
     *    HL(  11) /0.6000000000E+04/
     *    EQLAT(  11) /0.5984491404E+00/
     *    EQLON(  11) /0.2066043276E+01/
     *    SSLIP(  11) /0.8130000000E+00/
     *    DSLIP(  11) /-.2123000000E+01/
     *    DIP(  11) /0.6108652382E+00/
     *    DEPTH(  11) /0.5750000000E+03/
     *    WIDTH(  11) /0.1100000000E+05/
      DATA STRIKE(  12) /0.1919862177E+01/
     *    HL(  12) /0.6000000000E+04/
     *    EQLAT(  12) /0.5997823974E+00/
     *    EQLON(  12) /0.2065456496E+01/
     *    SSLIP(  12) /-.1519000000E+01/
     *    DSLIP(  12) /-.3970000000E+01/
     *    DIP(  12) /0.9075712110E+00/
     *    DEPTH(  12) /0.6900000000E+04/
     *    WIDTH(  12) /0.1127000000E+05/
      DATA STRIKE(  13) /0.1919862177E+01/
     *    HL(  13) /0.3000000000E+04/
     *    EQLAT(  13) /0.5983910210E+00/
     *    EQLON(  13) /0.2067885471E+01/
     *    SSLIP(  13) /0.5000000000E+00/
     *    DSLIP(  13) /-.7600000000E+00/
     *    DIP(  13) /0.6108652382E+00/
     *    DEPTH(  13) /0.1720000000E+04/
     *    WIDTH(  13) /0.2100000000E+05/
      DATA STRIKE(  14) /0.3490658504E+00/
     *    HL(  14) /0.4915000000E+04/
     *    EQLAT(  14) /0.5993752121E+00/
     *    EQLON(  14) /0.2066848047E+01/
     *    SSLIP(  14) /-.1313000000E+01/
     *    DSLIP(  14) /-.1320000000E+01/
     *    DIP(  14) /0.1570796327E+01/
     *    DEPTH(  14) /0.1720000000E+04/
     *    WIDTH(  14) /0.5180000000E+04/
      DATA EQLATR(  8)  /0.6108652382E+00/
     *   EQLONR(  8)  /0.2079856510E+01/
     *   EQRAD(  8)   /0.4000000000E+06/
     *   ITEQK(  8)   /    49268160/
     *   NLOC(  8)    /  15/
     *   NFP(  8)     /   3/
      DATA STRIKE(  15) /0.4415683008E+01/
     *    HL(  15) /0.1250000000E+05/
     *    EQLAT(  15) /0.6109233577E+00/
     *    EQLON(  15) /0.2077596308E+01/
     *    SSLIP(  15) /0.3220000000E+00/
     *    DSLIP(  15) /-.3482000000E+01/
     *    DIP(  15) /0.1308996939E+01/
     *    DEPTH(  15) /0.4830000000E+04/
     *    WIDTH(  15) /0.2200000000E+05/
      DATA STRIKE(  16) /0.4153883620E+01/
     *    HL(  16) /0.1250000000E+05/
     *    EQLAT(  16) /0.6132795522E+00/
     *    EQLON(  16) /0.2072922666E+01/
     *    SSLIP(  16) /-.1290000000E+01/
     *    DSLIP(  16) /-.1049000000E+01/
     *    DIP(  16) /0.6108652382E+00/
     *    DEPTH(  16) /0.3440000000E+04/
     *    WIDTH(  16) /0.2000000000E+05/
      DATA STRIKE(  17) /0.3892084232E+01/
     *    HL(  17) /0.1250000000E+05/
     *    EQLAT(  17) /0.6154030943E+00/
     *    EQLON(  17) /0.2069150835E+01/
     *    SSLIP(  17) /-.2330000000E+00/
     *    DSLIP(  17) /-.3230000000E+00/
     *    DIP(  17) /0.3490658504E+00/
     *    DEPTH(  17) /0.2050000000E+04/
     *    WIDTH(  17) /0.2000000000E+05/
      DATA EQLATR(  9)  /0.6248278722E+00/
     *   EQLONR(  9)  /0.2100207049E+01/
     *   EQRAD(  9)   /0.2000000000E+06/
     *   ITEQK(  9)   /    39738240/
     *   NLOC(  9)    /  18/
     *   NFP(  9)     /  98/
      DATA STRIKE(  18) /0.2340137461E+01/
     *    HL(  18) /0.1500000000E+04/
     *    EQLAT(  18) /0.6280858783E+00/
     *    EQLON(  18) /0.2103805394E+01/
     *    SSLIP(  18) /0.1614000000E+00/
     *    DSLIP(  18) /0.0000000000E+00/
     *    DIP(  18) /0.1570796327E+01/
     *    DEPTH(  18) /0.0000000000E+00/
     *    WIDTH(  18) /0.2000000000E+04/
      DATA STRIKE(  19) /0.2340137461E+01/
     *    HL(  19) /0.1500000000E+04/
     *    EQLAT(  19) /0.6280858783E+00/
     *    EQLON(  19) /0.2103805394E+01/
     *    SSLIP(  19) /0.1677000000E+00/
     *    DSLIP(  19) /0.0000000000E+00/
     *    DIP(  19) /0.1570796327E+01/
     *    DEPTH(  19) /0.2000000000E+04/
     *    WIDTH(  19) /0.2000000000E+04/
      DATA STRIKE(  20) /0.2340137461E+01/
     *    HL(  20) /0.1500000000E+04/
     *    EQLAT(  20) /0.6280858783E+00/
     *    EQLON(  20) /0.2103805394E+01/
     *    SSLIP(  20) /0.1747000000E+00/
     *    DSLIP(  20) /0.0000000000E+00/
     *    DIP(  20) /0.1570796327E+01/
     *    DEPTH(  20) /0.4000000000E+04/
     *    WIDTH(  20) /0.2000000000E+04/
      DATA STRIKE(  21) /0.2340137461E+01/
     *    HL(  21) /0.1500000000E+04/
     *    EQLAT(  21) /0.6280858783E+00/
     *    EQLON(  21) /0.2103805394E+01/
     *    SSLIP(  21) /0.1744000000E+00/
     *    DSLIP(  21) /0.0000000000E+00/
     *    DIP(  21) /0.1570796327E+01/
     *    DEPTH(  21) /0.6000000000E+04/
     *    WIDTH(  21) /0.2000000000E+04/
      DATA STRIKE(  22) /0.2340137461E+01/
     *    HL(  22) /0.1500000000E+04/
     *    EQLAT(  22) /0.6280858783E+00/
     *    EQLON(  22) /0.2103805394E+01/
     *    SSLIP(  22) /0.1590000000E+00/
     *    DSLIP(  22) /0.0000000000E+00/
     *    DIP(  22) /0.1570796327E+01/
     *    DEPTH(  22) /0.8000000000E+04/
     *    WIDTH(  22) /0.2000000000E+04/
      DATA STRIKE(  23) /0.2340137461E+01/
     *    HL(  23) /0.1500000000E+04/
     *    EQLAT(  23) /0.6280858783E+00/
     *    EQLON(  23) /0.2103805394E+01/
     *    SSLIP(  23) /0.1238000000E+00/
     *    DSLIP(  23) /0.0000000000E+00/
     *    DIP(  23) /0.1570796327E+01/
     *    DEPTH(  23) /0.1000000000E+05/
     *    WIDTH(  23) /0.2000000000E+04/
      DATA STRIKE(  24) /0.2340137461E+01/
     *    HL(  24) /0.1500000000E+04/
     *    EQLAT(  24) /0.6280858783E+00/
     *    EQLON(  24) /0.2103805394E+01/
     *    SSLIP(  24) /0.6880000000E-01/
     *    DSLIP(  24) /0.0000000000E+00/
     *    DIP(  24) /0.1570796327E+01/
     *    DEPTH(  24) /0.1200000000E+05/
     *    WIDTH(  24) /0.2000000000E+04/
      DATA STRIKE(  25) /0.2340137461E+01/
     *    HL(  25) /0.1500000000E+04/
     *    EQLAT(  25) /0.6277561856E+00/
     *    EQLON(  25) /0.2103388435E+01/
     *    SSLIP(  25) /0.2708000000E+00/
     *    DSLIP(  25) /0.0000000000E+00/
     *    DIP(  25) /0.1570796327E+01/
     *    DEPTH(  25) /0.0000000000E+00/
     *    WIDTH(  25) /0.2000000000E+04/
      DATA STRIKE(  26) /0.2340137461E+01/
     *    HL(  26) /0.1500000000E+04/
     *    EQLAT(  26) /0.6277561856E+00/
     *    EQLON(  26) /0.2103388435E+01/
     *    SSLIP(  26) /0.2869000000E+00/
     *    DSLIP(  26) /0.0000000000E+00/
     *    DIP(  26) /0.1570796327E+01/
     *    DEPTH(  26) /0.2000000000E+04/
     *    WIDTH(  26) /0.2000000000E+04/
      DATA STRIKE(  27) /0.2340137461E+01/
     *    HL(  27) /0.1500000000E+04/
     *    EQLAT(  27) /0.6277561856E+00/
     *    EQLON(  27) /0.2103388435E+01/
     *    SSLIP(  27) /0.3067000000E+00/
     *    DSLIP(  27) /0.0000000000E+00/
     *    DIP(  27) /0.1570796327E+01/
     *    DEPTH(  27) /0.4000000000E+04/
     *    WIDTH(  27) /0.2000000000E+04/
      DATA STRIKE(  28) /0.2340137461E+01/
     *    HL(  28) /0.1500000000E+04/
     *    EQLAT(  28) /0.6277561856E+00/
     *    EQLON(  28) /0.2103388435E+01/
     *    SSLIP(  28) /0.3128000000E+00/
     *    DSLIP(  28) /0.0000000000E+00/
     *    DIP(  28) /0.1570796327E+01/
     *    DEPTH(  28) /0.6000000000E+04/
     *    WIDTH(  28) /0.2000000000E+04/
      DATA STRIKE(  29) /0.2340137461E+01/
     *    HL(  29) /0.1500000000E+04/
     *    EQLAT(  29) /0.6277561856E+00/
     *    EQLON(  29) /0.2103388435E+01/
     *    SSLIP(  29) /0.2890000000E+00/
     *    DSLIP(  29) /0.0000000000E+00/
     *    DIP(  29) /0.1570796327E+01/
     *    DEPTH(  29) /0.8000000000E+04/
     *    WIDTH(  29) /0.2000000000E+04/
      DATA STRIKE(  30) /0.2340137461E+01/
     *    HL(  30) /0.1500000000E+04/
     *    EQLAT(  30) /0.6277561856E+00/
     *    EQLON(  30) /0.2103388435E+01/
     *    SSLIP(  30) /0.2265000000E+00/
     *    DSLIP(  30) /0.0000000000E+00/
     *    DIP(  30) /0.1570796327E+01/
     *    DEPTH(  30) /0.1000000000E+05/
     *    WIDTH(  30) /0.2000000000E+04/
      DATA STRIKE(  31) /0.2340137461E+01/
     *    HL(  31) /0.1500000000E+04/
     *    EQLAT(  31) /0.6277561856E+00/
     *    EQLON(  31) /0.2103388435E+01/
     *    SSLIP(  31) /0.1259000000E+00/
     *    DSLIP(  31) /0.0000000000E+00/
     *    DIP(  31) /0.1570796327E+01/
     *    DEPTH(  31) /0.1200000000E+05/
     *    WIDTH(  31) /0.2000000000E+04/
      DATA STRIKE(  32) /0.2399653189E+01/
     *    HL(  32) /0.1500000000E+04/
     *    EQLAT(  32) /0.6274216060E+00/
     *    EQLON(  32) /0.2102985962E+01/
     *    SSLIP(  32) /0.3079000000E+00/
     *    DSLIP(  32) /0.0000000000E+00/
     *    DIP(  32) /0.1570796327E+01/
     *    DEPTH(  32) /0.0000000000E+00/
     *    WIDTH(  32) /0.2000000000E+04/
      DATA STRIKE(  33) /0.2399653189E+01/
     *    HL(  33) /0.1500000000E+04/
     *    EQLAT(  33) /0.6274216060E+00/
     *    EQLON(  33) /0.2102985962E+01/
     *    SSLIP(  33) /0.3424000000E+00/
     *    DSLIP(  33) /0.0000000000E+00/
     *    DIP(  33) /0.1570796327E+01/
     *    DEPTH(  33) /0.2000000000E+04/
     *    WIDTH(  33) /0.2000000000E+04/
      DATA STRIKE(  34) /0.2399653189E+01/
     *    HL(  34) /0.1500000000E+04/
     *    EQLAT(  34) /0.6274216060E+00/
     *    EQLON(  34) /0.2102985962E+01/
     *    SSLIP(  34) /0.3873000000E+00/
     *    DSLIP(  34) /0.0000000000E+00/
     *    DIP(  34) /0.1570796327E+01/
     *    DEPTH(  34) /0.4000000000E+04/
     *    WIDTH(  34) /0.2000000000E+04/
      DATA STRIKE(  35) /0.2399653189E+01/
     *    HL(  35) /0.1500000000E+04/
     *    EQLAT(  35) /0.6274216060E+00/
     *    EQLON(  35) /0.2102985962E+01/
     *    SSLIP(  35) /0.4116000000E+00/
     *    DSLIP(  35) /0.0000000000E+00/
     *    DIP(  35) /0.1570796327E+01/
     *    DEPTH(  35) /0.6000000000E+04/
     *    WIDTH(  35) /0.2000000000E+04/
      DATA STRIKE(  36) /0.2399653189E+01/
     *    HL(  36) /0.1500000000E+04/
     *    EQLAT(  36) /0.6274216060E+00/
     *    EQLON(  36) /0.2102985962E+01/
     *    SSLIP(  36) /0.3901000000E+00/
     *    DSLIP(  36) /0.0000000000E+00/
     *    DIP(  36) /0.1570796327E+01/
     *    DEPTH(  36) /0.8000000000E+04/
     *    WIDTH(  36) /0.2000000000E+04/
      DATA STRIKE(  37) /0.2399653189E+01/
     *    HL(  37) /0.1500000000E+04/
     *    EQLAT(  37) /0.6274216060E+00/
     *    EQLON(  37) /0.2102985962E+01/
     *    SSLIP(  37) /0.3097000000E+00/
     *    DSLIP(  37) /0.0000000000E+00/
     *    DIP(  37) /0.1570796327E+01/
     *    DEPTH(  37) /0.1000000000E+05/
     *    WIDTH(  37) /0.2000000000E+04/
      DATA STRIKE(  38) /0.2399653189E+01/
     *    HL(  38) /0.1500000000E+04/
     *    EQLAT(  38) /0.6274216060E+00/
     *    EQLON(  38) /0.2102985962E+01/
     *    SSLIP(  38) /0.1732000000E+00/
     *    DSLIP(  38) /0.0000000000E+00/
     *    DIP(  38) /0.1570796327E+01/
     *    DEPTH(  38) /0.1200000000E+05/
     *    WIDTH(  38) /0.2000000000E+04/
      DATA STRIKE(  39) /0.2399653189E+01/
     *    HL(  39) /0.1500000000E+04/
     *    EQLAT(  39) /0.6270725402E+00/
     *    EQLON(  39) /0.2102593263E+01/
     *    SSLIP(  39) /0.2808000000E+00/
     *    DSLIP(  39) /0.0000000000E+00/
     *    DIP(  39) /0.1570796327E+01/
     *    DEPTH(  39) /0.0000000000E+00/
     *    WIDTH(  39) /0.2000000000E+04/
      DATA STRIKE(  40) /0.2399653189E+01/
     *    HL(  40) /0.1500000000E+04/
     *    EQLAT(  40) /0.6270725402E+00/
     *    EQLON(  40) /0.2102593263E+01/
     *    SSLIP(  40) /0.3490000000E+00/
     *    DSLIP(  40) /0.0000000000E+00/
     *    DIP(  40) /0.1570796327E+01/
     *    DEPTH(  40) /0.2000000000E+04/
     *    WIDTH(  40) /0.2000000000E+04/
      DATA STRIKE(  41) /0.2399653189E+01/
     *    HL(  41) /0.1500000000E+04/
     *    EQLAT(  41) /0.6270725402E+00/
     *    EQLON(  41) /0.2102593263E+01/
     *    SSLIP(  41) /0.4346000000E+00/
     *    DSLIP(  41) /0.0000000000E+00/
     *    DIP(  41) /0.1570796327E+01/
     *    DEPTH(  41) /0.4000000000E+04/
     *    WIDTH(  41) /0.2000000000E+04/
      DATA STRIKE(  42) /0.2399653189E+01/
     *    HL(  42) /0.1500000000E+04/
     *    EQLAT(  42) /0.6270725402E+00/
     *    EQLON(  42) /0.2102593263E+01/
     *    SSLIP(  42) /0.4883000000E+00/
     *    DSLIP(  42) /0.0000000000E+00/
     *    DIP(  42) /0.1570796327E+01/
     *    DEPTH(  42) /0.6000000000E+04/
     *    WIDTH(  42) /0.2000000000E+04/
      DATA STRIKE(  43) /0.2399653189E+01/
     *    HL(  43) /0.1500000000E+04/
     *    EQLAT(  43) /0.6270725402E+00/
     *    EQLON(  43) /0.2102593263E+01/
     *    SSLIP(  43) /0.4760000000E+00/
     *    DSLIP(  43) /0.0000000000E+00/
     *    DIP(  43) /0.1570796327E+01/
     *    DEPTH(  43) /0.8000000000E+04/
     *    WIDTH(  43) /0.2000000000E+04/
      DATA STRIKE(  44) /0.2399653189E+01/
     *    HL(  44) /0.1500000000E+04/
     *    EQLAT(  44) /0.6270725402E+00/
     *    EQLON(  44) /0.2102593263E+01/
     *    SSLIP(  44) /0.3829000000E+00/
     *    DSLIP(  44) /0.0000000000E+00/
     *    DIP(  44) /0.1570796327E+01/
     *    DEPTH(  44) /0.1000000000E+05/
     *    WIDTH(  44) /0.2000000000E+04/
      DATA STRIKE(  45) /0.2399653189E+01/
     *    HL(  45) /0.1500000000E+04/
     *    EQLAT(  45) /0.6270725402E+00/
     *    EQLON(  45) /0.2102593263E+01/
     *    SSLIP(  45) /0.2152000000E+00/
     *    DSLIP(  45) /0.0000000000E+00/
     *    DIP(  45) /0.1570796327E+01/
     *    DEPTH(  45) /0.1200000000E+05/
     *    WIDTH(  45) /0.2000000000E+04/
      DATA STRIKE(  46) /0.2399653189E+01/
     *    HL(  46) /0.1500000000E+04/
     *    EQLAT(  46) /0.6267234743E+00/
     *    EQLON(  46) /0.2102200564E+01/
     *    SSLIP(  46) /0.2348000000E+00/
     *    DSLIP(  46) /0.0000000000E+00/
     *    DIP(  46) /0.1570796327E+01/
     *    DEPTH(  46) /0.0000000000E+00/
     *    WIDTH(  46) /0.2000000000E+04/
      DATA STRIKE(  47) /0.2399653189E+01/
     *    HL(  47) /0.1500000000E+04/
     *    EQLAT(  47) /0.6267234743E+00/
     *    EQLON(  47) /0.2102200564E+01/
     *    SSLIP(  47) /0.3555000000E+00/
     *    DSLIP(  47) /0.0000000000E+00/
     *    DIP(  47) /0.1570796327E+01/
     *    DEPTH(  47) /0.2000000000E+04/
     *    WIDTH(  47) /0.2000000000E+04/
      DATA STRIKE(  48) /0.2399653189E+01/
     *    HL(  48) /0.1500000000E+04/
     *    EQLAT(  48) /0.6267234743E+00/
     *    EQLON(  48) /0.2102200564E+01/
     *    SSLIP(  48) /0.4878000000E+00/
     *    DSLIP(  48) /0.0000000000E+00/
     *    DIP(  48) /0.1570796327E+01/
     *    DEPTH(  48) /0.4000000000E+04/
     *    WIDTH(  48) /0.2000000000E+04/
      DATA STRIKE(  49) /0.2399653189E+01/
     *    HL(  49) /0.1500000000E+04/
     *    EQLAT(  49) /0.6267234743E+00/
     *    EQLON(  49) /0.2102200564E+01/
     *    SSLIP(  49) /0.5683000000E+00/
     *    DSLIP(  49) /0.0000000000E+00/
     *    DIP(  49) /0.1570796327E+01/
     *    DEPTH(  49) /0.6000000000E+04/
     *    WIDTH(  49) /0.2000000000E+04/
      DATA STRIKE(  50) /0.2399653189E+01/
     *    HL(  50) /0.1500000000E+04/
     *    EQLAT(  50) /0.6267234743E+00/
     *    EQLON(  50) /0.2102200564E+01/
     *    SSLIP(  50) /0.5605000000E+00/
     *    DSLIP(  50) /0.0000000000E+00/
     *    DIP(  50) /0.1570796327E+01/
     *    DEPTH(  50) /0.8000000000E+04/
     *    WIDTH(  50) /0.2000000000E+04/
      DATA STRIKE(  51) /0.2399653189E+01/
     *    HL(  51) /0.1500000000E+04/
     *    EQLAT(  51) /0.6267234743E+00/
     *    EQLON(  51) /0.2102200564E+01/
     *    SSLIP(  51) /0.4521000000E+00/
     *    DSLIP(  51) /0.0000000000E+00/
     *    DIP(  51) /0.1570796327E+01/
     *    DEPTH(  51) /0.1000000000E+05/
     *    WIDTH(  51) /0.2000000000E+04/
      DATA STRIKE(  52) /0.2399653189E+01/
     *    HL(  52) /0.1500000000E+04/
     *    EQLAT(  52) /0.6267234743E+00/
     *    EQLON(  52) /0.2102200564E+01/
     *    SSLIP(  52) /0.2541000000E+00/
     *    DSLIP(  52) /0.0000000000E+00/
     *    DIP(  52) /0.1570796327E+01/
     *    DEPTH(  52) /0.1200000000E+05/
     *    WIDTH(  52) /0.2000000000E+04/
      DATA STRIKE(  53) /0.2399653189E+01/
     *    HL(  53) /0.1500000000E+04/
     *    EQLAT(  53) /0.6263744085E+00/
     *    EQLON(  53) /0.2101807865E+01/
     *    SSLIP(  53) /0.3467000000E+00/
     *    DSLIP(  53) /0.0000000000E+00/
     *    DIP(  53) /0.1570796327E+01/
     *    DEPTH(  53) /0.0000000000E+00/
     *    WIDTH(  53) /0.2000000000E+04/
      DATA STRIKE(  54) /0.2399653189E+01/
     *    HL(  54) /0.1500000000E+04/
     *    EQLAT(  54) /0.6263744085E+00/
     *    EQLON(  54) /0.2101807865E+01/
     *    SSLIP(  54) /0.4530000000E+00/
     *    DSLIP(  54) /0.0000000000E+00/
     *    DIP(  54) /0.1570796327E+01/
     *    DEPTH(  54) /0.2000000000E+04/
     *    WIDTH(  54) /0.2000000000E+04/
      DATA STRIKE(  55) /0.2399653189E+01/
     *    HL(  55) /0.1500000000E+04/
     *    EQLAT(  55) /0.6263744085E+00/
     *    EQLON(  55) /0.2101807865E+01/
     *    SSLIP(  55) /0.5794000000E+00/
     *    DSLIP(  55) /0.0000000000E+00/
     *    DIP(  55) /0.1570796327E+01/
     *    DEPTH(  55) /0.4000000000E+04/
     *    WIDTH(  55) /0.2000000000E+04/
      DATA STRIKE(  56) /0.2399653189E+01/
     *    HL(  56) /0.1500000000E+04/
     *    EQLAT(  56) /0.6263744085E+00/
     *    EQLON(  56) /0.2101807865E+01/
     *    SSLIP(  56) /0.6534000000E+00/
     *    DSLIP(  56) /0.0000000000E+00/
     *    DIP(  56) /0.1570796327E+01/
     *    DEPTH(  56) /0.6000000000E+04/
     *    WIDTH(  56) /0.2000000000E+04/
      DATA STRIKE(  57) /0.2399653189E+01/
     *    HL(  57) /0.1500000000E+04/
     *    EQLAT(  57) /0.6263744085E+00/
     *    EQLON(  57) /0.2101807865E+01/
     *    SSLIP(  57) /0.6331000000E+00/
     *    DSLIP(  57) /0.0000000000E+00/
     *    DIP(  57) /0.1570796327E+01/
     *    DEPTH(  57) /0.8000000000E+04/
     *    WIDTH(  57) /0.2000000000E+04/
      DATA STRIKE(  58) /0.2399653189E+01/
     *    HL(  58) /0.1500000000E+04/
     *    EQLAT(  58) /0.6263744085E+00/
     *    EQLON(  58) /0.2101807865E+01/
     *    SSLIP(  58) /0.5051000000E+00/
     *    DSLIP(  58) /0.0000000000E+00/
     *    DIP(  58) /0.1570796327E+01/
     *    DEPTH(  58) /0.1000000000E+05/
     *    WIDTH(  58) /0.2000000000E+04/
      DATA STRIKE(  59) /0.2399653189E+01/
     *    HL(  59) /0.1500000000E+04/
     *    EQLAT(  59) /0.6263744085E+00/
     *    EQLON(  59) /0.2101807865E+01/
     *    SSLIP(  59) /0.2821000000E+00/
     *    DSLIP(  59) /0.0000000000E+00/
     *    DIP(  59) /0.1570796327E+01/
     *    DEPTH(  59) /0.1200000000E+05/
     *    WIDTH(  59) /0.2000000000E+04/
      DATA STRIKE(  60) /0.2399653189E+01/
     *    HL(  60) /0.1500000000E+04/
     *    EQLAT(  60) /0.6260253426E+00/
     *    EQLON(  60) /0.2101420053E+01/
     *    SSLIP(  60) /0.3319000000E+00/
     *    DSLIP(  60) /0.0000000000E+00/
     *    DIP(  60) /0.1570796327E+01/
     *    DEPTH(  60) /0.0000000000E+00/
     *    WIDTH(  60) /0.2000000000E+04/
      DATA STRIKE(  61) /0.2399653189E+01/
     *    HL(  61) /0.1500000000E+04/
     *    EQLAT(  61) /0.6260253426E+00/
     *    EQLON(  61) /0.2101420053E+01/
     *    SSLIP(  61) /0.4632000000E+00/
     *    DSLIP(  61) /0.0000000000E+00/
     *    DIP(  61) /0.1570796327E+01/
     *    DEPTH(  61) /0.2000000000E+04/
     *    WIDTH(  61) /0.2000000000E+04/
      DATA STRIKE(  62) /0.2399653189E+01/
     *    HL(  62) /0.1500000000E+04/
     *    EQLAT(  62) /0.6260253426E+00/
     *    EQLON(  62) /0.2101420053E+01/
     *    SSLIP(  62) /0.5964000000E+00/
     *    DSLIP(  62) /0.0000000000E+00/
     *    DIP(  62) /0.1570796327E+01/
     *    DEPTH(  62) /0.4000000000E+04/
     *    WIDTH(  62) /0.2000000000E+04/
      DATA STRIKE(  63) /0.2399653189E+01/
     *    HL(  63) /0.1500000000E+04/
     *    EQLAT(  63) /0.6260253426E+00/
     *    EQLON(  63) /0.2101420053E+01/
     *    SSLIP(  63) /0.6656000000E+00/
     *    DSLIP(  63) /0.0000000000E+00/
     *    DIP(  63) /0.1570796327E+01/
     *    DEPTH(  63) /0.6000000000E+04/
     *    WIDTH(  63) /0.2000000000E+04/
      DATA STRIKE(  64) /0.2399653189E+01/
     *    HL(  64) /0.1500000000E+04/
     *    EQLAT(  64) /0.6260253426E+00/
     *    EQLON(  64) /0.2101420053E+01/
     *    SSLIP(  64) /0.6377000000E+00/
     *    DSLIP(  64) /0.0000000000E+00/
     *    DIP(  64) /0.1570796327E+01/
     *    DEPTH(  64) /0.8000000000E+04/
     *    WIDTH(  64) /0.2000000000E+04/
      DATA STRIKE(  65) /0.2399653189E+01/
     *    HL(  65) /0.1500000000E+04/
     *    EQLAT(  65) /0.6260253426E+00/
     *    EQLON(  65) /0.2101420053E+01/
     *    SSLIP(  65) /0.5047000000E+00/
     *    DSLIP(  65) /0.0000000000E+00/
     *    DIP(  65) /0.1570796327E+01/
     *    DEPTH(  65) /0.1000000000E+05/
     *    WIDTH(  65) /0.2000000000E+04/
      DATA STRIKE(  66) /0.2399653189E+01/
     *    HL(  66) /0.1500000000E+04/
     *    EQLAT(  66) /0.6260253426E+00/
     *    EQLON(  66) /0.2101420053E+01/
     *    SSLIP(  66) /0.2805000000E+00/
     *    DSLIP(  66) /0.0000000000E+00/
     *    DIP(  66) /0.1570796327E+01/
     *    DEPTH(  66) /0.1200000000E+05/
     *    WIDTH(  66) /0.2000000000E+04/
      DATA STRIKE(  67) /0.2399653189E+01/
     *    HL(  67) /0.1500000000E+04/
     *    EQLAT(  67) /0.6256762768E+00/
     *    EQLON(  67) /0.2101027354E+01/
     *    SSLIP(  67) /0.3412000000E+00/
     *    DSLIP(  67) /0.0000000000E+00/
     *    DIP(  67) /0.1570796327E+01/
     *    DEPTH(  67) /0.0000000000E+00/
     *    WIDTH(  67) /0.2000000000E+04/
      DATA STRIKE(  68) /0.2399653189E+01/
     *    HL(  68) /0.1500000000E+04/
     *    EQLAT(  68) /0.6256762768E+00/
     *    EQLON(  68) /0.2101027354E+01/
     *    SSLIP(  68) /0.4197000000E+00/
     *    DSLIP(  68) /0.0000000000E+00/
     *    DIP(  68) /0.1570796327E+01/
     *    DEPTH(  68) /0.2000000000E+04/
     *    WIDTH(  68) /0.2000000000E+04/
      DATA STRIKE(  69) /0.2399653189E+01/
     *    HL(  69) /0.1500000000E+04/
     *    EQLAT(  69) /0.6256762768E+00/
     *    EQLON(  69) /0.2101027354E+01/
     *    SSLIP(  69) /0.5118000000E+00/
     *    DSLIP(  69) /0.0000000000E+00/
     *    DIP(  69) /0.1570796327E+01/
     *    DEPTH(  69) /0.4000000000E+04/
     *    WIDTH(  69) /0.2000000000E+04/
      DATA STRIKE(  70) /0.2399653189E+01/
     *    HL(  70) /0.1500000000E+04/
     *    EQLAT(  70) /0.6256762768E+00/
     *    EQLON(  70) /0.2101027354E+01/
     *    SSLIP(  70) /0.5620000000E+00/
     *    DSLIP(  70) /0.0000000000E+00/
     *    DIP(  70) /0.1570796327E+01/
     *    DEPTH(  70) /0.6000000000E+04/
     *    WIDTH(  70) /0.2000000000E+04/
      DATA STRIKE(  71) /0.2399653189E+01/
     *    HL(  71) /0.1500000000E+04/
     *    EQLAT(  71) /0.6256762768E+00/
     *    EQLON(  71) /0.2101027354E+01/
     *    SSLIP(  71) /0.5368000000E+00/
     *    DSLIP(  71) /0.0000000000E+00/
     *    DIP(  71) /0.1570796327E+01/
     *    DEPTH(  71) /0.8000000000E+04/
     *    WIDTH(  71) /0.2000000000E+04/
      DATA STRIKE(  72) /0.2399653189E+01/
     *    HL(  72) /0.1500000000E+04/
     *    EQLAT(  72) /0.6256762768E+00/
     *    EQLON(  72) /0.2101027354E+01/
     *    SSLIP(  72) /0.4250000000E+00/
     *    DSLIP(  72) /0.0000000000E+00/
     *    DIP(  72) /0.1570796327E+01/
     *    DEPTH(  72) /0.1000000000E+05/
     *    WIDTH(  72) /0.2000000000E+04/
      DATA STRIKE(  73) /0.2399653189E+01/
     *    HL(  73) /0.1500000000E+04/
     *    EQLAT(  73) /0.6256762768E+00/
     *    EQLON(  73) /0.2101027354E+01/
     *    SSLIP(  73) /0.2364000000E+00/
     *    DSLIP(  73) /0.0000000000E+00/
     *    DIP(  73) /0.1570796327E+01/
     *    DEPTH(  73) /0.1200000000E+05/
     *    WIDTH(  73) /0.2000000000E+04/
      DATA STRIKE(  74) /0.2399653189E+01/
     *    HL(  74) /0.1500000000E+04/
     *    EQLAT(  74) /0.6253320978E+00/
     *    EQLON(  74) /0.2100639541E+01/
     *    SSLIP(  74) /0.1551000000E+00/
     *    DSLIP(  74) /0.0000000000E+00/
     *    DIP(  74) /0.1570796327E+01/
     *    DEPTH(  74) /0.0000000000E+00/
     *    WIDTH(  74) /0.2000000000E+04/
      DATA STRIKE(  75) /0.2399653189E+01/
     *    HL(  75) /0.1500000000E+04/
     *    EQLAT(  75) /0.6253320978E+00/
     *    EQLON(  75) /0.2100639541E+01/
     *    SSLIP(  75) /0.2130000000E+00/
     *    DSLIP(  75) /0.0000000000E+00/
     *    DIP(  75) /0.1570796327E+01/
     *    DEPTH(  75) /0.2000000000E+04/
     *    WIDTH(  75) /0.2000000000E+04/
      DATA STRIKE(  76) /0.2399653189E+01/
     *    HL(  76) /0.1500000000E+04/
     *    EQLAT(  76) /0.6253320978E+00/
     *    EQLON(  76) /0.2100639541E+01/
     *    SSLIP(  76) /0.2877000000E+00/
     *    DSLIP(  76) /0.0000000000E+00/
     *    DIP(  76) /0.1570796327E+01/
     *    DEPTH(  76) /0.4000000000E+04/
     *    WIDTH(  76) /0.2000000000E+04/
      DATA STRIKE(  77) /0.2399653189E+01/
     *    HL(  77) /0.1500000000E+04/
     *    EQLAT(  77) /0.6253320978E+00/
     *    EQLON(  77) /0.2100639541E+01/
     *    SSLIP(  77) /0.3398000000E+00/
     *    DSLIP(  77) /0.0000000000E+00/
     *    DIP(  77) /0.1570796327E+01/
     *    DEPTH(  77) /0.6000000000E+04/
     *    WIDTH(  77) /0.2000000000E+04/
      DATA STRIKE(  78) /0.2399653189E+01/
     *    HL(  78) /0.1500000000E+04/
     *    EQLAT(  78) /0.6253320978E+00/
     *    EQLON(  78) /0.2100639541E+01/
     *    SSLIP(  78) /0.3414000000E+00/
     *    DSLIP(  78) /0.0000000000E+00/
     *    DIP(  78) /0.1570796327E+01/
     *    DEPTH(  78) /0.8000000000E+04/
     *    WIDTH(  78) /0.2000000000E+04/
      DATA STRIKE(  79) /0.2399653189E+01/
     *    HL(  79) /0.1500000000E+04/
     *    EQLAT(  79) /0.6253320978E+00/
     *    EQLON(  79) /0.2100639541E+01/
     *    SSLIP(  79) /0.2795000000E+00/
     *    DSLIP(  79) /0.0000000000E+00/
     *    DIP(  79) /0.1570796327E+01/
     *    DEPTH(  79) /0.1000000000E+05/
     *    WIDTH(  79) /0.2000000000E+04/
      DATA STRIKE(  80) /0.2399653189E+01/
     *    HL(  80) /0.1500000000E+04/
     *    EQLAT(  80) /0.6253320978E+00/
     *    EQLON(  80) /0.2100639541E+01/
     *    SSLIP(  80) /0.1584000000E+00/
     *    DSLIP(  80) /0.0000000000E+00/
     *    DIP(  80) /0.1570796327E+01/
     *    DEPTH(  80) /0.1200000000E+05/
     *    WIDTH(  80) /0.2000000000E+04/
      DATA STRIKE(  81) /0.2685538120E+01/
     *    HL(  81) /0.1500000000E+04/
     *    EQLAT(  81) /0.6249442857E+00/
     *    EQLON(  81) /0.2100314736E+01/
     *    SSLIP(  81) /0.0000000000E+00/
     *    DSLIP(  81) /0.0000000000E+00/
     *    DIP(  81) /0.1570796327E+01/
     *    DEPTH(  81) /0.0000000000E+00/
     *    WIDTH(  81) /0.2000000000E+04/
      DATA STRIKE(  82) /0.2685538120E+01/
     *    HL(  82) /0.1500000000E+04/
     *    EQLAT(  82) /0.6249442857E+00/
     *    EQLON(  82) /0.2100314736E+01/
     *    SSLIP(  82) /0.2600000000E-01/
     *    DSLIP(  82) /0.0000000000E+00/
     *    DIP(  82) /0.1570796327E+01/
     *    DEPTH(  82) /0.2000000000E+04/
     *    WIDTH(  82) /0.2000000000E+04/
      DATA STRIKE(  83) /0.2685538120E+01/
     *    HL(  83) /0.1500000000E+04/
     *    EQLAT(  83) /0.6249442857E+00/
     *    EQLON(  83) /0.2100314736E+01/
     *    SSLIP(  83) /0.7550000000E-01/
     *    DSLIP(  83) /0.0000000000E+00/
     *    DIP(  83) /0.1570796327E+01/
     *    DEPTH(  83) /0.4000000000E+04/
     *    WIDTH(  83) /0.2000000000E+04/
      DATA STRIKE(  84) /0.2685538120E+01/
     *    HL(  84) /0.1500000000E+04/
     *    EQLAT(  84) /0.6249442857E+00/
     *    EQLON(  84) /0.2100314736E+01/
     *    SSLIP(  84) /0.1218000000E+00/
     *    DSLIP(  84) /0.0000000000E+00/
     *    DIP(  84) /0.1570796327E+01/
     *    DEPTH(  84) /0.6000000000E+04/
     *    WIDTH(  84) /0.2000000000E+04/
      DATA STRIKE(  85) /0.2685538120E+01/
     *    HL(  85) /0.1500000000E+04/
     *    EQLAT(  85) /0.6249442857E+00/
     *    EQLON(  85) /0.2100314736E+01/
     *    SSLIP(  85) /0.1458000000E+00/
     *    DSLIP(  85) /0.0000000000E+00/
     *    DIP(  85) /0.1570796327E+01/
     *    DEPTH(  85) /0.8000000000E+04/
     *    WIDTH(  85) /0.2000000000E+04/
      DATA STRIKE(  86) /0.2685538120E+01/
     *    HL(  86) /0.1500000000E+04/
     *    EQLAT(  86) /0.6249442857E+00/
     *    EQLON(  86) /0.2100314736E+01/
     *    SSLIP(  86) /0.1332000000E+00/
     *    DSLIP(  86) /0.0000000000E+00/
     *    DIP(  86) /0.1570796327E+01/
     *    DEPTH(  86) /0.1000000000E+05/
     *    WIDTH(  86) /0.2000000000E+04/
      DATA STRIKE(  87) /0.2685538120E+01/
     *    HL(  87) /0.1500000000E+04/
     *    EQLAT(  87) /0.6249442857E+00/
     *    EQLON(  87) /0.2100314736E+01/
     *    SSLIP(  87) /0.8070000000E-01/
     *    DSLIP(  87) /0.0000000000E+00/
     *    DIP(  87) /0.1570796327E+01/
     *    DEPTH(  87) /0.1200000000E+05/
     *    WIDTH(  87) /0.2000000000E+04/
      DATA STRIKE(  88) /0.2685538120E+01/
     *    HL(  88) /0.1500000000E+04/
     *    EQLAT(  88) /0.6245224396E+00/
     *    EQLON(  88) /0.2100062536E+01/
     *    SSLIP(  88) /0.0000000000E+00/
     *    DSLIP(  88) /0.0000000000E+00/
     *    DIP(  88) /0.1570796327E+01/
     *    DEPTH(  88) /0.0000000000E+00/
     *    WIDTH(  88) /0.2000000000E+04/
      DATA STRIKE(  89) /0.2685538120E+01/
     *    HL(  89) /0.1500000000E+04/
     *    EQLAT(  89) /0.6245224396E+00/
     *    EQLON(  89) /0.2100062536E+01/
     *    SSLIP(  89) /0.0000000000E+00/
     *    DSLIP(  89) /0.0000000000E+00/
     *    DIP(  89) /0.1570796327E+01/
     *    DEPTH(  89) /0.2000000000E+04/
     *    WIDTH(  89) /0.2000000000E+04/
      DATA STRIKE(  90) /0.2685538120E+01/
     *    HL(  90) /0.1500000000E+04/
     *    EQLAT(  90) /0.6245224396E+00/
     *    EQLON(  90) /0.2100062536E+01/
     *    SSLIP(  90) /0.0000000000E+00/
     *    DSLIP(  90) /0.0000000000E+00/
     *    DIP(  90) /0.1570796327E+01/
     *    DEPTH(  90) /0.4000000000E+04/
     *    WIDTH(  90) /0.2000000000E+04/
      DATA STRIKE(  91) /0.2685538120E+01/
     *    HL(  91) /0.1500000000E+04/
     *    EQLAT(  91) /0.6245224396E+00/
     *    EQLON(  91) /0.2100062536E+01/
     *    SSLIP(  91) /0.0000000000E+00/
     *    DSLIP(  91) /0.0000000000E+00/
     *    DIP(  91) /0.1570796327E+01/
     *    DEPTH(  91) /0.6000000000E+04/
     *    WIDTH(  91) /0.2000000000E+04/
      DATA STRIKE(  92) /0.2685538120E+01/
     *    HL(  92) /0.1500000000E+04/
     *    EQLAT(  92) /0.6245224396E+00/
     *    EQLON(  92) /0.2100062536E+01/
     *    SSLIP(  92) /0.1290000000E-01/
     *    DSLIP(  92) /0.0000000000E+00/
     *    DIP(  92) /0.1570796327E+01/
     *    DEPTH(  92) /0.8000000000E+04/
     *    WIDTH(  92) /0.2000000000E+04/
      DATA STRIKE(  93) /0.2685538120E+01/
     *    HL(  93) /0.1500000000E+04/
     *    EQLAT(  93) /0.6245224396E+00/
     *    EQLON(  93) /0.2100062536E+01/
     *    SSLIP(  93) /0.2470000000E-01/
     *    DSLIP(  93) /0.0000000000E+00/
     *    DIP(  93) /0.1570796327E+01/
     *    DEPTH(  93) /0.1000000000E+05/
     *    WIDTH(  93) /0.2000000000E+04/
      DATA STRIKE(  94) /0.2685538120E+01/
     *    HL(  94) /0.1500000000E+04/
     *    EQLAT(  94) /0.6245224396E+00/
     *    EQLON(  94) /0.2100062536E+01/
     *    SSLIP(  94) /0.2040000000E-01/
     *    DSLIP(  94) /0.0000000000E+00/
     *    DIP(  94) /0.1570796327E+01/
     *    DEPTH(  94) /0.1200000000E+05/
     *    WIDTH(  94) /0.2000000000E+04/
      DATA STRIKE(  95) /0.2513099590E+01/
     *    HL(  95) /0.1500000000E+04/
     *    EQLAT(  95) /0.6241152543E+00/
     *    EQLON(  95) /0.2099761990E+01/
     *    SSLIP(  95) /0.0000000000E+00/
     *    DSLIP(  95) /0.0000000000E+00/
     *    DIP(  95) /0.1570796327E+01/
     *    DEPTH(  95) /0.0000000000E+00/
     *    WIDTH(  95) /0.2000000000E+04/
      DATA STRIKE(  96) /0.2513099590E+01/
     *    HL(  96) /0.1500000000E+04/
     *    EQLAT(  96) /0.6241152543E+00/
     *    EQLON(  96) /0.2099761990E+01/
     *    SSLIP(  96) /0.0000000000E+00/
     *    DSLIP(  96) /0.0000000000E+00/
     *    DIP(  96) /0.1570796327E+01/
     *    DEPTH(  96) /0.2000000000E+04/
     *    WIDTH(  96) /0.2000000000E+04/
      DATA STRIKE(  97) /0.2513099590E+01/
     *    HL(  97) /0.1500000000E+04/
     *    EQLAT(  97) /0.6241152543E+00/
     *    EQLON(  97) /0.2099761990E+01/
     *    SSLIP(  97) /0.0000000000E+00/
     *    DSLIP(  97) /0.0000000000E+00/
     *    DIP(  97) /0.1570796327E+01/
     *    DEPTH(  97) /0.4000000000E+04/
     *    WIDTH(  97) /0.2000000000E+04/
      DATA STRIKE(  98) /0.2513099590E+01/
     *    HL(  98) /0.1500000000E+04/
     *    EQLAT(  98) /0.6241152543E+00/
     *    EQLON(  98) /0.2099761990E+01/
     *    SSLIP(  98) /0.0000000000E+00/
     *    DSLIP(  98) /0.0000000000E+00/
     *    DIP(  98) /0.1570796327E+01/
     *    DEPTH(  98) /0.6000000000E+04/
     *    WIDTH(  98) /0.2000000000E+04/
      DATA STRIKE(  99) /0.2513099590E+01/
     *    HL(  99) /0.1500000000E+04/
     *    EQLAT(  99) /0.6241152543E+00/
     *    EQLON(  99) /0.2099761990E+01/
     *    SSLIP(  99) /0.0000000000E+00/
     *    DSLIP(  99) /0.0000000000E+00/
     *    DIP(  99) /0.1570796327E+01/
     *    DEPTH(  99) /0.8000000000E+04/
     *    WIDTH(  99) /0.2000000000E+04/
      DATA STRIKE( 100) /0.2513099590E+01/
     *    HL( 100) /0.1500000000E+04/
     *    EQLAT( 100) /0.6241152543E+00/
     *    EQLON( 100) /0.2099761990E+01/
     *    SSLIP( 100) /0.6600000000E-02/
     *    DSLIP( 100) /0.0000000000E+00/
     *    DIP( 100) /0.1570796327E+01/
     *    DEPTH( 100) /0.1000000000E+05/
     *    WIDTH( 100) /0.2000000000E+04/
      DATA STRIKE( 101) /0.2513099590E+01/
     *    HL( 101) /0.1500000000E+04/
     *    EQLAT( 101) /0.6241152543E+00/
     *    EQLON( 101) /0.2099761990E+01/
     *    SSLIP( 101) /0.8100000000E-02/
     *    DSLIP( 101) /0.0000000000E+00/
     *    DIP( 101) /0.1570796327E+01/
     *    DEPTH( 101) /0.1200000000E+05/
     *    WIDTH( 101) /0.2000000000E+04/
      DATA STRIKE( 102) /0.2513099590E+01/
     *    HL( 102) /0.1500000000E+04/
     *    EQLAT( 102) /0.6237370414E+00/
     *    EQLON( 102) /0.2099427410E+01/
     *    SSLIP( 102) /0.1600000000E-01/
     *    DSLIP( 102) /0.0000000000E+00/
     *    DIP( 102) /0.1570796327E+01/
     *    DEPTH( 102) /0.0000000000E+00/
     *    WIDTH( 102) /0.2000000000E+04/
      DATA STRIKE( 103) /0.2513099590E+01/
     *    HL( 103) /0.1500000000E+04/
     *    EQLAT( 103) /0.6237370414E+00/
     *    EQLON( 103) /0.2099427410E+01/
     *    SSLIP( 103) /0.0000000000E+00/
     *    DSLIP( 103) /0.0000000000E+00/
     *    DIP( 103) /0.1570796327E+01/
     *    DEPTH( 103) /0.2000000000E+04/
     *    WIDTH( 103) /0.2000000000E+04/
      DATA STRIKE( 104) /0.2513099590E+01/
     *    HL( 104) /0.1500000000E+04/
     *    EQLAT( 104) /0.6237370414E+00/
     *    EQLON( 104) /0.2099427410E+01/
     *    SSLIP( 104) /0.0000000000E+00/
     *    DSLIP( 104) /0.0000000000E+00/
     *    DIP( 104) /0.1570796327E+01/
     *    DEPTH( 104) /0.4000000000E+04/
     *    WIDTH( 104) /0.2000000000E+04/
      DATA STRIKE( 105) /0.2513099590E+01/
     *    HL( 105) /0.1500000000E+04/
     *    EQLAT( 105) /0.6237370414E+00/
     *    EQLON( 105) /0.2099427410E+01/
     *    SSLIP( 105) /0.2780000000E-01/
     *    DSLIP( 105) /0.0000000000E+00/
     *    DIP( 105) /0.1570796327E+01/
     *    DEPTH( 105) /0.6000000000E+04/
     *    WIDTH( 105) /0.2000000000E+04/
      DATA STRIKE( 106) /0.2513099590E+01/
     *    HL( 106) /0.1500000000E+04/
     *    EQLAT( 106) /0.6237370414E+00/
     *    EQLON( 106) /0.2099427410E+01/
     *    SSLIP( 106) /0.5500000000E-01/
     *    DSLIP( 106) /0.0000000000E+00/
     *    DIP( 106) /0.1570796327E+01/
     *    DEPTH( 106) /0.8000000000E+04/
     *    WIDTH( 106) /0.2000000000E+04/
      DATA STRIKE( 107) /0.2513099590E+01/
     *    HL( 107) /0.1500000000E+04/
     *    EQLAT( 107) /0.6237370414E+00/
     *    EQLON( 107) /0.2099427410E+01/
     *    SSLIP( 107) /0.6080000000E-01/
     *    DSLIP( 107) /0.0000000000E+00/
     *    DIP( 107) /0.1570796327E+01/
     *    DEPTH( 107) /0.1000000000E+05/
     *    WIDTH( 107) /0.2000000000E+04/
      DATA STRIKE( 108) /0.2513099590E+01/
     *    HL( 108) /0.1500000000E+04/
     *    EQLAT( 108) /0.6237370414E+00/
     *    EQLON( 108) /0.2099427410E+01/
     *    SSLIP( 108) /0.4030000000E-01/
     *    DSLIP( 108) /0.0000000000E+00/
     *    DIP( 108) /0.1570796327E+01/
     *    DEPTH( 108) /0.1200000000E+05/
     *    WIDTH( 108) /0.2000000000E+04/
      DATA STRIKE( 109) /0.2513099590E+01/
     *    HL( 109) /0.1500000000E+04/
     *    EQLAT( 109) /0.6233541162E+00/
     *    EQLON( 109) /0.2099088118E+01/
     *    SSLIP( 109) /0.1770000000E-01/
     *    DSLIP( 109) /0.0000000000E+00/
     *    DIP( 109) /0.1570796327E+01/
     *    DEPTH( 109) /0.0000000000E+00/
     *    WIDTH( 109) /0.2000000000E+04/
      DATA STRIKE( 110) /0.2513099590E+01/
     *    HL( 110) /0.1500000000E+04/
     *    EQLAT( 110) /0.6233541162E+00/
     *    EQLON( 110) /0.2099088118E+01/
     *    SSLIP( 110) /0.2360000000E-01/
     *    DSLIP( 110) /0.0000000000E+00/
     *    DIP( 110) /0.1570796327E+01/
     *    DEPTH( 110) /0.2000000000E+04/
     *    WIDTH( 110) /0.2000000000E+04/
      DATA STRIKE( 111) /0.2513099590E+01/
     *    HL( 111) /0.1500000000E+04/
     *    EQLAT( 111) /0.6233541162E+00/
     *    EQLON( 111) /0.2099088118E+01/
     *    SSLIP( 111) /0.7460000000E-01/
     *    DSLIP( 111) /0.0000000000E+00/
     *    DIP( 111) /0.1570796327E+01/
     *    DEPTH( 111) /0.4000000000E+04/
     *    WIDTH( 111) /0.2000000000E+04/
      DATA STRIKE( 112) /0.2513099590E+01/
     *    HL( 112) /0.1500000000E+04/
     *    EQLAT( 112) /0.6233541162E+00/
     *    EQLON( 112) /0.2099088118E+01/
     *    SSLIP( 112) /0.1180000000E+00/
     *    DSLIP( 112) /0.0000000000E+00/
     *    DIP( 112) /0.1570796327E+01/
     *    DEPTH( 112) /0.6000000000E+04/
     *    WIDTH( 112) /0.2000000000E+04/
      DATA STRIKE( 113) /0.2513099590E+01/
     *    HL( 113) /0.1500000000E+04/
     *    EQLAT( 113) /0.6233541162E+00/
     *    EQLON( 113) /0.2099088118E+01/
     *    SSLIP( 113) /0.1305000000E+00/
     *    DSLIP( 113) /0.0000000000E+00/
     *    DIP( 113) /0.1570796327E+01/
     *    DEPTH( 113) /0.8000000000E+04/
     *    WIDTH( 113) /0.2000000000E+04/
      DATA STRIKE( 114) /0.2513099590E+01/
     *    HL( 114) /0.1500000000E+04/
     *    EQLAT( 114) /0.6233541162E+00/
     *    EQLON( 114) /0.2099088118E+01/
     *    SSLIP( 114) /0.1109000000E+00/
     *    DSLIP( 114) /0.0000000000E+00/
     *    DIP( 114) /0.1570796327E+01/
     *    DEPTH( 114) /0.1000000000E+05/
     *    WIDTH( 114) /0.2000000000E+04/
      DATA STRIKE( 115) /0.2513099590E+01/
     *    HL( 115) /0.1500000000E+04/
     *    EQLAT( 115) /0.6233541162E+00/
     *    EQLON( 115) /0.2099088118E+01/
     *    SSLIP( 115) /0.6470000000E-01/
     *    DSLIP( 115) /0.0000000000E+00/
     *    DIP( 115) /0.1570796327E+01/
     *    DEPTH( 115) /0.1200000000E+05/
     *    WIDTH( 115) /0.2000000000E+04/
      DATA EQLATR( 10)  /0.6268494871E+00/
     *   EQLONR( 10)  /0.2103703467E+01/
     *   EQRAD( 10)   /0.2000000000E+06/
     *   ITEQK( 10)   /    56597760/
     *   NLOC( 10)    / 116/
     *   NFP( 10)     /  98/
      DATA STRIKE( 116) /0.2340137461E+01/
     *    HL( 116) /0.1500000000E+04/
     *    EQLAT( 116) /0.6280858783E+00/
     *    EQLON( 116) /0.2103805394E+01/
     *    SSLIP( 116) /0.1260000000E+00/
     *    DSLIP( 116) /0.0000000000E+00/
     *    DIP( 116) /0.1570796327E+01/
     *    DEPTH( 116) /0.0000000000E+00/
     *    WIDTH( 116) /0.2000000000E+04/
      DATA STRIKE( 117) /0.2340137461E+01/
     *    HL( 117) /0.1500000000E+04/
     *    EQLAT( 117) /0.6280858783E+00/
     *    EQLON( 117) /0.2103805394E+01/
     *    SSLIP( 117) /0.1253000000E+00/
     *    DSLIP( 117) /0.0000000000E+00/
     *    DIP( 117) /0.1570796327E+01/
     *    DEPTH( 117) /0.2000000000E+04/
     *    WIDTH( 117) /0.2000000000E+04/
      DATA STRIKE( 118) /0.2340137461E+01/
     *    HL( 118) /0.1500000000E+04/
     *    EQLAT( 118) /0.6280858783E+00/
     *    EQLON( 118) /0.2103805394E+01/
     *    SSLIP( 118) /0.1218000000E+00/
     *    DSLIP( 118) /0.0000000000E+00/
     *    DIP( 118) /0.1570796327E+01/
     *    DEPTH( 118) /0.4000000000E+04/
     *    WIDTH( 118) /0.2000000000E+04/
      DATA STRIKE( 119) /0.2340137461E+01/
     *    HL( 119) /0.1500000000E+04/
     *    EQLAT( 119) /0.6280858783E+00/
     *    EQLON( 119) /0.2103805394E+01/
     *    SSLIP( 119) /0.1124000000E+00/
     *    DSLIP( 119) /0.0000000000E+00/
     *    DIP( 119) /0.1570796327E+01/
     *    DEPTH( 119) /0.6000000000E+04/
     *    WIDTH( 119) /0.2000000000E+04/
      DATA STRIKE( 120) /0.2340137461E+01/
     *    HL( 120) /0.1500000000E+04/
     *    EQLAT( 120) /0.6280858783E+00/
     *    EQLON( 120) /0.2103805394E+01/
     *    SSLIP( 120) /0.9530000000E-01/
     *    DSLIP( 120) /0.0000000000E+00/
     *    DIP( 120) /0.1570796327E+01/
     *    DEPTH( 120) /0.8000000000E+04/
     *    WIDTH( 120) /0.2000000000E+04/
      DATA STRIKE( 121) /0.2340137461E+01/
     *    HL( 121) /0.1500000000E+04/
     *    EQLAT( 121) /0.6280858783E+00/
     *    EQLON( 121) /0.2103805394E+01/
     *    SSLIP( 121) /0.6980000000E-01/
     *    DSLIP( 121) /0.0000000000E+00/
     *    DIP( 121) /0.1570796327E+01/
     *    DEPTH( 121) /0.1000000000E+05/
     *    WIDTH( 121) /0.2000000000E+04/
      DATA STRIKE( 122) /0.2340137461E+01/
     *    HL( 122) /0.1500000000E+04/
     *    EQLAT( 122) /0.6280858783E+00/
     *    EQLON( 122) /0.2103805394E+01/
     *    SSLIP( 122) /0.3720000000E-01/
     *    DSLIP( 122) /0.0000000000E+00/
     *    DIP( 122) /0.1570796327E+01/
     *    DEPTH( 122) /0.1200000000E+05/
     *    WIDTH( 122) /0.2000000000E+04/
      DATA STRIKE( 123) /0.2340137461E+01/
     *    HL( 123) /0.1500000000E+04/
     *    EQLAT( 123) /0.6277561856E+00/
     *    EQLON( 123) /0.2103388435E+01/
     *    SSLIP( 123) /0.2204000000E+00/
     *    DSLIP( 123) /0.0000000000E+00/
     *    DIP( 123) /0.1570796327E+01/
     *    DEPTH( 123) /0.0000000000E+00/
     *    WIDTH( 123) /0.2000000000E+04/
      DATA STRIKE( 124) /0.2340137461E+01/
     *    HL( 124) /0.1500000000E+04/
     *    EQLAT( 124) /0.6277561856E+00/
     *    EQLON( 124) /0.2103388435E+01/
     *    SSLIP( 124) /0.2210000000E+00/
     *    DSLIP( 124) /0.0000000000E+00/
     *    DIP( 124) /0.1570796327E+01/
     *    DEPTH( 124) /0.2000000000E+04/
     *    WIDTH( 124) /0.2000000000E+04/
      DATA STRIKE( 125) /0.2340137461E+01/
     *    HL( 125) /0.1500000000E+04/
     *    EQLAT( 125) /0.6277561856E+00/
     *    EQLON( 125) /0.2103388435E+01/
     *    SSLIP( 125) /0.2170000000E+00/
     *    DSLIP( 125) /0.0000000000E+00/
     *    DIP( 125) /0.1570796327E+01/
     *    DEPTH( 125) /0.4000000000E+04/
     *    WIDTH( 125) /0.2000000000E+04/
      DATA STRIKE( 126) /0.2340137461E+01/
     *    HL( 126) /0.1500000000E+04/
     *    EQLAT( 126) /0.6277561856E+00/
     *    EQLON( 126) /0.2103388435E+01/
     *    SSLIP( 126) /0.2022000000E+00/
     *    DSLIP( 126) /0.0000000000E+00/
     *    DIP( 126) /0.1570796327E+01/
     *    DEPTH( 126) /0.6000000000E+04/
     *    WIDTH( 126) /0.2000000000E+04/
      DATA STRIKE( 127) /0.2340137461E+01/
     *    HL( 127) /0.1500000000E+04/
     *    EQLAT( 127) /0.6277561856E+00/
     *    EQLON( 127) /0.2103388435E+01/
     *    SSLIP( 127) /0.1724000000E+00/
     *    DSLIP( 127) /0.0000000000E+00/
     *    DIP( 127) /0.1570796327E+01/
     *    DEPTH( 127) /0.8000000000E+04/
     *    WIDTH( 127) /0.2000000000E+04/
      DATA STRIKE( 128) /0.2340137461E+01/
     *    HL( 128) /0.1500000000E+04/
     *    EQLAT( 128) /0.6277561856E+00/
     *    EQLON( 128) /0.2103388435E+01/
     *    SSLIP( 128) /0.1268000000E+00/
     *    DSLIP( 128) /0.0000000000E+00/
     *    DIP( 128) /0.1570796327E+01/
     *    DEPTH( 128) /0.1000000000E+05/
     *    WIDTH( 128) /0.2000000000E+04/
      DATA STRIKE( 129) /0.2340137461E+01/
     *    HL( 129) /0.1500000000E+04/
     *    EQLAT( 129) /0.6277561856E+00/
     *    EQLON( 129) /0.2103388435E+01/
     *    SSLIP( 129) /0.6750000000E-01/
     *    DSLIP( 129) /0.0000000000E+00/
     *    DIP( 129) /0.1570796327E+01/
     *    DEPTH( 129) /0.1200000000E+05/
     *    WIDTH( 129) /0.2000000000E+04/
      DATA STRIKE( 130) /0.2399653189E+01/
     *    HL( 130) /0.1500000000E+04/
     *    EQLAT( 130) /0.6274216060E+00/
     *    EQLON( 130) /0.2102985962E+01/
     *    SSLIP( 130) /0.2672000000E+00/
     *    DSLIP( 130) /0.0000000000E+00/
     *    DIP( 130) /0.1570796327E+01/
     *    DEPTH( 130) /0.0000000000E+00/
     *    WIDTH( 130) /0.2000000000E+04/
      DATA STRIKE( 131) /0.2399653189E+01/
     *    HL( 131) /0.1500000000E+04/
     *    EQLAT( 131) /0.6274216060E+00/
     *    EQLON( 131) /0.2102985962E+01/
     *    SSLIP( 131) /0.2727000000E+00/
     *    DSLIP( 131) /0.0000000000E+00/
     *    DIP( 131) /0.1570796327E+01/
     *    DEPTH( 131) /0.2000000000E+04/
     *    WIDTH( 131) /0.2000000000E+04/
      DATA STRIKE( 132) /0.2399653189E+01/
     *    HL( 132) /0.1500000000E+04/
     *    EQLAT( 132) /0.6274216060E+00/
     *    EQLON( 132) /0.2102985962E+01/
     *    SSLIP( 132) /0.2737000000E+00/
     *    DSLIP( 132) /0.0000000000E+00/
     *    DIP( 132) /0.1570796327E+01/
     *    DEPTH( 132) /0.4000000000E+04/
     *    WIDTH( 132) /0.2000000000E+04/
      DATA STRIKE( 133) /0.2399653189E+01/
     *    HL( 133) /0.1500000000E+04/
     *    EQLAT( 133) /0.6274216060E+00/
     *    EQLON( 133) /0.2102985962E+01/
     *    SSLIP( 133) /0.2597000000E+00/
     *    DSLIP( 133) /0.0000000000E+00/
     *    DIP( 133) /0.1570796327E+01/
     *    DEPTH( 133) /0.6000000000E+04/
     *    WIDTH( 133) /0.2000000000E+04/
      DATA STRIKE( 134) /0.2399653189E+01/
     *    HL( 134) /0.1500000000E+04/
     *    EQLAT( 134) /0.6274216060E+00/
     *    EQLON( 134) /0.2102985962E+01/
     *    SSLIP( 134) /0.2242000000E+00/
     *    DSLIP( 134) /0.0000000000E+00/
     *    DIP( 134) /0.1570796327E+01/
     *    DEPTH( 134) /0.8000000000E+04/
     *    WIDTH( 134) /0.2000000000E+04/
      DATA STRIKE( 135) /0.2399653189E+01/
     *    HL( 135) /0.1500000000E+04/
     *    EQLAT( 135) /0.6274216060E+00/
     *    EQLON( 135) /0.2102985962E+01/
     *    SSLIP( 135) /0.1660000000E+00/
     *    DSLIP( 135) /0.0000000000E+00/
     *    DIP( 135) /0.1570796327E+01/
     *    DEPTH( 135) /0.1000000000E+05/
     *    WIDTH( 135) /0.2000000000E+04/
      DATA STRIKE( 136) /0.2399653189E+01/
     *    HL( 136) /0.1500000000E+04/
     *    EQLAT( 136) /0.6274216060E+00/
     *    EQLON( 136) /0.2102985962E+01/
     *    SSLIP( 136) /0.8870000000E-01/
     *    DSLIP( 136) /0.0000000000E+00/
     *    DIP( 136) /0.1570796327E+01/
     *    DEPTH( 136) /0.1200000000E+05/
     *    WIDTH( 136) /0.2000000000E+04/
      DATA STRIKE( 137) /0.2399653189E+01/
     *    HL( 137) /0.1500000000E+04/
     *    EQLAT( 137) /0.6270725402E+00/
     *    EQLON( 137) /0.2102593263E+01/
     *    SSLIP( 137) /0.2551000000E+00/
     *    DSLIP( 137) /0.0000000000E+00/
     *    DIP( 137) /0.1570796327E+01/
     *    DEPTH( 137) /0.0000000000E+00/
     *    WIDTH( 137) /0.2000000000E+04/
      DATA STRIKE( 138) /0.2399653189E+01/
     *    HL( 138) /0.1500000000E+04/
     *    EQLAT( 138) /0.6270725402E+00/
     *    EQLON( 138) /0.2102593263E+01/
     *    SSLIP( 138) /0.2728000000E+00/
     *    DSLIP( 138) /0.0000000000E+00/
     *    DIP( 138) /0.1570796327E+01/
     *    DEPTH( 138) /0.2000000000E+04/
     *    WIDTH( 138) /0.2000000000E+04/
      DATA STRIKE( 139) /0.2399653189E+01/
     *    HL( 139) /0.1500000000E+04/
     *    EQLAT( 139) /0.6270725402E+00/
     *    EQLON( 139) /0.2102593263E+01/
     *    SSLIP( 139) /0.2876000000E+00/
     *    DSLIP( 139) /0.0000000000E+00/
     *    DIP( 139) /0.1570796327E+01/
     *    DEPTH( 139) /0.4000000000E+04/
     *    WIDTH( 139) /0.2000000000E+04/
      DATA STRIKE( 140) /0.2399653189E+01/
     *    HL( 140) /0.1500000000E+04/
     *    EQLAT( 140) /0.6270725402E+00/
     *    EQLON( 140) /0.2102593263E+01/
     *    SSLIP( 140) /0.2828000000E+00/
     *    DSLIP( 140) /0.0000000000E+00/
     *    DIP( 140) /0.1570796327E+01/
     *    DEPTH( 140) /0.6000000000E+04/
     *    WIDTH( 140) /0.2000000000E+04/
      DATA STRIKE( 141) /0.2399653189E+01/
     *    HL( 141) /0.1500000000E+04/
     *    EQLAT( 141) /0.6270725402E+00/
     *    EQLON( 141) /0.2102593263E+01/
     *    SSLIP( 141) /0.2499000000E+00/
     *    DSLIP( 141) /0.0000000000E+00/
     *    DIP( 141) /0.1570796327E+01/
     *    DEPTH( 141) /0.8000000000E+04/
     *    WIDTH( 141) /0.2000000000E+04/
      DATA STRIKE( 142) /0.2399653189E+01/
     *    HL( 142) /0.1500000000E+04/
     *    EQLAT( 142) /0.6270725402E+00/
     *    EQLON( 142) /0.2102593263E+01/
     *    SSLIP( 142) /0.1876000000E+00/
     *    DSLIP( 142) /0.0000000000E+00/
     *    DIP( 142) /0.1570796327E+01/
     *    DEPTH( 142) /0.1000000000E+05/
     *    WIDTH( 142) /0.2000000000E+04/
      DATA STRIKE( 143) /0.2399653189E+01/
     *    HL( 143) /0.1500000000E+04/
     *    EQLAT( 143) /0.6270725402E+00/
     *    EQLON( 143) /0.2102593263E+01/
     *    SSLIP( 143) /0.1009000000E+00/
     *    DSLIP( 143) /0.0000000000E+00/
     *    DIP( 143) /0.1570796327E+01/
     *    DEPTH( 143) /0.1200000000E+05/
     *    WIDTH( 143) /0.2000000000E+04/
      DATA STRIKE( 144) /0.2399653189E+01/
     *    HL( 144) /0.1500000000E+04/
     *    EQLAT( 144) /0.6267234743E+00/
     *    EQLON( 144) /0.2102200564E+01/
     *    SSLIP( 144) /0.1918000000E+00/
     *    DSLIP( 144) /0.0000000000E+00/
     *    DIP( 144) /0.1570796327E+01/
     *    DEPTH( 144) /0.0000000000E+00/
     *    WIDTH( 144) /0.2000000000E+04/
      DATA STRIKE( 145) /0.2399653189E+01/
     *    HL( 145) /0.1500000000E+04/
     *    EQLAT( 145) /0.6267234743E+00/
     *    EQLON( 145) /0.2102200564E+01/
     *    SSLIP( 145) /0.2339000000E+00/
     *    DSLIP( 145) /0.0000000000E+00/
     *    DIP( 145) /0.1570796327E+01/
     *    DEPTH( 145) /0.2000000000E+04/
     *    WIDTH( 145) /0.2000000000E+04/
      DATA STRIKE( 146) /0.2399653189E+01/
     *    HL( 146) /0.1500000000E+04/
     *    EQLAT( 146) /0.6267234743E+00/
     *    EQLON( 146) /0.2102200564E+01/
     *    SSLIP( 146) /0.2721000000E+00/
     *    DSLIP( 146) /0.0000000000E+00/
     *    DIP( 146) /0.1570796327E+01/
     *    DEPTH( 146) /0.4000000000E+04/
     *    WIDTH( 146) /0.2000000000E+04/
      DATA STRIKE( 147) /0.2399653189E+01/
     *    HL( 147) /0.1500000000E+04/
     *    EQLAT( 147) /0.6267234743E+00/
     *    EQLON( 147) /0.2102200564E+01/
     *    SSLIP( 147) /0.2837000000E+00/
     *    DSLIP( 147) /0.0000000000E+00/
     *    DIP( 147) /0.1570796327E+01/
     *    DEPTH( 147) /0.6000000000E+04/
     *    WIDTH( 147) /0.2000000000E+04/
      DATA STRIKE( 148) /0.2399653189E+01/
     *    HL( 148) /0.1500000000E+04/
     *    EQLAT( 148) /0.6267234743E+00/
     *    EQLON( 148) /0.2102200564E+01/
     *    SSLIP( 148) /0.2591000000E+00/
     *    DSLIP( 148) /0.0000000000E+00/
     *    DIP( 148) /0.1570796327E+01/
     *    DEPTH( 148) /0.8000000000E+04/
     *    WIDTH( 148) /0.2000000000E+04/
      DATA STRIKE( 149) /0.2399653189E+01/
     *    HL( 149) /0.1500000000E+04/
     *    EQLAT( 149) /0.6267234743E+00/
     *    EQLON( 149) /0.2102200564E+01/
     *    SSLIP( 149) /0.1981000000E+00/
     *    DSLIP( 149) /0.0000000000E+00/
     *    DIP( 149) /0.1570796327E+01/
     *    DEPTH( 149) /0.1000000000E+05/
     *    WIDTH( 149) /0.2000000000E+04/
      DATA STRIKE( 150) /0.2399653189E+01/
     *    HL( 150) /0.1500000000E+04/
     *    EQLAT( 150) /0.6267234743E+00/
     *    EQLON( 150) /0.2102200564E+01/
     *    SSLIP( 150) /0.1075000000E+00/
     *    DSLIP( 150) /0.0000000000E+00/
     *    DIP( 150) /0.1570796327E+01/
     *    DEPTH( 150) /0.1200000000E+05/
     *    WIDTH( 150) /0.2000000000E+04/
      DATA STRIKE( 151) /0.2399653189E+01/
     *    HL( 151) /0.1500000000E+04/
     *    EQLAT( 151) /0.6263744085E+00/
     *    EQLON( 151) /0.2101807865E+01/
     *    SSLIP( 151) /0.1839000000E+00/
     *    DSLIP( 151) /0.0000000000E+00/
     *    DIP( 151) /0.1570796327E+01/
     *    DEPTH( 151) /0.0000000000E+00/
     *    WIDTH( 151) /0.2000000000E+04/
      DATA STRIKE( 152) /0.2399653189E+01/
     *    HL( 152) /0.1500000000E+04/
     *    EQLAT( 152) /0.6263744085E+00/
     *    EQLON( 152) /0.2101807865E+01/
     *    SSLIP( 152) /0.2279000000E+00/
     *    DSLIP( 152) /0.0000000000E+00/
     *    DIP( 152) /0.1570796327E+01/
     *    DEPTH( 152) /0.2000000000E+04/
     *    WIDTH( 152) /0.2000000000E+04/
      DATA STRIKE( 153) /0.2399653189E+01/
     *    HL( 153) /0.1500000000E+04/
     *    EQLAT( 153) /0.6263744085E+00/
     *    EQLON( 153) /0.2101807865E+01/
     *    SSLIP( 153) /0.2740000000E+00/
     *    DSLIP( 153) /0.0000000000E+00/
     *    DIP( 153) /0.1570796327E+01/
     *    DEPTH( 153) /0.4000000000E+04/
     *    WIDTH( 153) /0.2000000000E+04/
      DATA STRIKE( 154) /0.2399653189E+01/
     *    HL( 154) /0.1500000000E+04/
     *    EQLAT( 154) /0.6263744085E+00/
     *    EQLON( 154) /0.2101807865E+01/
     *    SSLIP( 154) /0.2935000000E+00/
     *    DSLIP( 154) /0.0000000000E+00/
     *    DIP( 154) /0.1570796327E+01/
     *    DEPTH( 154) /0.6000000000E+04/
     *    WIDTH( 154) /0.2000000000E+04/
      DATA STRIKE( 155) /0.2399653189E+01/
     *    HL( 155) /0.1500000000E+04/
     *    EQLAT( 155) /0.6263744085E+00/
     *    EQLON( 155) /0.2101807865E+01/
     *    SSLIP( 155) /0.2729000000E+00/
     *    DSLIP( 155) /0.0000000000E+00/
     *    DIP( 155) /0.1570796327E+01/
     *    DEPTH( 155) /0.8000000000E+04/
     *    WIDTH( 155) /0.2000000000E+04/
      DATA STRIKE( 156) /0.2399653189E+01/
     *    HL( 156) /0.1500000000E+04/
     *    EQLAT( 156) /0.6263744085E+00/
     *    EQLON( 156) /0.2101807865E+01/
     *    SSLIP( 156) /0.2108000000E+00/
     *    DSLIP( 156) /0.0000000000E+00/
     *    DIP( 156) /0.1570796327E+01/
     *    DEPTH( 156) /0.1000000000E+05/
     *    WIDTH( 156) /0.2000000000E+04/
      DATA STRIKE( 157) /0.2399653189E+01/
     *    HL( 157) /0.1500000000E+04/
     *    EQLAT( 157) /0.6263744085E+00/
     *    EQLON( 157) /0.2101807865E+01/
     *    SSLIP( 157) /0.1150000000E+00/
     *    DSLIP( 157) /0.0000000000E+00/
     *    DIP( 157) /0.1570796327E+01/
     *    DEPTH( 157) /0.1200000000E+05/
     *    WIDTH( 157) /0.2000000000E+04/
      DATA STRIKE( 158) /0.2399653189E+01/
     *    HL( 158) /0.1500000000E+04/
     *    EQLAT( 158) /0.6260253426E+00/
     *    EQLON( 158) /0.2101420053E+01/
     *    SSLIP( 158) /0.1918000000E+00/
     *    DSLIP( 158) /0.0000000000E+00/
     *    DIP( 158) /0.1570796327E+01/
     *    DEPTH( 158) /0.0000000000E+00/
     *    WIDTH( 158) /0.2000000000E+04/
      DATA STRIKE( 159) /0.2399653189E+01/
     *    HL( 159) /0.1500000000E+04/
     *    EQLAT( 159) /0.6260253426E+00/
     *    EQLON( 159) /0.2101420053E+01/
     *    SSLIP( 159) /0.2510000000E+00/
     *    DSLIP( 159) /0.0000000000E+00/
     *    DIP( 159) /0.1570796327E+01/
     *    DEPTH( 159) /0.2000000000E+04/
     *    WIDTH( 159) /0.2000000000E+04/
      DATA STRIKE( 160) /0.2399653189E+01/
     *    HL( 160) /0.1500000000E+04/
     *    EQLAT( 160) /0.6260253426E+00/
     *    EQLON( 160) /0.2101420053E+01/
     *    SSLIP( 160) /0.3070000000E+00/
     *    DSLIP( 160) /0.0000000000E+00/
     *    DIP( 160) /0.1570796327E+01/
     *    DEPTH( 160) /0.4000000000E+04/
     *    WIDTH( 160) /0.2000000000E+04/
      DATA STRIKE( 161) /0.2399653189E+01/
     *    HL( 161) /0.1500000000E+04/
     *    EQLAT( 161) /0.6260253426E+00/
     *    EQLON( 161) /0.2101420053E+01/
     *    SSLIP( 161) /0.3294000000E+00/
     *    DSLIP( 161) /0.0000000000E+00/
     *    DIP( 161) /0.1570796327E+01/
     *    DEPTH( 161) /0.6000000000E+04/
     *    WIDTH( 161) /0.2000000000E+04/
      DATA STRIKE( 162) /0.2399653189E+01/
     *    HL( 162) /0.1500000000E+04/
     *    EQLAT( 162) /0.6260253426E+00/
     *    EQLON( 162) /0.2101420053E+01/
     *    SSLIP( 162) /0.3058000000E+00/
     *    DSLIP( 162) /0.0000000000E+00/
     *    DIP( 162) /0.1570796327E+01/
     *    DEPTH( 162) /0.8000000000E+04/
     *    WIDTH( 162) /0.2000000000E+04/
      DATA STRIKE( 163) /0.2399653189E+01/
     *    HL( 163) /0.1500000000E+04/
     *    EQLAT( 163) /0.6260253426E+00/
     *    EQLON( 163) /0.2101420053E+01/
     *    SSLIP( 163) /0.2358000000E+00/
     *    DSLIP( 163) /0.0000000000E+00/
     *    DIP( 163) /0.1570796327E+01/
     *    DEPTH( 163) /0.1000000000E+05/
     *    WIDTH( 163) /0.2000000000E+04/
      DATA STRIKE( 164) /0.2399653189E+01/
     *    HL( 164) /0.1500000000E+04/
     *    EQLAT( 164) /0.6260253426E+00/
     *    EQLON( 164) /0.2101420053E+01/
     *    SSLIP( 164) /0.1285000000E+00/
     *    DSLIP( 164) /0.0000000000E+00/
     *    DIP( 164) /0.1570796327E+01/
     *    DEPTH( 164) /0.1200000000E+05/
     *    WIDTH( 164) /0.2000000000E+04/
      DATA STRIKE( 165) /0.2399653189E+01/
     *    HL( 165) /0.1500000000E+04/
     *    EQLAT( 165) /0.6256762768E+00/
     *    EQLON( 165) /0.2101027354E+01/
     *    SSLIP( 165) /0.2688000000E+00/
     *    DSLIP( 165) /0.0000000000E+00/
     *    DIP( 165) /0.1570796327E+01/
     *    DEPTH( 165) /0.0000000000E+00/
     *    WIDTH( 165) /0.2000000000E+04/
      DATA STRIKE( 166) /0.2399653189E+01/
     *    HL( 166) /0.1500000000E+04/
     *    EQLAT( 166) /0.6256762768E+00/
     *    EQLON( 166) /0.2101027354E+01/
     *    SSLIP( 166) /0.3206000000E+00/
     *    DSLIP( 166) /0.0000000000E+00/
     *    DIP( 166) /0.1570796327E+01/
     *    DEPTH( 166) /0.2000000000E+04/
     *    WIDTH( 166) /0.2000000000E+04/
      DATA STRIKE( 167) /0.2399653189E+01/
     *    HL( 167) /0.1500000000E+04/
     *    EQLAT( 167) /0.6256762768E+00/
     *    EQLON( 167) /0.2101027354E+01/
     *    SSLIP( 167) /0.3713000000E+00/
     *    DSLIP( 167) /0.0000000000E+00/
     *    DIP( 167) /0.1570796327E+01/
     *    DEPTH( 167) /0.4000000000E+04/
     *    WIDTH( 167) /0.2000000000E+04/
      DATA STRIKE( 168) /0.2399653189E+01/
     *    HL( 168) /0.1500000000E+04/
     *    EQLAT( 168) /0.6256762768E+00/
     *    EQLON( 168) /0.2101027354E+01/
     *    SSLIP( 168) /0.3872000000E+00/
     *    DSLIP( 168) /0.0000000000E+00/
     *    DIP( 168) /0.1570796327E+01/
     *    DEPTH( 168) /0.6000000000E+04/
     *    WIDTH( 168) /0.2000000000E+04/
      DATA STRIKE( 169) /0.2399653189E+01/
     *    HL( 169) /0.1500000000E+04/
     *    EQLAT( 169) /0.6256762768E+00/
     *    EQLON( 169) /0.2101027354E+01/
     *    SSLIP( 169) /0.3538000000E+00/
     *    DSLIP( 169) /0.0000000000E+00/
     *    DIP( 169) /0.1570796327E+01/
     *    DEPTH( 169) /0.8000000000E+04/
     *    WIDTH( 169) /0.2000000000E+04/
      DATA STRIKE( 170) /0.2399653189E+01/
     *    HL( 170) /0.1500000000E+04/
     *    EQLAT( 170) /0.6256762768E+00/
     *    EQLON( 170) /0.2101027354E+01/
     *    SSLIP( 170) /0.2705000000E+00/
     *    DSLIP( 170) /0.0000000000E+00/
     *    DIP( 170) /0.1570796327E+01/
     *    DEPTH( 170) /0.1000000000E+05/
     *    WIDTH( 170) /0.2000000000E+04/
      DATA STRIKE( 171) /0.2399653189E+01/
     *    HL( 171) /0.1500000000E+04/
     *    EQLAT( 171) /0.6256762768E+00/
     *    EQLON( 171) /0.2101027354E+01/
     *    SSLIP( 171) /0.1468000000E+00/
     *    DSLIP( 171) /0.0000000000E+00/
     *    DIP( 171) /0.1570796327E+01/
     *    DEPTH( 171) /0.1200000000E+05/
     *    WIDTH( 171) /0.2000000000E+04/
      DATA STRIKE( 172) /0.2399653189E+01/
     *    HL( 172) /0.1500000000E+04/
     *    EQLAT( 172) /0.6253320978E+00/
     *    EQLON( 172) /0.2100639541E+01/
     *    SSLIP( 172) /0.1956000000E+00/
     *    DSLIP( 172) /0.0000000000E+00/
     *    DIP( 172) /0.1570796327E+01/
     *    DEPTH( 172) /0.0000000000E+00/
     *    WIDTH( 172) /0.2000000000E+04/
      DATA STRIKE( 173) /0.2399653189E+01/
     *    HL( 173) /0.1500000000E+04/
     *    EQLAT( 173) /0.6253320978E+00/
     *    EQLON( 173) /0.2100639541E+01/
     *    SSLIP( 173) /0.2962000000E+00/
     *    DSLIP( 173) /0.0000000000E+00/
     *    DIP( 173) /0.1570796327E+01/
     *    DEPTH( 173) /0.2000000000E+04/
     *    WIDTH( 173) /0.2000000000E+04/
      DATA STRIKE( 174) /0.2399653189E+01/
     *    HL( 174) /0.1500000000E+04/
     *    EQLAT( 174) /0.6253320978E+00/
     *    EQLON( 174) /0.2100639541E+01/
     *    SSLIP( 174) /0.3819000000E+00/
     *    DSLIP( 174) /0.0000000000E+00/
     *    DIP( 174) /0.1570796327E+01/
     *    DEPTH( 174) /0.4000000000E+04/
     *    WIDTH( 174) /0.2000000000E+04/
      DATA STRIKE( 175) /0.2399653189E+01/
     *    HL( 175) /0.1500000000E+04/
     *    EQLAT( 175) /0.6253320978E+00/
     *    EQLON( 175) /0.2100639541E+01/
     *    SSLIP( 175) /0.4147000000E+00/
     *    DSLIP( 175) /0.0000000000E+00/
     *    DIP( 175) /0.1570796327E+01/
     *    DEPTH( 175) /0.6000000000E+04/
     *    WIDTH( 175) /0.2000000000E+04/
      DATA STRIKE( 176) /0.2399653189E+01/
     *    HL( 176) /0.1500000000E+04/
     *    EQLAT( 176) /0.6253320978E+00/
     *    EQLON( 176) /0.2100639541E+01/
     *    SSLIP( 176) /0.3848000000E+00/
     *    DSLIP( 176) /0.0000000000E+00/
     *    DIP( 176) /0.1570796327E+01/
     *    DEPTH( 176) /0.8000000000E+04/
     *    WIDTH( 176) /0.2000000000E+04/
      DATA STRIKE( 177) /0.2399653189E+01/
     *    HL( 177) /0.1500000000E+04/
     *    EQLAT( 177) /0.6253320978E+00/
     *    EQLON( 177) /0.2100639541E+01/
     *    SSLIP( 177) /0.2958000000E+00/
     *    DSLIP( 177) /0.0000000000E+00/
     *    DIP( 177) /0.1570796327E+01/
     *    DEPTH( 177) /0.1000000000E+05/
     *    WIDTH( 177) /0.2000000000E+04/
      DATA STRIKE( 178) /0.2399653189E+01/
     *    HL( 178) /0.1500000000E+04/
     *    EQLAT( 178) /0.6253320978E+00/
     *    EQLON( 178) /0.2100639541E+01/
     *    SSLIP( 178) /0.1609000000E+00/
     *    DSLIP( 178) /0.0000000000E+00/
     *    DIP( 178) /0.1570796327E+01/
     *    DEPTH( 178) /0.1200000000E+05/
     *    WIDTH( 178) /0.2000000000E+04/
      DATA STRIKE( 179) /0.2685538120E+01/
     *    HL( 179) /0.1500000000E+04/
     *    EQLAT( 179) /0.6249442857E+00/
     *    EQLON( 179) /0.2100314736E+01/
     *    SSLIP( 179) /0.2415000000E+00/
     *    DSLIP( 179) /0.0000000000E+00/
     *    DIP( 179) /0.1570796327E+01/
     *    DEPTH( 179) /0.0000000000E+00/
     *    WIDTH( 179) /0.2000000000E+04/
      DATA STRIKE( 180) /0.2685538120E+01/
     *    HL( 180) /0.1500000000E+04/
     *    EQLAT( 180) /0.6249442857E+00/
     *    EQLON( 180) /0.2100314736E+01/
     *    SSLIP( 180) /0.3093000000E+00/
     *    DSLIP( 180) /0.0000000000E+00/
     *    DIP( 180) /0.1570796327E+01/
     *    DEPTH( 180) /0.2000000000E+04/
     *    WIDTH( 180) /0.2000000000E+04/
      DATA STRIKE( 181) /0.2685538120E+01/
     *    HL( 181) /0.1500000000E+04/
     *    EQLAT( 181) /0.6249442857E+00/
     *    EQLON( 181) /0.2100314736E+01/
     *    SSLIP( 181) /0.3836000000E+00/
     *    DSLIP( 181) /0.0000000000E+00/
     *    DIP( 181) /0.1570796327E+01/
     *    DEPTH( 181) /0.4000000000E+04/
     *    WIDTH( 181) /0.2000000000E+04/
      DATA STRIKE( 182) /0.2685538120E+01/
     *    HL( 182) /0.1500000000E+04/
     *    EQLAT( 182) /0.6249442857E+00/
     *    EQLON( 182) /0.2100314736E+01/
     *    SSLIP( 182) /0.4177000000E+00/
     *    DSLIP( 182) /0.0000000000E+00/
     *    DIP( 182) /0.1570796327E+01/
     *    DEPTH( 182) /0.6000000000E+04/
     *    WIDTH( 182) /0.2000000000E+04/
      DATA STRIKE( 183) /0.2685538120E+01/
     *    HL( 183) /0.1500000000E+04/
     *    EQLAT( 183) /0.6249442857E+00/
     *    EQLON( 183) /0.2100314736E+01/
     *    SSLIP( 183) /0.3908000000E+00/
     *    DSLIP( 183) /0.0000000000E+00/
     *    DIP( 183) /0.1570796327E+01/
     *    DEPTH( 183) /0.8000000000E+04/
     *    WIDTH( 183) /0.2000000000E+04/
      DATA STRIKE( 184) /0.2685538120E+01/
     *    HL( 184) /0.1500000000E+04/
     *    EQLAT( 184) /0.6249442857E+00/
     *    EQLON( 184) /0.2100314736E+01/
     *    SSLIP( 184) /0.3024000000E+00/
     *    DSLIP( 184) /0.0000000000E+00/
     *    DIP( 184) /0.1570796327E+01/
     *    DEPTH( 184) /0.1000000000E+05/
     *    WIDTH( 184) /0.2000000000E+04/
      DATA STRIKE( 185) /0.2685538120E+01/
     *    HL( 185) /0.1500000000E+04/
     *    EQLAT( 185) /0.6249442857E+00/
     *    EQLON( 185) /0.2100314736E+01/
     *    SSLIP( 185) /0.1651000000E+00/
     *    DSLIP( 185) /0.0000000000E+00/
     *    DIP( 185) /0.1570796327E+01/
     *    DEPTH( 185) /0.1200000000E+05/
     *    WIDTH( 185) /0.2000000000E+04/
      DATA STRIKE( 186) /0.2685538120E+01/
     *    HL( 186) /0.1500000000E+04/
     *    EQLAT( 186) /0.6245224396E+00/
     *    EQLON( 186) /0.2100062536E+01/
     *    SSLIP( 186) /0.2458000000E+00/
     *    DSLIP( 186) /0.0000000000E+00/
     *    DIP( 186) /0.1570796327E+01/
     *    DEPTH( 186) /0.0000000000E+00/
     *    WIDTH( 186) /0.2000000000E+04/
      DATA STRIKE( 187) /0.2685538120E+01/
     *    HL( 187) /0.1500000000E+04/
     *    EQLAT( 187) /0.6245224396E+00/
     *    EQLON( 187) /0.2100062536E+01/
     *    SSLIP( 187) /0.3065000000E+00/
     *    DSLIP( 187) /0.0000000000E+00/
     *    DIP( 187) /0.1570796327E+01/
     *    DEPTH( 187) /0.2000000000E+04/
     *    WIDTH( 187) /0.2000000000E+04/
      DATA STRIKE( 188) /0.2685538120E+01/
     *    HL( 188) /0.1500000000E+04/
     *    EQLAT( 188) /0.6245224396E+00/
     *    EQLON( 188) /0.2100062536E+01/
     *    SSLIP( 188) /0.3758000000E+00/
     *    DSLIP( 188) /0.0000000000E+00/
     *    DIP( 188) /0.1570796327E+01/
     *    DEPTH( 188) /0.4000000000E+04/
     *    WIDTH( 188) /0.2000000000E+04/
      DATA STRIKE( 189) /0.2685538120E+01/
     *    HL( 189) /0.1500000000E+04/
     *    EQLAT( 189) /0.6245224396E+00/
     *    EQLON( 189) /0.2100062536E+01/
     *    SSLIP( 189) /0.4081000000E+00/
     *    DSLIP( 189) /0.0000000000E+00/
     *    DIP( 189) /0.1570796327E+01/
     *    DEPTH( 189) /0.6000000000E+04/
     *    WIDTH( 189) /0.2000000000E+04/
      DATA STRIKE( 190) /0.2685538120E+01/
     *    HL( 190) /0.1500000000E+04/
     *    EQLAT( 190) /0.6245224396E+00/
     *    EQLON( 190) /0.2100062536E+01/
     *    SSLIP( 190) /0.3819000000E+00/
     *    DSLIP( 190) /0.0000000000E+00/
     *    DIP( 190) /0.1570796327E+01/
     *    DEPTH( 190) /0.8000000000E+04/
     *    WIDTH( 190) /0.2000000000E+04/
      DATA STRIKE( 191) /0.2685538120E+01/
     *    HL( 191) /0.1500000000E+04/
     *    EQLAT( 191) /0.6245224396E+00/
     *    EQLON( 191) /0.2100062536E+01/
     *    SSLIP( 191) /0.2958000000E+00/
     *    DSLIP( 191) /0.0000000000E+00/
     *    DIP( 191) /0.1570796327E+01/
     *    DEPTH( 191) /0.1000000000E+05/
     *    WIDTH( 191) /0.2000000000E+04/
      DATA STRIKE( 192) /0.2685538120E+01/
     *    HL( 192) /0.1500000000E+04/
     *    EQLAT( 192) /0.6245224396E+00/
     *    EQLON( 192) /0.2100062536E+01/
     *    SSLIP( 192) /0.1616000000E+00/
     *    DSLIP( 192) /0.0000000000E+00/
     *    DIP( 192) /0.1570796327E+01/
     *    DEPTH( 192) /0.1200000000E+05/
     *    WIDTH( 192) /0.2000000000E+04/
      DATA STRIKE( 193) /0.2513099590E+01/
     *    HL( 193) /0.1500000000E+04/
     *    EQLAT( 193) /0.6241152543E+00/
     *    EQLON( 193) /0.2099761990E+01/
     *    SSLIP( 193) /0.2764000000E+00/
     *    DSLIP( 193) /0.0000000000E+00/
     *    DIP( 193) /0.1570796327E+01/
     *    DEPTH( 193) /0.0000000000E+00/
     *    WIDTH( 193) /0.2000000000E+04/
      DATA STRIKE( 194) /0.2513099590E+01/
     *    HL( 194) /0.1500000000E+04/
     *    EQLAT( 194) /0.6241152543E+00/
     *    EQLON( 194) /0.2099761990E+01/
     *    SSLIP( 194) /0.3299000000E+00/
     *    DSLIP( 194) /0.0000000000E+00/
     *    DIP( 194) /0.1570796327E+01/
     *    DEPTH( 194) /0.2000000000E+04/
     *    WIDTH( 194) /0.2000000000E+04/
      DATA STRIKE( 195) /0.2513099590E+01/
     *    HL( 195) /0.1500000000E+04/
     *    EQLAT( 195) /0.6241152543E+00/
     *    EQLON( 195) /0.2099761990E+01/
     *    SSLIP( 195) /0.3814000000E+00/
     *    DSLIP( 195) /0.0000000000E+00/
     *    DIP( 195) /0.1570796327E+01/
     *    DEPTH( 195) /0.4000000000E+04/
     *    WIDTH( 195) /0.2000000000E+04/
      DATA STRIKE( 196) /0.2513099590E+01/
     *    HL( 196) /0.1500000000E+04/
     *    EQLAT( 196) /0.6241152543E+00/
     *    EQLON( 196) /0.2099761990E+01/
     *    SSLIP( 196) /0.3973000000E+00/
     *    DSLIP( 196) /0.0000000000E+00/
     *    DIP( 196) /0.1570796327E+01/
     *    DEPTH( 196) /0.6000000000E+04/
     *    WIDTH( 196) /0.2000000000E+04/
      DATA STRIKE( 197) /0.2513099590E+01/
     *    HL( 197) /0.1500000000E+04/
     *    EQLAT( 197) /0.6241152543E+00/
     *    EQLON( 197) /0.2099761990E+01/
     *    SSLIP( 197) /0.3627000000E+00/
     *    DSLIP( 197) /0.0000000000E+00/
     *    DIP( 197) /0.1570796327E+01/
     *    DEPTH( 197) /0.8000000000E+04/
     *    WIDTH( 197) /0.2000000000E+04/
      DATA STRIKE( 198) /0.2513099590E+01/
     *    HL( 198) /0.1500000000E+04/
     *    EQLAT( 198) /0.6241152543E+00/
     *    EQLON( 198) /0.2099761990E+01/
     *    SSLIP( 198) /0.2771000000E+00/
     *    DSLIP( 198) /0.0000000000E+00/
     *    DIP( 198) /0.1570796327E+01/
     *    DEPTH( 198) /0.1000000000E+05/
     *    WIDTH( 198) /0.2000000000E+04/
      DATA STRIKE( 199) /0.2513099590E+01/
     *    HL( 199) /0.1500000000E+04/
     *    EQLAT( 199) /0.6241152543E+00/
     *    EQLON( 199) /0.2099761990E+01/
     *    SSLIP( 199) /0.1504000000E+00/
     *    DSLIP( 199) /0.0000000000E+00/
     *    DIP( 199) /0.1570796327E+01/
     *    DEPTH( 199) /0.1200000000E+05/
     *    WIDTH( 199) /0.2000000000E+04/
      DATA STRIKE( 200) /0.2513099590E+01/
     *    HL( 200) /0.1500000000E+04/
     *    EQLAT( 200) /0.6237370414E+00/
     *    EQLON( 200) /0.2099427410E+01/
     *    SSLIP( 200) /0.1822000000E+00/
     *    DSLIP( 200) /0.0000000000E+00/
     *    DIP( 200) /0.1570796327E+01/
     *    DEPTH( 200) /0.0000000000E+00/
     *    WIDTH( 200) /0.2000000000E+04/
      DATA STRIKE( 201) /0.2513099590E+01/
     *    HL( 201) /0.1500000000E+04/
     *    EQLAT( 201) /0.6237370414E+00/
     *    EQLON( 201) /0.2099427410E+01/
     *    SSLIP( 201) /0.2694000000E+00/
     *    DSLIP( 201) /0.0000000000E+00/
     *    DIP( 201) /0.1570796327E+01/
     *    DEPTH( 201) /0.2000000000E+04/
     *    WIDTH( 201) /0.2000000000E+04/
      DATA STRIKE( 202) /0.2513099590E+01/
     *    HL( 202) /0.1500000000E+04/
     *    EQLAT( 202) /0.6237370414E+00/
     *    EQLON( 202) /0.2099427410E+01/
     *    SSLIP( 202) /0.3241000000E+00/
     *    DSLIP( 202) /0.0000000000E+00/
     *    DIP( 202) /0.1570796327E+01/
     *    DEPTH( 202) /0.4000000000E+04/
     *    WIDTH( 202) /0.2000000000E+04/
      DATA STRIKE( 203) /0.2513099590E+01/
     *    HL( 203) /0.1500000000E+04/
     *    EQLAT( 203) /0.6237370414E+00/
     *    EQLON( 203) /0.2099427410E+01/
     *    SSLIP( 203) /0.3345000000E+00/
     *    DSLIP( 203) /0.0000000000E+00/
     *    DIP( 203) /0.1570796327E+01/
     *    DEPTH( 203) /0.6000000000E+04/
     *    WIDTH( 203) /0.2000000000E+04/
      DATA STRIKE( 204) /0.2513099590E+01/
     *    HL( 204) /0.1500000000E+04/
     *    EQLAT( 204) /0.6237370414E+00/
     *    EQLON( 204) /0.2099427410E+01/
     *    SSLIP( 204) /0.3007000000E+00/
     *    DSLIP( 204) /0.0000000000E+00/
     *    DIP( 204) /0.1570796327E+01/
     *    DEPTH( 204) /0.8000000000E+04/
     *    WIDTH( 204) /0.2000000000E+04/
      DATA STRIKE( 205) /0.2513099590E+01/
     *    HL( 205) /0.1500000000E+04/
     *    EQLAT( 205) /0.6237370414E+00/
     *    EQLON( 205) /0.2099427410E+01/
     *    SSLIP( 205) /0.2270000000E+00/
     *    DSLIP( 205) /0.0000000000E+00/
     *    DIP( 205) /0.1570796327E+01/
     *    DEPTH( 205) /0.1000000000E+05/
     *    WIDTH( 205) /0.2000000000E+04/
      DATA STRIKE( 206) /0.2513099590E+01/
     *    HL( 206) /0.1500000000E+04/
     *    EQLAT( 206) /0.6237370414E+00/
     *    EQLON( 206) /0.2099427410E+01/
     *    SSLIP( 206) /0.1224000000E+00/
     *    DSLIP( 206) /0.0000000000E+00/
     *    DIP( 206) /0.1570796327E+01/
     *    DEPTH( 206) /0.1200000000E+05/
     *    WIDTH( 206) /0.2000000000E+04/
      DATA STRIKE( 207) /0.2513099590E+01/
     *    HL( 207) /0.1500000000E+04/
     *    EQLAT( 207) /0.6233541162E+00/
     *    EQLON( 207) /0.2099088118E+01/
     *    SSLIP( 207) /0.1942000000E+00/
     *    DSLIP( 207) /0.0000000000E+00/
     *    DIP( 207) /0.1570796327E+01/
     *    DEPTH( 207) /0.0000000000E+00/
     *    WIDTH( 207) /0.2000000000E+04/
      DATA STRIKE( 208) /0.2513099590E+01/
     *    HL( 208) /0.1500000000E+04/
     *    EQLAT( 208) /0.6233541162E+00/
     *    EQLON( 208) /0.2099088118E+01/
     *    SSLIP( 208) /0.2079000000E+00/
     *    DSLIP( 208) /0.0000000000E+00/
     *    DIP( 208) /0.1570796327E+01/
     *    DEPTH( 208) /0.2000000000E+04/
     *    WIDTH( 208) /0.2000000000E+04/
      DATA STRIKE( 209) /0.2513099590E+01/
     *    HL( 209) /0.1500000000E+04/
     *    EQLAT( 209) /0.6233541162E+00/
     *    EQLON( 209) /0.2099088118E+01/
     *    SSLIP( 209) /0.2162000000E+00/
     *    DSLIP( 209) /0.0000000000E+00/
     *    DIP( 209) /0.1570796327E+01/
     *    DEPTH( 209) /0.4000000000E+04/
     *    WIDTH( 209) /0.2000000000E+04/
      DATA STRIKE( 210) /0.2513099590E+01/
     *    HL( 210) /0.1500000000E+04/
     *    EQLAT( 210) /0.6233541162E+00/
     *    EQLON( 210) /0.2099088118E+01/
     *    SSLIP( 210) /0.2087000000E+00/
     *    DSLIP( 210) /0.0000000000E+00/
     *    DIP( 210) /0.1570796327E+01/
     *    DEPTH( 210) /0.6000000000E+04/
     *    WIDTH( 210) /0.2000000000E+04/
      DATA STRIKE( 211) /0.2513099590E+01/
     *    HL( 211) /0.1500000000E+04/
     *    EQLAT( 211) /0.6233541162E+00/
     *    EQLON( 211) /0.2099088118E+01/
     *    SSLIP( 211) /0.1813000000E+00/
     *    DSLIP( 211) /0.0000000000E+00/
     *    DIP( 211) /0.1570796327E+01/
     *    DEPTH( 211) /0.8000000000E+04/
     *    WIDTH( 211) /0.2000000000E+04/
      DATA STRIKE( 212) /0.2513099590E+01/
     *    HL( 212) /0.1500000000E+04/
     *    EQLAT( 212) /0.6233541162E+00/
     *    EQLON( 212) /0.2099088118E+01/
     *    SSLIP( 212) /0.1345000000E+00/
     *    DSLIP( 212) /0.0000000000E+00/
     *    DIP( 212) /0.1570796327E+01/
     *    DEPTH( 212) /0.1000000000E+05/
     *    WIDTH( 212) /0.2000000000E+04/
      DATA STRIKE( 213) /0.2513099590E+01/
     *    HL( 213) /0.1500000000E+04/
     *    EQLAT( 213) /0.6233541162E+00/
     *    EQLON( 213) /0.2099088118E+01/
     *    SSLIP( 213) /0.7190000000E-01/
     *    DSLIP( 213) /0.0000000000E+00/
     *    DIP( 213) /0.1570796327E+01/
     *    DEPTH( 213) /0.1200000000E+05/
     *    WIDTH( 213) /0.2000000000E+04/
      DATA EQLATR( 11)  /0.6493158888E+00/
     *   EQLONR( 11)  /0.2122461044E+01/
     *   EQRAD( 11)   /0.2000000000E+06/
     *   ITEQK( 11)   /    65972160/
     *   NLOC( 11)    / 214/
     *   NFP( 11)     /   1/
      DATA STRIKE( 214) /0.2617993878E+01/
     *    HL( 214) /0.8450000000E+04/
     *    EQLAT( 214) /0.6493158888E+00/
     *    EQLON( 214) /0.2122461044E+01/
     *    SSLIP( 214) /0.7490000000E+00/
     *    DSLIP( 214) /-.1590000000E+00/
     *    DIP( 214) /0.1483529864E+01/
     *    DEPTH( 214) /0.5080000000E+04/
     *    WIDTH( 214) /0.1310000000E+05/
      DATA EQLATR( 12)  /0.6464456949E+00/
     *   EQLONR( 12)  /0.2120584815E+01/
     *   EQRAD( 12)   /0.2000000000E+06/
     *   ITEQK( 12)   /    63491040/
     *   NLOC( 12)    / 215/
     *   NFP( 12)     /   1/
      DATA STRIKE( 215) /0.2722713633E+01/
     *    HL( 215) /0.1000000000E+05/
     *    EQLAT( 215) /0.6464456949E+00/
     *    EQLON( 215) /0.2120584815E+01/
     *    SSLIP( 215) /0.2360000000E+00/
     *    DSLIP( 215) /-.1040000000E+00/
     *    DIP( 215) /0.1570796327E+01/
     *    DEPTH( 215) /0.4000000000E+04/
     *    WIDTH( 215) /0.8000000000E+04/
      DATA EQLATR( 13)  /0.6471729736E+00/
     *   EQLONR( 13)  /0.2126974640E+01/
     *   EQRAD( 13)   /0.2000000000E+06/
     *   ITEQK( 13)   /    68856480/
     *   NLOC( 13)    / 216/
     *   NFP( 13)     /   1/
      DATA STRIKE( 216) /0.5515240436E+01/
     *    HL( 216) /0.1850000000E+05/
     *    EQLAT( 216) /0.6471729736E+00/
     *    EQLON( 216) /0.2127231552E+01/
     *    SSLIP( 216) /0.1660000000E+01/
     *    DSLIP( 216) /-.1190000000E+01/
     *    DIP( 216) /0.1221730476E+01/
     *    DEPTH( 216) /0.5000000000E+04/
     *    WIDTH( 216) /0.1330000000E+05/
      DATA EQLATR( 14)  /0.7046185660E+00/
     *   EQLONR( 14)  /0.2171199363E+01/
     *   EQRAD( 14)   /0.2000000000E+06/
     *   ITEQK( 14)   /    70181280/
     *   NLOC( 14)    / 217/
     *   NFP( 14)     /   1/
      DATA STRIKE( 217) /0.2967059728E+01/
     *    HL( 217) /0.1075000000E+05/
     *    EQLAT( 217) /0.7046185660E+00/
     *    EQLON( 217) /0.2171199363E+01/
     *    SSLIP( 217) /0.1900000000E+00/
     *    DSLIP( 217) /-.2690000000E+01/
     *    DIP( 217) /0.2094395102E+00/
     *    DEPTH( 217) /0.6300000000E+04/
     *    WIDTH( 217) /0.1600000000E+05/
      DATA EQLATR( 15)  /0.5972516700E+00/
     *   EQLONR( 15)  /0.2032086848E+01/
     *   EQRAD( 15)   /0.5000000000E+06/
     *   ITEQK( 15)   /    70273440/
     *   NLOC( 15)    / 218/
     *   NFP( 15)     /  26/
      DATA STRIKE( 218) /0.2653598595E+01/
     *    HL( 218) /0.2482000000E+04/
     *    EQLAT( 218) /0.6044850126E+00/
     *    EQLON( 218) /0.2036134965E+01/
     *    SSLIP( 218) /0.2000000000E+01/
     *    DSLIP( 218) /0.0000000000E+00/
     *    DIP( 218) /0.1570796327E+01/
     *    DEPTH( 218) /0.0000000000E+00/
     *    WIDTH( 218) /0.1000000000E+05/
      DATA STRIKE( 219) /0.2215171887E+01/
     *    HL( 219) /0.4336000000E+04/
     *    EQLAT( 219) /0.6037336483E+00/
     *    EQLON( 219) /0.2035252701E+01/
     *    SSLIP( 219) /0.2700000000E+01/
     *    DSLIP( 219) /0.0000000000E+00/
     *    DIP( 219) /0.1570796327E+01/
     *    DEPTH( 219) /0.0000000000E+00/
     *    WIDTH( 219) /0.1000000000E+05/
      DATA STRIKE( 220) /0.2572615317E+01/
     *    HL( 220) /0.1720000000E+04/
     *    EQLAT( 220) /0.6030985230E+00/
     *    EQLON( 220) /0.2034413896E+01/
     *    SSLIP( 220) /0.6400000000E+01/
     *    DSLIP( 220) /0.0000000000E+00/
     *    DIP( 220) /0.1570796327E+01/
     *    DEPTH( 220) /0.0000000000E+00/
     *    WIDTH( 220) /0.1000000000E+05/
      DATA STRIKE( 221) /0.2445380815E+01/
     *    HL( 221) /0.1444000000E+04/
     *    EQLAT( 221) /0.6026960501E+00/
     *    EQLON( 221) /0.2034064830E+01/
     *    SSLIP( 221) /0.5800000000E+01/
     *    DSLIP( 221) /0.0000000000E+00/
     *    DIP( 221) /0.1570796327E+01/
     *    DEPTH( 221) /0.0000000000E+00/
     *    WIDTH( 221) /0.1000000000E+05/
      DATA STRIKE( 222) /0.2469117293E+01/
     *    HL( 222) /0.1340000000E+04/
     *    EQLAT( 222) /0.6023567581E+00/
     *    EQLON( 222) /0.2033725538E+01/
     *    SSLIP( 222) /0.2550000000E+01/
     *    DSLIP( 222) /0.0000000000E+00/
     *    DIP( 222) /0.1570796327E+01/
     *    DEPTH( 222) /0.0000000000E+00/
     *    WIDTH( 222) /0.1000000000E+05/
      DATA STRIKE( 223) /0.2465801167E+01/
     *    HL( 223) /0.2256000000E+04/
     *    EQLAT( 223) /0.6019155389E+00/
     *    EQLON( 223) /0.2033303692E+01/
     *    SSLIP( 223) /0.4800000000E+01/
     *    DSLIP( 223) /0.0000000000E+00/
     *    DIP( 223) /0.1570796327E+01/
     *    DEPTH( 223) /0.0000000000E+00/
     *    WIDTH( 223) /0.1000000000E+05/
      DATA STRIKE( 224) /0.2702293281E+01/
     *    HL( 224) /0.2185000000E+04/
     *    EQLAT( 224) /0.6013338206E+00/
     *    EQLON( 224) /0.2032857760E+01/
     *    SSLIP( 224) /0.3600000000E+01/
     *    DSLIP( 224) /0.0000000000E+00/
     *    DIP( 224) /0.1570796327E+01/
     *    DEPTH( 224) /0.0000000000E+00/
     *    WIDTH( 224) /0.1000000000E+05/
      DATA STRIKE( 225) /0.3135484001E+01/
     *    HL( 225) /0.1349000000E+04/
     *    EQLAT( 225) /0.6023131249E+00/
     *    EQLON( 225) /0.2033885584E+01/
     *    SSLIP( 225) /0.3750000000E+01/
     *    DSLIP( 225) /0.0000000000E+00/
     *    DIP( 225) /0.1570796327E+01/
     *    DEPTH( 225) /0.0000000000E+00/
     *    WIDTH( 225) /0.1000000000E+05/
      DATA STRIKE( 226) /0.3136182133E+01/
     *    HL( 226) /0.1680000000E+04/
     *    EQLAT( 226) /0.6019301996E+00/
     *    EQLON( 226) /0.2033565491E+01/
     *    SSLIP( 226) /0.1300000000E+01/
     *    DSLIP( 226) /0.0000000000E+00/
     *    DIP( 226) /0.1570796327E+01/
     *    DEPTH( 226) /0.0000000000E+00/
     *    WIDTH( 226) /0.1000000000E+05/
      DATA STRIKE( 227) /0.3294483496E+01/
     *    HL( 227) /0.2290000000E+04/
     *    EQLAT( 227) /0.6006695483E+00/
     *    EQLON( 227) /0.2032746233E+01/
     *    SSLIP( 227) /0.3450000000E+01/
     *    DSLIP( 227) /0.0000000000E+00/
     *    DIP( 227) /0.1570796327E+01/
     *    DEPTH( 227) /0.0000000000E+00/
     *    WIDTH( 227) /0.1000000000E+05/
      DATA STRIKE( 228) /0.2456027323E+01/
     *    HL( 228) /0.8650000000E+03/
     *    EQLAT( 228) /0.6022015983E+00/
     *    EQLON( 228) /0.2033987337E+01/
     *    SSLIP( 228) /0.1500000000E+01/
     *    DSLIP( 228) /0.0000000000E+00/
     *    DIP( 228) /0.1570796327E+01/
     *    DEPTH( 228) /0.0000000000E+00/
     *    WIDTH( 228) /0.1000000000E+05/
      DATA STRIKE( 229) /0.2596526328E+01/
     *    HL( 229) /0.1612000000E+04/
     *    EQLAT( 229) /0.6018816795E+00/
     *    EQLON( 229) /0.2033725538E+01/
     *    SSLIP( 229) /0.2400000000E+01/
     *    DSLIP( 229) /0.0000000000E+00/
     *    DIP( 229) /0.1570796327E+01/
     *    DEPTH( 229) /0.0000000000E+00/
     *    WIDTH( 229) /0.1000000000E+05/
      DATA STRIKE( 230) /0.2711194460E+01/
     *    HL( 230) /0.2380000000E+04/
     *    EQLAT( 230) /0.6013046736E+00/
     *    EQLON( 230) /0.2033366698E+01/
     *    SSLIP( 230) /0.2250000000E+01/
     *    DSLIP( 230) /0.0000000000E+00/
     *    DIP( 230) /0.1570796327E+01/
     *    DEPTH( 230) /0.0000000000E+00/
     *    WIDTH( 230) /0.1000000000E+05/
      DATA STRIKE( 231) /0.2711368993E+01/
     *    HL( 231) /0.2375000000E+04/
     *    EQLAT( 231) /0.6006259151E+00/
     *    EQLON( 231) /0.2032988660E+01/
     *    SSLIP( 231) /0.6150000000E+01/
     *    DSLIP( 231) /0.0000000000E+00/
     *    DIP( 231) /0.1570796327E+01/
     *    DEPTH( 231) /0.0000000000E+00/
     *    WIDTH( 231) /0.1000000000E+05/
      DATA STRIKE( 232) /0.2311339528E+01/
     *    HL( 232) /0.1472000000E+04/
     *    EQLAT( 232) /0.6001557234E+00/
     *    EQLON( 232) /0.2032605560E+01/
     *    SSLIP( 232) /0.9000000000E+00/
     *    DSLIP( 232) /0.0000000000E+00/
     *    DIP( 232) /0.1570796327E+01/
     *    DEPTH( 232) /0.0000000000E+00/
     *    WIDTH( 232) /0.1000000000E+05/
      DATA STRIKE( 233) /0.3187145747E+01/
     *    HL( 233) /0.7880000000E+03/
     *    EQLAT( 233) /0.5998745508E+00/
     *    EQLON( 233) /0.2032406767E+01/
     *    SSLIP( 233) /0.1400000000E+01/
     *    DSLIP( 233) /0.0000000000E+00/
     *    DIP( 233) /0.1570796327E+01/
     *    DEPTH( 233) /0.0000000000E+00/
     *    WIDTH( 233) /0.1000000000E+05/
      DATA STRIKE( 234) /0.2727775088E+01/
     *    HL( 234) /0.2692000000E+04/
     *    EQLAT( 234) /0.5993654383E+00/
     *    EQLON( 234) /0.2032207974E+01/
     *    SSLIP( 234) /0.3800000000E+01/
     *    DSLIP( 234) /0.0000000000E+00/
     *    DIP( 234) /0.1570796327E+01/
     *    DEPTH( 234) /0.0000000000E+00/
     *    WIDTH( 234) /0.1000000000E+05/
      DATA STRIKE( 235) /0.3250675732E+01/
     *    HL( 235) /0.2898000000E+04/
     *    EQLAT( 235) /0.5993024319E+00/
     *    EQLON( 235) /0.2032474660E+01/
     *    SSLIP( 235) /0.3200000000E+01/
     *    DSLIP( 235) /0.0000000000E+00/
     *    DIP( 235) /0.1570796327E+01/
     *    DEPTH( 235) /0.0000000000E+00/
     *    WIDTH( 235) /0.1000000000E+05/
      DATA STRIKE( 236) /0.2739643327E+01/
     *    HL( 236) /0.1732000000E+04/
     *    EQLAT( 236) /0.5985994133E+00/
     *    EQLON( 236) /0.2032402055E+01/
     *    SSLIP( 236) /0.4100000000E+01/
     *    DSLIP( 236) /0.0000000000E+00/
     *    DIP( 236) /0.1570796327E+01/
     *    DEPTH( 236) /0.0000000000E+00/
     *    WIDTH( 236) /0.1000000000E+05/
      DATA STRIKE( 237) /0.3051708197E+01/
     *    HL( 237) /0.1959000000E+04/
     *    EQLAT( 237) /0.5980419551E+00/
     *    EQLON( 237) /0.2032242008E+01/
     *    SSLIP( 237) /0.2800000000E+01/
     *    DSLIP( 237) /0.0000000000E+00/
     *    DIP( 237) /0.1570796327E+01/
     *    DEPTH( 237) /0.0000000000E+00/
     *    WIDTH( 237) /0.1000000000E+05/
      DATA STRIKE( 238) /0.3189763741E+01/
     *    HL( 238) /0.2006000000E+04/
     *    EQLAT( 238) /0.5974262030E+00/
     *    EQLON( 238) /0.2032227522E+01/
     *    SSLIP( 238) /0.1900000000E+01/
     *    DSLIP( 238) /0.0000000000E+00/
     *    DIP( 238) /0.1570796327E+01/
     *    DEPTH( 238) /0.0000000000E+00/
     *    WIDTH( 238) /0.1000000000E+05/
      DATA STRIKE( 239) /0.2920284904E+01/
     *    HL( 239) /0.2070000000E+04/
     *    EQLAT( 239) /0.5967910776E+00/
     *    EQLON( 239) /0.2032159628E+01/
     *    SSLIP( 239) /0.3100000000E+01/
     *    DSLIP( 239) /0.0000000000E+00/
     *    DIP( 239) /0.1570796327E+01/
     *    DEPTH( 239) /0.0000000000E+00/
     *    WIDTH( 239) /0.1000000000E+05/
      DATA STRIKE( 240) /0.2750289835E+01/
     *    HL( 240) /0.3578000000E+04/
     *    EQLAT( 240) /0.5960397134E+00/
     *    EQLON( 240) /0.2031694149E+01/
     *    SSLIP( 240) /0.1300000000E+01/
     *    DSLIP( 240) /0.0000000000E+00/
     *    DIP( 240) /0.1570796327E+01/
     *    DEPTH( 240) /0.0000000000E+00/
     *    WIDTH( 240) /0.1000000000E+05/
      DATA STRIKE( 241) /0.2836509100E+01/
     *    HL( 241) /0.3025000000E+04/
     *    EQLAT( 241) /0.5944348832E+00/
     *    EQLON( 241) /0.2030991130E+01/
     *    SSLIP( 241) /0.1000000000E+00/
     *    DSLIP( 241) /0.0000000000E+00/
     *    DIP( 241) /0.1570796327E+01/
     *    DEPTH( 241) /0.0000000000E+00/
     *    WIDTH( 241) /0.1000000000E+05/
      DATA STRIKE( 242) /0.8377580410E+00/
     *    HL( 242) /0.1400000000E+05/
     *    EQLAT( 242) /0.5969753844E+00/
     *    EQLON( 242) /0.2038253620E+01/
     *    SSLIP( 242) /-.4400000000E+00/
     *    DSLIP( 242) /0.0000000000E+00/
     *    DIP( 242) /0.1570796327E+01/
     *    DEPTH( 242) /0.0000000000E+00/
     *    WIDTH( 242) /0.1000000000E+05/
      DATA STRIKE( 243) /0.1402197521E+01/
     *    HL( 243) /0.5807000000E+04/
     *    EQLAT( 243) /0.6044705264E+00/
     *    EQLON( 243) /0.2034399409E+01/
     *    SSLIP( 243) /-.2300000000E+00/
     *    DSLIP( 243) /0.0000000000E+00/
     *    DIP( 243) /0.1570796327E+01/
     *    DEPTH( 243) /0.0000000000E+00/
     *    WIDTH( 243) /0.1000000000E+05/
      DATA EQLATR( 16)  /0.5759586532E+00/
     *   EQLONR( 16)  /0.2020218609E+01/
     *   EQRAD( 16)   /0.2000000000E+06/
     *   ITEQK( 16)   /    67857120/
     *   NLOC( 16)    / 244/
     *   NFP( 16)     /   2/
      DATA STRIKE( 244) /0.2268928028E+01/
     *    HL( 244) /0.1250000000E+05/
     *    EQLAT( 244) /0.5752071144E+00/
     *    EQLON( 244) /0.2020097483E+01/
     *    SSLIP( 244) /0.1300000000E+01/
     *    DSLIP( 244) /0.0000000000E+00/
     *    DIP( 244) /0.1570796327E+01/
     *    DEPTH( 244) /0.0000000000E+00/
     *    WIDTH( 244) /0.1000000000E+05/
      DATA STRIKE( 245) /0.6981317008E+00/
     *    HL( 245) /0.1250000000E+05/
     *    EQLAT( 245) /0.5778397690E+00/
     *    EQLON( 245) /0.2020228383E+01/
     *    SSLIP( 245) /-.3000000000E+00/
     *    DSLIP( 245) /0.0000000000E+00/
     *    DIP( 245) /0.1570796327E+01/
     *    DEPTH( 245) /0.0000000000E+00/
     *    WIDTH( 245) /0.1000000000E+05/
      DATA EQLATR( 17)  /0.6321757084E+00/
     *   EQLONR( 17)  /0.2097013096E+01/
     *   EQRAD( 17)   /0.2000000000E+06/
     *   ITEQK( 17)   /    65456640/
     *   NLOC( 17)    / 246/
     *   NFP( 17)     /   1/
      DATA STRIKE( 246) /0.5672320069E+01/
     *    HL( 246) /0.1000000000E+05/
     *    EQLAT( 246) /0.6321776282E+00/
     *    EQLON( 246) /0.2099490417E+01/
     *    SSLIP( 246) /0.0000000000E+00/
     *    DSLIP( 246) /-.2250000000E+01/
     *    DIP( 246) /0.3054326191E+00/
     *    DEPTH( 246) /0.7500000000E+04/
     *    WIDTH( 246) /0.5000000000E+04/
      DATA EQLATR( 18)  /0.6303780192E+00/
     *   EQLONR( 18)  /0.2097013096E+01/
     *   EQRAD( 18)   /0.2000000000E+06/
     *   ITEQK( 18)   /    66644640/
     *   NLOC( 18)    / 247/
     *   NFP( 18)     /   1/
      DATA STRIKE( 247) /0.5672320069E+01/
     *    HL( 247) /0.1100000000E+05/
     *    EQLAT( 247) /0.6290845557E+00/
     *    EQLON( 247) /0.2095078748E+01/
     *    SSLIP( 247) /0.0000000000E+00/
     *    DSLIP( 247) /-.2400000000E+00/
     *    DIP( 247) /0.2617993878E+00/
     *    DEPTH( 247) /0.4500000000E+04/
     *    WIDTH( 247) /0.6000000000E+04/
      DATA EQLATR( 19)  /0.5939355445E+00/
     *   EQLONR( 19)  /0.2060361182E+01/
     *   EQRAD( 19)   /0.2000000000E+06/
     *   ITEQK( 19)   /    67779360/
     *   NLOC( 19)    / 248/
     *   NFP( 19)     /   1/
      DATA STRIKE( 248) /0.1570796327E+01/
     *    HL( 248) /0.2250000000E+04/
     *    EQLAT( 248) /0.5939355445E+00/
     *    EQLON( 248) /0.2060361182E+01/
     *    SSLIP( 248) /0.0000000000E+00/
     *    DSLIP( 248) /-.1090000000E+01/
     *    DIP( 248) /0.5235987756E+00/
     *    DEPTH( 248) /0.1200000000E+05/
     *    WIDTH( 248) /0.6000000000E+04/
      DATA EQLATR( 20)  /0.6559528524E+00/
     *   EQLONR( 20)  /0.2066760781E+01/
     *   EQRAD( 20)   /0.2000000000E+06/
     *   ITEQK( 20)   /    67150080/
     *   NLOC( 20)    / 249/
     *   NFP( 20)     /   2/
      DATA STRIKE( 249) /0.5724679947E+01/
     *    HL( 249) /0.7500000000E+04/
     *    EQLAT( 249) /0.6557057137E+00/
     *    EQLON( 249) /0.2066629881E+01/
     *    SSLIP( 249) /0.5160000000E+00/
     *    DSLIP( 249) /0.0000000000E+00/
     *    DIP( 249) /0.9599310886E+00/
     *    DEPTH( 249) /0.1000000000E+04/
     *    WIDTH( 249) /0.8000000000E+04/
      DATA STRIKE( 250) /0.8377580410E+00/
     *    HL( 250) /0.3750000000E+04/
     *    EQLAT( 250) /0.6560256326E+00/
     *    EQLON( 250) /0.2067095186E+01/
     *    SSLIP( 250) /-.8240000000E+00/
     *    DSLIP( 250) /0.0000000000E+00/
     *    DIP( 250) /0.1570796327E+01/
     *    DEPTH( 250) /0.2000000000E+04/
     *    WIDTH( 250) /0.6000000000E+04/
      DATA EQLATR( 21)  /0.6005580218E+00/
     *   EQLONR( 21)  /0.2069276847E+01/
     *   EQRAD( 21)   /0.2000000000E+06/
     *   ITEQK( 21)   /    71091360/
     *   NLOC( 21)    / 251/
     *   NFP( 21)     /   1/
      DATA STRIKE( 251) /0.5100724739E+01/
     *    HL( 251) /0.5045000000E+04/
     *    EQLAT( 251) /0.5998551777E+00/
     *    EQLON( 251) /0.2068602976E+01/
     *    SSLIP( 251) /0.0000000000E+00/
     *    DSLIP( 251) /-.2410000000E+01/
     *    DIP( 251) /0.7365289443E+00/
     *    DEPTH( 251) /0.5494000000E+04/
     *    WIDTH( 251) /0.1351000000E+05/
      DATA EQLATR( 22)  /0.5991715322E+00/
     *   EQLONR( 22)  /0.2032261381E+01/
     *   EQRAD( 22)   /0.1000000000E+06/
     *   ITEQK( 22)   /    63283680/
     *   NLOC( 22)    / 252/
     *   NFP( 22)     /   1/
      DATA STRIKE( 252) /0.6178465552E+01/
     *    HL( 252) /0.3000000000E+04/
     *    EQLAT( 252) /0.5991715322E+00/
     *    EQLON( 252) /0.2032246895E+01/
     *    SSLIP( 252) /0.5400000000E+00/
     *    DSLIP( 252) /-.1800000000E+00/
     *    DIP( 252) /0.1483529864E+01/
     *    DEPTH( 252) /0.7500000000E+03/
     *    WIDTH( 252) /0.4250000000E+04/
      DATA EQLATR( 23)  /0.5923647481E+00/
     *   EQLONR( 23)  /0.2035752040E+01/
     *   EQRAD( 23)   /0.2000000000E+06/
     *   ITEQK( 23)   /    67131360/
     *   NLOC( 23)    / 253/
     *   NFP( 23)     /   1/
      DATA STRIKE( 253) /0.1867502300E+01/
     *    HL( 253) /0.5500000000E+04/
     *    EQLAT( 253) /0.5932374128E+00/
     *    EQLON( 253) /0.2035432121E+01/
     *    SSLIP( 253) /0.1800000000E+00/
     *    DSLIP( 253) /-.2400000000E+00/
     *    DIP( 253) /0.8028514559E+00/
     *    DEPTH( 253) /0.6000000000E+04/
     *    WIDTH( 253) /0.7000000000E+04/
      DATA EQLATR( 24)  /0.5934119457E+00/
     *   EQLONR( 24)  /0.2030341519E+01/
     *   EQRAD( 24)   /0.2000000000E+06/
     *   ITEQK( 24)   /    70176960/
     *   NLOC( 24)    / 254/
     *   NFP( 24)     /  19/
      DATA STRIKE( 254) /0.3001966313E+01/
     *    HL( 254) /0.2500000000E+04/
     *    EQLAT( 254) /0.5947891850E+00/
     *    EQLON( 254) /0.2030526873E+01/
     *    SSLIP( 254) /0.6900000000E-02/
     *    DSLIP( 254) /0.0000000000E+00/
     *    DIP( 254) /0.1570796327E+01/
     *    DEPTH( 254) /0.0000000000E+00/
     *    WIDTH( 254) /0.5000000000E+04/
      DATA STRIKE( 255) /0.3001966313E+01/
     *    HL( 255) /0.2500000000E+04/
     *    EQLAT( 255) /0.5947891850E+00/
     *    EQLON( 255) /0.2030526873E+01/
     *    SSLIP( 255) /0.3000000000E-02/
     *    DSLIP( 255) /0.0000000000E+00/
     *    DIP( 255) /0.1570796327E+01/
     *    DEPTH( 255) /0.5000000000E+04/
     *    WIDTH( 255) /0.5000000000E+04/
      DATA STRIKE( 256) /0.3001966313E+01/
     *    HL( 256) /0.2500000000E+04/
     *    EQLAT( 256) /0.5940100700E+00/
     *    EQLON( 256) /0.2030395275E+01/
     *    SSLIP( 256) /0.1143000000E+00/
     *    DSLIP( 256) /0.0000000000E+00/
     *    DIP( 256) /0.1570796327E+01/
     *    DEPTH( 256) /0.0000000000E+00/
     *    WIDTH( 256) /0.5000000000E+04/
      DATA STRIKE( 257) /0.3001966313E+01/
     *    HL( 257) /0.2500000000E+04/
     *    EQLAT( 257) /0.5940100700E+00/
     *    EQLON( 257) /0.2030395275E+01/
     *    SSLIP( 257) /0.1613000000E+00/
     *    DSLIP( 257) /0.0000000000E+00/
     *    DIP( 257) /0.1570796327E+01/
     *    DEPTH( 257) /0.5000000000E+04/
     *    WIDTH( 257) /0.5000000000E+04/
      DATA STRIKE( 258) /0.3001966313E+01/
     *    HL( 258) /0.2500000000E+04/
     *    EQLAT( 258) /0.5940100700E+00/
     *    EQLON( 258) /0.2030395275E+01/
     *    SSLIP( 258) /0.1053000000E+00/
     *    DSLIP( 258) /0.0000000000E+00/
     *    DIP( 258) /0.1570796327E+01/
     *    DEPTH( 258) /0.1000000000E+05/
     *    WIDTH( 258) /0.5000000000E+04/
      DATA STRIKE( 259) /0.3001966313E+01/
     *    HL( 259) /0.2500000000E+04/
     *    EQLAT( 259) /0.5940100700E+00/
     *    EQLON( 259) /0.2030395275E+01/
     *    SSLIP( 259) /0.3250000000E-01/
     *    DSLIP( 259) /0.0000000000E+00/
     *    DIP( 259) /0.1570796327E+01/
     *    DEPTH( 259) /0.1500000000E+05/
     *    WIDTH( 259) /0.5000000000E+04/
      DATA STRIKE( 260) /0.3001966313E+01/
     *    HL( 260) /0.2500000000E+04/
     *    EQLAT( 260) /0.5932311296E+00/
     *    EQLON( 260) /0.2030264026E+01/
     *    SSLIP( 260) /0.9660000000E-01/
     *    DSLIP( 260) /0.0000000000E+00/
     *    DIP( 260) /0.1570796327E+01/
     *    DEPTH( 260) /0.0000000000E+00/
     *    WIDTH( 260) /0.5000000000E+04/
      DATA STRIKE( 261) /0.3001966313E+01/
     *    HL( 261) /0.2500000000E+04/
     *    EQLAT( 261) /0.5932311296E+00/
     *    EQLON( 261) /0.2030264026E+01/
     *    SSLIP( 261) /0.5406000000E+00/
     *    DSLIP( 261) /0.0000000000E+00/
     *    DIP( 261) /0.1570796327E+01/
     *    DEPTH( 261) /0.5000000000E+04/
     *    WIDTH( 261) /0.5000000000E+04/
      DATA STRIKE( 262) /0.3001966313E+01/
     *    HL( 262) /0.2500000000E+04/
     *    EQLAT( 262) /0.5932311296E+00/
     *    EQLON( 262) /0.2030264026E+01/
     *    SSLIP( 262) /0.5760000000E+00/
     *    DSLIP( 262) /0.0000000000E+00/
     *    DIP( 262) /0.1570796327E+01/
     *    DEPTH( 262) /0.1000000000E+05/
     *    WIDTH( 262) /0.5000000000E+04/
      DATA STRIKE( 263) /0.3001966313E+01/
     *    HL( 263) /0.2500000000E+04/
     *    EQLAT( 263) /0.5932311296E+00/
     *    EQLON( 263) /0.2030264026E+01/
     *    SSLIP( 263) /0.2093000000E+00/
     *    DSLIP( 263) /0.0000000000E+00/
     *    DIP( 263) /0.1570796327E+01/
     *    DEPTH( 263) /0.1500000000E+05/
     *    WIDTH( 263) /0.5000000000E+04/
      DATA STRIKE( 264) /0.3001966313E+01/
     *    HL( 264) /0.2500000000E+04/
     *    EQLAT( 264) /0.5924520146E+00/
     *    EQLON( 264) /0.2030132777E+01/
     *    SSLIP( 264) /0.6710000000E-01/
     *    DSLIP( 264) /0.0000000000E+00/
     *    DIP( 264) /0.1570796327E+01/
     *    DEPTH( 264) /0.0000000000E+00/
     *    WIDTH( 264) /0.5000000000E+04/
      DATA STRIKE( 265) /0.3001966313E+01/
     *    HL( 265) /0.2500000000E+04/
     *    EQLAT( 265) /0.5924520146E+00/
     *    EQLON( 265) /0.2030132777E+01/
     *    SSLIP( 265) /0.4750000000E+00/
     *    DSLIP( 265) /0.0000000000E+00/
     *    DIP( 265) /0.1570796327E+01/
     *    DEPTH( 265) /0.5000000000E+04/
     *    WIDTH( 265) /0.5000000000E+04/
      DATA STRIKE( 266) /0.3001966313E+01/
     *    HL( 266) /0.2500000000E+04/
     *    EQLAT( 266) /0.5924520146E+00/
     *    EQLON( 266) /0.2030132777E+01/
     *    SSLIP( 266) /0.5283000000E+00/
     *    DSLIP( 266) /0.0000000000E+00/
     *    DIP( 266) /0.1570796327E+01/
     *    DEPTH( 266) /0.1000000000E+05/
     *    WIDTH( 266) /0.5000000000E+04/
      DATA STRIKE( 267) /0.3001966313E+01/
     *    HL( 267) /0.2500000000E+04/
     *    EQLAT( 267) /0.5924520146E+00/
     *    EQLON( 267) /0.2030132777E+01/
     *    SSLIP( 267) /0.1803000000E+00/
     *    DSLIP( 267) /0.0000000000E+00/
     *    DIP( 267) /0.1570796327E+01/
     *    DEPTH( 267) /0.1500000000E+05/
     *    WIDTH( 267) /0.5000000000E+04/
      DATA STRIKE( 268) /0.3001966313E+01/
     *    HL( 268) /0.2500000000E+04/
     *    EQLAT( 268) /0.5916728996E+00/
     *    EQLON( 268) /0.2030001529E+01/
     *    SSLIP( 268) /0.1930000000E-01/
     *    DSLIP( 268) /0.0000000000E+00/
     *    DIP( 268) /0.1570796327E+01/
     *    DEPTH( 268) /0.5000000000E+04/
     *    WIDTH( 268) /0.5000000000E+04/
      DATA STRIKE( 269) /0.3001966313E+01/
     *    HL( 269) /0.2500000000E+04/
     *    EQLAT( 269) /0.5916728996E+00/
     *    EQLON( 269) /0.2030001529E+01/
     *    SSLIP( 269) /0.4110000000E-01/
     *    DSLIP( 269) /0.0000000000E+00/
     *    DIP( 269) /0.1570796327E+01/
     *    DEPTH( 269) /0.1000000000E+05/
     *    WIDTH( 269) /0.5000000000E+04/
      DATA STRIKE( 270) /0.3001966313E+01/
     *    HL( 270) /0.2500000000E+04/
     *    EQLAT( 270) /0.5916728996E+00/
     *    EQLON( 270) /0.2030001529E+01/
     *    SSLIP( 270) /0.1070000000E-01/
     *    DSLIP( 270) /0.0000000000E+00/
     *    DIP( 270) /0.1570796327E+01/
     *    DEPTH( 270) /0.1500000000E+05/
     *    WIDTH( 270) /0.5000000000E+04/
      DATA STRIKE( 271) /0.3001966313E+01/
     *    HL( 271) /0.2500000000E+04/
     *    EQLAT( 271) /0.5908936101E+00/
     *    EQLON( 271) /0.2029870629E+01/
     *    SSLIP( 271) /0.3780000000E-01/
     *    DSLIP( 271) /0.0000000000E+00/
     *    DIP( 271) /0.1570796327E+01/
     *    DEPTH( 271) /0.0000000000E+00/
     *    WIDTH( 271) /0.5000000000E+04/
      DATA STRIKE( 272) /0.3001966313E+01/
     *    HL( 272) /0.2500000000E+04/
     *    EQLAT( 272) /0.5901144951E+00/
     *    EQLON( 272) /0.2029739729E+01/
     *    SSLIP( 272) /0.9400000000E-02/
     *    DSLIP( 272) /0.0000000000E+00/
     *    DIP( 272) /0.1570796327E+01/
     *    DEPTH( 272) /0.0000000000E+00/
     *    WIDTH( 272) /0.5000000000E+04/
      DATA EQLATR( 25)  /0.1047197551E+01/
     *   EQLONR( 25)  /0.2617993878E+01/
     *   EQRAD( 25)   /0.1500000000E+07/
     *   ITEQK( 25)   /    55414080/
     *   NLOC( 25)    / 273/
     *   NFP( 25)     /  68/
      DATA STRIKE( 273) /0.6667157743E+00/
     *    HL( 273) /0.2500000000E+05/
     *    EQLAT( 273) /0.9787806445E+00/
     *    EQLON( 273) /0.2642355707E+01/
     *    SSLIP( 273) /-.1019000000E+00/
     *    DSLIP( 273) /-.1873700000E+01/
     *    DIP( 273) /0.1396263402E+00/
     *    DEPTH( 273) /0.1100000000E+05/
     *    WIDTH( 273) /0.5000000000E+05/
      DATA STRIKE( 274) /0.6667157743E+00/
     *    HL( 274) /0.2500000000E+05/
     *    EQLAT( 274) /0.9849474164E+00/
     *    EQLON( 274) /0.2633614575E+01/
     *    SSLIP( 274) /-.1069000000E+00/
     *    DSLIP( 274) /-.1859500000E+01/
     *    DIP( 274) /0.1396263402E+00/
     *    DEPTH( 274) /0.1100000000E+05/
     *    WIDTH( 274) /0.5000000000E+05/
      DATA STRIKE( 275) /0.6667157743E+00/
     *    HL( 275) /0.2500000000E+05/
     *    EQLAT( 275) /0.9911143627E+00/
     *    EQLON( 275) /0.2624786176E+01/
     *    SSLIP( 275) /-.1586000000E+00/
     *    DSLIP( 275) /-.2004300000E+01/
     *    DIP( 275) /0.1396263402E+00/
     *    DEPTH( 275) /0.1100000000E+05/
     *    WIDTH( 275) /0.5000000000E+05/
      DATA STRIKE( 276) /0.6667157743E+00/
     *    HL( 276) /0.2500000000E+05/
     *    EQLAT( 276) /0.9972811346E+00/
     *    EQLON( 276) /0.2615880110E+01/
     *    SSLIP( 276) /-.1112000000E+00/
     *    DSLIP( 276) /-.1771880000E+02/
     *    DIP( 276) /0.1396263402E+00/
     *    DEPTH( 276) /0.1100000000E+05/
     *    WIDTH( 276) /0.5000000000E+05/
      DATA STRIKE( 277) /0.6667157743E+00/
     *    HL( 277) /0.2500000000E+05/
     *    EQLAT( 277) /0.1003447906E+01/
     *    EQLON( 277) /0.2606881890E+01/
     *    SSLIP( 277) /-.1663000000E+00/
     *    DSLIP( 277) /-.1773250000E+02/
     *    DIP( 277) /0.1396263402E+00/
     *    DEPTH( 277) /0.1100000000E+05/
     *    WIDTH( 277) /0.5000000000E+05/
      DATA STRIKE( 278) /0.6667157743E+00/
     *    HL( 278) /0.2500000000E+05/
     *    EQLAT( 278) /0.1009614853E+01/
     *    EQLON( 278) /0.2597796579E+01/
     *    SSLIP( 278) /-.1153000000E+00/
     *    DSLIP( 278) /-.2955300000E+01/
     *    DIP( 278) /0.1396263402E+00/
     *    DEPTH( 278) /0.1100000000E+05/
     *    WIDTH( 278) /0.5000000000E+05/
      DATA STRIKE( 279) /0.6667157743E+00/
     *    HL( 279) /0.2500000000E+05/
     *    EQLAT( 279) /0.1015776738E+01/
     *    EQLON( 279) /0.2588623826E+01/
     *    SSLIP( 279) /-.1926000000E+00/
     *    DSLIP( 279) /-.3025200000E+01/
     *    DIP( 279) /0.1396263402E+00/
     *    DEPTH( 279) /0.1100000000E+05/
     *    WIDTH( 279) /0.5000000000E+05/
      DATA STRIKE( 280) /0.6632251158E+00/
     *    HL( 280) /0.2493100000E+05/
     *    EQLAT( 280) /0.9835851869E+00/
     *    EQLON( 280) /0.2652662924E+01/
     *    SSLIP( 280) /-.1081000000E+00/
     *    DSLIP( 280) /-.1519600000E+01/
     *    DIP( 280) /0.1396263402E+00/
     *    DEPTH( 280) /0.1795900000E+05/
     *    WIDTH( 280) /0.5000000000E+05/
      DATA STRIKE( 281) /0.6632251158E+00/
     *    HL( 281) /0.2493000000E+05/
     *    EQLAT( 281) /0.9897519587E+00/
     *    EQLON( 281) /0.2644004171E+01/
     *    SSLIP( 281) /-.3355000000E+00/
     *    DSLIP( 281) /-.1913000000E+01/
     *    DIP( 281) /0.1396263402E+00/
     *    DEPTH( 281) /0.1795900000E+05/
     *    WIDTH( 281) /0.5000000000E+05/
      DATA STRIKE( 282) /0.6632251158E+00/
     *    HL( 282) /0.2492900000E+05/
     *    EQLAT( 282) /0.9959187306E+00/
     *    EQLON( 282) /0.2635262864E+01/
     *    SSLIP( 282) /-.1997000000E+00/
     *    DSLIP( 282) /-.2201700000E+01/
     *    DIP( 282) /0.1396263402E+00/
     *    DEPTH( 282) /0.1795900000E+05/
     *    WIDTH( 282) /0.5000000000E+05/
      DATA STRIKE( 283) /0.6632251158E+00/
     *    HL( 283) /0.2492800000E+05/
     *    EQLAT( 283) /0.1002085677E+01/
     *    EQLON( 283) /0.2626448951E+01/
     *    SSLIP( 283) /-.1335000000E+00/
     *    DSLIP( 283) /-.1784090000E+02/
     *    DIP( 283) /0.1396263402E+00/
     *    DEPTH( 283) /0.1795900000E+05/
     *    WIDTH( 283) /0.5000000000E+05/
      DATA STRIKE( 284) /0.6632251158E+00/
     *    HL( 284) /0.2492800000E+05/
     *    EQLAT( 284) /0.1008252449E+01/
     *    EQLON( 284) /0.2617543059E+01/
     *    SSLIP( 284) /-.1604000000E+00/
     *    DSLIP( 284) /-.1770760000E+02/
     *    DIP( 284) /0.1396263402E+00/
     *    DEPTH( 284) /0.1795900000E+05/
     *    WIDTH( 284) /0.5000000000E+05/
      DATA STRIKE( 285) /0.6632251158E+00/
     *    HL( 285) /0.2492700000E+05/
     *    EQLAT( 285) /0.1014419221E+01/
     *    EQLON( 285) /0.2608554614E+01/
     *    SSLIP( 285) /-.2107000000E+00/
     *    DSLIP( 285) /-.2912700000E+01/
     *    DIP( 285) /0.1396263402E+00/
     *    DEPTH( 285) /0.1795900000E+05/
     *    WIDTH( 285) /0.5000000000E+05/
      DATA STRIKE( 286) /0.6632251158E+00/
     *    HL( 286) /0.2492500000E+05/
     *    EQLAT( 286) /0.1020586167E+01/
     *    EQLON( 286) /0.2599478902E+01/
     *    SSLIP( 286) /-.1689000000E+00/
     *    DSLIP( 286) /-.2529400000E+01/
     *    DIP( 286) /0.1396263402E+00/
     *    DEPTH( 286) /0.1795900000E+05/
     *    WIDTH( 286) /0.5000000000E+05/
      DATA STRIKE( 287) /0.6597344573E+00/
     *    HL( 287) /0.2486300000E+05/
     *    EQLAT( 287) /0.9883750685E+00/
     *    EQLON( 287) /0.2662625787E+01/
     *    SSLIP( 287) /-.5409000000E+00/
     *    DSLIP( 287) /-.1267000000E+01/
     *    DIP( 287) /0.1396263402E+00/
     *    DEPTH( 287) /0.2491700000E+05/
     *    WIDTH( 287) /0.5000000000E+05/
      DATA STRIKE( 288) /0.6597344573E+00/
     *    HL( 288) /0.2486200000E+05/
     *    EQLAT( 288) /0.9945420149E+00/
     *    EQLON( 288) /0.2654049413E+01/
     *    SSLIP( 288) /-.1013600000E+01/
     *    DSLIP( 288) /-.4670100000E+01/
     *    DIP( 288) /0.1396263402E+00/
     *    DEPTH( 288) /0.2491700000E+05/
     *    WIDTH( 288) /0.5000000000E+05/
      DATA STRIKE( 289) /0.6597344573E+00/
     *    HL( 289) /0.2486000000E+05/
     *    EQLAT( 289) /0.1000703900E+01/
     *    EQLON( 289) /0.2645390660E+01/
     *    SSLIP( 289) /0.3133000000E+00/
     *    DSLIP( 289) /-.9657400000E+01/
     *    DIP( 289) /0.1396263402E+00/
     *    DEPTH( 289) /0.2491700000E+05/
     *    WIDTH( 289) /0.5000000000E+05/
      DATA STRIKE( 290) /0.6597344573E+00/
     *    HL( 290) /0.2485800000E+05/
     *    EQLAT( 290) /0.1006870672E+01/
     *    EQLON( 290) /0.2636649528E+01/
     *    SSLIP( 290) /0.6830000000E-01/
     *    DSLIP( 290) /-.1250590000E+02/
     *    DIP( 290) /0.1396263402E+00/
     *    DEPTH( 290) /0.2491700000E+05/
     *    WIDTH( 290) /0.5000000000E+05/
      DATA STRIKE( 291) /0.6597344573E+00/
     *    HL( 291) /0.2485600000E+05/
     *    EQLAT( 291) /0.1013042505E+01/
     *    EQLON( 291) /0.2627830728E+01/
     *    SSLIP( 291) /0.7000000000E-02/
     *    DSLIP( 291) /-.6801100000E+01/
     *    DIP( 291) /0.1396263402E+00/
     *    DEPTH( 291) /0.2491700000E+05/
     *    WIDTH( 291) /0.5000000000E+05/
      DATA STRIKE( 292) /0.6597344573E+00/
     *    HL( 292) /0.2485400000E+05/
     *    EQLAT( 292) /0.1019209277E+01/
     *    EQLON( 292) /0.2618924662E+01/
     *    SSLIP( 292) /-.3081000000E+00/
     *    DSLIP( 292) /-.7947200000E+01/
     *    DIP( 292) /0.1396263402E+00/
     *    DEPTH( 292) /0.2491700000E+05/
     *    WIDTH( 292) /0.5000000000E+05/
      DATA STRIKE( 293) /0.6597344573E+00/
     *    HL( 293) /0.2485200000E+05/
     *    EQLAT( 293) /0.1025376049E+01/
     *    EQLON( 293) /0.2609936216E+01/
     *    SSLIP( 293) /-.3791000000E+00/
     *    DSLIP( 293) /-.5466700000E+01/
     *    DIP( 293) /0.1396263402E+00/
     *    DEPTH( 293) /0.2491700000E+05/
     *    WIDTH( 293) /0.5000000000E+05/
      DATA STRIKE( 294) /0.6562437987E+00/
     *    HL( 294) /0.2479600000E+05/
     *    EQLAT( 294) /0.9931310907E+00/
     *    EQLON( 294) /0.2672166978E+01/
     *    SSLIP( 294) /-.1489100000E+01/
     *    DSLIP( 294) /-.3051500000E+01/
     *    DIP( 294) /0.1570796327E+00/
     *    DEPTH( 294) /0.3230800000E+05/
     *    WIDTH( 294) /0.5000000000E+05/
      DATA STRIKE( 295) /0.6562437987E+00/
     *    HL( 295) /0.2479300000E+05/
     *    EQLAT( 295) /0.9992980371E+00/
     *    EQLON( 295) /0.2663658498E+01/
     *    SSLIP( 295) /-.1456000000E+01/
     *    DSLIP( 295) /-.3652700000E+01/
     *    DIP( 295) /0.1570796327E+00/
     *    DEPTH( 295) /0.3230800000E+05/
     *    WIDTH( 295) /0.5000000000E+05/
      DATA STRIKE( 296) /0.6562437987E+00/
     *    HL( 296) /0.2479000000E+05/
     *    EQLAT( 296) /0.1005464809E+01/
     *    EQLON( 296) /0.2655067638E+01/
     *    SSLIP( 296) /0.4759000000E+00/
     *    DSLIP( 296) /-.2532000000E+01/
     *    DIP( 296) /0.1570796327E+00/
     *    DEPTH( 296) /0.3230800000E+05/
     *    WIDTH( 296) /0.5000000000E+05/
      DATA STRIKE( 297) /0.6562437987E+00/
     *    HL( 297) /0.2478800000E+05/
     *    EQLAT( 297) /0.1011626694E+01/
     *    EQLON( 297) /0.2646403998E+01/
     *    SSLIP( 297) /-.8200000000E-01/
     *    DSLIP( 297) /-.5151600000E+01/
     *    DIP( 297) /0.1570796327E+00/
     *    DEPTH( 297) /0.3230800000E+05/
     *    WIDTH( 297) /0.5000000000E+05/
      DATA STRIKE( 298) /0.6562437987E+00/
     *    HL( 298) /0.2478500000E+05/
     *    EQLAT( 298) /0.1017798527E+01/
     *    EQLON( 298) /0.2637657979E+01/
     *    SSLIP( 298) /0.5500000000E-01/
     *    DSLIP( 298) /-.3341300000E+01/
     *    DIP( 298) /0.1570796327E+00/
     *    DEPTH( 298) /0.3230800000E+05/
     *    WIDTH( 298) /0.5000000000E+05/
      DATA STRIKE( 299) /0.6562437987E+00/
     *    HL( 299) /0.2478200000E+05/
     *    EQLAT( 299) /0.1023960412E+01/
     *    EQLON( 299) /0.2628829406E+01/
     *    SSLIP( 299) /-.1146000000E+00/
     *    DSLIP( 299) /-.1733670000E+02/
     *    DIP( 299) /0.1570796327E+00/
     *    DEPTH( 299) /0.3230800000E+05/
     *    WIDTH( 299) /0.5000000000E+05/
      DATA STRIKE( 300) /0.6562437987E+00/
     *    HL( 300) /0.2477900000E+05/
     *    EQLAT( 300) /0.1030127184E+01/
     *    EQLON( 300) /0.2619908853E+01/
     *    SSLIP( 300) /-.8620000000E-01/
     *    DSLIP( 300) /-.3891200000E+01/
     *    DIP( 300) /0.1570796327E+00/
     *    DEPTH( 300) /0.3230800000E+05/
     *    WIDTH( 300) /0.5000000000E+05/
      DATA STRIKE( 301) /0.7888888219E+00/
     *    HL( 301) /0.2000000000E+05/
     *    EQLAT( 301) /0.1016247104E+01/
     *    EQLON( 301) /0.2572717070E+01/
     *    SSLIP( 301) /-.2278000000E+00/
     *    DSLIP( 301) /-.1993220000E+02/
     *    DIP( 301) /0.1396263402E+00/
     *    DEPTH( 301) /0.4000000000E+04/
     *    WIDTH( 301) /0.5000000000E+05/
      DATA STRIKE( 302) /0.8761552845E+00/
     *    HL( 302) /0.2000000000E+05/
     *    EQLAT( 302) /0.1020464867E+01/
     *    EQLON( 302) /0.2563874185E+01/
     *    SSLIP( 302) /-.2191000000E+00/
     *    DSLIP( 302) /-.2011580000E+02/
     *    DIP( 302) /0.1396263402E+00/
     *    DEPTH( 302) /0.4000000000E+04/
     *    WIDTH( 302) /0.5000000000E+05/
      DATA STRIKE( 303) /0.9808750396E+00/
     *    HL( 303) /0.2000000000E+05/
     *    EQLAT( 303) /0.1024222211E+01/
     *    EQLON( 303) /0.2554240840E+01/
     *    SSLIP( 303) /0.1012000000E+00/
     *    DSLIP( 303) /-.1412720000E+02/
     *    DIP( 303) /0.1396263402E+00/
     *    DEPTH( 303) /0.4000000000E+04/
     *    WIDTH( 303) /0.5000000000E+05/
      DATA STRIKE( 304) /0.1087340124E+01/
     *    HL( 304) /0.2000000000E+05/
     *    EQLAT( 304) /0.1027426810E+01/
     *    EQLON( 304) /0.2543846532E+01/
     *    SSLIP( 304) /0.1074000000E+00/
     *    DSLIP( 304) /-.1317610000E+02/
     *    DIP( 304) /0.1396263402E+00/
     *    DEPTH( 304) /0.4000000000E+04/
     *    WIDTH( 304) /0.5000000000E+05/
      DATA STRIKE( 305) /0.1209513172E+01/
     *    HL( 305) /0.2000000000E+05/
     *    EQLAT( 305) /0.1029996284E+01/
     *    EQLON( 305) /0.2532773290E+01/
     *    SSLIP( 305) /0.1648000000E+00/
     *    DSLIP( 305) /-.2407700000E+01/
     *    DIP( 305) /0.1396263402E+00/
     *    DEPTH( 305) /0.4000000000E+04/
     *    WIDTH( 305) /0.5000000000E+05/
      DATA STRIKE( 306) /0.1331686219E+01/
     *    HL( 306) /0.2000000000E+05/
     *    EQLAT( 306) /0.1031853140E+01/
     *    EQLON( 306) /0.2521132991E+01/
     *    SSLIP( 306) /0.3620000000E-01/
     *    DSLIP( 306) /-.2325600000E+01/
     *    DIP( 306) /0.1396263402E+00/
     *    DEPTH( 306) /0.4000000000E+04/
     *    WIDTH( 306) /0.5000000000E+05/
      DATA STRIKE( 307) /0.7836528341E+00/
     *    HL( 307) /0.2241000000E+05/
     *    EQLAT( 307) /0.1021759377E+01/
     *    EQLON( 307) /0.2582830380E+01/
     *    SSLIP( 307) /-.3950000000E+00/
     *    DSLIP( 307) /-.2349190000E+02/
     *    DIP( 307) /0.1396263402E+00/
     *    DEPTH( 307) /0.1095900000E+05/
     *    WIDTH( 307) /0.5000000000E+05/
      DATA STRIKE( 308) /0.8709192967E+00/
     *    HL( 308) /0.2238500000E+05/
     *    EQLAT( 308) /0.1026437907E+01/
     *    EQLON( 308) /0.2573095283E+01/
     *    SSLIP( 308) /0.6610000000E-01/
     *    DSLIP( 308) /-.2273440000E+02/
     *    DIP( 308) /0.1396263402E+00/
     *    DEPTH( 308) /0.1095900000E+05/
     *    WIDTH( 308) /0.5000000000E+05/
      DATA STRIKE( 309) /0.9773843811E+00/
     *    HL( 309) /0.2235300000E+05/
     *    EQLAT( 309) /0.1030684817E+01/
     *    EQLON( 309) /0.2562274242E+01/
     *    SSLIP( 309) /0.1282000000E+01/
     *    DSLIP( 309) /-.1435200000E+02/
     *    DIP( 309) /0.1396263402E+00/
     *    DEPTH( 309) /0.1095900000E+05/
     *    WIDTH( 309) /0.5000000000E+05/
      DATA STRIKE( 310) /0.1082104136E+01/
     *    HL( 310) /0.2232100000E+05/
     *    EQLAT( 310) /0.1034306375E+01/
     *    EQLON( 310) /0.2550595022E+01/
     *    SSLIP( 310) /-.2238000000E+00/
     *    DSLIP( 310) /-.1812040000E+02/
     *    DIP( 310) /0.1396263402E+00/
     *    DEPTH( 310) /0.1095900000E+05/
     *    WIDTH( 310) /0.5000000000E+05/
      DATA STRIKE( 311) /0.1204277184E+01/
     *    HL( 311) /0.2228800000E+05/
     *    EQLAT( 311) /0.1037268548E+01/
     *    EQLON( 311) /0.2537912412E+01/
     *    SSLIP( 311) /-.9678000000E+00/
     *    DSLIP( 311) /-.4154600000E+01/
     *    DIP( 311) /0.1396263402E+00/
     *    DEPTH( 311) /0.1095900000E+05/
     *    WIDTH( 311) /0.5000000000E+05/
      DATA STRIKE( 312) /0.1328195561E+01/
     *    HL( 312) /0.2226100000E+05/
     *    EQLAT( 312) /0.1039401689E+01/
     *    EQLON( 312) /0.2524580017E+01/
     *    SSLIP( 312) /-.2491700000E+01/
     *    DSLIP( 312) /-.5336200000E+01/
     *    DIP( 312) /0.1396263402E+00/
     *    DEPTH( 312) /0.1095900000E+05/
     *    WIDTH( 312) /0.5000000000E+05/
      DATA STRIKE( 313) /0.7801621756E+00/
     *    HL( 313) /0.2482100000E+05/
     *    EQLAT( 313) /0.1027257164E+01/
     *    EQLON( 313) /0.2592599337E+01/
     *    SSLIP( 313) /0.1743000000E+00/
     *    DSLIP( 313) /-.1264160000E+02/
     *    DIP( 313) /0.1396263402E+00/
     *    DEPTH( 313) /0.1791700000E+05/
     *    WIDTH( 313) /0.5000000000E+05/
      DATA STRIKE( 314) /0.8674286382E+00/
     *    HL( 314) /0.2477000000E+05/
     *    EQLAT( 314) /0.1032386513E+01/
     *    EQLON( 314) /0.2581977089E+01/
     *    SSLIP( 314) /0.2028400000E+01/
     *    DSLIP( 314) /-.1658740000E+02/
     *    DIP( 314) /0.1396263402E+00/
     *    DEPTH( 314) /0.1791700000E+05/
     *    WIDTH( 314) /0.5000000000E+05/
      DATA STRIKE( 315) /0.9721483934E+00/
     *    HL( 315) /0.2470600000E+05/
     *    EQLAT( 315) /0.1037123162E+01/
     *    EQLON( 315) /0.2569992437E+01/
     *    SSLIP( 315) /0.2138900000E+01/
     *    DSLIP( 315) /-.1823890000E+02/
     *    DIP( 315) /0.1396263402E+00/
     *    DEPTH( 315) /0.1791700000E+05/
     *    WIDTH( 315) /0.5000000000E+05/
      DATA STRIKE( 316) /0.1076868148E+01/
     *    HL( 316) /0.2464300000E+05/
     *    EQLAT( 316) /0.1041166391E+01/
     *    EQLON( 316) /0.2557067401E+01/
     *    SSLIP( 316) /-.1315800000E+01/
     *    DSLIP( 316) /-.1477380000E+02/
     *    DIP( 316) /0.1396263402E+00/
     *    DEPTH( 316) /0.1791700000E+05/
     *    WIDTH( 316) /0.5000000000E+05/
      DATA STRIKE( 317) /0.1200786525E+01/
     *    HL( 317) /0.2457500000E+05/
     *    EQLAT( 317) /0.1044521438E+01/
     *    EQLON( 317) /0.2542828307E+01/
     *    SSLIP( 317) /-.5067000000E+00/
     *    DSLIP( 317) /-.8131500000E+01/
     *    DIP( 317) /0.1396263402E+00/
     *    DEPTH( 317) /0.1791700000E+05/
     *    WIDTH( 317) /0.5000000000E+05/
      DATA STRIKE( 318) /0.1324704902E+01/
     *    HL( 318) /0.2452100000E+05/
     *    EQLAT( 318) /0.1046945526E+01/
     *    EQLON( 318) /0.2527876769E+01/
     *    SSLIP( 318) /-.7069000000E+00/
     *    DSLIP( 318) /-.9321200000E+01/
     *    DIP( 318) /0.1396263402E+00/
     *    DEPTH( 318) /0.1791700000E+05/
     *    WIDTH( 318) /0.5000000000E+05/
      DATA STRIKE( 319) /0.1450368608E+01/
     *    HL( 319) /0.2448700000E+05/
     *    EQLAT( 319) /0.1048399909E+01/
     *    EQLON( 319) /0.2512435318E+01/
     *    SSLIP( 319) /0.9059000000E+00/
     *    DSLIP( 319) /-.1408620000E+02/
     *    DIP( 319) /0.1396263402E+00/
     *    DEPTH( 319) /0.1791700000E+05/
     *    WIDTH( 319) /0.5000000000E+05/
      DATA STRIKE( 320) /0.7749261879E+00/
     *    HL( 320) /0.2723200000E+05/
     *    EQLAT( 320) /0.1032716205E+01/
     *    EQLON( 320) /0.2601965996E+01/
     *    SSLIP( 320) /0.9104000000E+00/
     *    DSLIP( 320) /-.8145000000E+01/
     *    DIP( 320) /0.1396263402E+00/
     *    DEPTH( 320) /0.2487600000E+05/
     *    WIDTH( 320) /0.5000000000E+05/
      DATA STRIKE( 321) /0.8621926505E+00/
     *    HL( 321) /0.2715600000E+05/
     *    EQLAT( 321) /0.1038315745E+01/
     *    EQLON( 321) /0.2590461309E+01/
     *    SSLIP( 321) /0.4737400000E+01/
     *    DSLIP( 321) /-.1347200000E+02/
     *    DIP( 321) /0.1396263402E+00/
     *    DEPTH( 321) /0.2487600000E+05/
     *    WIDTH( 321) /0.5000000000E+05/
      DATA STRIKE( 322) /0.9669124056E+00/
     *    HL( 322) /0.2706000000E+05/
     *    EQLAT( 322) /0.1043542134E+01/
     *    EQLON( 322) /0.2577332593E+01/
     *    SSLIP( 322) /0.2496000000E+01/
     *    DSLIP( 322) /-.2960350000E+02/
     *    DIP( 322) /0.1396263402E+00/
     *    DEPTH( 322) /0.2487600000E+05/
     *    WIDTH( 322) /0.5000000000E+05/
      DATA STRIKE( 323) /0.1071632161E+01/
     *    HL( 323) /0.2696400000E+05/
     *    EQLAT( 323) /0.1048012096E+01/
     *    EQLON( 323) /0.2563190539E+01/
     *    SSLIP( 323) /-.4036000000E+00/
     *    DSLIP( 323) /-.1632030000E+02/
     *    DIP( 323) /0.1396263402E+00/
     *    DEPTH( 323) /0.2487600000E+05/
     *    WIDTH( 323) /0.5000000000E+05/
      DATA STRIKE( 324) /0.1197295867E+01/
     *    HL( 324) /0.2686300000E+05/
     *    EQLAT( 324) /0.1051769267E+01/
     *    EQLON( 324) /0.2547468090E+01/
     *    SSLIP( 324) /0.2986000000E+00/
     *    DSLIP( 324) /-.5632000000E+01/
     *    DIP( 324) /0.1396263402E+00/
     *    DEPTH( 324) /0.2487600000E+05/
     *    WIDTH( 324) /0.5000000000E+05/
      DATA STRIKE( 325) /0.1322959573E+01/
     *    HL( 325) /0.2678100000E+05/
     *    EQLAT( 325) /0.1054489188E+01/
     *    EQLON( 325) /0.2530969842E+01/
     *    SSLIP( 325) /-.3800200000E+01/
     *    DSLIP( 325) /-.1071970000E+02/
     *    DIP( 325) /0.1396263402E+00/
     *    DEPTH( 325) /0.2487600000E+05/
     *    WIDTH( 325) /0.5000000000E+05/
      DATA STRIKE( 326) /0.1448623279E+01/
     *    HL( 326) /0.2672900000E+05/
     *    EQLAT( 326) /0.1056113217E+01/
     *    EQLON( 326) /0.2513957768E+01/
     *    SSLIP( 326) /-.7076000000E+00/
     *    DSLIP( 326) /-.1434350000E+02/
     *    DIP( 326) /0.1396263402E+00/
     *    DEPTH( 326) /0.2487600000E+05/
     *    WIDTH( 326) /0.5000000000E+05/
      DATA STRIKE( 327) /0.7714355294E+00/
     *    HL( 327) /0.2964400000E+05/
     *    EQLAT( 327) /0.1038155698E+01/
     *    EQLON( 327) /0.2610823542E+01/
     *    SSLIP( 327) /0.3292000000E+01/
     *    DSLIP( 327) /-.6754100000E+01/
     *    DIP( 327) /0.1570796327E+00/
     *    DEPTH( 327) /0.3226600000E+05/
     *    WIDTH( 327) /0.5000000000E+05/
      DATA STRIKE( 328) /0.8569566627E+00/
     *    HL( 328) /0.2954300000E+05/
     *    EQLAT( 328) /0.1044206231E+01/
     *    EQLON( 328) /0.2598441303E+01/
     *    SSLIP( 328) /0.5912900000E+01/
     *    DSLIP( 328) /-.1538440000E+02/
     *    DIP( 328) /0.1570796327E+00/
     *    DEPTH( 328) /0.3226600000E+05/
     *    WIDTH( 328) /0.5000000000E+05/
      DATA STRIKE( 329) /0.9616764178E+00/
     *    HL( 329) /0.2941500000E+05/
     *    EQLAT( 329) /0.1049927072E+01/
     *    EQLON( 329) /0.2584192610E+01/
     *    SSLIP( 329) /0.4312700000E+01/
     *    DSLIP( 329) /-.1654700000E+02/
     *    DIP( 329) /0.1570796327E+00/
     *    DEPTH( 329) /0.3226600000E+05/
     *    WIDTH( 329) /0.5000000000E+05/
      DATA STRIKE( 330) /0.1066396173E+01/
     *    HL( 330) /0.2928700000E+05/
     *    EQLAT( 330) /0.1054828480E+01/
     *    EQLON( 330) /0.2568877346E+01/
     *    SSLIP( 330) /-.9762000000E+00/
     *    DSLIP( 330) /-.1471710000E+02/
     *    DIP( 330) /0.1570796327E+00/
     *    DEPTH( 330) /0.3226600000E+05/
     *    WIDTH( 330) /0.5000000000E+05/
      DATA STRIKE( 331) /0.1192059879E+01/
     *    HL( 331) /0.2915000000E+05/
     *    EQLAT( 331) /0.1058997897E+01/
     *    EQLON( 331) /0.2551753746E+01/
     *    SSLIP( 331) /-.5810000000E-01/
     *    DSLIP( 331) /-.9923200000E+01/
     *    DIP( 331) /0.1570796327E+00/
     *    DEPTH( 331) /0.3226600000E+05/
     *    WIDTH( 331) /0.5000000000E+05/
      DATA STRIKE( 332) /0.1319468915E+01/
     *    HL( 332) /0.2904100000E+05/
     *    EQLAT( 332) /0.1062008590E+01/
     *    EQLON( 332) /0.2533820488E+01/
     *    SSLIP( 332) /0.4920000000E-01/
     *    DSLIP( 332) /-.3943600000E+01/
     *    DIP( 332) /0.1570796327E+00/
     *    DEPTH( 332) /0.3226600000E+05/
     *    WIDTH( 332) /0.5000000000E+05/
      DATA STRIKE( 333) /0.1446877950E+01/
     *    HL( 333) /0.2897000000E+05/
     *    EQLAT( 333) /0.1063821812E+01/
     *    EQLON( 333) /0.2515349145E+01/
     *    SSLIP( 333) /-.1381600000E+01/
     *    DSLIP( 333) /-.4455500000E+01/
     *    DIP( 333) /0.1570796327E+00/
     *    DEPTH( 333) /0.3226600000E+05/
     *    WIDTH( 333) /0.5000000000E+05/
      DATA STRIKE( 334) /0.8517206750E+00/
     *    HL( 334) /0.3193100000E+05/
     *    EQLAT( 334) /0.1050062858E+01/
     *    EQLON( 334) /0.2606683097E+01/
     *    SSLIP( 334) /0.4959000000E+00/
     *    DSLIP( 334) /-.9483400000E+01/
     *    DIP( 334) /0.2094395102E+00/
     *    DEPTH( 334) /0.4008800000E+05/
     *    WIDTH( 334) /0.5000000000E+05/
      DATA STRIKE( 335) /0.9564404301E+00/
     *    HL( 335) /0.3177000000E+05/
     *    EQLAT( 335) /0.1056287750E+01/
     *    EQLON( 335) /0.2591309714E+01/
     *    SSLIP( 335) /-.1091000000E+01/
     *    DSLIP( 335) /-.5017200000E+01/
     *    DIP( 335) /0.2094395102E+00/
     *    DEPTH( 335) /0.4008800000E+05/
     *    WIDTH( 335) /0.5000000000E+05/
      DATA STRIKE( 336) /0.1062905514E+01/
     *    HL( 336) /0.3161000000E+05/
     *    EQLAT( 336) /0.1061615891E+01/
     *    EQLON( 336) /0.2574806753E+01/
     *    SSLIP( 336) /0.4420000000E+00/
     *    DSLIP( 336) /-.1080910000E+02/
     *    DIP( 336) /0.2094395102E+00/
     *    DEPTH( 336) /0.4008800000E+05/
     *    WIDTH( 336) /0.6718700000E+05/
      DATA STRIKE( 337) /0.1188569221E+01/
     *    HL( 337) /0.3143800000E+05/
     *    EQLAT( 337) /0.1066197380E+01/
     *    EQLON( 337) /0.2556233483E+01/
     *    SSLIP( 337) /-.5380000000E+01/
     *    DSLIP( 337) /-.5816300000E+01/
     *    DIP( 337) /0.2094395102E+00/
     *    DEPTH( 337) /0.4008800000E+05/
     *    WIDTH( 337) /0.5000000000E+05/
      DATA STRIKE( 338) /0.1315978256E+01/
     *    HL( 338) /0.3130000000E+05/
     *    EQLAT( 338) /0.1069518392E+01/
     *    EQLON( 338) /0.2536806921E+01/
     *    SSLIP( 338) /-.1587600000E+01/
     *    DSLIP( 338) /-.9149000000E+00/
     *    DIP( 338) /0.2094395102E+00/
     *    DEPTH( 338) /0.4008800000E+05/
     *    WIDTH( 338) /0.5000000000E+05/
      DATA STRIKE( 339) /0.1445132621E+01/
     *    HL( 339) /0.3121100000E+05/
     *    EQLAT( 339) /0.1071511035E+01/
     *    EQLON( 339) /0.2516822901E+01/
     *    SSLIP( 339) /-.1638700000E+01/
     *    DSLIP( 339) /-.5341700000E+01/
     *    DIP( 339) /0.2094395102E+00/
     *    DEPTH( 339) /0.4008800000E+05/
     *    WIDTH( 339) /0.5000000000E+05/
      DATA STRIKE( 340) /0.6894050545E+00/
     *    HL( 340) /0.3000000000E+05/
     *    EQLAT( 340) /0.1043711780E+01/
     *    EQLON( 340) /0.2578733744E+01/
     *    SSLIP( 340) /-.3708000000E+00/
     *    DSLIP( 340) /-.8595200000E+01/
     *    DIP( 340) /0.1047197551E+01/
     *    DEPTH( 340) /0.8700000000E+02/
     *    WIDTH( 340) /0.2990000000E+05/
      DATA EQLATR( 26)  /0.6031730486E+00/
     *   EQLONR( 26)  /0.2030199275E+01/
     *   EQRAD( 26)   /0.5000000000E+06/
     *   ITEQK( 26)   /    74112480/
     *   NLOC( 26)    / 341/
     *   NFP( 26)     /  75/
      DATA STRIKE( 341) /0.2820103005E+01/
     *    HL( 341) /0.2270500000E+04/
     *    EQLAT( 341) /0.6058208876E+00/
     *    EQLON( 341) /0.2031163045E+01/
     *    SSLIP( 341) /0.1150400000E+01/
     *    DSLIP( 341) /0.2618000000E+00/
     *    DIP( 341) /0.1570796327E+01/
     *    DEPTH( 341) /0.0000000000E+00/
     *    WIDTH( 341) /0.4000000000E+04/
      DATA STRIKE( 342) /0.2747846374E+01/
     *    HL( 342) /0.2109500000E+04/
     *    EQLAT( 342) /0.6051779083E+00/
     *    EQLON( 342) /0.2030873321E+01/
     *    SSLIP( 342) /0.2782500000E+01/
     *    DSLIP( 342) /0.4126000000E+00/
     *    DIP( 342) /0.1570796327E+01/
     *    DEPTH( 342) /0.0000000000E+00/
     *    WIDTH( 342) /0.4000000000E+04/
      DATA STRIKE( 343) /0.2596526328E+01/
     *    HL( 343) /0.2226000000E+04/
     *    EQLAT( 343) /0.6045740244E+00/
     *    EQLON( 343) /0.2030500518E+01/
     *    SSLIP( 343) /0.4048700000E+01/
     *    DSLIP( 343) /0.1023000000E+00/
     *    DIP( 343) /0.1570796327E+01/
     *    DEPTH( 343) /0.0000000000E+00/
     *    WIDTH( 343) /0.4000000000E+04/
      DATA STRIKE( 344) /0.2478542071E+01/
     *    HL( 344) /0.2592000000E+04/
     *    EQLAT( 344) /0.6039553052E+00/
     *    EQLON( 344) /0.2029978490E+01/
     *    SSLIP( 344) /0.4546800000E+01/
     *    DSLIP( 344) /-.3698000000E+00/
     *    DIP( 344) /0.1570796327E+01/
     *    DEPTH( 344) /0.0000000000E+00/
     *    WIDTH( 344) /0.4000000000E+04/
      DATA STRIKE( 345) /0.2484825256E+01/
     *    HL( 345) /0.2312500000E+04/
     *    EQLAT( 345) /0.6033479306E+00/
     *    EQLON( 345) /0.2029407942E+01/
     *    SSLIP( 345) /0.3089200000E+01/
     *    DSLIP( 345) /-.5984000000E+00/
     *    DIP( 345) /0.1570796327E+01/
     *    DEPTH( 345) /0.0000000000E+00/
     *    WIDTH( 345) /0.4000000000E+04/
      DATA STRIKE( 346) /0.3010692960E+01/
     *    HL( 346) /0.2290500000E+04/
     *    EQLAT( 346) /0.6027046022E+00/
     *    EQLON( 346) /0.2029083835E+01/
     *    SSLIP( 346) /0.4360800000E+01/
     *    DSLIP( 346) /-.5773000000E+00/
     *    DIP( 346) /0.1570796327E+01/
     *    DEPTH( 346) /0.0000000000E+00/
     *    WIDTH( 346) /0.4000000000E+04/
      DATA STRIKE( 347) /0.2898991888E+01/
     *    HL( 347) /0.2316500000E+04/
     *    EQLAT( 347) /0.6019959985E+00/
     *    EQLON( 347) /0.2028921519E+01/
     *    SSLIP( 347) /0.3496600000E+01/
     *    DSLIP( 347) /0.1102000000E+00/
     *    DIP( 347) /0.1570796327E+01/
     *    DEPTH( 347) /0.0000000000E+00/
     *    WIDTH( 347) /0.4000000000E+04/
      DATA STRIKE( 348) /0.2572440785E+01/
     *    HL( 348) /0.2312500000E+04/
     *    EQLAT( 348) /0.6013381839E+00/
     *    EQLON( 348) /0.2028579434E+01/
     *    SSLIP( 348) /0.2550100000E+01/
     *    DSLIP( 348) /-.1169000000E+00/
     *    DIP( 348) /0.1570796327E+01/
     *    DEPTH( 348) /0.0000000000E+00/
     *    WIDTH( 348) /0.4000000000E+04/
      DATA STRIKE( 349) /0.2352180233E+01/
     *    HL( 349) /0.2442000000E+04/
     *    EQLAT( 349) /0.6007630980E+00/
     *    EQLON( 349) /0.2028013948E+01/
     *    SSLIP( 349) /0.1769000000E+01/
     *    DSLIP( 349) /-.6660000000E-01/
     *    DIP( 349) /0.1570796327E+01/
     *    DEPTH( 349) /0.0000000000E+00/
     *    WIDTH( 349) /0.4000000000E+04/
      DATA STRIKE( 350) /0.2535439804E+01/
     *    HL( 350) /0.2397500000E+04/
     *    EQLAT( 350) /0.6001845213E+00/
     *    EQLON( 350) /0.2027425946E+01/
     *    SSLIP( 350) /0.1167400000E+01/
     *    DSLIP( 350) /-.4856000000E+00/
     *    DIP( 350) /0.1570796327E+01/
     *    DEPTH( 350) /0.0000000000E+00/
     *    WIDTH( 350) /0.4000000000E+04/
      DATA STRIKE( 351) /0.2556732821E+01/
     *    HL( 351) /0.3224000000E+04/
     *    EQLAT( 351) /0.5994535774E+00/
     *    EQLON( 351) /0.2026829218E+01/
     *    SSLIP( 351) /0.2236000000E+00/
     *    DSLIP( 351) /-.3527000000E+00/
     *    DIP( 351) /0.1570796327E+01/
     *    DEPTH( 351) /0.0000000000E+00/
     *    WIDTH( 351) /0.4000000000E+04/
      DATA STRIKE( 352) /0.2976309973E+01/
     *    HL( 352) /0.2151500000E+04/
     *    EQLAT( 352) /0.6054559392E+00/
     *    EQLON( 352) /0.2029619651E+01/
     *    SSLIP( 352) /0.6711000000E+00/
     *    DSLIP( 352) /0.1559000000E+00/
     *    DIP( 352) /0.1570796327E+01/
     *    DEPTH( 352) /0.0000000000E+00/
     *    WIDTH( 352) /0.4000000000E+04/
      DATA STRIKE( 353) /0.2976309973E+01/
     *    HL( 353) /0.2151500000E+04/
     *    EQLAT( 353) /0.6047909688E+00/
     *    EQLON( 353) /0.2029485260E+01/
     *    SSLIP( 353) /0.1140700000E+01/
     *    DSLIP( 353) /0.2141000000E+00/
     *    DIP( 353) /0.1570796327E+01/
     *    DEPTH( 353) /0.0000000000E+00/
     *    WIDTH( 353) /0.4000000000E+04/
      DATA STRIKE( 354) /0.2976309973E+01/
     *    HL( 354) /0.2151500000E+04/
     *    EQLAT( 354) /0.6041242530E+00/
     *    EQLON( 354) /0.2029350870E+01/
     *    SSLIP( 354) /0.1597600000E+01/
     *    DSLIP( 354) /-.6701000000E+00/
     *    DIP( 354) /0.1570796327E+01/
     *    DEPTH( 354) /0.0000000000E+00/
     *    WIDTH( 354) /0.4000000000E+04/
      DATA STRIKE( 355) /0.2976309973E+01/
     *    HL( 355) /0.2151500000E+04/
     *    EQLAT( 355) /0.6034592826E+00/
     *    EQLON( 355) /0.2029216480E+01/
     *    SSLIP( 355) /0.1358000000E+01/
     *    DSLIP( 355) /-.1217100000E+01/
     *    DIP( 355) /0.1570796327E+01/
     *    DEPTH( 355) /0.0000000000E+00/
     *    WIDTH( 355) /0.4000000000E+04/
      DATA STRIKE( 356) /0.2820103005E+01/
     *    HL( 356) /0.2270500000E+04/
     *    EQLAT( 356) /0.6058208876E+00/
     *    EQLON( 356) /0.2031163045E+01/
     *    SSLIP( 356) /0.1199900000E+01/
     *    DSLIP( 356) /0.1526000000E+00/
     *    DIP( 356) /0.1570796327E+01/
     *    DEPTH( 356) /0.4000000000E+04/
     *    WIDTH( 356) /0.4000000000E+04/
      DATA STRIKE( 357) /0.2747846374E+01/
     *    HL( 357) /0.2109500000E+04/
     *    EQLAT( 357) /0.6051779083E+00/
     *    EQLON( 357) /0.2030873321E+01/
     *    SSLIP( 357) /0.2348400000E+01/
     *    DSLIP( 357) /0.3548000000E+00/
     *    DIP( 357) /0.1570796327E+01/
     *    DEPTH( 357) /0.4000000000E+04/
     *    WIDTH( 357) /0.4000000000E+04/
      DATA STRIKE( 358) /0.2596526328E+01/
     *    HL( 358) /0.2226000000E+04/
     *    EQLAT( 358) /0.6045740244E+00/
     *    EQLON( 358) /0.2030500518E+01/
     *    SSLIP( 358) /0.3323400000E+01/
     *    DSLIP( 358) /-.4700000000E-02/
     *    DIP( 358) /0.1570796327E+01/
     *    DEPTH( 358) /0.4000000000E+04/
     *    WIDTH( 358) /0.4000000000E+04/
      DATA STRIKE( 359) /0.2478542071E+01/
     *    HL( 359) /0.2592000000E+04/
     *    EQLAT( 359) /0.6039553052E+00/
     *    EQLON( 359) /0.2029978490E+01/
     *    SSLIP( 359) /0.3682500000E+01/
     *    DSLIP( 359) /-.2527000000E+00/
     *    DIP( 359) /0.1570796327E+01/
     *    DEPTH( 359) /0.4000000000E+04/
     *    WIDTH( 359) /0.4000000000E+04/
      DATA STRIKE( 360) /0.2484825256E+01/
     *    HL( 360) /0.2312500000E+04/
     *    EQLAT( 360) /0.6033479306E+00/
     *    EQLON( 360) /0.2029407942E+01/
     *    SSLIP( 360) /0.3236100000E+01/
     *    DSLIP( 360) /-.3317000000E+00/
     *    DIP( 360) /0.1570796327E+01/
     *    DEPTH( 360) /0.4000000000E+04/
     *    WIDTH( 360) /0.4000000000E+04/
      DATA STRIKE( 361) /0.3010692960E+01/
     *    HL( 361) /0.2290500000E+04/
     *    EQLAT( 361) /0.6027046022E+00/
     *    EQLON( 361) /0.2029083835E+01/
     *    SSLIP( 361) /0.3789700000E+01/
     *    DSLIP( 361) /-.1631000000E+00/
     *    DIP( 361) /0.1570796327E+01/
     *    DEPTH( 361) /0.4000000000E+04/
     *    WIDTH( 361) /0.4000000000E+04/
      DATA STRIKE( 362) /0.2898991888E+01/
     *    HL( 362) /0.2316500000E+04/
     *    EQLAT( 362) /0.6019959985E+00/
     *    EQLON( 362) /0.2028921519E+01/
     *    SSLIP( 362) /0.3068000000E+01/
     *    DSLIP( 362) /-.6670000000E-01/
     *    DIP( 362) /0.1570796327E+01/
     *    DEPTH( 362) /0.4000000000E+04/
     *    WIDTH( 362) /0.4000000000E+04/
      DATA STRIKE( 363) /0.2572440785E+01/
     *    HL( 363) /0.2312500000E+04/
     *    EQLAT( 363) /0.6013381839E+00/
     *    EQLON( 363) /0.2028579434E+01/
     *    SSLIP( 363) /0.2133500000E+01/
     *    DSLIP( 363) /0.5310000000E-01/
     *    DIP( 363) /0.1570796327E+01/
     *    DEPTH( 363) /0.4000000000E+04/
     *    WIDTH( 363) /0.4000000000E+04/
      DATA STRIKE( 364) /0.2352180233E+01/
     *    HL( 364) /0.2442000000E+04/
     *    EQLAT( 364) /0.6007630980E+00/
     *    EQLON( 364) /0.2028013948E+01/
     *    SSLIP( 364) /0.1440300000E+01/
     *    DSLIP( 364) /0.9390000000E-01/
     *    DIP( 364) /0.1570796327E+01/
     *    DEPTH( 364) /0.4000000000E+04/
     *    WIDTH( 364) /0.4000000000E+04/
      DATA STRIKE( 365) /0.2535439804E+01/
     *    HL( 365) /0.2397500000E+04/
     *    EQLAT( 365) /0.6001845213E+00/
     *    EQLON( 365) /0.2027425946E+01/
     *    SSLIP( 365) /0.8963000000E+00/
     *    DSLIP( 365) /-.4050000000E+00/
     *    DIP( 365) /0.1570796327E+01/
     *    DEPTH( 365) /0.4000000000E+04/
     *    WIDTH( 365) /0.4000000000E+04/
      DATA STRIKE( 366) /0.2556732821E+01/
     *    HL( 366) /0.3224000000E+04/
     *    EQLAT( 366) /0.5994535774E+00/
     *    EQLON( 366) /0.2026829218E+01/
     *    SSLIP( 366) /0.2240000000E-01/
     *    DSLIP( 366) /-.4457000000E+00/
     *    DIP( 366) /0.1570796327E+01/
     *    DEPTH( 366) /0.4000000000E+04/
     *    WIDTH( 366) /0.4000000000E+04/
      DATA STRIKE( 367) /0.2976309973E+01/
     *    HL( 367) /0.2151500000E+04/
     *    EQLAT( 367) /0.6054559392E+00/
     *    EQLON( 367) /0.2029619651E+01/
     *    SSLIP( 367) /0.1069800000E+01/
     *    DSLIP( 367) /-.7220000000E-01/
     *    DIP( 367) /0.1570796327E+01/
     *    DEPTH( 367) /0.4000000000E+04/
     *    WIDTH( 367) /0.4000000000E+04/
      DATA STRIKE( 368) /0.2976309973E+01/
     *    HL( 368) /0.2151500000E+04/
     *    EQLAT( 368) /0.6047909688E+00/
     *    EQLON( 368) /0.2029485260E+01/
     *    SSLIP( 368) /0.1345900000E+01/
     *    DSLIP( 368) /-.2874000000E+00/
     *    DIP( 368) /0.1570796327E+01/
     *    DEPTH( 368) /0.4000000000E+04/
     *    WIDTH( 368) /0.4000000000E+04/
      DATA STRIKE( 369) /0.2976309973E+01/
     *    HL( 369) /0.2151500000E+04/
     *    EQLAT( 369) /0.6041242530E+00/
     *    EQLON( 369) /0.2029350870E+01/
     *    SSLIP( 369) /0.1398900000E+01/
     *    DSLIP( 369) /-.8677000000E+00/
     *    DIP( 369) /0.1570796327E+01/
     *    DEPTH( 369) /0.4000000000E+04/
     *    WIDTH( 369) /0.4000000000E+04/
      DATA STRIKE( 370) /0.2976309973E+01/
     *    HL( 370) /0.2151500000E+04/
     *    EQLAT( 370) /0.6034592826E+00/
     *    EQLON( 370) /0.2029216480E+01/
     *    SSLIP( 370) /0.1203000000E+01/
     *    DSLIP( 370) /-.8652000000E+00/
     *    DIP( 370) /0.1570796327E+01/
     *    DEPTH( 370) /0.4000000000E+04/
     *    WIDTH( 370) /0.4000000000E+04/
      DATA STRIKE( 371) /0.2820103005E+01/
     *    HL( 371) /0.2270500000E+04/
     *    EQLAT( 371) /0.6058208876E+00/
     *    EQLON( 371) /0.2031163045E+01/
     *    SSLIP( 371) /0.1302100000E+01/
     *    DSLIP( 371) /0.9290000000E-01/
     *    DIP( 371) /0.1570796327E+01/
     *    DEPTH( 371) /0.8000000000E+04/
     *    WIDTH( 371) /0.4000000000E+04/
      DATA STRIKE( 372) /0.2747846374E+01/
     *    HL( 372) /0.2109500000E+04/
     *    EQLAT( 372) /0.6051779083E+00/
     *    EQLON( 372) /0.2030873321E+01/
     *    SSLIP( 372) /0.1943000000E+01/
     *    DSLIP( 372) /0.2923000000E+00/
     *    DIP( 372) /0.1570796327E+01/
     *    DEPTH( 372) /0.8000000000E+04/
     *    WIDTH( 372) /0.4000000000E+04/
      DATA STRIKE( 373) /0.2596526328E+01/
     *    HL( 373) /0.2226000000E+04/
     *    EQLAT( 373) /0.6045740244E+00/
     *    EQLON( 373) /0.2030500518E+01/
     *    SSLIP( 373) /0.2601900000E+01/
     *    DSLIP( 373) /0.2512000000E+00/
     *    DIP( 373) /0.1570796327E+01/
     *    DEPTH( 373) /0.8000000000E+04/
     *    WIDTH( 373) /0.4000000000E+04/
      DATA STRIKE( 374) /0.2478542071E+01/
     *    HL( 374) /0.2592000000E+04/
     *    EQLAT( 374) /0.6039553052E+00/
     *    EQLON( 374) /0.2029978490E+01/
     *    SSLIP( 374) /0.3035000000E+01/
     *    DSLIP( 374) /0.1615000000E+00/
     *    DIP( 374) /0.1570796327E+01/
     *    DEPTH( 374) /0.8000000000E+04/
     *    WIDTH( 374) /0.4000000000E+04/
      DATA STRIKE( 375) /0.2484825256E+01/
     *    HL( 375) /0.2312500000E+04/
     *    EQLAT( 375) /0.6033479306E+00/
     *    EQLON( 375) /0.2029407942E+01/
     *    SSLIP( 375) /0.3022100000E+01/
     *    DSLIP( 375) /0.7100000000E-01/
     *    DIP( 375) /0.1570796327E+01/
     *    DEPTH( 375) /0.8000000000E+04/
     *    WIDTH( 375) /0.4000000000E+04/
      DATA STRIKE( 376) /0.3010692960E+01/
     *    HL( 376) /0.2290500000E+04/
     *    EQLAT( 376) /0.6027046022E+00/
     *    EQLON( 376) /0.2029083835E+01/
     *    SSLIP( 376) /0.3158300000E+01/
     *    DSLIP( 376) /0.1888000000E+00/
     *    DIP( 376) /0.1570796327E+01/
     *    DEPTH( 376) /0.8000000000E+04/
     *    WIDTH( 376) /0.4000000000E+04/
      DATA STRIKE( 377) /0.2898991888E+01/
     *    HL( 377) /0.2316500000E+04/
     *    EQLAT( 377) /0.6019959985E+00/
     *    EQLON( 377) /0.2028921519E+01/
     *    SSLIP( 377) /0.2677700000E+01/
     *    DSLIP( 377) /0.1630000000E+00/
     *    DIP( 377) /0.1570796327E+01/
     *    DEPTH( 377) /0.8000000000E+04/
     *    WIDTH( 377) /0.4000000000E+04/
      DATA STRIKE( 378) /0.2572440785E+01/
     *    HL( 378) /0.2312500000E+04/
     *    EQLAT( 378) /0.6013381839E+00/
     *    EQLON( 378) /0.2028579434E+01/
     *    SSLIP( 378) /0.1906700000E+01/
     *    DSLIP( 378) /0.2341000000E+00/
     *    DIP( 378) /0.1570796327E+01/
     *    DEPTH( 378) /0.8000000000E+04/
     *    WIDTH( 378) /0.4000000000E+04/
      DATA STRIKE( 379) /0.2352180233E+01/
     *    HL( 379) /0.2442000000E+04/
     *    EQLAT( 379) /0.6007630980E+00/
     *    EQLON( 379) /0.2028013948E+01/
     *    SSLIP( 379) /0.1258400000E+01/
     *    DSLIP( 379) /0.2608000000E+00/
     *    DIP( 379) /0.1570796327E+01/
     *    DEPTH( 379) /0.8000000000E+04/
     *    WIDTH( 379) /0.4000000000E+04/
      DATA STRIKE( 380) /0.2535439804E+01/
     *    HL( 380) /0.2397500000E+04/
     *    EQLAT( 380) /0.6001845213E+00/
     *    EQLON( 380) /0.2027425946E+01/
     *    SSLIP( 380) /0.7488000000E+00/
     *    DSLIP( 380) /-.7310000000E-01/
     *    DIP( 380) /0.1570796327E+01/
     *    DEPTH( 380) /0.8000000000E+04/
     *    WIDTH( 380) /0.4000000000E+04/
      DATA STRIKE( 381) /0.2556732821E+01/
     *    HL( 381) /0.3224000000E+04/
     *    EQLAT( 381) /0.5994535774E+00/
     *    EQLON( 381) /0.2026829218E+01/
     *    SSLIP( 381) /0.9930000000E-01/
     *    DSLIP( 381) /-.1502000000E+00/
     *    DIP( 381) /0.1570796327E+01/
     *    DEPTH( 381) /0.8000000000E+04/
     *    WIDTH( 381) /0.4000000000E+04/
      DATA STRIKE( 382) /0.2976309973E+01/
     *    HL( 382) /0.2151500000E+04/
     *    EQLAT( 382) /0.6054559392E+00/
     *    EQLON( 382) /0.2029619651E+01/
     *    SSLIP( 382) /0.1212800000E+01/
     *    DSLIP( 382) /-.3620000000E+00/
     *    DIP( 382) /0.1570796327E+01/
     *    DEPTH( 382) /0.8000000000E+04/
     *    WIDTH( 382) /0.4000000000E+04/
      DATA STRIKE( 383) /0.2976309973E+01/
     *    HL( 383) /0.2151500000E+04/
     *    EQLAT( 383) /0.6047909688E+00/
     *    EQLON( 383) /0.2029485260E+01/
     *    SSLIP( 383) /0.1254700000E+01/
     *    DSLIP( 383) /-.5756000000E+00/
     *    DIP( 383) /0.1570796327E+01/
     *    DEPTH( 383) /0.8000000000E+04/
     *    WIDTH( 383) /0.4000000000E+04/
      DATA STRIKE( 384) /0.2976309973E+01/
     *    HL( 384) /0.2151500000E+04/
     *    EQLAT( 384) /0.6041242530E+00/
     *    EQLON( 384) /0.2029350870E+01/
     *    SSLIP( 384) /0.1169500000E+01/
     *    DSLIP( 384) /-.7954000000E+00/
     *    DIP( 384) /0.1570796327E+01/
     *    DEPTH( 384) /0.8000000000E+04/
     *    WIDTH( 384) /0.4000000000E+04/
      DATA STRIKE( 385) /0.2976309973E+01/
     *    HL( 385) /0.2151500000E+04/
     *    EQLAT( 385) /0.6034592826E+00/
     *    EQLON( 385) /0.2029216480E+01/
     *    SSLIP( 385) /0.1073400000E+01/
     *    DSLIP( 385) /-.7060000000E+00/
     *    DIP( 385) /0.1570796327E+01/
     *    DEPTH( 385) /0.8000000000E+04/
     *    WIDTH( 385) /0.4000000000E+04/
      DATA STRIKE( 386) /0.2820103005E+01/
     *    HL( 386) /0.2270500000E+04/
     *    EQLAT( 386) /0.6058208876E+00/
     *    EQLON( 386) /0.2031163045E+01/
     *    SSLIP( 386) /0.1356700000E+01/
     *    DSLIP( 386) /0.2090000000E+00/
     *    DIP( 386) /0.1570796327E+01/
     *    DEPTH( 386) /0.1200000000E+05/
     *    WIDTH( 386) /0.4000000000E+04/
      DATA STRIKE( 387) /0.2747846374E+01/
     *    HL( 387) /0.2109500000E+04/
     *    EQLAT( 387) /0.6051779083E+00/
     *    EQLON( 387) /0.2030873321E+01/
     *    SSLIP( 387) /0.1727500000E+01/
     *    DSLIP( 387) /0.3923000000E+00/
     *    DIP( 387) /0.1570796327E+01/
     *    DEPTH( 387) /0.1200000000E+05/
     *    WIDTH( 387) /0.4000000000E+04/
      DATA STRIKE( 388) /0.2596526328E+01/
     *    HL( 388) /0.2226000000E+04/
     *    EQLAT( 388) /0.6045740244E+00/
     *    EQLON( 388) /0.2030500518E+01/
     *    SSLIP( 388) /0.2186000000E+01/
     *    DSLIP( 388) /0.5106000000E+00/
     *    DIP( 388) /0.1570796327E+01/
     *    DEPTH( 388) /0.1200000000E+05/
     *    WIDTH( 388) /0.4000000000E+04/
      DATA STRIKE( 389) /0.2478542071E+01/
     *    HL( 389) /0.2592000000E+04/
     *    EQLAT( 389) /0.6039553052E+00/
     *    EQLON( 389) /0.2029978490E+01/
     *    SSLIP( 389) /0.2616300000E+01/
     *    DSLIP( 389) /0.5531000000E+00/
     *    DIP( 389) /0.1570796327E+01/
     *    DEPTH( 389) /0.1200000000E+05/
     *    WIDTH( 389) /0.4000000000E+04/
      DATA STRIKE( 390) /0.2484825256E+01/
     *    HL( 390) /0.2312500000E+04/
     *    EQLAT( 390) /0.6033479306E+00/
     *    EQLON( 390) /0.2029407942E+01/
     *    SSLIP( 390) /0.2755700000E+01/
     *    DSLIP( 390) /0.4741000000E+00/
     *    DIP( 390) /0.1570796327E+01/
     *    DEPTH( 390) /0.1200000000E+05/
     *    WIDTH( 390) /0.4000000000E+04/
      DATA STRIKE( 391) /0.3010692960E+01/
     *    HL( 391) /0.2290500000E+04/
     *    EQLAT( 391) /0.6027046022E+00/
     *    EQLON( 391) /0.2029083835E+01/
     *    SSLIP( 391) /0.2749800000E+01/
     *    DSLIP( 391) /0.4991000000E+00/
     *    DIP( 391) /0.1570796327E+01/
     *    DEPTH( 391) /0.1200000000E+05/
     *    WIDTH( 391) /0.4000000000E+04/
      DATA STRIKE( 392) /0.2898991888E+01/
     *    HL( 392) /0.2316500000E+04/
     *    EQLAT( 392) /0.6019959985E+00/
     *    EQLON( 392) /0.2028921519E+01/
     *    SSLIP( 392) /0.2411000000E+01/
     *    DSLIP( 392) /0.4580000000E+00/
     *    DIP( 392) /0.1570796327E+01/
     *    DEPTH( 392) /0.1200000000E+05/
     *    WIDTH( 392) /0.4000000000E+04/
      DATA STRIKE( 393) /0.2572440785E+01/
     *    HL( 393) /0.2312500000E+04/
     *    EQLAT( 393) /0.6013381839E+00/
     *    EQLON( 393) /0.2028579434E+01/
     *    SSLIP( 393) /0.1809800000E+01/
     *    DSLIP( 393) /0.4625000000E+00/
     *    DIP( 393) /0.1570796327E+01/
     *    DEPTH( 393) /0.1200000000E+05/
     *    WIDTH( 393) /0.4000000000E+04/
      DATA STRIKE( 394) /0.2352180233E+01/
     *    HL( 394) /0.2442000000E+04/
     *    EQLAT( 394) /0.6007630980E+00/
     *    EQLON( 394) /0.2028013948E+01/
     *    SSLIP( 394) /0.1217300000E+01/
     *    DSLIP( 394) /0.4520000000E+00/
     *    DIP( 394) /0.1570796327E+01/
     *    DEPTH( 394) /0.1200000000E+05/
     *    WIDTH( 394) /0.4000000000E+04/
      DATA STRIKE( 395) /0.2535439804E+01/
     *    HL( 395) /0.2397500000E+04/
     *    EQLAT( 395) /0.6001845213E+00/
     *    EQLON( 395) /0.2027425946E+01/
     *    SSLIP( 395) /0.7510000000E+00/
     *    DSLIP( 395) /0.2408000000E+00/
     *    DIP( 395) /0.1570796327E+01/
     *    DEPTH( 395) /0.1200000000E+05/
     *    WIDTH( 395) /0.4000000000E+04/
      DATA STRIKE( 396) /0.2556732821E+01/
     *    HL( 396) /0.3224000000E+04/
     *    EQLAT( 396) /0.5994535774E+00/
     *    EQLON( 396) /0.2026829218E+01/
     *    SSLIP( 396) /0.2714000000E+00/
     *    DSLIP( 396) /0.1633000000E+00/
     *    DIP( 396) /0.1570796327E+01/
     *    DEPTH( 396) /0.1200000000E+05/
     *    WIDTH( 396) /0.4000000000E+04/
      DATA STRIKE( 397) /0.2976309973E+01/
     *    HL( 397) /0.2151500000E+04/
     *    EQLAT( 397) /0.6054559392E+00/
     *    EQLON( 397) /0.2029619651E+01/
     *    SSLIP( 397) /0.1171500000E+01/
     *    DSLIP( 397) /-.5387000000E+00/
     *    DIP( 397) /0.1570796327E+01/
     *    DEPTH( 397) /0.1200000000E+05/
     *    WIDTH( 397) /0.4000000000E+04/
      DATA STRIKE( 398) /0.2976309973E+01/
     *    HL( 398) /0.2151500000E+04/
     *    EQLAT( 398) /0.6047909688E+00/
     *    EQLON( 398) /0.2029485260E+01/
     *    SSLIP( 398) /0.1128400000E+01/
     *    DSLIP( 398) /-.6493000000E+00/
     *    DIP( 398) /0.1570796327E+01/
     *    DEPTH( 398) /0.1200000000E+05/
     *    WIDTH( 398) /0.4000000000E+04/
      DATA STRIKE( 399) /0.2976309973E+01/
     *    HL( 399) /0.2151500000E+04/
     *    EQLAT( 399) /0.6041242530E+00/
     *    EQLON( 399) /0.2029350870E+01/
     *    SSLIP( 399) /0.1031800000E+01/
     *    DSLIP( 399) /-.6974000000E+00/
     *    DIP( 399) /0.1570796327E+01/
     *    DEPTH( 399) /0.1200000000E+05/
     *    WIDTH( 399) /0.4000000000E+04/
      DATA STRIKE( 400) /0.2976309973E+01/
     *    HL( 400) /0.2151500000E+04/
     *    EQLAT( 400) /0.6034592826E+00/
     *    EQLON( 400) /0.2029216480E+01/
     *    SSLIP( 400) /0.9772000000E+00/
     *    DSLIP( 400) /-.6053000000E+00/
     *    DIP( 400) /0.1570796327E+01/
     *    DEPTH( 400) /0.1200000000E+05/
     *    WIDTH( 400) /0.4000000000E+04/
      DATA STRIKE( 401) /0.2820103005E+01/
     *    HL( 401) /0.2270500000E+04/
     *    EQLAT( 401) /0.6058208876E+00/
     *    EQLON( 401) /0.2031163045E+01/
     *    SSLIP( 401) /0.1386400000E+01/
     *    DSLIP( 401) /0.3411000000E+00/
     *    DIP( 401) /0.1570796327E+01/
     *    DEPTH( 401) /0.1600000000E+05/
     *    WIDTH( 401) /0.4000000000E+04/
      DATA STRIKE( 402) /0.2747846374E+01/
     *    HL( 402) /0.2109500000E+04/
     *    EQLAT( 402) /0.6051779083E+00/
     *    EQLON( 402) /0.2030873321E+01/
     *    SSLIP( 402) /0.1652800000E+01/
     *    DSLIP( 402) /0.5090000000E+00/
     *    DIP( 402) /0.1570796327E+01/
     *    DEPTH( 402) /0.1600000000E+05/
     *    WIDTH( 402) /0.4000000000E+04/
      DATA STRIKE( 403) /0.2596526328E+01/
     *    HL( 403) /0.2226000000E+04/
     *    EQLAT( 403) /0.6045740244E+00/
     *    EQLON( 403) /0.2030500518E+01/
     *    SSLIP( 403) /0.2019800000E+01/
     *    DSLIP( 403) /0.6727000000E+00/
     *    DIP( 403) /0.1570796327E+01/
     *    DEPTH( 403) /0.1600000000E+05/
     *    WIDTH( 403) /0.4000000000E+04/
      DATA STRIKE( 404) /0.2478542071E+01/
     *    HL( 404) /0.2592000000E+04/
     *    EQLAT( 404) /0.6039553052E+00/
     *    EQLON( 404) /0.2029978490E+01/
     *    SSLIP( 404) /0.2421800000E+01/
     *    DSLIP( 404) /0.7716000000E+00/
     *    DIP( 404) /0.1570796327E+01/
     *    DEPTH( 404) /0.1600000000E+05/
     *    WIDTH( 404) /0.4000000000E+04/
      DATA STRIKE( 405) /0.2484825256E+01/
     *    HL( 405) /0.2312500000E+04/
     *    EQLAT( 405) /0.6033479306E+00/
     *    EQLON( 405) /0.2029407942E+01/
     *    SSLIP( 405) /0.2601600000E+01/
     *    DSLIP( 405) /0.7070000000E+00/
     *    DIP( 405) /0.1570796327E+01/
     *    DEPTH( 405) /0.1600000000E+05/
     *    WIDTH( 405) /0.4000000000E+04/
      DATA STRIKE( 406) /0.3010692960E+01/
     *    HL( 406) /0.2290500000E+04/
     *    EQLAT( 406) /0.6027046022E+00/
     *    EQLON( 406) /0.2029083835E+01/
     *    SSLIP( 406) /0.2562100000E+01/
     *    DSLIP( 406) /0.6724000000E+00/
     *    DIP( 406) /0.1570796327E+01/
     *    DEPTH( 406) /0.1600000000E+05/
     *    WIDTH( 406) /0.4000000000E+04/
      DATA STRIKE( 407) /0.2898991888E+01/
     *    HL( 407) /0.2316500000E+04/
     *    EQLAT( 407) /0.6019959985E+00/
     *    EQLON( 407) /0.2028921519E+01/
     *    SSLIP( 407) /0.2283700000E+01/
     *    DSLIP( 407) /0.6286000000E+00/
     *    DIP( 407) /0.1570796327E+01/
     *    DEPTH( 407) /0.1600000000E+05/
     *    WIDTH( 407) /0.4000000000E+04/
      DATA STRIKE( 408) /0.2572440785E+01/
     *    HL( 408) /0.2312500000E+04/
     *    EQLAT( 408) /0.6013381839E+00/
     *    EQLON( 408) /0.2028579434E+01/
     *    SSLIP( 408) /0.1781600000E+01/
     *    DSLIP( 408) /0.6066000000E+00/
     *    DIP( 408) /0.1570796327E+01/
     *    DEPTH( 408) /0.1600000000E+05/
     *    WIDTH( 408) /0.4000000000E+04/
      DATA STRIKE( 409) /0.2352180233E+01/
     *    HL( 409) /0.2442000000E+04/
     *    EQLAT( 409) /0.6007630980E+00/
     *    EQLON( 409) /0.2028013948E+01/
     *    SSLIP( 409) /0.1235200000E+01/
     *    DSLIP( 409) /0.5706000000E+00/
     *    DIP( 409) /0.1570796327E+01/
     *    DEPTH( 409) /0.1600000000E+05/
     *    WIDTH( 409) /0.4000000000E+04/
      DATA STRIKE( 410) /0.2535439804E+01/
     *    HL( 410) /0.2397500000E+04/
     *    EQLAT( 410) /0.6001845213E+00/
     *    EQLON( 410) /0.2027425946E+01/
     *    SSLIP( 410) /0.7988000000E+00/
     *    DSLIP( 410) /0.4110000000E+00/
     *    DIP( 410) /0.1570796327E+01/
     *    DEPTH( 410) /0.1600000000E+05/
     *    WIDTH( 410) /0.4000000000E+04/
      DATA STRIKE( 411) /0.2556732821E+01/
     *    HL( 411) /0.3224000000E+04/
     *    EQLAT( 411) /0.5994535774E+00/
     *    EQLON( 411) /0.2026829218E+01/
     *    SSLIP( 411) /0.4033000000E+00/
     *    DSLIP( 411) /0.3309000000E+00/
     *    DIP( 411) /0.1570796327E+01/
     *    DEPTH( 411) /0.1600000000E+05/
     *    WIDTH( 411) /0.4000000000E+04/
      DATA STRIKE( 412) /0.2976309973E+01/
     *    HL( 412) /0.2151500000E+04/
     *    EQLAT( 412) /0.6054559392E+00/
     *    EQLON( 412) /0.2029619651E+01/
     *    SSLIP( 412) /0.1116600000E+01/
     *    DSLIP( 412) /-.5933000000E+00/
     *    DIP( 412) /0.1570796327E+01/
     *    DEPTH( 412) /0.1600000000E+05/
     *    WIDTH( 412) /0.4000000000E+04/
      DATA STRIKE( 413) /0.2976309973E+01/
     *    HL( 413) /0.2151500000E+04/
     *    EQLAT( 413) /0.6047909688E+00/
     *    EQLON( 413) /0.2029485260E+01/
     *    SSLIP( 413) /0.1058600000E+01/
     *    DSLIP( 413) /-.6413000000E+00/
     *    DIP( 413) /0.1570796327E+01/
     *    DEPTH( 413) /0.1600000000E+05/
     *    WIDTH( 413) /0.4000000000E+04/
      DATA STRIKE( 414) /0.2976309973E+01/
     *    HL( 414) /0.2151500000E+04/
     *    EQLAT( 414) /0.6041242530E+00/
     *    EQLON( 414) /0.2029350870E+01/
     *    SSLIP( 414) /0.9744000000E+00/
     *    DSLIP( 414) /-.6313000000E+00/
     *    DIP( 414) /0.1570796327E+01/
     *    DEPTH( 414) /0.1600000000E+05/
     *    WIDTH( 414) /0.4000000000E+04/
      DATA STRIKE( 415) /0.2976309973E+01/
     *    HL( 415) /0.2151500000E+04/
     *    EQLAT( 415) /0.6034592826E+00/
     *    EQLON( 415) /0.2029216480E+01/
     *    SSLIP( 415) /0.9314000000E+00/
     *    DSLIP( 415) /-.5589000000E+00/
     *    DIP( 415) /0.1570796327E+01/
     *    DEPTH( 415) /0.1600000000E+05/
     *    WIDTH( 415) /0.4000000000E+04/
      DATA EQLATR( 27)  /0.6231872627E+00/
     *   EQLONR( 27)  /0.2113628631E+01/
     *   EQRAD( 27)   /0.2000000000E+06/
     *   ITEQK( 27)   /    76312800/
     *   NLOC( 27)    / 416/
     *   NFP( 27)     / 200/
      DATA STRIKE( 416) /0.2038544566E+01/
     *    HL( 416) /0.1004700000E+04/
     *    EQLAT( 416) /0.6226921128E+00/
     *    EQLON( 416) /0.2114788751E+01/
     *    SSLIP( 416) /-.2700000000E-01/
     *    DSLIP( 416) /-.3000000000E-01/
     *    DIP( 416) /0.9197885158E+00/
     *    DEPTH( 416) /0.0000000000E+00/
     *    WIDTH( 416) /0.2079100000E+04/
      DATA STRIKE( 417) /0.2038544566E+01/
     *    HL( 417) /0.1004300000E+04/
     *    EQLAT( 417) /0.6225495194E+00/
     *    EQLON( 417) /0.2114443001E+01/
     *    SSLIP( 417) /0.0000000000E+00/
     *    DSLIP( 417) /0.0000000000E+00/
     *    DIP( 417) /0.9197885158E+00/
     *    DEPTH( 417) /0.0000000000E+00/
     *    WIDTH( 417) /0.2079100000E+04/
      DATA STRIKE( 418) /0.2038544566E+01/
     *    HL( 418) /0.1004800000E+04/
     *    EQLAT( 418) /0.6224069260E+00/
     *    EQLON( 418) /0.2114097426E+01/
     *    SSLIP( 418) /0.0000000000E+00/
     *    DSLIP( 418) /0.0000000000E+00/
     *    DIP( 418) /0.9197885158E+00/
     *    DEPTH( 418) /0.0000000000E+00/
     *    WIDTH( 418) /0.2079100000E+04/
      DATA STRIKE( 419) /0.2038544566E+01/
     *    HL( 419) /0.1004400000E+04/
     *    EQLAT( 419) /0.6222645071E+00/
     *    EQLON( 419) /0.2113751676E+01/
     *    SSLIP( 419) /-.5300000000E-01/
     *    DSLIP( 419) /-.5000000000E-01/
     *    DIP( 419) /0.9197885158E+00/
     *    DEPTH( 419) /0.0000000000E+00/
     *    WIDTH( 419) /0.2079100000E+04/
      DATA STRIKE( 420) /0.2038544566E+01/
     *    HL( 420) /0.1004500000E+04/
     *    EQLAT( 420) /0.6221219137E+00/
     *    EQLON( 420) /0.2113406101E+01/
     *    SSLIP( 420) /-.1270000000E+00/
     *    DSLIP( 420) /-.1300000000E+00/
     *    DIP( 420) /0.9197885158E+00/
     *    DEPTH( 420) /0.0000000000E+00/
     *    WIDTH( 420) /0.2079100000E+04/
      DATA STRIKE( 421) /0.2038544566E+01/
     *    HL( 421) /0.1005000000E+04/
     *    EQLAT( 421) /0.6219793203E+00/
     *    EQLON( 421) /0.2113060526E+01/
     *    SSLIP( 421) /-.1290000000E+00/
     *    DSLIP( 421) /-.2200000000E+00/
     *    DIP( 421) /0.9197885158E+00/
     *    DEPTH( 421) /0.0000000000E+00/
     *    WIDTH( 421) /0.2079100000E+04/
      DATA STRIKE( 422) /0.2038544566E+01/
     *    HL( 422) /0.1004700000E+04/
     *    EQLAT( 422) /0.6218367269E+00/
     *    EQLON( 422) /0.2112714776E+01/
     *    SSLIP( 422) /-.1350000000E+00/
     *    DSLIP( 422) /-.3400000000E+00/
     *    DIP( 422) /0.9197885158E+00/
     *    DEPTH( 422) /0.0000000000E+00/
     *    WIDTH( 422) /0.2079100000E+04/
      DATA STRIKE( 423) /0.2038544566E+01/
     *    HL( 423) /0.1004800000E+04/
     *    EQLAT( 423) /0.6216941335E+00/
     *    EQLON( 423) /0.2112369201E+01/
     *    SSLIP( 423) /-.1830000000E+00/
     *    DSLIP( 423) /-.4100000000E+00/
     *    DIP( 423) /0.9197885158E+00/
     *    DEPTH( 423) /0.0000000000E+00/
     *    WIDTH( 423) /0.2079100000E+04/
      DATA STRIKE( 424) /0.2038544566E+01/
     *    HL( 424) /0.1005300000E+04/
     *    EQLAT( 424) /0.6215515401E+00/
     *    EQLON( 424) /0.2112023626E+01/
     *    SSLIP( 424) /-.2700000000E+00/
     *    DSLIP( 424) /-.4500000000E+00/
     *    DIP( 424) /0.9197885158E+00/
     *    DEPTH( 424) /0.0000000000E+00/
     *    WIDTH( 424) /0.2079100000E+04/
      DATA STRIKE( 425) /0.2038544566E+01/
     *    HL( 425) /0.1005000000E+04/
     *    EQLAT( 425) /0.6214089467E+00/
     *    EQLON( 425) /0.2111677876E+01/
     *    SSLIP( 425) /-.3590000000E+00/
     *    DSLIP( 425) /-.4700000000E+00/
     *    DIP( 425) /0.9197885158E+00/
     *    DEPTH( 425) /0.0000000000E+00/
     *    WIDTH( 425) /0.2079100000E+04/
      DATA STRIKE( 426) /0.2038544566E+01/
     *    HL( 426) /0.1005000000E+04/
     *    EQLAT( 426) /0.6212663533E+00/
     *    EQLON( 426) /0.2111332301E+01/
     *    SSLIP( 426) /-.4120000000E+00/
     *    DSLIP( 426) /-.4400000000E+00/
     *    DIP( 426) /0.9197885158E+00/
     *    DEPTH( 426) /0.0000000000E+00/
     *    WIDTH( 426) /0.2079100000E+04/
      DATA STRIKE( 427) /0.2038544566E+01/
     *    HL( 427) /0.1005500000E+04/
     *    EQLAT( 427) /0.6211237599E+00/
     *    EQLON( 427) /0.2110986726E+01/
     *    SSLIP( 427) /-.4110000000E+00/
     *    DSLIP( 427) /-.4100000000E+00/
     *    DIP( 427) /0.9197885158E+00/
     *    DEPTH( 427) /0.0000000000E+00/
     *    WIDTH( 427) /0.2079100000E+04/
      DATA STRIKE( 428) /0.2038544566E+01/
     *    HL( 428) /0.1005200000E+04/
     *    EQLAT( 428) /0.6209811665E+00/
     *    EQLON( 428) /0.2110640976E+01/
     *    SSLIP( 428) /-.4040000000E+00/
     *    DSLIP( 428) /-.4000000000E+00/
     *    DIP( 428) /0.9197885158E+00/
     *    DEPTH( 428) /0.0000000000E+00/
     *    WIDTH( 428) /0.2079100000E+04/
      DATA STRIKE( 429) /0.2038544566E+01/
     *    HL( 429) /0.1005700000E+04/
     *    EQLAT( 429) /0.6208385731E+00/
     *    EQLON( 429) /0.2110295401E+01/
     *    SSLIP( 429) /-.4430000000E+00/
     *    DSLIP( 429) /-.4400000000E+00/
     *    DIP( 429) /0.9197885158E+00/
     *    DEPTH( 429) /0.0000000000E+00/
     *    WIDTH( 429) /0.2079100000E+04/
      DATA STRIKE( 430) /0.2038544566E+01/
     *    HL( 430) /0.1005300000E+04/
     *    EQLAT( 430) /0.6206961543E+00/
     *    EQLON( 430) /0.2109949651E+01/
     *    SSLIP( 430) /-.5100000000E+00/
     *    DSLIP( 430) /-.5300000000E+00/
     *    DIP( 430) /0.9197885158E+00/
     *    DEPTH( 430) /0.0000000000E+00/
     *    WIDTH( 430) /0.2079100000E+04/
      DATA STRIKE( 431) /0.2038544566E+01/
     *    HL( 431) /0.1005400000E+04/
     *    EQLAT( 431) /0.6205535609E+00/
     *    EQLON( 431) /0.2109604076E+01/
     *    SSLIP( 431) /-.4940000000E+00/
     *    DSLIP( 431) /-.6500000000E+00/
     *    DIP( 431) /0.9197885158E+00/
     *    DEPTH( 431) /0.0000000000E+00/
     *    WIDTH( 431) /0.2079100000E+04/
      DATA STRIKE( 432) /0.2038544566E+01/
     *    HL( 432) /0.1005900000E+04/
     *    EQLAT( 432) /0.6204109675E+00/
     *    EQLON( 432) /0.2109258501E+01/
     *    SSLIP( 432) /-.3680000000E+00/
     *    DSLIP( 432) /-.7300000000E+00/
     *    DIP( 432) /0.9197885158E+00/
     *    DEPTH( 432) /0.0000000000E+00/
     *    WIDTH( 432) /0.2079100000E+04/
      DATA STRIKE( 433) /0.2038544566E+01/
     *    HL( 433) /0.1005600000E+04/
     *    EQLAT( 433) /0.6202683741E+00/
     *    EQLON( 433) /0.2108912751E+01/
     *    SSLIP( 433) /-.1830000000E+00/
     *    DSLIP( 433) /-.7000000000E+00/
     *    DIP( 433) /0.9197885158E+00/
     *    DEPTH( 433) /0.0000000000E+00/
     *    WIDTH( 433) /0.2079100000E+04/
      DATA STRIKE( 434) /0.2038544566E+01/
     *    HL( 434) /0.1005700000E+04/
     *    EQLAT( 434) /0.6201257807E+00/
     *    EQLON( 434) /0.2108567176E+01/
     *    SSLIP( 434) /-.1900000000E-01/
     *    DSLIP( 434) /-.5600000000E+00/
     *    DIP( 434) /0.9197885158E+00/
     *    DEPTH( 434) /0.0000000000E+00/
     *    WIDTH( 434) /0.2079100000E+04/
      DATA STRIKE( 435) /0.2038544566E+01/
     *    HL( 435) /0.1006200000E+04/
     *    EQLAT( 435) /0.6199831873E+00/
     *    EQLON( 435) /0.2108221601E+01/
     *    SSLIP( 435) /0.4400000000E-01/
     *    DSLIP( 435) /-.3200000000E+00/
     *    DIP( 435) /0.9197885158E+00/
     *    DEPTH( 435) /0.0000000000E+00/
     *    WIDTH( 435) /0.2079100000E+04/
      DATA STRIKE( 436) /0.2038544566E+01/
     *    HL( 436) /0.1003900000E+04/
     *    EQLAT( 436) /0.6228615843E+00/
     *    EQLON( 436) /0.2114682635E+01/
     *    SSLIP( 436) /-.3400000000E-01/
     *    DSLIP( 436) /-.3000000000E-01/
     *    DIP( 436) /0.9197885158E+00/
     *    DEPTH( 436) /0.1591000000E+04/
     *    WIDTH( 436) /0.2079100000E+04/
      DATA STRIKE( 437) /0.2038544566E+01/
     *    HL( 437) /0.1004100000E+04/
     *    EQLAT( 437) /0.6227189909E+00/
     *    EQLON( 437) /0.2114337060E+01/
     *    SSLIP( 437) /-.3800000000E-01/
     *    DSLIP( 437) /-.4000000000E-01/
     *    DIP( 437) /0.9197885158E+00/
     *    DEPTH( 437) /0.1591000000E+04/
     *    WIDTH( 437) /0.2079100000E+04/
      DATA STRIKE( 438) /0.2038544566E+01/
     *    HL( 438) /0.1004500000E+04/
     *    EQLAT( 438) /0.6225763975E+00/
     *    EQLON( 438) /0.2113991485E+01/
     *    SSLIP( 438) /-.4000000000E-02/
     *    DSLIP( 438) /0.0000000000E+00/
     *    DIP( 438) /0.9197885158E+00/
     *    DEPTH( 438) /0.1591000000E+04/
     *    WIDTH( 438) /0.2079100000E+04/
      DATA STRIKE( 439) /0.2038544566E+01/
     *    HL( 439) /0.1004200000E+04/
     *    EQLAT( 439) /0.6224338041E+00/
     *    EQLON( 439) /0.2113645735E+01/
     *    SSLIP( 439) /-.8600000000E-01/
     *    DSLIP( 439) /-.1000000000E+00/
     *    DIP( 439) /0.9197885158E+00/
     *    DEPTH( 439) /0.1591000000E+04/
     *    WIDTH( 439) /0.2079100000E+04/
      DATA STRIKE( 440) /0.2038544566E+01/
     *    HL( 440) /0.1004300000E+04/
     *    EQLAT( 440) /0.6222912107E+00/
     *    EQLON( 440) /0.2113300160E+01/
     *    SSLIP( 440) /-.1220000000E+00/
     *    DSLIP( 440) /-.3500000000E+00/
     *    DIP( 440) /0.9197885158E+00/
     *    DEPTH( 440) /0.1591000000E+04/
     *    WIDTH( 440) /0.2079100000E+04/
      DATA STRIKE( 441) /0.2038544566E+01/
     *    HL( 441) /0.1004800000E+04/
     *    EQLAT( 441) /0.6221486173E+00/
     *    EQLON( 441) /0.2112954585E+01/
     *    SSLIP( 441) /-.7800000000E-01/
     *    DSLIP( 441) /-.6400000000E+00/
     *    DIP( 441) /0.9197885158E+00/
     *    DEPTH( 441) /0.1591000000E+04/
     *    WIDTH( 441) /0.2079100000E+04/
      DATA STRIKE( 442) /0.2038544566E+01/
     *    HL( 442) /0.1004400000E+04/
     *    EQLAT( 442) /0.6220060239E+00/
     *    EQLON( 442) /0.2112608835E+01/
     *    SSLIP( 442) /-.9000000000E-02/
     *    DSLIP( 442) /-.9200000000E+00/
     *    DIP( 442) /0.9197885158E+00/
     *    DEPTH( 442) /0.1591000000E+04/
     *    WIDTH( 442) /0.2079100000E+04/
      DATA STRIKE( 443) /0.2038544566E+01/
     *    HL( 443) /0.1004900000E+04/
     *    EQLAT( 443) /0.6218636050E+00/
     *    EQLON( 443) /0.2112263260E+01/
     *    SSLIP( 443) /0.1700000000E-01/
     *    DSLIP( 443) /-.1110000000E+01/
     *    DIP( 443) /0.9197885158E+00/
     *    DEPTH( 443) /0.1591000000E+04/
     *    WIDTH( 443) /0.2079100000E+04/
      DATA STRIKE( 444) /0.2038544566E+01/
     *    HL( 444) /0.1004600000E+04/
     *    EQLAT( 444) /0.6217210116E+00/
     *    EQLON( 444) /0.2111917510E+01/
     *    SSLIP( 444) /-.3100000000E-01/
     *    DSLIP( 444) /-.1190000000E+01/
     *    DIP( 444) /0.9197885158E+00/
     *    DEPTH( 444) /0.1591000000E+04/
     *    WIDTH( 444) /0.2079100000E+04/
      DATA STRIKE( 445) /0.2038544566E+01/
     *    HL( 445) /0.1004700000E+04/
     *    EQLAT( 445) /0.6215784182E+00/
     *    EQLON( 445) /0.2111571935E+01/
     *    SSLIP( 445) /-.1460000000E+00/
     *    DSLIP( 445) /-.1170000000E+01/
     *    DIP( 445) /0.9197885158E+00/
     *    DEPTH( 445) /0.1591000000E+04/
     *    WIDTH( 445) /0.2079100000E+04/
      DATA STRIKE( 446) /0.2038544566E+01/
     *    HL( 446) /0.1005200000E+04/
     *    EQLAT( 446) /0.6214358248E+00/
     *    EQLON( 446) /0.2111226360E+01/
     *    SSLIP( 446) /-.2920000000E+00/
     *    DSLIP( 446) /-.1090000000E+01/
     *    DIP( 446) /0.9197885158E+00/
     *    DEPTH( 446) /0.1591000000E+04/
     *    WIDTH( 446) /0.2079100000E+04/
      DATA STRIKE( 447) /0.2038544566E+01/
     *    HL( 447) /0.1004900000E+04/
     *    EQLAT( 447) /0.6212932314E+00/
     *    EQLON( 447) /0.2110880610E+01/
     *    SSLIP( 447) /-.3740000000E+00/
     *    DSLIP( 447) /-.9700000000E+00/
     *    DIP( 447) /0.9197885158E+00/
     *    DEPTH( 447) /0.1591000000E+04/
     *    WIDTH( 447) /0.2079100000E+04/
      DATA STRIKE( 448) /0.2038544566E+01/
     *    HL( 448) /0.1004900000E+04/
     *    EQLAT( 448) /0.6211506380E+00/
     *    EQLON( 448) /0.2110535035E+01/
     *    SSLIP( 448) /-.4320000000E+00/
     *    DSLIP( 448) /-.8800000000E+00/
     *    DIP( 448) /0.9197885158E+00/
     *    DEPTH( 448) /0.1591000000E+04/
     *    WIDTH( 448) /0.2079100000E+04/
      DATA STRIKE( 449) /0.2038544566E+01/
     *    HL( 449) /0.1005400000E+04/
     *    EQLAT( 449) /0.6210080446E+00/
     *    EQLON( 449) /0.2110189459E+01/
     *    SSLIP( 449) /-.5030000000E+00/
     *    DSLIP( 449) /-.8800000000E+00/
     *    DIP( 449) /0.9197885158E+00/
     *    DEPTH( 449) /0.1591000000E+04/
     *    WIDTH( 449) /0.2079100000E+04/
      DATA STRIKE( 450) /0.2038544566E+01/
     *    HL( 450) /0.1005100000E+04/
     *    EQLAT( 450) /0.6208654512E+00/
     *    EQLON( 450) /0.2109843710E+01/
     *    SSLIP( 450) /-.5590000000E+00/
     *    DSLIP( 450) /-.9700000000E+00/
     *    DIP( 450) /0.9197885158E+00/
     *    DEPTH( 450) /0.1591000000E+04/
     *    WIDTH( 450) /0.2079100000E+04/
      DATA STRIKE( 451) /0.2038544566E+01/
     *    HL( 451) /0.1005200000E+04/
     *    EQLAT( 451) /0.6207228578E+00/
     *    EQLON( 451) /0.2109498135E+01/
     *    SSLIP( 451) /-.4560000000E+00/
     *    DSLIP( 451) /-.1100000000E+01/
     *    DIP( 451) /0.9197885158E+00/
     *    DEPTH( 451) /0.1591000000E+04/
     *    WIDTH( 451) /0.2079100000E+04/
      DATA STRIKE( 452) /0.2038544566E+01/
     *    HL( 452) /0.1005700000E+04/
     *    EQLAT( 452) /0.6205802644E+00/
     *    EQLON( 452) /0.2109152559E+01/
     *    SSLIP( 452) /-.2050000000E+00/
     *    DSLIP( 452) /-.1150000000E+01/
     *    DIP( 452) /0.9197885158E+00/
     *    DEPTH( 452) /0.1591000000E+04/
     *    WIDTH( 452) /0.2079100000E+04/
      DATA STRIKE( 453) /0.2038544566E+01/
     *    HL( 453) /0.1005300000E+04/
     *    EQLAT( 453) /0.6204376710E+00/
     *    EQLON( 453) /0.2108806810E+01/
     *    SSLIP( 453) /0.7600000000E-01/
     *    DSLIP( 453) /-.1050000000E+01/
     *    DIP( 453) /0.9197885158E+00/
     *    DEPTH( 453) /0.1591000000E+04/
     *    WIDTH( 453) /0.2079100000E+04/
      DATA STRIKE( 454) /0.2038544566E+01/
     *    HL( 454) /0.1005900000E+04/
     *    EQLAT( 454) /0.6202952521E+00/
     *    EQLON( 454) /0.2108461234E+01/
     *    SSLIP( 454) /0.2280000000E+00/
     *    DSLIP( 454) /-.8200000000E+00/
     *    DIP( 454) /0.9197885158E+00/
     *    DEPTH( 454) /0.1591000000E+04/
     *    WIDTH( 454) /0.2079100000E+04/
      DATA STRIKE( 455) /0.2038544566E+01/
     *    HL( 455) /0.1005500000E+04/
     *    EQLAT( 455) /0.6201526587E+00/
     *    EQLON( 455) /0.2108115485E+01/
     *    SSLIP( 455) /0.1800000000E+00/
     *    DSLIP( 455) /-.4600000000E+00/
     *    DIP( 455) /0.9197885158E+00/
     *    DEPTH( 455) /0.1591000000E+04/
     *    WIDTH( 455) /0.2079100000E+04/
      DATA STRIKE( 456) /0.2038544566E+01/
     *    HL( 456) /0.1003700000E+04/
     *    EQLAT( 456) /0.6230310557E+00/
     *    EQLON( 456) /0.2114576694E+01/
     *    SSLIP( 456) /-.4400000000E-01/
     *    DSLIP( 456) /-.4000000000E-01/
     *    DIP( 456) /0.9197885158E+00/
     *    DEPTH( 456) /0.3182000000E+04/
     *    WIDTH( 456) /0.2079100000E+04/
      DATA STRIKE( 457) /0.2038544566E+01/
     *    HL( 457) /0.1003800000E+04/
     *    EQLAT( 457) /0.6228884623E+00/
     *    EQLON( 457) /0.2114231118E+01/
     *    SSLIP( 457) /-.6700000000E-01/
     *    DSLIP( 457) /-.7000000000E-01/
     *    DIP( 457) /0.9197885158E+00/
     *    DEPTH( 457) /0.3182000000E+04/
     *    WIDTH( 457) /0.2079100000E+04/
      DATA STRIKE( 458) /0.2038544566E+01/
     *    HL( 458) /0.1004300000E+04/
     *    EQLAT( 458) /0.6227458689E+00/
     *    EQLON( 458) /0.2113885543E+01/
     *    SSLIP( 458) /-.1900000000E-01/
     *    DSLIP( 458) /-.1200000000E+00/
     *    DIP( 458) /0.9197885158E+00/
     *    DEPTH( 458) /0.3182000000E+04/
     *    WIDTH( 458) /0.2079100000E+04/
      DATA STRIKE( 459) /0.2038544566E+01/
     *    HL( 459) /0.1003900000E+04/
     *    EQLAT( 459) /0.6226032755E+00/
     *    EQLON( 459) /0.2113539793E+01/
     *    SSLIP( 459) /-.3000000000E-02/
     *    DSLIP( 459) /-.3300000000E+00/
     *    DIP( 459) /0.9197885158E+00/
     *    DEPTH( 459) /0.3182000000E+04/
     *    WIDTH( 459) /0.2079100000E+04/
      DATA STRIKE( 460) /0.2038544566E+01/
     *    HL( 460) /0.1004400000E+04/
     *    EQLAT( 460) /0.6224606821E+00/
     *    EQLON( 460) /0.2113194218E+01/
     *    SSLIP( 460) /0.3200000000E-01/
     *    DSLIP( 460) /-.6900000000E+00/
     *    DIP( 460) /0.9197885158E+00/
     *    DEPTH( 460) /0.3182000000E+04/
     *    WIDTH( 460) /0.2079100000E+04/
      DATA STRIKE( 461) /0.2038544566E+01/
     *    HL( 461) /0.1004100000E+04/
     *    EQLAT( 461) /0.6223180887E+00/
     *    EQLON( 461) /0.2112848469E+01/
     *    SSLIP( 461) /0.1260000000E+00/
     *    DSLIP( 461) /-.1110000000E+01/
     *    DIP( 461) /0.9197885158E+00/
     *    DEPTH( 461) /0.3182000000E+04/
     *    WIDTH( 461) /0.2079100000E+04/
      DATA STRIKE( 462) /0.2038544566E+01/
     *    HL( 462) /0.1004200000E+04/
     *    EQLAT( 462) /0.6221754953E+00/
     *    EQLON( 462) /0.2112502893E+01/
     *    SSLIP( 462) /0.2680000000E+00/
     *    DSLIP( 462) /-.1520000000E+01/
     *    DIP( 462) /0.9197885158E+00/
     *    DEPTH( 462) /0.3182000000E+04/
     *    WIDTH( 462) /0.2079100000E+04/
      DATA STRIKE( 463) /0.2038544566E+01/
     *    HL( 463) /0.1004700000E+04/
     *    EQLAT( 463) /0.6220329019E+00/
     *    EQLON( 463) /0.2112157318E+01/
     *    SSLIP( 463) /0.3960000000E+00/
     *    DSLIP( 463) /-.1820000000E+01/
     *    DIP( 463) /0.9197885158E+00/
     *    DEPTH( 463) /0.3182000000E+04/
     *    WIDTH( 463) /0.2079100000E+04/
      DATA STRIKE( 464) /0.2038544566E+01/
     *    HL( 464) /0.1004400000E+04/
     *    EQLAT( 464) /0.6218903085E+00/
     *    EQLON( 464) /0.2111811568E+01/
     *    SSLIP( 464) /0.4420000000E+00/
     *    DSLIP( 464) /-.1970000000E+01/
     *    DIP( 464) /0.9197885158E+00/
     *    DEPTH( 464) /0.3182000000E+04/
     *    WIDTH( 464) /0.2079100000E+04/
      DATA STRIKE( 465) /0.2038544566E+01/
     *    HL( 465) /0.1004400000E+04/
     *    EQLAT( 465) /0.6217477152E+00/
     *    EQLON( 465) /0.2111465993E+01/
     *    SSLIP( 465) /0.3570000000E+00/
     *    DSLIP( 465) /-.1960000000E+01/
     *    DIP( 465) /0.9197885158E+00/
     *    DEPTH( 465) /0.3182000000E+04/
     *    WIDTH( 465) /0.2079100000E+04/
      DATA STRIKE( 466) /0.2038544566E+01/
     *    HL( 466) /0.1004900000E+04/
     *    EQLAT( 466) /0.6216051218E+00/
     *    EQLON( 466) /0.2111120418E+01/
     *    SSLIP( 466) /0.1730000000E+00/
     *    DSLIP( 466) /-.1810000000E+01/
     *    DIP( 466) /0.9197885158E+00/
     *    DEPTH( 466) /0.3182000000E+04/
     *    WIDTH( 466) /0.2079100000E+04/
      DATA STRIKE( 467) /0.2038544566E+01/
     *    HL( 467) /0.1004600000E+04/
     *    EQLAT( 467) /0.6214625284E+00/
     *    EQLON( 467) /0.2110774668E+01/
     *    SSLIP( 467) /-.5000000000E-02/
     *    DSLIP( 467) /-.1580000000E+01/
     *    DIP( 467) /0.9197885158E+00/
     *    DEPTH( 467) /0.3182000000E+04/
     *    WIDTH( 467) /0.2079100000E+04/
      DATA STRIKE( 468) /0.2038544566E+01/
     *    HL( 468) /0.1004700000E+04/
     *    EQLAT( 468) /0.6213201095E+00/
     *    EQLON( 468) /0.2110429093E+01/
     *    SSLIP( 468) /-.1310000000E+00/
     *    DSLIP( 468) /-.1360000000E+01/
     *    DIP( 468) /0.9197885158E+00/
     *    DEPTH( 468) /0.3182000000E+04/
     *    WIDTH( 468) /0.2079100000E+04/
      DATA STRIKE( 469) /0.2038544566E+01/
     *    HL( 469) /0.1005200000E+04/
     *    EQLAT( 469) /0.6211775161E+00/
     *    EQLON( 469) /0.2110083518E+01/
     *    SSLIP( 469) /-.2280000000E+00/
     *    DSLIP( 469) /-.1210000000E+01/
     *    DIP( 469) /0.9197885158E+00/
     *    DEPTH( 469) /0.3182000000E+04/
     *    WIDTH( 469) /0.2079100000E+04/
      DATA STRIKE( 470) /0.2038544566E+01/
     *    HL( 470) /0.1004800000E+04/
     *    EQLAT( 470) /0.6210349227E+00/
     *    EQLON( 470) /0.2109737768E+01/
     *    SSLIP( 470) /-.2430000000E+00/
     *    DSLIP( 470) /-.1150000000E+01/
     *    DIP( 470) /0.9197885158E+00/
     *    DEPTH( 470) /0.3182000000E+04/
     *    WIDTH( 470) /0.2079100000E+04/
      DATA STRIKE( 471) /0.2038544566E+01/
     *    HL( 471) /0.1005300000E+04/
     *    EQLAT( 471) /0.6208923293E+00/
     *    EQLON( 471) /0.2109392193E+01/
     *    SSLIP( 471) /-.9800000000E-01/
     *    DSLIP( 471) /-.1120000000E+01/
     *    DIP( 471) /0.9197885158E+00/
     *    DEPTH( 471) /0.3182000000E+04/
     *    WIDTH( 471) /0.2079100000E+04/
      DATA STRIKE( 472) /0.2038544566E+01/
     *    HL( 472) /0.1005000000E+04/
     *    EQLAT( 472) /0.6207497359E+00/
     *    EQLON( 472) /0.2109046443E+01/
     *    SSLIP( 472) /0.1640000000E+00/
     *    DSLIP( 472) /-.1020000000E+01/
     *    DIP( 472) /0.9197885158E+00/
     *    DEPTH( 472) /0.3182000000E+04/
     *    WIDTH( 472) /0.2079100000E+04/
      DATA STRIKE( 473) /0.2038544566E+01/
     *    HL( 473) /0.1005100000E+04/
     *    EQLAT( 473) /0.6206071425E+00/
     *    EQLON( 473) /0.2108700868E+01/
     *    SSLIP( 473) /0.3730000000E+00/
     *    DSLIP( 473) /-.8100000000E+00/
     *    DIP( 473) /0.9197885158E+00/
     *    DEPTH( 473) /0.3182000000E+04/
     *    WIDTH( 473) /0.2079100000E+04/
      DATA STRIKE( 474) /0.2038544566E+01/
     *    HL( 474) /0.1005600000E+04/
     *    EQLAT( 474) /0.6204645491E+00/
     *    EQLON( 474) /0.2108355293E+01/
     *    SSLIP( 474) /0.3590000000E+00/
     *    DSLIP( 474) /-.5600000000E+00/
     *    DIP( 474) /0.9197885158E+00/
     *    DEPTH( 474) /0.3182000000E+04/
     *    WIDTH( 474) /0.2079100000E+04/
      DATA STRIKE( 475) /0.2038544566E+01/
     *    HL( 475) /0.1005300000E+04/
     *    EQLAT( 475) /0.6203219557E+00/
     *    EQLON( 475) /0.2108009543E+01/
     *    SSLIP( 475) /0.1850000000E+00/
     *    DSLIP( 475) /-.2800000000E+00/
     *    DIP( 475) /0.9197885158E+00/
     *    DEPTH( 475) /0.3182000000E+04/
     *    WIDTH( 475) /0.2079100000E+04/
      DATA STRIKE( 476) /0.2038544566E+01/
     *    HL( 476) /0.1003400000E+04/
     *    EQLAT( 476) /0.6232003527E+00/
     *    EQLON( 476) /0.2114470752E+01/
     *    SSLIP( 476) /-.4400000000E-01/
     *    DSLIP( 476) /-.4000000000E-01/
     *    DIP( 476) /0.9197885158E+00/
     *    DEPTH( 476) /0.4773000000E+04/
     *    WIDTH( 476) /0.2079100000E+04/
      DATA STRIKE( 477) /0.2038544566E+01/
     *    HL( 477) /0.1003900000E+04/
     *    EQLAT( 477) /0.6230577593E+00/
     *    EQLON( 477) /0.2114125177E+01/
     *    SSLIP( 477) /-.3200000000E-01/
     *    DSLIP( 477) /-.1200000000E+00/
     *    DIP( 477) /0.9197885158E+00/
     *    DEPTH( 477) /0.4773000000E+04/
     *    WIDTH( 477) /0.2079100000E+04/
      DATA STRIKE( 478) /0.2038544566E+01/
     *    HL( 478) /0.1003600000E+04/
     *    EQLAT( 478) /0.6229151659E+00/
     *    EQLON( 478) /0.2113779427E+01/
     *    SSLIP( 478) /0.6400000000E-01/
     *    DSLIP( 478) /-.2600000000E+00/
     *    DIP( 478) /0.9197885158E+00/
     *    DEPTH( 478) /0.4773000000E+04/
     *    WIDTH( 478) /0.2079100000E+04/
      DATA STRIKE( 479) /0.2038544566E+01/
     *    HL( 479) /0.1003700000E+04/
     *    EQLAT( 479) /0.6227725725E+00/
     *    EQLON( 479) /0.2113433852E+01/
     *    SSLIP( 479) /0.1620000000E+00/
     *    DSLIP( 479) /-.5000000000E+00/
     *    DIP( 479) /0.9197885158E+00/
     *    DEPTH( 479) /0.4773000000E+04/
     *    WIDTH( 479) /0.2079100000E+04/
      DATA STRIKE( 480) /0.2038544566E+01/
     *    HL( 480) /0.1004200000E+04/
     *    EQLAT( 480) /0.6226299791E+00/
     *    EQLON( 480) /0.2113088277E+01/
     *    SSLIP( 480) /0.2470000000E+00/
     *    DSLIP( 480) /-.8500000000E+00/
     *    DIP( 480) /0.9197885158E+00/
     *    DEPTH( 480) /0.4773000000E+04/
     *    WIDTH( 480) /0.2079100000E+04/
      DATA STRIKE( 481) /0.2038544566E+01/
     *    HL( 481) /0.1003900000E+04/
     *    EQLAT( 481) /0.6224875602E+00/
     *    EQLON( 481) /0.2112742527E+01/
     *    SSLIP( 481) /0.3500000000E+00/
     *    DSLIP( 481) /-.1270000000E+01/
     *    DIP( 481) /0.9197885158E+00/
     *    DEPTH( 481) /0.4773000000E+04/
     *    WIDTH( 481) /0.2079100000E+04/
      DATA STRIKE( 482) /0.2038544566E+01/
     *    HL( 482) /0.1003900000E+04/
     *    EQLAT( 482) /0.6223449668E+00/
     *    EQLON( 482) /0.2112396952E+01/
     *    SSLIP( 482) /0.5050000000E+00/
     *    DSLIP( 482) /-.1700000000E+01/
     *    DIP( 482) /0.9197885158E+00/
     *    DEPTH( 482) /0.4773000000E+04/
     *    WIDTH( 482) /0.2079100000E+04/
      DATA STRIKE( 483) /0.2038544566E+01/
     *    HL( 483) /0.1004400000E+04/
     *    EQLAT( 483) /0.6222023734E+00/
     *    EQLON( 483) /0.2112051377E+01/
     *    SSLIP( 483) /0.6810000000E+00/
     *    DSLIP( 483) /-.2030000000E+01/
     *    DIP( 483) /0.9197885158E+00/
     *    DEPTH( 483) /0.4773000000E+04/
     *    WIDTH( 483) /0.2079100000E+04/
      DATA STRIKE( 484) /0.2038544566E+01/
     *    HL( 484) /0.1004100000E+04/
     *    EQLAT( 484) /0.6220597800E+00/
     *    EQLON( 484) /0.2111705627E+01/
     *    SSLIP( 484) /0.7920000000E+00/
     *    DSLIP( 484) /-.2220000000E+01/
     *    DIP( 484) /0.9197885158E+00/
     *    DEPTH( 484) /0.4773000000E+04/
     *    WIDTH( 484) /0.2079100000E+04/
      DATA STRIKE( 485) /0.2038544566E+01/
     *    HL( 485) /0.1004600000E+04/
     *    EQLAT( 485) /0.6219171866E+00/
     *    EQLON( 485) /0.2111360052E+01/
     *    SSLIP( 485) /0.7520000000E+00/
     *    DSLIP( 485) /-.2240000000E+01/
     *    DIP( 485) /0.9197885158E+00/
     *    DEPTH( 485) /0.4773000000E+04/
     *    WIDTH( 485) /0.2079100000E+04/
      DATA STRIKE( 486) /0.2038544566E+01/
     *    HL( 486) /0.1004300000E+04/
     *    EQLAT( 486) /0.6217745932E+00/
     *    EQLON( 486) /0.2111014302E+01/
     *    SSLIP( 486) /0.5810000000E+00/
     *    DSLIP( 486) /-.2070000000E+01/
     *    DIP( 486) /0.9197885158E+00/
     *    DEPTH( 486) /0.4773000000E+04/
     *    WIDTH( 486) /0.2079100000E+04/
      DATA STRIKE( 487) /0.2038544566E+01/
     *    HL( 487) /0.1004300000E+04/
     *    EQLAT( 487) /0.6216319998E+00/
     *    EQLON( 487) /0.2110668727E+01/
     *    SSLIP( 487) /0.3660000000E+00/
     *    DSLIP( 487) /-.1790000000E+01/
     *    DIP( 487) /0.9197885158E+00/
     *    DEPTH( 487) /0.4773000000E+04/
     *    WIDTH( 487) /0.2079100000E+04/
      DATA STRIKE( 488) /0.2038544566E+01/
     *    HL( 488) /0.1004800000E+04/
     *    EQLAT( 488) /0.6214894064E+00/
     *    EQLON( 488) /0.2110323152E+01/
     *    SSLIP( 488) /0.1860000000E+00/
     *    DSLIP( 488) /-.1450000000E+01/
     *    DIP( 488) /0.9197885158E+00/
     *    DEPTH( 488) /0.4773000000E+04/
     *    WIDTH( 488) /0.2079100000E+04/
      DATA STRIKE( 489) /0.2038544566E+01/
     *    HL( 489) /0.1004500000E+04/
     *    EQLAT( 489) /0.6213468130E+00/
     *    EQLON( 489) /0.2109977402E+01/
     *    SSLIP( 489) /0.7000000000E-01/
     *    DSLIP( 489) /-.1150000000E+01/
     *    DIP( 489) /0.9197885158E+00/
     *    DEPTH( 489) /0.4773000000E+04/
     *    WIDTH( 489) /0.2079100000E+04/
      DATA STRIKE( 490) /0.2038544566E+01/
     *    HL( 490) /0.1004600000E+04/
     *    EQLAT( 490) /0.6212042196E+00/
     *    EQLON( 490) /0.2109631827E+01/
     *    SSLIP( 490) /0.4200000000E-01/
     *    DSLIP( 490) /-.9100000000E+00/
     *    DIP( 490) /0.9197885158E+00/
     *    DEPTH( 490) /0.4773000000E+04/
     *    WIDTH( 490) /0.2079100000E+04/
      DATA STRIKE( 491) /0.2038544566E+01/
     *    HL( 491) /0.1005100000E+04/
     *    EQLAT( 491) /0.6210616262E+00/
     *    EQLON( 491) /0.2109286252E+01/
     *    SSLIP( 491) /0.1310000000E+00/
     *    DSLIP( 491) /-.7100000000E+00/
     *    DIP( 491) /0.9197885158E+00/
     *    DEPTH( 491) /0.4773000000E+04/
     *    WIDTH( 491) /0.2079100000E+04/
      DATA STRIKE( 492) /0.2038544566E+01/
     *    HL( 492) /0.1004800000E+04/
     *    EQLAT( 492) /0.6209192074E+00/
     *    EQLON( 492) /0.2108940502E+01/
     *    SSLIP( 492) /0.2680000000E+00/
     *    DSLIP( 492) /-.5100000000E+00/
     *    DIP( 492) /0.9197885158E+00/
     *    DEPTH( 492) /0.4773000000E+04/
     *    WIDTH( 492) /0.2079100000E+04/
      DATA STRIKE( 493) /0.2038544566E+01/
     *    HL( 493) /0.1004800000E+04/
     *    EQLAT( 493) /0.6207766140E+00/
     *    EQLON( 493) /0.2108594927E+01/
     *    SSLIP( 493) /0.2930000000E+00/
     *    DSLIP( 493) /-.3300000000E+00/
     *    DIP( 493) /0.9197885158E+00/
     *    DEPTH( 493) /0.4773000000E+04/
     *    WIDTH( 493) /0.2079100000E+04/
      DATA STRIKE( 494) /0.2038544566E+01/
     *    HL( 494) /0.1005300000E+04/
     *    EQLAT( 494) /0.6206340206E+00/
     *    EQLON( 494) /0.2108249351E+01/
     *    SSLIP( 494) /0.1730000000E+00/
     *    DSLIP( 494) /-.1700000000E+00/
     *    DIP( 494) /0.9197885158E+00/
     *    DEPTH( 494) /0.4773000000E+04/
     *    WIDTH( 494) /0.2079100000E+04/
      DATA STRIKE( 495) /0.2038544566E+01/
     *    HL( 495) /0.1005000000E+04/
     *    EQLAT( 495) /0.6204914272E+00/
     *    EQLON( 495) /0.2107903602E+01/
     *    SSLIP( 495) /0.5600000000E-01/
     *    DSLIP( 495) /-.6000000000E-01/
     *    DIP( 495) /0.9197885158E+00/
     *    DEPTH( 495) /0.4773000000E+04/
     *    WIDTH( 495) /0.2079100000E+04/
      DATA STRIKE( 496) /0.2038544566E+01/
     *    HL( 496) /0.1003200000E+04/
     *    EQLAT( 496) /0.6233698242E+00/
     *    EQLON( 496) /0.2114364811E+01/
     *    SSLIP( 496) /0.3000000000E-02/
     *    DSLIP( 496) /-.4000000000E-01/
     *    DIP( 496) /0.9197885158E+00/
     *    DEPTH( 496) /0.6364000000E+04/
     *    WIDTH( 496) /0.2079100000E+04/
      DATA STRIKE( 497) /0.2038544566E+01/
     *    HL( 497) /0.1003700000E+04/
     *    EQLAT( 497) /0.6232272308E+00/
     *    EQLON( 497) /0.2114019235E+01/
     *    SSLIP( 497) /0.5200000000E-01/
     *    DSLIP( 497) /-.1300000000E+00/
     *    DIP( 497) /0.9197885158E+00/
     *    DEPTH( 497) /0.6364000000E+04/
     *    WIDTH( 497) /0.2079100000E+04/
      DATA STRIKE( 498) /0.2038544566E+01/
     *    HL( 498) /0.1003400000E+04/
     *    EQLAT( 498) /0.6230846374E+00/
     *    EQLON( 498) /0.2113673486E+01/
     *    SSLIP( 498) /0.1570000000E+00/
     *    DSLIP( 498) /-.2500000000E+00/
     *    DIP( 498) /0.9197885158E+00/
     *    DEPTH( 498) /0.6364000000E+04/
     *    WIDTH( 498) /0.2079100000E+04/
      DATA STRIKE( 499) /0.2038544566E+01/
     *    HL( 499) /0.1003500000E+04/
     *    EQLAT( 499) /0.6229420440E+00/
     *    EQLON( 499) /0.2113327911E+01/
     *    SSLIP( 499) /0.2810000000E+00/
     *    DSLIP( 499) /-.4200000000E+00/
     *    DIP( 499) /0.9197885158E+00/
     *    DEPTH( 499) /0.6364000000E+04/
     *    WIDTH( 499) /0.2079100000E+04/
      DATA STRIKE( 500) /0.2038544566E+01/
     *    HL( 500) /0.1003900000E+04/
     *    EQLAT( 500) /0.6227994506E+00/
     *    EQLON( 500) /0.2112982335E+01/
     *    SSLIP( 500) /0.3750000000E+00/
     *    DSLIP( 500) /-.6700000000E+00/
     *    DIP( 500) /0.9197885158E+00/
     *    DEPTH( 500) /0.6364000000E+04/
     *    WIDTH( 500) /0.2079100000E+04/
      DATA STRIKE( 501) /0.2038544566E+01/
     *    HL( 501) /0.1003600000E+04/
     *    EQLAT( 501) /0.6226568572E+00/
     *    EQLON( 501) /0.2112636586E+01/
     *    SSLIP( 501) /0.4550000000E+00/
     *    DSLIP( 501) /-.9800000000E+00/
     *    DIP( 501) /0.9197885158E+00/
     *    DEPTH( 501) /0.6364000000E+04/
     *    WIDTH( 501) /0.2079100000E+04/
      DATA STRIKE( 502) /0.2038544566E+01/
     *    HL( 502) /0.1004100000E+04/
     *    EQLAT( 502) /0.6225142638E+00/
     *    EQLON( 502) /0.2112291010E+01/
     *    SSLIP( 502) /0.5680000000E+00/
     *    DSLIP( 502) /-.1300000000E+01/
     *    DIP( 502) /0.9197885158E+00/
     *    DEPTH( 502) /0.6364000000E+04/
     *    WIDTH( 502) /0.2079100000E+04/
      DATA STRIKE( 503) /0.2038544566E+01/
     *    HL( 503) /0.1003800000E+04/
     *    EQLAT( 503) /0.6223716704E+00/
     *    EQLON( 503) /0.2111945261E+01/
     *    SSLIP( 503) /0.7150000000E+00/
     *    DSLIP( 503) /-.1590000000E+01/
     *    DIP( 503) /0.9197885158E+00/
     *    DEPTH( 503) /0.6364000000E+04/
     *    WIDTH( 503) /0.2079100000E+04/
      DATA STRIKE( 504) /0.2038544566E+01/
     *    HL( 504) /0.1003900000E+04/
     *    EQLAT( 504) /0.6222290770E+00/
     *    EQLON( 504) /0.2111599685E+01/
     *    SSLIP( 504) /0.8270000000E+00/
     *    DSLIP( 504) /-.1770000000E+01/
     *    DIP( 504) /0.9197885158E+00/
     *    DEPTH( 504) /0.6364000000E+04/
     *    WIDTH( 504) /0.2079100000E+04/
      DATA STRIKE( 505) /0.2038544566E+01/
     *    HL( 505) /0.1004300000E+04/
     *    EQLAT( 505) /0.6220866581E+00/
     *    EQLON( 505) /0.2111254110E+01/
     *    SSLIP( 505) /0.8130000000E+00/
     *    DSLIP( 505) /-.1800000000E+01/
     *    DIP( 505) /0.9197885158E+00/
     *    DEPTH( 505) /0.6364000000E+04/
     *    WIDTH( 505) /0.2079100000E+04/
      DATA STRIKE( 506) /0.2038544566E+01/
     *    HL( 506) /0.1004000000E+04/
     *    EQLAT( 506) /0.6219440647E+00/
     *    EQLON( 506) /0.2110908361E+01/
     *    SSLIP( 506) /0.6770000000E+00/
     *    DSLIP( 506) /-.1650000000E+01/
     *    DIP( 506) /0.9197885158E+00/
     *    DEPTH( 506) /0.6364000000E+04/
     *    WIDTH( 506) /0.2079100000E+04/
      DATA STRIKE( 507) /0.2038544566E+01/
     *    HL( 507) /0.1004100000E+04/
     *    EQLAT( 507) /0.6218014713E+00/
     *    EQLON( 507) /0.2110562785E+01/
     *    SSLIP( 507) /0.4740000000E+00/
     *    DSLIP( 507) /-.1380000000E+01/
     *    DIP( 507) /0.9197885158E+00/
     *    DEPTH( 507) /0.6364000000E+04/
     *    WIDTH( 507) /0.2079100000E+04/
      DATA STRIKE( 508) /0.2038544566E+01/
     *    HL( 508) /0.1004600000E+04/
     *    EQLAT( 508) /0.6216588779E+00/
     *    EQLON( 508) /0.2110217210E+01/
     *    SSLIP( 508) /0.2820000000E+00/
     *    DSLIP( 508) /-.1050000000E+01/
     *    DIP( 508) /0.9197885158E+00/
     *    DEPTH( 508) /0.6364000000E+04/
     *    WIDTH( 508) /0.2079100000E+04/
      DATA STRIKE( 509) /0.2038544566E+01/
     *    HL( 509) /0.1004300000E+04/
     *    EQLAT( 509) /0.6215162845E+00/
     *    EQLON( 509) /0.2109871460E+01/
     *    SSLIP( 509) /0.1540000000E+00/
     *    DSLIP( 509) /-.7100000000E+00/
     *    DIP( 509) /0.9197885158E+00/
     *    DEPTH( 509) /0.6364000000E+04/
     *    WIDTH( 509) /0.2079100000E+04/
      DATA STRIKE( 510) /0.2038544566E+01/
     *    HL( 510) /0.1004700000E+04/
     *    EQLAT( 510) /0.6213736911E+00/
     *    EQLON( 510) /0.2109525885E+01/
     *    SSLIP( 510) /0.9300000000E-01/
     *    DSLIP( 510) /-.4300000000E+00/
     *    DIP( 510) /0.9197885158E+00/
     *    DEPTH( 510) /0.6364000000E+04/
     *    WIDTH( 510) /0.2079100000E+04/
      DATA STRIKE( 511) /0.2038544566E+01/
     *    HL( 511) /0.1004400000E+04/
     *    EQLAT( 511) /0.6212310977E+00/
     *    EQLON( 511) /0.2109180136E+01/
     *    SSLIP( 511) /0.9500000000E-01/
     *    DSLIP( 511) /-.2200000000E+00/
     *    DIP( 511) /0.9197885158E+00/
     *    DEPTH( 511) /0.6364000000E+04/
     *    WIDTH( 511) /0.2079100000E+04/
      DATA STRIKE( 512) /0.2038544566E+01/
     *    HL( 512) /0.1004500000E+04/
     *    EQLAT( 512) /0.6210885043E+00/
     *    EQLON( 512) /0.2108834560E+01/
     *    SSLIP( 512) /0.9900000000E-01/
     *    DSLIP( 512) /-.1000000000E+00/
     *    DIP( 512) /0.9197885158E+00/
     *    DEPTH( 512) /0.6364000000E+04/
     *    WIDTH( 512) /0.2079100000E+04/
      DATA STRIKE( 513) /0.2038544566E+01/
     *    HL( 513) /0.1005000000E+04/
     *    EQLAT( 513) /0.6209459109E+00/
     *    EQLON( 513) /0.2108488985E+01/
     *    SSLIP( 513) /0.4200000000E-01/
     *    DSLIP( 513) /-.4000000000E-01/
     *    DIP( 513) /0.9197885158E+00/
     *    DEPTH( 513) /0.6364000000E+04/
     *    WIDTH( 513) /0.2079100000E+04/
      DATA STRIKE( 514) /0.2038544566E+01/
     *    HL( 514) /0.1004700000E+04/
     *    EQLAT( 514) /0.6208033175E+00/
     *    EQLON( 514) /0.2108143235E+01/
     *    SSLIP( 514) /0.0000000000E+00/
     *    DSLIP( 514) /0.0000000000E+00/
     *    DIP( 514) /0.9197885158E+00/
     *    DEPTH( 514) /0.6364000000E+04/
     *    WIDTH( 514) /0.2079100000E+04/
      DATA STRIKE( 515) /0.2038544566E+01/
     *    HL( 515) /0.1004800000E+04/
     *    EQLAT( 515) /0.6206607241E+00/
     *    EQLON( 515) /0.2107797660E+01/
     *    SSLIP( 515) /0.0000000000E+00/
     *    DSLIP( 515) /0.0000000000E+00/
     *    DIP( 515) /0.9197885158E+00/
     *    DEPTH( 515) /0.6364000000E+04/
     *    WIDTH( 515) /0.2079100000E+04/
      DATA STRIKE( 516) /0.2038544566E+01/
     *    HL( 516) /0.1002900000E+04/
     *    EQLAT( 516) /0.6235391211E+00/
     *    EQLON( 516) /0.2114258869E+01/
     *    SSLIP( 516) /0.3400000000E-01/
     *    DSLIP( 516) /-.3000000000E-01/
     *    DIP( 516) /0.9197885158E+00/
     *    DEPTH( 516) /0.7955100000E+04/
     *    WIDTH( 516) /0.2079100000E+04/
      DATA STRIKE( 517) /0.2038544566E+01/
     *    HL( 517) /0.1003400000E+04/
     *    EQLAT( 517) /0.6233965277E+00/
     *    EQLON( 517) /0.2113913294E+01/
     *    SSLIP( 517) /0.8100000000E-01/
     *    DSLIP( 517) /-.8000000000E-01/
     *    DIP( 517) /0.9197885158E+00/
     *    DEPTH( 517) /0.7955100000E+04/
     *    WIDTH( 517) /0.2079100000E+04/
      DATA STRIKE( 518) /0.2038544566E+01/
     *    HL( 518) /0.1003100000E+04/
     *    EQLAT( 518) /0.6232541088E+00/
     *    EQLON( 518) /0.2113567544E+01/
     *    SSLIP( 518) /0.1460000000E+00/
     *    DSLIP( 518) /-.1500000000E+00/
     *    DIP( 518) /0.9197885158E+00/
     *    DEPTH( 518) /0.7955100000E+04/
     *    WIDTH( 518) /0.2079100000E+04/
      DATA STRIKE( 519) /0.2038544566E+01/
     *    HL( 519) /0.1003600000E+04/
     *    EQLAT( 519) /0.6231115154E+00/
     *    EQLON( 519) /0.2113221969E+01/
     *    SSLIP( 519) /0.2210000000E+00/
     *    DSLIP( 519) /-.2200000000E+00/
     *    DIP( 519) /0.9197885158E+00/
     *    DEPTH( 519) /0.7955100000E+04/
     *    WIDTH( 519) /0.2079100000E+04/
      DATA STRIKE( 520) /0.2038544566E+01/
     *    HL( 520) /0.1003300000E+04/
     *    EQLAT( 520) /0.6229689220E+00/
     *    EQLON( 520) /0.2112876219E+01/
     *    SSLIP( 520) /0.2880000000E+00/
     *    DSLIP( 520) /-.3300000000E+00/
     *    DIP( 520) /0.9197885158E+00/
     *    DEPTH( 520) /0.7955100000E+04/
     *    WIDTH( 520) /0.2079100000E+04/
      DATA STRIKE( 521) /0.2038544566E+01/
     *    HL( 521) /0.1003400000E+04/
     *    EQLAT( 521) /0.6228263286E+00/
     *    EQLON( 521) /0.2112530644E+01/
     *    SSLIP( 521) /0.3510000000E+00/
     *    DSLIP( 521) /-.4800000000E+00/
     *    DIP( 521) /0.9197885158E+00/
     *    DEPTH( 521) /0.7955100000E+04/
     *    WIDTH( 521) /0.2079100000E+04/
      DATA STRIKE( 522) /0.2038544566E+01/
     *    HL( 522) /0.1003800000E+04/
     *    EQLAT( 522) /0.6226837352E+00/
     *    EQLON( 522) /0.2112185069E+01/
     *    SSLIP( 522) /0.4250000000E+00/
     *    DSLIP( 522) /-.6600000000E+00/
     *    DIP( 522) /0.9197885158E+00/
     *    DEPTH( 522) /0.7955100000E+04/
     *    WIDTH( 522) /0.2079100000E+04/
      DATA STRIKE( 523) /0.2038544566E+01/
     *    HL( 523) /0.1003500000E+04/
     *    EQLAT( 523) /0.6225411418E+00/
     *    EQLON( 523) /0.2111839319E+01/
     *    SSLIP( 523) /0.5080000000E+00/
     *    DSLIP( 523) /-.8300000000E+00/
     *    DIP( 523) /0.9197885158E+00/
     *    DEPTH( 523) /0.7955100000E+04/
     *    WIDTH( 523) /0.2079100000E+04/
      DATA STRIKE( 524) /0.2038544566E+01/
     *    HL( 524) /0.1003600000E+04/
     *    EQLAT( 524) /0.6223985484E+00/
     *    EQLON( 524) /0.2111493744E+01/
     *    SSLIP( 524) /0.5780000000E+00/
     *    DSLIP( 524) /-.9400000000E+00/
     *    DIP( 524) /0.9197885158E+00/
     *    DEPTH( 524) /0.7955100000E+04/
     *    WIDTH( 524) /0.2079100000E+04/
      DATA STRIKE( 525) /0.2038544566E+01/
     *    HL( 525) /0.1004100000E+04/
     *    EQLAT( 525) /0.6222559550E+00/
     *    EQLON( 525) /0.2111148169E+01/
     *    SSLIP( 525) /0.5790000000E+00/
     *    DSLIP( 525) /-.9500000000E+00/
     *    DIP( 525) /0.9197885158E+00/
     *    DEPTH( 525) /0.7955100000E+04/
     *    WIDTH( 525) /0.2079100000E+04/
      DATA STRIKE( 526) /0.2038544566E+01/
     *    HL( 526) /0.1003800000E+04/
     *    EQLAT( 526) /0.6221133616E+00/
     *    EQLON( 526) /0.2110802419E+01/
     *    SSLIP( 526) /0.4860000000E+00/
     *    DSLIP( 526) /-.8400000000E+00/
     *    DIP( 526) /0.9197885158E+00/
     *    DEPTH( 526) /0.7955100000E+04/
     *    WIDTH( 526) /0.2079100000E+04/
      DATA STRIKE( 527) /0.2038544566E+01/
     *    HL( 527) /0.1004300000E+04/
     *    EQLAT( 527) /0.6219707682E+00/
     *    EQLON( 527) /0.2110456844E+01/
     *    SSLIP( 527) /0.3350000000E+00/
     *    DSLIP( 527) /-.6600000000E+00/
     *    DIP( 527) /0.9197885158E+00/
     *    DEPTH( 527) /0.7955100000E+04/
     *    WIDTH( 527) /0.2079100000E+04/
      DATA STRIKE( 528) /0.2038544566E+01/
     *    HL( 528) /0.1003900000E+04/
     *    EQLAT( 528) /0.6218281748E+00/
     *    EQLON( 528) /0.2110111094E+01/
     *    SSLIP( 528) /0.1820000000E+00/
     *    DSLIP( 528) /-.4400000000E+00/
     *    DIP( 528) /0.9197885158E+00/
     *    DEPTH( 528) /0.7955100000E+04/
     *    WIDTH( 528) /0.2079100000E+04/
      DATA STRIKE( 529) /0.2038544566E+01/
     *    HL( 529) /0.1004000000E+04/
     *    EQLAT( 529) /0.6216855814E+00/
     *    EQLON( 529) /0.2109765519E+01/
     *    SSLIP( 529) /0.7400000000E-01/
     *    DSLIP( 529) /-.2400000000E+00/
     *    DIP( 529) /0.9197885158E+00/
     *    DEPTH( 529) /0.7955100000E+04/
     *    WIDTH( 529) /0.2079100000E+04/
      DATA STRIKE( 530) /0.2038544566E+01/
     *    HL( 530) /0.1004500000E+04/
     *    EQLAT( 530) /0.6215431626E+00/
     *    EQLON( 530) /0.2109419944E+01/
     *    SSLIP( 530) /0.2200000000E-01/
     *    DSLIP( 530) /-.8000000000E-01/
     *    DIP( 530) /0.9197885158E+00/
     *    DEPTH( 530) /0.7955100000E+04/
     *    WIDTH( 530) /0.2079100000E+04/
      DATA STRIKE( 531) /0.2038544566E+01/
     *    HL( 531) /0.1004200000E+04/
     *    EQLAT( 531) /0.6214005692E+00/
     *    EQLON( 531) /0.2109074194E+01/
     *    SSLIP( 531) /0.0000000000E+00/
     *    DSLIP( 531) /0.0000000000E+00/
     *    DIP( 531) /0.9197885158E+00/
     *    DEPTH( 531) /0.7955100000E+04/
     *    WIDTH( 531) /0.2079100000E+04/
      DATA STRIKE( 532) /0.2038544566E+01/
     *    HL( 532) /0.1004300000E+04/
     *    EQLAT( 532) /0.6212579758E+00/
     *    EQLON( 532) /0.2108728619E+01/
     *    SSLIP( 532) /0.0000000000E+00/
     *    DSLIP( 532) /0.0000000000E+00/
     *    DIP( 532) /0.9197885158E+00/
     *    DEPTH( 532) /0.7955100000E+04/
     *    WIDTH( 532) /0.2079100000E+04/
      DATA STRIKE( 533) /0.2038544566E+01/
     *    HL( 533) /0.1004700000E+04/
     *    EQLAT( 533) /0.6211153824E+00/
     *    EQLON( 533) /0.2108383044E+01/
     *    SSLIP( 533) /0.0000000000E+00/
     *    DSLIP( 533) /0.0000000000E+00/
     *    DIP( 533) /0.9197885158E+00/
     *    DEPTH( 533) /0.7955100000E+04/
     *    WIDTH( 533) /0.2079100000E+04/
      DATA STRIKE( 534) /0.2038544566E+01/
     *    HL( 534) /0.1004400000E+04/
     *    EQLAT( 534) /0.6209727890E+00/
     *    EQLON( 534) /0.2108037294E+01/
     *    SSLIP( 534) /0.0000000000E+00/
     *    DSLIP( 534) /0.0000000000E+00/
     *    DIP( 534) /0.9197885158E+00/
     *    DEPTH( 534) /0.7955100000E+04/
     *    WIDTH( 534) /0.2079100000E+04/
      DATA STRIKE( 535) /0.2038544566E+01/
     *    HL( 535) /0.1004900000E+04/
     *    EQLAT( 535) /0.6208301956E+00/
     *    EQLON( 535) /0.2107691719E+01/
     *    SSLIP( 535) /0.0000000000E+00/
     *    DSLIP( 535) /0.0000000000E+00/
     *    DIP( 535) /0.9197885158E+00/
     *    DEPTH( 535) /0.7955100000E+04/
     *    WIDTH( 535) /0.2079100000E+04/
      DATA STRIKE( 536) /0.2038544566E+01/
     *    HL( 536) /0.1003100000E+04/
     *    EQLAT( 536) /0.6237085926E+00/
     *    EQLON( 536) /0.2114152928E+01/
     *    SSLIP( 536) /0.2200000000E-01/
     *    DSLIP( 536) /-.2000000000E-01/
     *    DIP( 536) /0.9197885158E+00/
     *    DEPTH( 536) /0.9546100000E+04/
     *    WIDTH( 536) /0.2079100000E+04/
      DATA STRIKE( 537) /0.2038544566E+01/
     *    HL( 537) /0.1002800000E+04/
     *    EQLAT( 537) /0.6235659992E+00/
     *    EQLON( 537) /0.2113807178E+01/
     *    SSLIP( 537) /0.3400000000E-01/
     *    DSLIP( 537) /-.3000000000E-01/
     *    DIP( 537) /0.9197885158E+00/
     *    DEPTH( 537) /0.9546100000E+04/
     *    WIDTH( 537) /0.2079100000E+04/
      DATA STRIKE( 538) /0.2038544566E+01/
     *    HL( 538) /0.1002900000E+04/
     *    EQLAT( 538) /0.6234234058E+00/
     *    EQLON( 538) /0.2113461603E+01/
     *    SSLIP( 538) /0.4700000000E-01/
     *    DSLIP( 538) /-.5000000000E-01/
     *    DIP( 538) /0.9197885158E+00/
     *    DEPTH( 538) /0.9546100000E+04/
     *    WIDTH( 538) /0.2079100000E+04/
      DATA STRIKE( 539) /0.2038544566E+01/
     *    HL( 539) /0.1003300000E+04/
     *    EQLAT( 539) /0.6232808124E+00/
     *    EQLON( 539) /0.2113116028E+01/
     *    SSLIP( 539) /0.6200000000E-01/
     *    DSLIP( 539) /-.6000000000E-01/
     *    DIP( 539) /0.9197885158E+00/
     *    DEPTH( 539) /0.9546100000E+04/
     *    WIDTH( 539) /0.2079100000E+04/
      DATA STRIKE( 540) /0.2038544566E+01/
     *    HL( 540) /0.1003000000E+04/
     *    EQLAT( 540) /0.6231382190E+00/
     *    EQLON( 540) /0.2112770278E+01/
     *    SSLIP( 540) /0.8300000000E-01/
     *    DSLIP( 540) /-.8000000000E-01/
     *    DIP( 540) /0.9197885158E+00/
     *    DEPTH( 540) /0.9546100000E+04/
     *    WIDTH( 540) /0.2079100000E+04/
      DATA STRIKE( 541) /0.2038544566E+01/
     *    HL( 541) /0.1003100000E+04/
     *    EQLAT( 541) /0.6229956256E+00/
     *    EQLON( 541) /0.2112424703E+01/
     *    SSLIP( 541) /0.1160000000E+00/
     *    DSLIP( 541) /-.1200000000E+00/
     *    DIP( 541) /0.9197885158E+00/
     *    DEPTH( 541) /0.9546100000E+04/
     *    WIDTH( 541) /0.2079100000E+04/
      DATA STRIKE( 542) /0.2038544566E+01/
     *    HL( 542) /0.1003600000E+04/
     *    EQLAT( 542) /0.6228530322E+00/
     *    EQLON( 542) /0.2112079127E+01/
     *    SSLIP( 542) /0.1640000000E+00/
     *    DSLIP( 542) /-.1600000000E+00/
     *    DIP( 542) /0.9197885158E+00/
     *    DEPTH( 542) /0.9546100000E+04/
     *    WIDTH( 542) /0.2079100000E+04/
      DATA STRIKE( 543) /0.2038544566E+01/
     *    HL( 543) /0.1003300000E+04/
     *    EQLAT( 543) /0.6227106133E+00/
     *    EQLON( 543) /0.2111733378E+01/
     *    SSLIP( 543) /0.2180000000E+00/
     *    DSLIP( 543) /-.2200000000E+00/
     *    DIP( 543) /0.9197885158E+00/
     *    DEPTH( 543) /0.9546100000E+04/
     *    WIDTH( 543) /0.2079100000E+04/
      DATA STRIKE( 544) /0.2038544566E+01/
     *    HL( 544) /0.1003800000E+04/
     *    EQLAT( 544) /0.6225680199E+00/
     *    EQLON( 544) /0.2111387803E+01/
     *    SSLIP( 544) /0.2540000000E+00/
     *    DSLIP( 544) /-.2500000000E+00/
     *    DIP( 544) /0.9197885158E+00/
     *    DEPTH( 544) /0.9546100000E+04/
     *    WIDTH( 544) /0.2079100000E+04/
      DATA STRIKE( 545) /0.2038544566E+01/
     *    HL( 545) /0.1003400000E+04/
     *    EQLAT( 545) /0.6224254265E+00/
     *    EQLON( 545) /0.2111042053E+01/
     *    SSLIP( 545) /0.2520000000E+00/
     *    DSLIP( 545) /-.2500000000E+00/
     *    DIP( 545) /0.9197885158E+00/
     *    DEPTH( 545) /0.9546100000E+04/
     *    WIDTH( 545) /0.2079100000E+04/
      DATA STRIKE( 546) /0.2038544566E+01/
     *    HL( 546) /0.1003500000E+04/
     *    EQLAT( 546) /0.6222828331E+00/
     *    EQLON( 546) /0.2110696478E+01/
     *    SSLIP( 546) /0.2030000000E+00/
     *    DSLIP( 546) /-.2000000000E+00/
     *    DIP( 546) /0.9197885158E+00/
     *    DEPTH( 546) /0.9546100000E+04/
     *    WIDTH( 546) /0.2079100000E+04/
      DATA STRIKE( 547) /0.2038544566E+01/
     *    HL( 547) /0.1004000000E+04/
     *    EQLAT( 547) /0.6221402397E+00/
     *    EQLON( 547) /0.2110350902E+01/
     *    SSLIP( 547) /0.1230000000E+00/
     *    DSLIP( 547) /-.1200000000E+00/
     *    DIP( 547) /0.9197885158E+00/
     *    DEPTH( 547) /0.9546100000E+04/
     *    WIDTH( 547) /0.2079100000E+04/
      DATA STRIKE( 548) /0.2038544566E+01/
     *    HL( 548) /0.1003700000E+04/
     *    EQLAT( 548) /0.6219976463E+00/
     *    EQLON( 548) /0.2110005153E+01/
     *    SSLIP( 548) /0.4100000000E-01/
     *    DSLIP( 548) /-.4000000000E-01/
     *    DIP( 548) /0.9197885158E+00/
     *    DEPTH( 548) /0.9546100000E+04/
     *    WIDTH( 548) /0.2079100000E+04/
      DATA STRIKE( 549) /0.2038544566E+01/
     *    HL( 549) /0.1003800000E+04/
     *    EQLAT( 549) /0.6218550529E+00/
     *    EQLON( 549) /0.2109659577E+01/
     *    SSLIP( 549) /0.0000000000E+00/
     *    DSLIP( 549) /0.0000000000E+00/
     *    DIP( 549) /0.9197885158E+00/
     *    DEPTH( 549) /0.9546100000E+04/
     *    WIDTH( 549) /0.2079100000E+04/
      DATA STRIKE( 550) /0.2038544566E+01/
     *    HL( 550) /0.1004200000E+04/
     *    EQLAT( 550) /0.6217124595E+00/
     *    EQLON( 550) /0.2109314002E+01/
     *    SSLIP( 550) /0.0000000000E+00/
     *    DSLIP( 550) /0.0000000000E+00/
     *    DIP( 550) /0.9197885158E+00/
     *    DEPTH( 550) /0.9546100000E+04/
     *    WIDTH( 550) /0.2079100000E+04/
      DATA STRIKE( 551) /0.2038544566E+01/
     *    HL( 551) /0.1003900000E+04/
     *    EQLAT( 551) /0.6215698661E+00/
     *    EQLON( 551) /0.2108968253E+01/
     *    SSLIP( 551) /-.1500000000E-01/
     *    DSLIP( 551) /-.2000000000E-01/
     *    DIP( 551) /0.9197885158E+00/
     *    DEPTH( 551) /0.9546100000E+04/
     *    WIDTH( 551) /0.2079100000E+04/
      DATA STRIKE( 552) /0.2038544566E+01/
     *    HL( 552) /0.1004400000E+04/
     *    EQLAT( 552) /0.6214272727E+00/
     *    EQLON( 552) /0.2108622677E+01/
     *    SSLIP( 552) /-.3500000000E-01/
     *    DSLIP( 552) /-.4000000000E-01/
     *    DIP( 552) /0.9197885158E+00/
     *    DEPTH( 552) /0.9546100000E+04/
     *    WIDTH( 552) /0.2079100000E+04/
      DATA STRIKE( 553) /0.2038544566E+01/
     *    HL( 553) /0.1004100000E+04/
     *    EQLAT( 553) /0.6212846793E+00/
     *    EQLON( 553) /0.2108276928E+01/
     *    SSLIP( 553) /-.4500000000E-01/
     *    DSLIP( 553) /-.4000000000E-01/
     *    DIP( 553) /0.9197885158E+00/
     *    DEPTH( 553) /0.9546100000E+04/
     *    WIDTH( 553) /0.2079100000E+04/
      DATA STRIKE( 554) /0.2038544566E+01/
     *    HL( 554) /0.1004200000E+04/
     *    EQLAT( 554) /0.6211422604E+00/
     *    EQLON( 554) /0.2107931352E+01/
     *    SSLIP( 554) /-.4100000000E-01/
     *    DSLIP( 554) /-.4000000000E-01/
     *    DIP( 554) /0.9197885158E+00/
     *    DEPTH( 554) /0.9546100000E+04/
     *    WIDTH( 554) /0.2079100000E+04/
      DATA STRIKE( 555) /0.2038544566E+01/
     *    HL( 555) /0.1004700000E+04/
     *    EQLAT( 555) /0.6209996670E+00/
     *    EQLON( 555) /0.2107585777E+01/
     *    SSLIP( 555) /-.2500000000E-01/
     *    DSLIP( 555) /-.2000000000E-01/
     *    DIP( 555) /0.9197885158E+00/
     *    DEPTH( 555) /0.9546100000E+04/
     *    WIDTH( 555) /0.2079100000E+04/
      DATA STRIKE( 556) /0.2038544566E+01/
     *    HL( 556) /0.1002800000E+04/
     *    EQLAT( 556) /0.6238780640E+00/
     *    EQLON( 556) /0.2114046986E+01/
     *    SSLIP( 556) /0.7000000000E-02/
     *    DSLIP( 556) /-.1000000000E-01/
     *    DIP( 556) /0.9197885158E+00/
     *    DEPTH( 556) /0.1113710000E+05/
     *    WIDTH( 556) /0.2079100000E+04/
      DATA STRIKE( 557) /0.2038544566E+01/
     *    HL( 557) /0.1002500000E+04/
     *    EQLAT( 557) /0.6237354706E+00/
     *    EQLON( 557) /0.2113701236E+01/
     *    SSLIP( 557) /0.1000000000E-02/
     *    DSLIP( 557) /0.0000000000E+00/
     *    DIP( 557) /0.9197885158E+00/
     *    DEPTH( 557) /0.1113710000E+05/
     *    WIDTH( 557) /0.2079100000E+04/
      DATA STRIKE( 558) /0.2038544566E+01/
     *    HL( 558) /0.1002600000E+04/
     *    EQLAT( 558) /0.6235928772E+00/
     *    EQLON( 558) /0.2113355661E+01/
     *    SSLIP( 558) /0.0000000000E+00/
     *    DSLIP( 558) /0.0000000000E+00/
     *    DIP( 558) /0.9197885158E+00/
     *    DEPTH( 558) /0.1113710000E+05/
     *    WIDTH( 558) /0.2079100000E+04/
      DATA STRIKE( 559) /0.2038544566E+01/
     *    HL( 559) /0.1003100000E+04/
     *    EQLAT( 559) /0.6234502838E+00/
     *    EQLON( 559) /0.2113010086E+01/
     *    SSLIP( 559) /0.0000000000E+00/
     *    DSLIP( 559) /0.0000000000E+00/
     *    DIP( 559) /0.9197885158E+00/
     *    DEPTH( 559) /0.1113710000E+05/
     *    WIDTH( 559) /0.2079100000E+04/
      DATA STRIKE( 560) /0.2038544566E+01/
     *    HL( 560) /0.1002800000E+04/
     *    EQLAT( 560) /0.6233076904E+00/
     *    EQLON( 560) /0.2112664336E+01/
     *    SSLIP( 560) /0.0000000000E+00/
     *    DSLIP( 560) /0.0000000000E+00/
     *    DIP( 560) /0.9197885158E+00/
     *    DEPTH( 560) /0.1113710000E+05/
     *    WIDTH( 560) /0.2079100000E+04/
      DATA STRIKE( 561) /0.2038544566E+01/
     *    HL( 561) /0.1003300000E+04/
     *    EQLAT( 561) /0.6231650970E+00/
     *    EQLON( 561) /0.2112318761E+01/
     *    SSLIP( 561) /0.0000000000E+00/
     *    DSLIP( 561) /0.0000000000E+00/
     *    DIP( 561) /0.9197885158E+00/
     *    DEPTH( 561) /0.1113710000E+05/
     *    WIDTH( 561) /0.2079100000E+04/
      DATA STRIKE( 562) /0.2038544566E+01/
     *    HL( 562) /0.1002900000E+04/
     *    EQLAT( 562) /0.6230225036E+00/
     *    EQLON( 562) /0.2111973011E+01/
     *    SSLIP( 562) /0.0000000000E+00/
     *    DSLIP( 562) /0.0000000000E+00/
     *    DIP( 562) /0.9197885158E+00/
     *    DEPTH( 562) /0.1113710000E+05/
     *    WIDTH( 562) /0.2079100000E+04/
      DATA STRIKE( 563) /0.2038544566E+01/
     *    HL( 563) /0.1003000000E+04/
     *    EQLAT( 563) /0.6228799102E+00/
     *    EQLON( 563) /0.2111627436E+01/
     *    SSLIP( 563) /0.0000000000E+00/
     *    DSLIP( 563) /0.0000000000E+00/
     *    DIP( 563) /0.9197885158E+00/
     *    DEPTH( 563) /0.1113710000E+05/
     *    WIDTH( 563) /0.2079100000E+04/
      DATA STRIKE( 564) /0.2038544566E+01/
     *    HL( 564) /0.1003500000E+04/
     *    EQLAT( 564) /0.6227373168E+00/
     *    EQLON( 564) /0.2111281861E+01/
     *    SSLIP( 564) /0.0000000000E+00/
     *    DSLIP( 564) /0.0000000000E+00/
     *    DIP( 564) /0.9197885158E+00/
     *    DEPTH( 564) /0.1113710000E+05/
     *    WIDTH( 564) /0.2079100000E+04/
      DATA STRIKE( 565) /0.2038544566E+01/
     *    HL( 565) /0.1003200000E+04/
     *    EQLAT( 565) /0.6225947234E+00/
     *    EQLON( 565) /0.2110936111E+01/
     *    SSLIP( 565) /0.0000000000E+00/
     *    DSLIP( 565) /0.0000000000E+00/
     *    DIP( 565) /0.9197885158E+00/
     *    DEPTH( 565) /0.1113710000E+05/
     *    WIDTH( 565) /0.2079100000E+04/
      DATA STRIKE( 566) /0.2038544566E+01/
     *    HL( 566) /0.1003300000E+04/
     *    EQLAT( 566) /0.6224521300E+00/
     *    EQLON( 566) /0.2110590536E+01/
     *    SSLIP( 566) /0.0000000000E+00/
     *    DSLIP( 566) /0.0000000000E+00/
     *    DIP( 566) /0.9197885158E+00/
     *    DEPTH( 566) /0.1113710000E+05/
     *    WIDTH( 566) /0.2079100000E+04/
      DATA STRIKE( 567) /0.2038544566E+01/
     *    HL( 567) /0.1003700000E+04/
     *    EQLAT( 567) /0.6223097112E+00/
     *    EQLON( 567) /0.2110244961E+01/
     *    SSLIP( 567) /0.0000000000E+00/
     *    DSLIP( 567) /0.0000000000E+00/
     *    DIP( 567) /0.9197885158E+00/
     *    DEPTH( 567) /0.1113710000E+05/
     *    WIDTH( 567) /0.2079100000E+04/
      DATA STRIKE( 568) /0.2038544566E+01/
     *    HL( 568) /0.1003500000E+04/
     *    EQLAT( 568) /0.6221671178E+00/
     *    EQLON( 568) /0.2109899211E+01/
     *    SSLIP( 568) /0.0000000000E+00/
     *    DSLIP( 568) /0.0000000000E+00/
     *    DIP( 568) /0.9197885158E+00/
     *    DEPTH( 568) /0.1113710000E+05/
     *    WIDTH( 568) /0.2079100000E+04/
      DATA STRIKE( 569) /0.2038544566E+01/
     *    HL( 569) /0.1003900000E+04/
     *    EQLAT( 569) /0.6220245244E+00/
     *    EQLON( 569) /0.2109553636E+01/
     *    SSLIP( 569) /0.0000000000E+00/
     *    DSLIP( 569) /0.0000000000E+00/
     *    DIP( 569) /0.9197885158E+00/
     *    DEPTH( 569) /0.1113710000E+05/
     *    WIDTH( 569) /0.2079100000E+04/
      DATA STRIKE( 570) /0.2038544566E+01/
     *    HL( 570) /0.1003600000E+04/
     *    EQLAT( 570) /0.6218819310E+00/
     *    EQLON( 570) /0.2109207886E+01/
     *    SSLIP( 570) /-.6000000000E-02/
     *    DSLIP( 570) /-.1000000000E-01/
     *    DIP( 570) /0.9197885158E+00/
     *    DEPTH( 570) /0.1113710000E+05/
     *    WIDTH( 570) /0.2079100000E+04/
      DATA STRIKE( 571) /0.2038544566E+01/
     *    HL( 571) /0.1003700000E+04/
     *    EQLAT( 571) /0.6217393376E+00/
     *    EQLON( 571) /0.2108862311E+01/
     *    SSLIP( 571) /-.4500000000E-01/
     *    DSLIP( 571) /-.5000000000E-01/
     *    DIP( 571) /0.9197885158E+00/
     *    DEPTH( 571) /0.1113710000E+05/
     *    WIDTH( 571) /0.2079100000E+04/
      DATA STRIKE( 572) /0.2038544566E+01/
     *    HL( 572) /0.1004200000E+04/
     *    EQLAT( 572) /0.6215967442E+00/
     *    EQLON( 572) /0.2108516736E+01/
     *    SSLIP( 572) /-.9500000000E-01/
     *    DSLIP( 572) /-.9000000000E-01/
     *    DIP( 572) /0.9197885158E+00/
     *    DEPTH( 572) /0.1113710000E+05/
     *    WIDTH( 572) /0.2079100000E+04/
      DATA STRIKE( 573) /0.2038544566E+01/
     *    HL( 573) /0.1003800000E+04/
     *    EQLAT( 573) /0.6214541508E+00/
     *    EQLON( 573) /0.2108170986E+01/
     *    SSLIP( 573) /-.1270000000E+00/
     *    DSLIP( 573) /-.1300000000E+00/
     *    DIP( 573) /0.9197885158E+00/
     *    DEPTH( 573) /0.1113710000E+05/
     *    WIDTH( 573) /0.2079100000E+04/
      DATA STRIKE( 574) /0.2038544566E+01/
     *    HL( 574) /0.1003900000E+04/
     *    EQLAT( 574) /0.6213115574E+00/
     *    EQLON( 574) /0.2107825411E+01/
     *    SSLIP( 574) /-.1260000000E+00/
     *    DSLIP( 574) /-.1300000000E+00/
     *    DIP( 574) /0.9197885158E+00/
     *    DEPTH( 574) /0.1113710000E+05/
     *    WIDTH( 574) /0.2079100000E+04/
      DATA STRIKE( 575) /0.2038544566E+01/
     *    HL( 575) /0.1004400000E+04/
     *    EQLAT( 575) /0.6211689640E+00/
     *    EQLON( 575) /0.2107479836E+01/
     *    SSLIP( 575) /-.8400000000E-01/
     *    DSLIP( 575) /-.8000000000E-01/
     *    DIP( 575) /0.9197885158E+00/
     *    DEPTH( 575) /0.1113710000E+05/
     *    WIDTH( 575) /0.2079100000E+04/
      DATA STRIKE( 576) /0.2038544566E+01/
     *    HL( 576) /0.1002200000E+04/
     *    EQLAT( 576) /0.6240473610E+00/
     *    EQLON( 576) /0.2113940870E+01/
     *    SSLIP( 576) /0.1000000000E-02/
     *    DSLIP( 576) /0.0000000000E+00/
     *    DIP( 576) /0.9197885158E+00/
     *    DEPTH( 576) /0.1272810000E+05/
     *    WIDTH( 576) /0.2079100000E+04/
      DATA STRIKE( 577) /0.2038544566E+01/
     *    HL( 577) /0.1002300000E+04/
     *    EQLAT( 577) /0.6239047676E+00/
     *    EQLON( 577) /0.2113595295E+01/
     *    SSLIP( 577) /0.0000000000E+00/
     *    DSLIP( 577) /0.0000000000E+00/
     *    DIP( 577) /0.9197885158E+00/
     *    DEPTH( 577) /0.1272810000E+05/
     *    WIDTH( 577) /0.2079100000E+04/
      DATA STRIKE( 578) /0.2038544566E+01/
     *    HL( 578) /0.1002800000E+04/
     *    EQLAT( 578) /0.6237621742E+00/
     *    EQLON( 578) /0.2113249720E+01/
     *    SSLIP( 578) /0.0000000000E+00/
     *    DSLIP( 578) /0.0000000000E+00/
     *    DIP( 578) /0.9197885158E+00/
     *    DEPTH( 578) /0.1272810000E+05/
     *    WIDTH( 578) /0.2079100000E+04/
      DATA STRIKE( 579) /0.2038544566E+01/
     *    HL( 579) /0.1002400000E+04/
     *    EQLAT( 579) /0.6236195808E+00/
     *    EQLON( 579) /0.2112903970E+01/
     *    SSLIP( 579) /0.0000000000E+00/
     *    DSLIP( 579) /0.0000000000E+00/
     *    DIP( 579) /0.9197885158E+00/
     *    DEPTH( 579) /0.1272810000E+05/
     *    WIDTH( 579) /0.2079100000E+04/
      DATA STRIKE( 580) /0.2038544566E+01/
     *    HL( 580) /0.1002500000E+04/
     *    EQLAT( 580) /0.6234771619E+00/
     *    EQLON( 580) /0.2112558395E+01/
     *    SSLIP( 580) /0.0000000000E+00/
     *    DSLIP( 580) /0.0000000000E+00/
     *    DIP( 580) /0.9197885158E+00/
     *    DEPTH( 580) /0.1272810000E+05/
     *    WIDTH( 580) /0.2079100000E+04/
      DATA STRIKE( 581) /0.2038544566E+01/
     *    HL( 581) /0.1003000000E+04/
     *    EQLAT( 581) /0.6233345685E+00/
     *    EQLON( 581) /0.2112212820E+01/
     *    SSLIP( 581) /0.0000000000E+00/
     *    DSLIP( 581) /0.0000000000E+00/
     *    DIP( 581) /0.9197885158E+00/
     *    DEPTH( 581) /0.1272810000E+05/
     *    WIDTH( 581) /0.2079100000E+04/
      DATA STRIKE( 582) /0.2038544566E+01/
     *    HL( 582) /0.1002700000E+04/
     *    EQLAT( 582) /0.6231919751E+00/
     *    EQLON( 582) /0.2111867070E+01/
     *    SSLIP( 582) /0.0000000000E+00/
     *    DSLIP( 582) /0.0000000000E+00/
     *    DIP( 582) /0.9197885158E+00/
     *    DEPTH( 582) /0.1272810000E+05/
     *    WIDTH( 582) /0.2079100000E+04/
      DATA STRIKE( 583) /0.2038544566E+01/
     *    HL( 583) /0.1002800000E+04/
     *    EQLAT( 583) /0.6230493817E+00/
     *    EQLON( 583) /0.2111521495E+01/
     *    SSLIP( 583) /0.0000000000E+00/
     *    DSLIP( 583) /0.0000000000E+00/
     *    DIP( 583) /0.9197885158E+00/
     *    DEPTH( 583) /0.1272810000E+05/
     *    WIDTH( 583) /0.2079100000E+04/
      DATA STRIKE( 584) /0.2038544566E+01/
     *    HL( 584) /0.1003300000E+04/
     *    EQLAT( 584) /0.6229067883E+00/
     *    EQLON( 584) /0.2111175920E+01/
     *    SSLIP( 584) /0.0000000000E+00/
     *    DSLIP( 584) /0.0000000000E+00/
     *    DIP( 584) /0.9197885158E+00/
     *    DEPTH( 584) /0.1272810000E+05/
     *    WIDTH( 584) /0.2079100000E+04/
      DATA STRIKE( 585) /0.2038544566E+01/
     *    HL( 585) /0.1002900000E+04/
     *    EQLAT( 585) /0.6227641949E+00/
     *    EQLON( 585) /0.2110830170E+01/
     *    SSLIP( 585) /0.0000000000E+00/
     *    DSLIP( 585) /0.0000000000E+00/
     *    DIP( 585) /0.9197885158E+00/
     *    DEPTH( 585) /0.1272810000E+05/
     *    WIDTH( 585) /0.2079100000E+04/
      DATA STRIKE( 586) /0.2038544566E+01/
     *    HL( 586) /0.1003400000E+04/
     *    EQLAT( 586) /0.6226216015E+00/
     *    EQLON( 586) /0.2110484595E+01/
     *    SSLIP( 586) /0.0000000000E+00/
     *    DSLIP( 586) /0.0000000000E+00/
     *    DIP( 586) /0.9197885158E+00/
     *    DEPTH( 586) /0.1272810000E+05/
     *    WIDTH( 586) /0.2079100000E+04/
      DATA STRIKE( 587) /0.2038544566E+01/
     *    HL( 587) /0.1003100000E+04/
     *    EQLAT( 587) /0.6224790081E+00/
     *    EQLON( 587) /0.2110138845E+01/
     *    SSLIP( 587) /0.0000000000E+00/
     *    DSLIP( 587) /0.0000000000E+00/
     *    DIP( 587) /0.9197885158E+00/
     *    DEPTH( 587) /0.1272810000E+05/
     *    WIDTH( 587) /0.2079100000E+04/
      DATA STRIKE( 588) /0.2038544566E+01/
     *    HL( 588) /0.1003200000E+04/
     *    EQLAT( 588) /0.6223364147E+00/
     *    EQLON( 588) /0.2109793270E+01/
     *    SSLIP( 588) /0.0000000000E+00/
     *    DSLIP( 588) /0.0000000000E+00/
     *    DIP( 588) /0.9197885158E+00/
     *    DEPTH( 588) /0.1272810000E+05/
     *    WIDTH( 588) /0.2079100000E+04/
      DATA STRIKE( 589) /0.2038544566E+01/
     *    HL( 589) /0.1003700000E+04/
     *    EQLAT( 589) /0.6221938213E+00/
     *    EQLON( 589) /0.2109447695E+01/
     *    SSLIP( 589) /0.0000000000E+00/
     *    DSLIP( 589) /0.0000000000E+00/
     *    DIP( 589) /0.9197885158E+00/
     *    DEPTH( 589) /0.1272810000E+05/
     *    WIDTH( 589) /0.2079100000E+04/
      DATA STRIKE( 590) /0.2038544566E+01/
     *    HL( 590) /0.1003300000E+04/
     *    EQLAT( 590) /0.6220512279E+00/
     *    EQLON( 590) /0.2109101945E+01/
     *    SSLIP( 590) /-.7000000000E-02/
     *    DSLIP( 590) /-.1000000000E-01/
     *    DIP( 590) /0.9197885158E+00/
     *    DEPTH( 590) /0.1272810000E+05/
     *    WIDTH( 590) /0.2079100000E+04/
      DATA STRIKE( 591) /0.2038544566E+01/
     *    HL( 591) /0.1003400000E+04/
     *    EQLAT( 591) /0.6219086345E+00/
     *    EQLON( 591) /0.2108756370E+01/
     *    SSLIP( 591) /-.5700000000E-01/
     *    DSLIP( 591) /-.6000000000E-01/
     *    DIP( 591) /0.9197885158E+00/
     *    DEPTH( 591) /0.1272810000E+05/
     *    WIDTH( 591) /0.2079100000E+04/
      DATA STRIKE( 592) /0.2038544566E+01/
     *    HL( 592) /0.1003900000E+04/
     *    EQLAT( 592) /0.6217662156E+00/
     *    EQLON( 592) /0.2108410794E+01/
     *    SSLIP( 592) /-.1230000000E+00/
     *    DSLIP( 592) /-.1200000000E+00/
     *    DIP( 592) /0.9197885158E+00/
     *    DEPTH( 592) /0.1272810000E+05/
     *    WIDTH( 592) /0.2079100000E+04/
      DATA STRIKE( 593) /0.2038544566E+01/
     *    HL( 593) /0.1003600000E+04/
     *    EQLAT( 593) /0.6216236222E+00/
     *    EQLON( 593) /0.2108065045E+01/
     *    SSLIP( 593) /-.1700000000E+00/
     *    DSLIP( 593) /-.1700000000E+00/
     *    DIP( 593) /0.9197885158E+00/
     *    DEPTH( 593) /0.1272810000E+05/
     *    WIDTH( 593) /0.2079100000E+04/
      DATA STRIKE( 594) /0.2038544566E+01/
     *    HL( 594) /0.1004100000E+04/
     *    EQLAT( 594) /0.6214810288E+00/
     *    EQLON( 594) /0.2107719470E+01/
     *    SSLIP( 594) /-.1750000000E+00/
     *    DSLIP( 594) /-.1700000000E+00/
     *    DIP( 594) /0.9197885158E+00/
     *    DEPTH( 594) /0.1272810000E+05/
     *    WIDTH( 594) /0.2079100000E+04/
      DATA STRIKE( 595) /0.2038544566E+01/
     *    HL( 595) /0.1003700000E+04/
     *    EQLAT( 595) /0.6213384354E+00/
     *    EQLON( 595) /0.2107373720E+01/
     *    SSLIP( 595) /-.1200000000E+00/
     *    DSLIP( 595) /-.1200000000E+00/
     *    DIP( 595) /0.9197885158E+00/
     *    DEPTH( 595) /0.1272810000E+05/
     *    WIDTH( 595) /0.2079100000E+04/
      DATA STRIKE( 596) /0.2038544566E+01/
     *    HL( 596) /0.1001900000E+04/
     *    EQLAT( 596) /0.6242168324E+00/
     *    EQLON( 596) /0.2113834929E+01/
     *    SSLIP( 596) /0.0000000000E+00/
     *    DSLIP( 596) /0.0000000000E+00/
     *    DIP( 596) /0.9197885158E+00/
     *    DEPTH( 596) /0.1431910000E+05/
     *    WIDTH( 596) /0.2079100000E+04/
      DATA STRIKE( 597) /0.2038544566E+01/
     *    HL( 597) /0.1002000000E+04/
     *    EQLAT( 597) /0.6240742390E+00/
     *    EQLON( 597) /0.2113489353E+01/
     *    SSLIP( 597) /0.0000000000E+00/
     *    DSLIP( 597) /0.0000000000E+00/
     *    DIP( 597) /0.9197885158E+00/
     *    DEPTH( 597) /0.1431910000E+05/
     *    WIDTH( 597) /0.2079100000E+04/
      DATA STRIKE( 598) /0.2038544566E+01/
     *    HL( 598) /0.1002500000E+04/
     *    EQLAT( 598) /0.6239316456E+00/
     *    EQLON( 598) /0.2113143778E+01/
     *    SSLIP( 598) /0.0000000000E+00/
     *    DSLIP( 598) /0.0000000000E+00/
     *    DIP( 598) /0.9197885158E+00/
     *    DEPTH( 598) /0.1431910000E+05/
     *    WIDTH( 598) /0.2079100000E+04/
      DATA STRIKE( 599) /0.2038544566E+01/
     *    HL( 599) /0.1002200000E+04/
     *    EQLAT( 599) /0.6237890522E+00/
     *    EQLON( 599) /0.2112798029E+01/
     *    SSLIP( 599) /0.0000000000E+00/
     *    DSLIP( 599) /0.0000000000E+00/
     *    DIP( 599) /0.9197885158E+00/
     *    DEPTH( 599) /0.1431910000E+05/
     *    WIDTH( 599) /0.2079100000E+04/
      DATA STRIKE( 600) /0.2038544566E+01/
     *    HL( 600) /0.1002700000E+04/
     *    EQLAT( 600) /0.6236464588E+00/
     *    EQLON( 600) /0.2112452453E+01/
     *    SSLIP( 600) /0.0000000000E+00/
     *    DSLIP( 600) /0.0000000000E+00/
     *    DIP( 600) /0.9197885158E+00/
     *    DEPTH( 600) /0.1431910000E+05/
     *    WIDTH( 600) /0.2079100000E+04/
      DATA STRIKE( 601) /0.2038544566E+01/
     *    HL( 601) /0.1002400000E+04/
     *    EQLAT( 601) /0.6235038654E+00/
     *    EQLON( 601) /0.2112106704E+01/
     *    SSLIP( 601) /0.0000000000E+00/
     *    DSLIP( 601) /0.0000000000E+00/
     *    DIP( 601) /0.9197885158E+00/
     *    DEPTH( 601) /0.1431910000E+05/
     *    WIDTH( 601) /0.2079100000E+04/
      DATA STRIKE( 602) /0.2038544566E+01/
     *    HL( 602) /0.1002400000E+04/
     *    EQLAT( 602) /0.6233612720E+00/
     *    EQLON( 602) /0.2111761128E+01/
     *    SSLIP( 602) /0.0000000000E+00/
     *    DSLIP( 602) /0.0000000000E+00/
     *    DIP( 602) /0.9197885158E+00/
     *    DEPTH( 602) /0.1431910000E+05/
     *    WIDTH( 602) /0.2079100000E+04/
      DATA STRIKE( 603) /0.2038544566E+01/
     *    HL( 603) /0.1002900000E+04/
     *    EQLAT( 603) /0.6232186786E+00/
     *    EQLON( 603) /0.2111415553E+01/
     *    SSLIP( 603) /0.0000000000E+00/
     *    DSLIP( 603) /0.0000000000E+00/
     *    DIP( 603) /0.9197885158E+00/
     *    DEPTH( 603) /0.1431910000E+05/
     *    WIDTH( 603) /0.2079100000E+04/
      DATA STRIKE( 604) /0.2038544566E+01/
     *    HL( 604) /0.1002600000E+04/
     *    EQLAT( 604) /0.6230760852E+00/
     *    EQLON( 604) /0.2111069804E+01/
     *    SSLIP( 604) /0.0000000000E+00/
     *    DSLIP( 604) /0.0000000000E+00/
     *    DIP( 604) /0.9197885158E+00/
     *    DEPTH( 604) /0.1431910000E+05/
     *    WIDTH( 604) /0.2079100000E+04/
      DATA STRIKE( 605) /0.2038544566E+01/
     *    HL( 605) /0.1002700000E+04/
     *    EQLAT( 605) /0.6229336664E+00/
     *    EQLON( 605) /0.2110724228E+01/
     *    SSLIP( 605) /0.0000000000E+00/
     *    DSLIP( 605) /0.0000000000E+00/
     *    DIP( 605) /0.9197885158E+00/
     *    DEPTH( 605) /0.1431910000E+05/
     *    WIDTH( 605) /0.2079100000E+04/
      DATA STRIKE( 606) /0.2038544566E+01/
     *    HL( 606) /0.1003200000E+04/
     *    EQLAT( 606) /0.6227910730E+00/
     *    EQLON( 606) /0.2110378653E+01/
     *    SSLIP( 606) /0.0000000000E+00/
     *    DSLIP( 606) /0.0000000000E+00/
     *    DIP( 606) /0.9197885158E+00/
     *    DEPTH( 606) /0.1431910000E+05/
     *    WIDTH( 606) /0.2079100000E+04/
      DATA STRIKE( 607) /0.2038544566E+01/
     *    HL( 607) /0.1002800000E+04/
     *    EQLAT( 607) /0.6226484796E+00/
     *    EQLON( 607) /0.2110032903E+01/
     *    SSLIP( 607) /0.0000000000E+00/
     *    DSLIP( 607) /0.0000000000E+00/
     *    DIP( 607) /0.9197885158E+00/
     *    DEPTH( 607) /0.1431910000E+05/
     *    WIDTH( 607) /0.2079100000E+04/
      DATA STRIKE( 608) /0.2038544566E+01/
     *    HL( 608) /0.1002900000E+04/
     *    EQLAT( 608) /0.6225058862E+00/
     *    EQLON( 608) /0.2109687328E+01/
     *    SSLIP( 608) /0.0000000000E+00/
     *    DSLIP( 608) /0.0000000000E+00/
     *    DIP( 608) /0.9197885158E+00/
     *    DEPTH( 608) /0.1431910000E+05/
     *    WIDTH( 608) /0.2079100000E+04/
      DATA STRIKE( 609) /0.2038544566E+01/
     *    HL( 609) /0.1003400000E+04/
     *    EQLAT( 609) /0.6223632928E+00/
     *    EQLON( 609) /0.2109341753E+01/
     *    SSLIP( 609) /0.0000000000E+00/
     *    DSLIP( 609) /0.0000000000E+00/
     *    DIP( 609) /0.9197885158E+00/
     *    DEPTH( 609) /0.1431910000E+05/
     *    WIDTH( 609) /0.2079100000E+04/
      DATA STRIKE( 610) /0.2038544566E+01/
     *    HL( 610) /0.1003100000E+04/
     *    EQLAT( 610) /0.6222206994E+00/
     *    EQLON( 610) /0.2108996003E+01/
     *    SSLIP( 610) /-.1000000000E-02/
     *    DSLIP( 610) /0.0000000000E+00/
     *    DIP( 610) /0.9197885158E+00/
     *    DEPTH( 610) /0.1431910000E+05/
     *    WIDTH( 610) /0.2079100000E+04/
      DATA STRIKE( 611) /0.2038544566E+01/
     *    HL( 611) /0.1003600000E+04/
     *    EQLAT( 611) /0.6220781060E+00/
     *    EQLON( 611) /0.2108650428E+01/
     *    SSLIP( 611) /-.3700000000E-01/
     *    DSLIP( 611) /-.4000000000E-01/
     *    DIP( 611) /0.9197885158E+00/
     *    DEPTH( 611) /0.1431910000E+05/
     *    WIDTH( 611) /0.2079100000E+04/
      DATA STRIKE( 612) /0.2038544566E+01/
     *    HL( 612) /0.1003200000E+04/
     *    EQLAT( 612) /0.6219355126E+00/
     *    EQLON( 612) /0.2108304678E+01/
     *    SSLIP( 612) /-.8600000000E-01/
     *    DSLIP( 612) /-.9000000000E-01/
     *    DIP( 612) /0.9197885158E+00/
     *    DEPTH( 612) /0.1431910000E+05/
     *    WIDTH( 612) /0.2079100000E+04/
      DATA STRIKE( 613) /0.2038544566E+01/
     *    HL( 613) /0.1003300000E+04/
     *    EQLAT( 613) /0.6217929192E+00/
     *    EQLON( 613) /0.2107959103E+01/
     *    SSLIP( 613) /-.1240000000E+00/
     *    DSLIP( 613) /-.1200000000E+00/
     *    DIP( 613) /0.9197885158E+00/
     *    DEPTH( 613) /0.1431910000E+05/
     *    WIDTH( 613) /0.2079100000E+04/
      DATA STRIKE( 614) /0.2038544566E+01/
     *    HL( 614) /0.1003800000E+04/
     *    EQLAT( 614) /0.6216503258E+00/
     *    EQLON( 614) /0.2107613528E+01/
     *    SSLIP( 614) /-.1310000000E+00/
     *    DSLIP( 614) /-.1300000000E+00/
     *    DIP( 614) /0.9197885158E+00/
     *    DEPTH( 614) /0.1431910000E+05/
     *    WIDTH( 614) /0.2079100000E+04/
      DATA STRIKE( 615) /0.2038544566E+01/
     *    HL( 615) /0.1003500000E+04/
     *    EQLAT( 615) /0.6215077324E+00/
     *    EQLON( 615) /0.2107267778E+01/
     *    SSLIP( 615) /-.9200000000E-01/
     *    DSLIP( 615) /-.9000000000E-01/
     *    DIP( 615) /0.9197885158E+00/
     *    DEPTH( 615) /0.1431910000E+05/
     *    WIDTH( 615) /0.2079100000E+04/
      DATA EQLATR( 28)  /0.6250896716E+00/
     *   EQLONR( 28)  /0.2100922634E+01/
     *   EQRAD( 28)   /0.2000000000E+06/
     *   ITEQK( 28)   /    76760640/
     *   NLOC( 28)    / 616/
     *   NFP( 28)     / 300/
      DATA STRIKE( 616) /0.2424262331E+01/
     *    HL( 616) /0.1000000000E+04/
     *    EQLAT( 616) /0.6240597528E+00/
     *    EQLON( 616) /0.2099508917E+01/
     *    SSLIP( 616) /0.1400000000E-01/
     *    DSLIP( 616) /0.0000000000E+00/
     *    DIP( 616) /0.1570796327E+01/
     *    DEPTH( 616) /0.0000000000E+00/
     *    WIDTH( 616) /0.1000000000E+04/
      DATA STRIKE( 617) /0.2426007660E+01/
     *    HL( 617) /0.1000000000E+04/
     *    EQLAT( 617) /0.6242967685E+00/
     *    EQLON( 617) /0.2099762164E+01/
     *    SSLIP( 617) /0.2700000000E-01/
     *    DSLIP( 617) /0.0000000000E+00/
     *    DIP( 617) /0.1570796327E+01/
     *    DEPTH( 617) /0.0000000000E+00/
     *    WIDTH( 617) /0.1000000000E+04/
      DATA STRIKE( 618) /0.2426007660E+01/
     *    HL( 618) /0.1000000000E+04/
     *    EQLAT( 618) /0.6245337842E+00/
     *    EQLON( 618) /0.2100015412E+01/
     *    SSLIP( 618) /0.7000000000E-02/
     *    DSLIP( 618) /0.0000000000E+00/
     *    DIP( 618) /0.1570796327E+01/
     *    DEPTH( 618) /0.0000000000E+00/
     *    WIDTH( 618) /0.1000000000E+04/
      DATA STRIKE( 619) /0.2426007660E+01/
     *    HL( 619) /0.1000000000E+04/
     *    EQLAT( 619) /0.6247707999E+00/
     *    EQLON( 619) /0.2100268484E+01/
     *    SSLIP( 619) /0.5300000000E-01/
     *    DSLIP( 619) /0.0000000000E+00/
     *    DIP( 619) /0.1570796327E+01/
     *    DEPTH( 619) /0.0000000000E+00/
     *    WIDTH( 619) /0.1000000000E+04/
      DATA STRIKE( 620) /0.2426007660E+01/
     *    HL( 620) /0.1000000000E+04/
     *    EQLAT( 620) /0.6250079902E+00/
     *    EQLON( 620) /0.2100521732E+01/
     *    SSLIP( 620) /0.6500000000E-01/
     *    DSLIP( 620) /0.0000000000E+00/
     *    DIP( 620) /0.1570796327E+01/
     *    DEPTH( 620) /0.0000000000E+00/
     *    WIDTH( 620) /0.1000000000E+04/
      DATA STRIKE( 621) /0.2426007660E+01/
     *    HL( 621) /0.1000000000E+04/
     *    EQLAT( 621) /0.6252450059E+00/
     *    EQLON( 621) /0.2100774979E+01/
     *    SSLIP( 621) /0.1120000000E+00/
     *    DSLIP( 621) /0.0000000000E+00/
     *    DIP( 621) /0.1570796327E+01/
     *    DEPTH( 621) /0.0000000000E+00/
     *    WIDTH( 621) /0.1000000000E+04/
      DATA STRIKE( 622) /0.2426007660E+01/
     *    HL( 622) /0.1000000000E+04/
     *    EQLAT( 622) /0.6254820216E+00/
     *    EQLON( 622) /0.2101028226E+01/
     *    SSLIP( 622) /0.1200000000E+00/
     *    DSLIP( 622) /0.0000000000E+00/
     *    DIP( 622) /0.1570796327E+01/
     *    DEPTH( 622) /0.0000000000E+00/
     *    WIDTH( 622) /0.1000000000E+04/
      DATA STRIKE( 623) /0.2426007660E+01/
     *    HL( 623) /0.1000000000E+04/
     *    EQLAT( 623) /0.6257190373E+00/
     *    EQLON( 623) /0.2101281473E+01/
     *    SSLIP( 623) /0.1780000000E+00/
     *    DSLIP( 623) /0.0000000000E+00/
     *    DIP( 623) /0.1570796327E+01/
     *    DEPTH( 623) /0.0000000000E+00/
     *    WIDTH( 623) /0.1000000000E+04/
      DATA STRIKE( 624) /0.2426007660E+01/
     *    HL( 624) /0.1000000000E+04/
     *    EQLAT( 624) /0.6259560530E+00/
     *    EQLON( 624) /0.2101534721E+01/
     *    SSLIP( 624) /0.1970000000E+00/
     *    DSLIP( 624) /0.0000000000E+00/
     *    DIP( 624) /0.1570796327E+01/
     *    DEPTH( 624) /0.0000000000E+00/
     *    WIDTH( 624) /0.1000000000E+04/
      DATA STRIKE( 625) /0.2426007660E+01/
     *    HL( 625) /0.1000000000E+04/
     *    EQLAT( 625) /0.6261930688E+00/
     *    EQLON( 625) /0.2101787968E+01/
     *    SSLIP( 625) /0.2210000000E+00/
     *    DSLIP( 625) /0.0000000000E+00/
     *    DIP( 625) /0.1570796327E+01/
     *    DEPTH( 625) /0.0000000000E+00/
     *    WIDTH( 625) /0.1000000000E+04/
      DATA STRIKE( 626) /0.2426007660E+01/
     *    HL( 626) /0.1000000000E+04/
     *    EQLAT( 626) /0.6264302590E+00/
     *    EQLON( 626) /0.2102041215E+01/
     *    SSLIP( 626) /0.9500000000E-01/
     *    DSLIP( 626) /0.0000000000E+00/
     *    DIP( 626) /0.1570796327E+01/
     *    DEPTH( 626) /0.0000000000E+00/
     *    WIDTH( 626) /0.1000000000E+04/
      DATA STRIKE( 627) /0.2426007660E+01/
     *    HL( 627) /0.1000000000E+04/
     *    EQLAT( 627) /0.6266672747E+00/
     *    EQLON( 627) /0.2102294463E+01/
     *    SSLIP( 627) /0.2870000000E+00/
     *    DSLIP( 627) /0.0000000000E+00/
     *    DIP( 627) /0.1570796327E+01/
     *    DEPTH( 627) /0.0000000000E+00/
     *    WIDTH( 627) /0.1000000000E+04/
      DATA STRIKE( 628) /0.2426007660E+01/
     *    HL( 628) /0.1000000000E+04/
     *    EQLAT( 628) /0.6269042904E+00/
     *    EQLON( 628) /0.2102547710E+01/
     *    SSLIP( 628) /0.2350000000E+00/
     *    DSLIP( 628) /0.0000000000E+00/
     *    DIP( 628) /0.1570796327E+01/
     *    DEPTH( 628) /0.0000000000E+00/
     *    WIDTH( 628) /0.1000000000E+04/
      DATA STRIKE( 629) /0.2426007660E+01/
     *    HL( 629) /0.1000000000E+04/
     *    EQLAT( 629) /0.6271413061E+00/
     *    EQLON( 629) /0.2102800957E+01/
     *    SSLIP( 629) /0.2700000000E-01/
     *    DSLIP( 629) /0.0000000000E+00/
     *    DIP( 629) /0.1570796327E+01/
     *    DEPTH( 629) /0.0000000000E+00/
     *    WIDTH( 629) /0.1000000000E+04/
      DATA STRIKE( 630) /0.2426007660E+01/
     *    HL( 630) /0.1000000000E+04/
     *    EQLAT( 630) /0.6273783218E+00/
     *    EQLON( 630) /0.2103054204E+01/
     *    SSLIP( 630) /0.1250000000E+00/
     *    DSLIP( 630) /0.0000000000E+00/
     *    DIP( 630) /0.1570796327E+01/
     *    DEPTH( 630) /0.0000000000E+00/
     *    WIDTH( 630) /0.1000000000E+04/
      DATA STRIKE( 631) /0.2426007660E+01/
     *    HL( 631) /0.1000000000E+04/
     *    EQLAT( 631) /0.6276153376E+00/
     *    EQLON( 631) /0.2103307452E+01/
     *    SSLIP( 631) /0.1240000000E+00/
     *    DSLIP( 631) /0.0000000000E+00/
     *    DIP( 631) /0.1570796327E+01/
     *    DEPTH( 631) /0.0000000000E+00/
     *    WIDTH( 631) /0.1000000000E+04/
      DATA STRIKE( 632) /0.2426007660E+01/
     *    HL( 632) /0.1000000000E+04/
     *    EQLAT( 632) /0.6278525278E+00/
     *    EQLON( 632) /0.2103560699E+01/
     *    SSLIP( 632) /0.4400000000E-01/
     *    DSLIP( 632) /0.0000000000E+00/
     *    DIP( 632) /0.1570796327E+01/
     *    DEPTH( 632) /0.0000000000E+00/
     *    WIDTH( 632) /0.1000000000E+04/
      DATA STRIKE( 633) /0.2426007660E+01/
     *    HL( 633) /0.1000000000E+04/
     *    EQLAT( 633) /0.6280895435E+00/
     *    EQLON( 633) /0.2103813946E+01/
     *    SSLIP( 633) /0.3000000000E-01/
     *    DSLIP( 633) /0.0000000000E+00/
     *    DIP( 633) /0.1570796327E+01/
     *    DEPTH( 633) /0.0000000000E+00/
     *    WIDTH( 633) /0.1000000000E+04/
      DATA STRIKE( 634) /0.2426007660E+01/
     *    HL( 634) /0.1000000000E+04/
     *    EQLAT( 634) /0.6283265592E+00/
     *    EQLON( 634) /0.2104067194E+01/
     *    SSLIP( 634) /0.9000000000E-02/
     *    DSLIP( 634) /0.0000000000E+00/
     *    DIP( 634) /0.1570796327E+01/
     *    DEPTH( 634) /0.0000000000E+00/
     *    WIDTH( 634) /0.1000000000E+04/
      DATA STRIKE( 635) /0.2426007660E+01/
     *    HL( 635) /0.1000000000E+04/
     *    EQLAT( 635) /0.6285635749E+00/
     *    EQLON( 635) /0.2104320441E+01/
     *    SSLIP( 635) /0.6200000000E-01/
     *    DSLIP( 635) /0.0000000000E+00/
     *    DIP( 635) /0.1570796327E+01/
     *    DEPTH( 635) /0.0000000000E+00/
     *    WIDTH( 635) /0.1000000000E+04/
      DATA STRIKE( 636) /0.2424262331E+01/
     *    HL( 636) /0.1000000000E+04/
     *    EQLAT( 636) /0.6240597528E+00/
     *    EQLON( 636) /0.2099508917E+01/
     *    SSLIP( 636) /0.2100000000E-01/
     *    DSLIP( 636) /0.0000000000E+00/
     *    DIP( 636) /0.1570796327E+01/
     *    DEPTH( 636) /0.1000000000E+04/
     *    WIDTH( 636) /0.1000000000E+04/
      DATA STRIKE( 637) /0.2426007660E+01/
     *    HL( 637) /0.1000000000E+04/
     *    EQLAT( 637) /0.6242967685E+00/
     *    EQLON( 637) /0.2099762164E+01/
     *    SSLIP( 637) /0.5400000000E-01/
     *    DSLIP( 637) /0.0000000000E+00/
     *    DIP( 637) /0.1570796327E+01/
     *    DEPTH( 637) /0.1000000000E+04/
     *    WIDTH( 637) /0.1000000000E+04/
      DATA STRIKE( 638) /0.2426007660E+01/
     *    HL( 638) /0.1000000000E+04/
     *    EQLAT( 638) /0.6245337842E+00/
     *    EQLON( 638) /0.2100015412E+01/
     *    SSLIP( 638) /0.9300000000E-01/
     *    DSLIP( 638) /0.0000000000E+00/
     *    DIP( 638) /0.1570796327E+01/
     *    DEPTH( 638) /0.1000000000E+04/
     *    WIDTH( 638) /0.1000000000E+04/
      DATA STRIKE( 639) /0.2426007660E+01/
     *    HL( 639) /0.1000000000E+04/
     *    EQLAT( 639) /0.6247707999E+00/
     *    EQLON( 639) /0.2100268484E+01/
     *    SSLIP( 639) /0.1910000000E+00/
     *    DSLIP( 639) /0.0000000000E+00/
     *    DIP( 639) /0.1570796327E+01/
     *    DEPTH( 639) /0.1000000000E+04/
     *    WIDTH( 639) /0.1000000000E+04/
      DATA STRIKE( 640) /0.2426007660E+01/
     *    HL( 640) /0.1000000000E+04/
     *    EQLAT( 640) /0.6250079902E+00/
     *    EQLON( 640) /0.2100521732E+01/
     *    SSLIP( 640) /0.1840000000E+00/
     *    DSLIP( 640) /0.0000000000E+00/
     *    DIP( 640) /0.1570796327E+01/
     *    DEPTH( 640) /0.1000000000E+04/
     *    WIDTH( 640) /0.1000000000E+04/
      DATA STRIKE( 641) /0.2426007660E+01/
     *    HL( 641) /0.1000000000E+04/
     *    EQLAT( 641) /0.6252450059E+00/
     *    EQLON( 641) /0.2100774979E+01/
     *    SSLIP( 641) /0.2030000000E+00/
     *    DSLIP( 641) /0.0000000000E+00/
     *    DIP( 641) /0.1570796327E+01/
     *    DEPTH( 641) /0.1000000000E+04/
     *    WIDTH( 641) /0.1000000000E+04/
      DATA STRIKE( 642) /0.2426007660E+01/
     *    HL( 642) /0.1000000000E+04/
     *    EQLAT( 642) /0.6254820216E+00/
     *    EQLON( 642) /0.2101028226E+01/
     *    SSLIP( 642) /0.2590000000E+00/
     *    DSLIP( 642) /0.0000000000E+00/
     *    DIP( 642) /0.1570796327E+01/
     *    DEPTH( 642) /0.1000000000E+04/
     *    WIDTH( 642) /0.1000000000E+04/
      DATA STRIKE( 643) /0.2426007660E+01/
     *    HL( 643) /0.1000000000E+04/
     *    EQLAT( 643) /0.6257190373E+00/
     *    EQLON( 643) /0.2101281473E+01/
     *    SSLIP( 643) /0.3410000000E+00/
     *    DSLIP( 643) /0.0000000000E+00/
     *    DIP( 643) /0.1570796327E+01/
     *    DEPTH( 643) /0.1000000000E+04/
     *    WIDTH( 643) /0.1000000000E+04/
      DATA STRIKE( 644) /0.2426007660E+01/
     *    HL( 644) /0.1000000000E+04/
     *    EQLAT( 644) /0.6259560530E+00/
     *    EQLON( 644) /0.2101534721E+01/
     *    SSLIP( 644) /0.2650000000E+00/
     *    DSLIP( 644) /0.0000000000E+00/
     *    DIP( 644) /0.1570796327E+01/
     *    DEPTH( 644) /0.1000000000E+04/
     *    WIDTH( 644) /0.1000000000E+04/
      DATA STRIKE( 645) /0.2426007660E+01/
     *    HL( 645) /0.1000000000E+04/
     *    EQLAT( 645) /0.6261930688E+00/
     *    EQLON( 645) /0.2101787968E+01/
     *    SSLIP( 645) /0.2690000000E+00/
     *    DSLIP( 645) /0.0000000000E+00/
     *    DIP( 645) /0.1570796327E+01/
     *    DEPTH( 645) /0.1000000000E+04/
     *    WIDTH( 645) /0.1000000000E+04/
      DATA STRIKE( 646) /0.2426007660E+01/
     *    HL( 646) /0.1000000000E+04/
     *    EQLAT( 646) /0.6264302590E+00/
     *    EQLON( 646) /0.2102041215E+01/
     *    SSLIP( 646) /0.2140000000E+00/
     *    DSLIP( 646) /0.0000000000E+00/
     *    DIP( 646) /0.1570796327E+01/
     *    DEPTH( 646) /0.1000000000E+04/
     *    WIDTH( 646) /0.1000000000E+04/
      DATA STRIKE( 647) /0.2426007660E+01/
     *    HL( 647) /0.1000000000E+04/
     *    EQLAT( 647) /0.6266672747E+00/
     *    EQLON( 647) /0.2102294463E+01/
     *    SSLIP( 647) /0.3260000000E+00/
     *    DSLIP( 647) /0.0000000000E+00/
     *    DIP( 647) /0.1570796327E+01/
     *    DEPTH( 647) /0.1000000000E+04/
     *    WIDTH( 647) /0.1000000000E+04/
      DATA STRIKE( 648) /0.2426007660E+01/
     *    HL( 648) /0.1000000000E+04/
     *    EQLAT( 648) /0.6269042904E+00/
     *    EQLON( 648) /0.2102547710E+01/
     *    SSLIP( 648) /0.2550000000E+00/
     *    DSLIP( 648) /0.0000000000E+00/
     *    DIP( 648) /0.1570796327E+01/
     *    DEPTH( 648) /0.1000000000E+04/
     *    WIDTH( 648) /0.1000000000E+04/
      DATA STRIKE( 649) /0.2426007660E+01/
     *    HL( 649) /0.1000000000E+04/
     *    EQLAT( 649) /0.6271413061E+00/
     *    EQLON( 649) /0.2102800957E+01/
     *    SSLIP( 649) /0.1130000000E+00/
     *    DSLIP( 649) /0.0000000000E+00/
     *    DIP( 649) /0.1570796327E+01/
     *    DEPTH( 649) /0.1000000000E+04/
     *    WIDTH( 649) /0.1000000000E+04/
      DATA STRIKE( 650) /0.2426007660E+01/
     *    HL( 650) /0.1000000000E+04/
     *    EQLAT( 650) /0.6273783218E+00/
     *    EQLON( 650) /0.2103054204E+01/
     *    SSLIP( 650) /0.2290000000E+00/
     *    DSLIP( 650) /0.0000000000E+00/
     *    DIP( 650) /0.1570796327E+01/
     *    DEPTH( 650) /0.1000000000E+04/
     *    WIDTH( 650) /0.1000000000E+04/
      DATA STRIKE( 651) /0.2426007660E+01/
     *    HL( 651) /0.1000000000E+04/
     *    EQLAT( 651) /0.6276153376E+00/
     *    EQLON( 651) /0.2103307452E+01/
     *    SSLIP( 651) /0.2220000000E+00/
     *    DSLIP( 651) /0.0000000000E+00/
     *    DIP( 651) /0.1570796327E+01/
     *    DEPTH( 651) /0.1000000000E+04/
     *    WIDTH( 651) /0.1000000000E+04/
      DATA STRIKE( 652) /0.2426007660E+01/
     *    HL( 652) /0.1000000000E+04/
     *    EQLAT( 652) /0.6278525278E+00/
     *    EQLON( 652) /0.2103560699E+01/
     *    SSLIP( 652) /0.1110000000E+00/
     *    DSLIP( 652) /0.0000000000E+00/
     *    DIP( 652) /0.1570796327E+01/
     *    DEPTH( 652) /0.1000000000E+04/
     *    WIDTH( 652) /0.1000000000E+04/
      DATA STRIKE( 653) /0.2426007660E+01/
     *    HL( 653) /0.1000000000E+04/
     *    EQLAT( 653) /0.6280895435E+00/
     *    EQLON( 653) /0.2103813946E+01/
     *    SSLIP( 653) /0.6800000000E-01/
     *    DSLIP( 653) /0.0000000000E+00/
     *    DIP( 653) /0.1570796327E+01/
     *    DEPTH( 653) /0.1000000000E+04/
     *    WIDTH( 653) /0.1000000000E+04/
      DATA STRIKE( 654) /0.2426007660E+01/
     *    HL( 654) /0.1000000000E+04/
     *    EQLAT( 654) /0.6283265592E+00/
     *    EQLON( 654) /0.2104067194E+01/
     *    SSLIP( 654) /0.4400000000E-01/
     *    DSLIP( 654) /0.0000000000E+00/
     *    DIP( 654) /0.1570796327E+01/
     *    DEPTH( 654) /0.1000000000E+04/
     *    WIDTH( 654) /0.1000000000E+04/
      DATA STRIKE( 655) /0.2426007660E+01/
     *    HL( 655) /0.1000000000E+04/
     *    EQLAT( 655) /0.6285635749E+00/
     *    EQLON( 655) /0.2104320441E+01/
     *    SSLIP( 655) /0.4400000000E-01/
     *    DSLIP( 655) /0.0000000000E+00/
     *    DIP( 655) /0.1570796327E+01/
     *    DEPTH( 655) /0.1000000000E+04/
     *    WIDTH( 655) /0.1000000000E+04/
      DATA STRIKE( 656) /0.2424262331E+01/
     *    HL( 656) /0.1000000000E+04/
     *    EQLAT( 656) /0.6240597528E+00/
     *    EQLON( 656) /0.2099508917E+01/
     *    SSLIP( 656) /0.1800000000E-01/
     *    DSLIP( 656) /0.0000000000E+00/
     *    DIP( 656) /0.1570796327E+01/
     *    DEPTH( 656) /0.2000000000E+04/
     *    WIDTH( 656) /0.1000000000E+04/
      DATA STRIKE( 657) /0.2426007660E+01/
     *    HL( 657) /0.1000000000E+04/
     *    EQLAT( 657) /0.6242967685E+00/
     *    EQLON( 657) /0.2099762164E+01/
     *    SSLIP( 657) /0.5500000000E-01/
     *    DSLIP( 657) /0.0000000000E+00/
     *    DIP( 657) /0.1570796327E+01/
     *    DEPTH( 657) /0.2000000000E+04/
     *    WIDTH( 657) /0.1000000000E+04/
      DATA STRIKE( 658) /0.2426007660E+01/
     *    HL( 658) /0.1000000000E+04/
     *    EQLAT( 658) /0.6245337842E+00/
     *    EQLON( 658) /0.2100015412E+01/
     *    SSLIP( 658) /0.1310000000E+00/
     *    DSLIP( 658) /0.0000000000E+00/
     *    DIP( 658) /0.1570796327E+01/
     *    DEPTH( 658) /0.2000000000E+04/
     *    WIDTH( 658) /0.1000000000E+04/
      DATA STRIKE( 659) /0.2426007660E+01/
     *    HL( 659) /0.1000000000E+04/
     *    EQLAT( 659) /0.6247707999E+00/
     *    EQLON( 659) /0.2100268484E+01/
     *    SSLIP( 659) /0.2590000000E+00/
     *    DSLIP( 659) /0.0000000000E+00/
     *    DIP( 659) /0.1570796327E+01/
     *    DEPTH( 659) /0.2000000000E+04/
     *    WIDTH( 659) /0.1000000000E+04/
      DATA STRIKE( 660) /0.2426007660E+01/
     *    HL( 660) /0.1000000000E+04/
     *    EQLAT( 660) /0.6250079902E+00/
     *    EQLON( 660) /0.2100521732E+01/
     *    SSLIP( 660) /0.2580000000E+00/
     *    DSLIP( 660) /0.0000000000E+00/
     *    DIP( 660) /0.1570796327E+01/
     *    DEPTH( 660) /0.2000000000E+04/
     *    WIDTH( 660) /0.1000000000E+04/
      DATA STRIKE( 661) /0.2426007660E+01/
     *    HL( 661) /0.1000000000E+04/
     *    EQLAT( 661) /0.6252450059E+00/
     *    EQLON( 661) /0.2100774979E+01/
     *    SSLIP( 661) /0.2500000000E+00/
     *    DSLIP( 661) /0.0000000000E+00/
     *    DIP( 661) /0.1570796327E+01/
     *    DEPTH( 661) /0.2000000000E+04/
     *    WIDTH( 661) /0.1000000000E+04/
      DATA STRIKE( 662) /0.2426007660E+01/
     *    HL( 662) /0.1000000000E+04/
     *    EQLAT( 662) /0.6254820216E+00/
     *    EQLON( 662) /0.2101028226E+01/
     *    SSLIP( 662) /0.3180000000E+00/
     *    DSLIP( 662) /0.0000000000E+00/
     *    DIP( 662) /0.1570796327E+01/
     *    DEPTH( 662) /0.2000000000E+04/
     *    WIDTH( 662) /0.1000000000E+04/
      DATA STRIKE( 663) /0.2426007660E+01/
     *    HL( 663) /0.1000000000E+04/
     *    EQLAT( 663) /0.6257190373E+00/
     *    EQLON( 663) /0.2101281473E+01/
     *    SSLIP( 663) /0.3850000000E+00/
     *    DSLIP( 663) /0.0000000000E+00/
     *    DIP( 663) /0.1570796327E+01/
     *    DEPTH( 663) /0.2000000000E+04/
     *    WIDTH( 663) /0.1000000000E+04/
      DATA STRIKE( 664) /0.2426007660E+01/
     *    HL( 664) /0.1000000000E+04/
     *    EQLAT( 664) /0.6259560530E+00/
     *    EQLON( 664) /0.2101534721E+01/
     *    SSLIP( 664) /0.2340000000E+00/
     *    DSLIP( 664) /0.0000000000E+00/
     *    DIP( 664) /0.1570796327E+01/
     *    DEPTH( 664) /0.2000000000E+04/
     *    WIDTH( 664) /0.1000000000E+04/
      DATA STRIKE( 665) /0.2426007660E+01/
     *    HL( 665) /0.1000000000E+04/
     *    EQLAT( 665) /0.6261930688E+00/
     *    EQLON( 665) /0.2101787968E+01/
     *    SSLIP( 665) /0.2430000000E+00/
     *    DSLIP( 665) /0.0000000000E+00/
     *    DIP( 665) /0.1570796327E+01/
     *    DEPTH( 665) /0.2000000000E+04/
     *    WIDTH( 665) /0.1000000000E+04/
      DATA STRIKE( 666) /0.2426007660E+01/
     *    HL( 666) /0.1000000000E+04/
     *    EQLAT( 666) /0.6264302590E+00/
     *    EQLON( 666) /0.2102041215E+01/
     *    SSLIP( 666) /0.3110000000E+00/
     *    DSLIP( 666) /0.0000000000E+00/
     *    DIP( 666) /0.1570796327E+01/
     *    DEPTH( 666) /0.2000000000E+04/
     *    WIDTH( 666) /0.1000000000E+04/
      DATA STRIKE( 667) /0.2426007660E+01/
     *    HL( 667) /0.1000000000E+04/
     *    EQLAT( 667) /0.6266672747E+00/
     *    EQLON( 667) /0.2102294463E+01/
     *    SSLIP( 667) /0.3330000000E+00/
     *    DSLIP( 667) /0.0000000000E+00/
     *    DIP( 667) /0.1570796327E+01/
     *    DEPTH( 667) /0.2000000000E+04/
     *    WIDTH( 667) /0.1000000000E+04/
      DATA STRIKE( 668) /0.2426007660E+01/
     *    HL( 668) /0.1000000000E+04/
     *    EQLAT( 668) /0.6269042904E+00/
     *    EQLON( 668) /0.2102547710E+01/
     *    SSLIP( 668) /0.2680000000E+00/
     *    DSLIP( 668) /0.0000000000E+00/
     *    DIP( 668) /0.1570796327E+01/
     *    DEPTH( 668) /0.2000000000E+04/
     *    WIDTH( 668) /0.1000000000E+04/
      DATA STRIKE( 669) /0.2426007660E+01/
     *    HL( 669) /0.1000000000E+04/
     *    EQLAT( 669) /0.6271413061E+00/
     *    EQLON( 669) /0.2102800957E+01/
     *    SSLIP( 669) /0.2770000000E+00/
     *    DSLIP( 669) /0.0000000000E+00/
     *    DIP( 669) /0.1570796327E+01/
     *    DEPTH( 669) /0.2000000000E+04/
     *    WIDTH( 669) /0.1000000000E+04/
      DATA STRIKE( 670) /0.2426007660E+01/
     *    HL( 670) /0.1000000000E+04/
     *    EQLAT( 670) /0.6273783218E+00/
     *    EQLON( 670) /0.2103054204E+01/
     *    SSLIP( 670) /0.3350000000E+00/
     *    DSLIP( 670) /0.0000000000E+00/
     *    DIP( 670) /0.1570796327E+01/
     *    DEPTH( 670) /0.2000000000E+04/
     *    WIDTH( 670) /0.1000000000E+04/
      DATA STRIKE( 671) /0.2426007660E+01/
     *    HL( 671) /0.1000000000E+04/
     *    EQLAT( 671) /0.6276153376E+00/
     *    EQLON( 671) /0.2103307452E+01/
     *    SSLIP( 671) /0.2610000000E+00/
     *    DSLIP( 671) /0.0000000000E+00/
     *    DIP( 671) /0.1570796327E+01/
     *    DEPTH( 671) /0.2000000000E+04/
     *    WIDTH( 671) /0.1000000000E+04/
      DATA STRIKE( 672) /0.2426007660E+01/
     *    HL( 672) /0.1000000000E+04/
     *    EQLAT( 672) /0.6278525278E+00/
     *    EQLON( 672) /0.2103560699E+01/
     *    SSLIP( 672) /0.1370000000E+00/
     *    DSLIP( 672) /0.0000000000E+00/
     *    DIP( 672) /0.1570796327E+01/
     *    DEPTH( 672) /0.2000000000E+04/
     *    WIDTH( 672) /0.1000000000E+04/
      DATA STRIKE( 673) /0.2426007660E+01/
     *    HL( 673) /0.1000000000E+04/
     *    EQLAT( 673) /0.6280895435E+00/
     *    EQLON( 673) /0.2103813946E+01/
     *    SSLIP( 673) /0.9500000000E-01/
     *    DSLIP( 673) /0.0000000000E+00/
     *    DIP( 673) /0.1570796327E+01/
     *    DEPTH( 673) /0.2000000000E+04/
     *    WIDTH( 673) /0.1000000000E+04/
      DATA STRIKE( 674) /0.2426007660E+01/
     *    HL( 674) /0.1000000000E+04/
     *    EQLAT( 674) /0.6283265592E+00/
     *    EQLON( 674) /0.2104067194E+01/
     *    SSLIP( 674) /0.6200000000E-01/
     *    DSLIP( 674) /0.0000000000E+00/
     *    DIP( 674) /0.1570796327E+01/
     *    DEPTH( 674) /0.2000000000E+04/
     *    WIDTH( 674) /0.1000000000E+04/
      DATA STRIKE( 675) /0.2426007660E+01/
     *    HL( 675) /0.1000000000E+04/
     *    EQLAT( 675) /0.6285635749E+00/
     *    EQLON( 675) /0.2104320441E+01/
     *    SSLIP( 675) /0.3900000000E-01/
     *    DSLIP( 675) /0.0000000000E+00/
     *    DIP( 675) /0.1570796327E+01/
     *    DEPTH( 675) /0.2000000000E+04/
     *    WIDTH( 675) /0.1000000000E+04/
      DATA STRIKE( 676) /0.2424262331E+01/
     *    HL( 676) /0.1000000000E+04/
     *    EQLAT( 676) /0.6240597528E+00/
     *    EQLON( 676) /0.2099508917E+01/
     *    SSLIP( 676) /0.8000000000E-02/
     *    DSLIP( 676) /0.0000000000E+00/
     *    DIP( 676) /0.1570796327E+01/
     *    DEPTH( 676) /0.3000000000E+04/
     *    WIDTH( 676) /0.1000000000E+04/
      DATA STRIKE( 677) /0.2426007660E+01/
     *    HL( 677) /0.1000000000E+04/
     *    EQLAT( 677) /0.6242967685E+00/
     *    EQLON( 677) /0.2099762164E+01/
     *    SSLIP( 677) /0.3600000000E-01/
     *    DSLIP( 677) /0.0000000000E+00/
     *    DIP( 677) /0.1570796327E+01/
     *    DEPTH( 677) /0.3000000000E+04/
     *    WIDTH( 677) /0.1000000000E+04/
      DATA STRIKE( 678) /0.2426007660E+01/
     *    HL( 678) /0.1000000000E+04/
     *    EQLAT( 678) /0.6245337842E+00/
     *    EQLON( 678) /0.2100015412E+01/
     *    SSLIP( 678) /0.1050000000E+00/
     *    DSLIP( 678) /0.0000000000E+00/
     *    DIP( 678) /0.1570796327E+01/
     *    DEPTH( 678) /0.3000000000E+04/
     *    WIDTH( 678) /0.1000000000E+04/
      DATA STRIKE( 679) /0.2426007660E+01/
     *    HL( 679) /0.1000000000E+04/
     *    EQLAT( 679) /0.6247707999E+00/
     *    EQLON( 679) /0.2100268484E+01/
     *    SSLIP( 679) /0.2380000000E+00/
     *    DSLIP( 679) /0.0000000000E+00/
     *    DIP( 679) /0.1570796327E+01/
     *    DEPTH( 679) /0.3000000000E+04/
     *    WIDTH( 679) /0.1000000000E+04/
      DATA STRIKE( 680) /0.2426007660E+01/
     *    HL( 680) /0.1000000000E+04/
     *    EQLAT( 680) /0.6250079902E+00/
     *    EQLON( 680) /0.2100521732E+01/
     *    SSLIP( 680) /0.2590000000E+00/
     *    DSLIP( 680) /0.0000000000E+00/
     *    DIP( 680) /0.1570796327E+01/
     *    DEPTH( 680) /0.3000000000E+04/
     *    WIDTH( 680) /0.1000000000E+04/
      DATA STRIKE( 681) /0.2426007660E+01/
     *    HL( 681) /0.1000000000E+04/
     *    EQLAT( 681) /0.6252450059E+00/
     *    EQLON( 681) /0.2100774979E+01/
     *    SSLIP( 681) /0.2450000000E+00/
     *    DSLIP( 681) /0.0000000000E+00/
     *    DIP( 681) /0.1570796327E+01/
     *    DEPTH( 681) /0.3000000000E+04/
     *    WIDTH( 681) /0.1000000000E+04/
      DATA STRIKE( 682) /0.2426007660E+01/
     *    HL( 682) /0.1000000000E+04/
     *    EQLAT( 682) /0.6254820216E+00/
     *    EQLON( 682) /0.2101028226E+01/
     *    SSLIP( 682) /0.3040000000E+00/
     *    DSLIP( 682) /0.0000000000E+00/
     *    DIP( 682) /0.1570796327E+01/
     *    DEPTH( 682) /0.3000000000E+04/
     *    WIDTH( 682) /0.1000000000E+04/
      DATA STRIKE( 683) /0.2426007660E+01/
     *    HL( 683) /0.1000000000E+04/
     *    EQLAT( 683) /0.6257190373E+00/
     *    EQLON( 683) /0.2101281473E+01/
     *    SSLIP( 683) /0.3440000000E+00/
     *    DSLIP( 683) /0.0000000000E+00/
     *    DIP( 683) /0.1570796327E+01/
     *    DEPTH( 683) /0.3000000000E+04/
     *    WIDTH( 683) /0.1000000000E+04/
      DATA STRIKE( 684) /0.2426007660E+01/
     *    HL( 684) /0.1000000000E+04/
     *    EQLAT( 684) /0.6259560530E+00/
     *    EQLON( 684) /0.2101534721E+01/
     *    SSLIP( 684) /0.1920000000E+00/
     *    DSLIP( 684) /0.0000000000E+00/
     *    DIP( 684) /0.1570796327E+01/
     *    DEPTH( 684) /0.3000000000E+04/
     *    WIDTH( 684) /0.1000000000E+04/
      DATA STRIKE( 685) /0.2426007660E+01/
     *    HL( 685) /0.1000000000E+04/
     *    EQLAT( 685) /0.6261930688E+00/
     *    EQLON( 685) /0.2101787968E+01/
     *    SSLIP( 685) /0.2280000000E+00/
     *    DSLIP( 685) /0.0000000000E+00/
     *    DIP( 685) /0.1570796327E+01/
     *    DEPTH( 685) /0.3000000000E+04/
     *    WIDTH( 685) /0.1000000000E+04/
      DATA STRIKE( 686) /0.2426007660E+01/
     *    HL( 686) /0.1000000000E+04/
     *    EQLAT( 686) /0.6264302590E+00/
     *    EQLON( 686) /0.2102041215E+01/
     *    SSLIP( 686) /0.3720000000E+00/
     *    DSLIP( 686) /0.0000000000E+00/
     *    DIP( 686) /0.1570796327E+01/
     *    DEPTH( 686) /0.3000000000E+04/
     *    WIDTH( 686) /0.1000000000E+04/
      DATA STRIKE( 687) /0.2426007660E+01/
     *    HL( 687) /0.1000000000E+04/
     *    EQLAT( 687) /0.6266672747E+00/
     *    EQLON( 687) /0.2102294463E+01/
     *    SSLIP( 687) /0.3530000000E+00/
     *    DSLIP( 687) /0.0000000000E+00/
     *    DIP( 687) /0.1570796327E+01/
     *    DEPTH( 687) /0.3000000000E+04/
     *    WIDTH( 687) /0.1000000000E+04/
      DATA STRIKE( 688) /0.2426007660E+01/
     *    HL( 688) /0.1000000000E+04/
     *    EQLAT( 688) /0.6269042904E+00/
     *    EQLON( 688) /0.2102547710E+01/
     *    SSLIP( 688) /0.3030000000E+00/
     *    DSLIP( 688) /0.0000000000E+00/
     *    DIP( 688) /0.1570796327E+01/
     *    DEPTH( 688) /0.3000000000E+04/
     *    WIDTH( 688) /0.1000000000E+04/
      DATA STRIKE( 689) /0.2426007660E+01/
     *    HL( 689) /0.1000000000E+04/
     *    EQLAT( 689) /0.6271413061E+00/
     *    EQLON( 689) /0.2102800957E+01/
     *    SSLIP( 689) /0.4000000000E+00/
     *    DSLIP( 689) /0.0000000000E+00/
     *    DIP( 689) /0.1570796327E+01/
     *    DEPTH( 689) /0.3000000000E+04/
     *    WIDTH( 689) /0.1000000000E+04/
      DATA STRIKE( 690) /0.2426007660E+01/
     *    HL( 690) /0.1000000000E+04/
     *    EQLAT( 690) /0.6273783218E+00/
     *    EQLON( 690) /0.2103054204E+01/
     *    SSLIP( 690) /0.4130000000E+00/
     *    DSLIP( 690) /0.0000000000E+00/
     *    DIP( 690) /0.1570796327E+01/
     *    DEPTH( 690) /0.3000000000E+04/
     *    WIDTH( 690) /0.1000000000E+04/
      DATA STRIKE( 691) /0.2426007660E+01/
     *    HL( 691) /0.1000000000E+04/
     *    EQLAT( 691) /0.6276153376E+00/
     *    EQLON( 691) /0.2103307452E+01/
     *    SSLIP( 691) /0.2730000000E+00/
     *    DSLIP( 691) /0.0000000000E+00/
     *    DIP( 691) /0.1570796327E+01/
     *    DEPTH( 691) /0.3000000000E+04/
     *    WIDTH( 691) /0.1000000000E+04/
      DATA STRIKE( 692) /0.2426007660E+01/
     *    HL( 692) /0.1000000000E+04/
     *    EQLAT( 692) /0.6278525278E+00/
     *    EQLON( 692) /0.2103560699E+01/
     *    SSLIP( 692) /0.1410000000E+00/
     *    DSLIP( 692) /0.0000000000E+00/
     *    DIP( 692) /0.1570796327E+01/
     *    DEPTH( 692) /0.3000000000E+04/
     *    WIDTH( 692) /0.1000000000E+04/
      DATA STRIKE( 693) /0.2426007660E+01/
     *    HL( 693) /0.1000000000E+04/
     *    EQLAT( 693) /0.6280895435E+00/
     *    EQLON( 693) /0.2103813946E+01/
     *    SSLIP( 693) /0.1060000000E+00/
     *    DSLIP( 693) /0.0000000000E+00/
     *    DIP( 693) /0.1570796327E+01/
     *    DEPTH( 693) /0.3000000000E+04/
     *    WIDTH( 693) /0.1000000000E+04/
      DATA STRIKE( 694) /0.2426007660E+01/
     *    HL( 694) /0.1000000000E+04/
     *    EQLAT( 694) /0.6283265592E+00/
     *    EQLON( 694) /0.2104067194E+01/
     *    SSLIP( 694) /0.7900000000E-01/
     *    DSLIP( 694) /0.0000000000E+00/
     *    DIP( 694) /0.1570796327E+01/
     *    DEPTH( 694) /0.3000000000E+04/
     *    WIDTH( 694) /0.1000000000E+04/
      DATA STRIKE( 695) /0.2426007660E+01/
     *    HL( 695) /0.1000000000E+04/
     *    EQLAT( 695) /0.6285635749E+00/
     *    EQLON( 695) /0.2104320441E+01/
     *    SSLIP( 695) /0.5700000000E-01/
     *    DSLIP( 695) /0.0000000000E+00/
     *    DIP( 695) /0.1570796327E+01/
     *    DEPTH( 695) /0.3000000000E+04/
     *    WIDTH( 695) /0.1000000000E+04/
      DATA STRIKE( 696) /0.2424262331E+01/
     *    HL( 696) /0.1000000000E+04/
     *    EQLAT( 696) /0.6240597528E+00/
     *    EQLON( 696) /0.2099508917E+01/
     *    SSLIP( 696) /0.0000000000E+00/
     *    DSLIP( 696) /0.0000000000E+00/
     *    DIP( 696) /0.1570796327E+01/
     *    DEPTH( 696) /0.4000000000E+04/
     *    WIDTH( 696) /0.1000000000E+04/
      DATA STRIKE( 697) /0.2426007660E+01/
     *    HL( 697) /0.1000000000E+04/
     *    EQLAT( 697) /0.6242967685E+00/
     *    EQLON( 697) /0.2099762164E+01/
     *    SSLIP( 697) /0.1200000000E-01/
     *    DSLIP( 697) /0.0000000000E+00/
     *    DIP( 697) /0.1570796327E+01/
     *    DEPTH( 697) /0.4000000000E+04/
     *    WIDTH( 697) /0.1000000000E+04/
      DATA STRIKE( 698) /0.2426007660E+01/
     *    HL( 698) /0.1000000000E+04/
     *    EQLAT( 698) /0.6245337842E+00/
     *    EQLON( 698) /0.2100015412E+01/
     *    SSLIP( 698) /0.5300000000E-01/
     *    DSLIP( 698) /0.0000000000E+00/
     *    DIP( 698) /0.1570796327E+01/
     *    DEPTH( 698) /0.4000000000E+04/
     *    WIDTH( 698) /0.1000000000E+04/
      DATA STRIKE( 699) /0.2426007660E+01/
     *    HL( 699) /0.1000000000E+04/
     *    EQLAT( 699) /0.6247707999E+00/
     *    EQLON( 699) /0.2100268484E+01/
     *    SSLIP( 699) /0.1700000000E+00/
     *    DSLIP( 699) /0.0000000000E+00/
     *    DIP( 699) /0.1570796327E+01/
     *    DEPTH( 699) /0.4000000000E+04/
     *    WIDTH( 699) /0.1000000000E+04/
      DATA STRIKE( 700) /0.2426007660E+01/
     *    HL( 700) /0.1000000000E+04/
     *    EQLAT( 700) /0.6250079902E+00/
     *    EQLON( 700) /0.2100521732E+01/
     *    SSLIP( 700) /0.2160000000E+00/
     *    DSLIP( 700) /0.0000000000E+00/
     *    DIP( 700) /0.1570796327E+01/
     *    DEPTH( 700) /0.4000000000E+04/
     *    WIDTH( 700) /0.1000000000E+04/
      DATA STRIKE( 701) /0.2426007660E+01/
     *    HL( 701) /0.1000000000E+04/
     *    EQLAT( 701) /0.6252450059E+00/
     *    EQLON( 701) /0.2100774979E+01/
     *    SSLIP( 701) /0.2160000000E+00/
     *    DSLIP( 701) /0.0000000000E+00/
     *    DIP( 701) /0.1570796327E+01/
     *    DEPTH( 701) /0.4000000000E+04/
     *    WIDTH( 701) /0.1000000000E+04/
      DATA STRIKE( 702) /0.2426007660E+01/
     *    HL( 702) /0.1000000000E+04/
     *    EQLAT( 702) /0.6254820216E+00/
     *    EQLON( 702) /0.2101028226E+01/
     *    SSLIP( 702) /0.2630000000E+00/
     *    DSLIP( 702) /0.0000000000E+00/
     *    DIP( 702) /0.1570796327E+01/
     *    DEPTH( 702) /0.4000000000E+04/
     *    WIDTH( 702) /0.1000000000E+04/
      DATA STRIKE( 703) /0.2426007660E+01/
     *    HL( 703) /0.1000000000E+04/
     *    EQLAT( 703) /0.6257190373E+00/
     *    EQLON( 703) /0.2101281473E+01/
     *    SSLIP( 703) /0.2850000000E+00/
     *    DSLIP( 703) /0.0000000000E+00/
     *    DIP( 703) /0.1570796327E+01/
     *    DEPTH( 703) /0.4000000000E+04/
     *    WIDTH( 703) /0.1000000000E+04/
      DATA STRIKE( 704) /0.2426007660E+01/
     *    HL( 704) /0.1000000000E+04/
     *    EQLAT( 704) /0.6259560530E+00/
     *    EQLON( 704) /0.2101534721E+01/
     *    SSLIP( 704) /0.1760000000E+00/
     *    DSLIP( 704) /0.0000000000E+00/
     *    DIP( 704) /0.1570796327E+01/
     *    DEPTH( 704) /0.4000000000E+04/
     *    WIDTH( 704) /0.1000000000E+04/
      DATA STRIKE( 705) /0.2426007660E+01/
     *    HL( 705) /0.1000000000E+04/
     *    EQLAT( 705) /0.6261930688E+00/
     *    EQLON( 705) /0.2101787968E+01/
     *    SSLIP( 705) /0.2400000000E+00/
     *    DSLIP( 705) /0.0000000000E+00/
     *    DIP( 705) /0.1570796327E+01/
     *    DEPTH( 705) /0.4000000000E+04/
     *    WIDTH( 705) /0.1000000000E+04/
      DATA STRIKE( 706) /0.2426007660E+01/
     *    HL( 706) /0.1000000000E+04/
     *    EQLAT( 706) /0.6264302590E+00/
     *    EQLON( 706) /0.2102041215E+01/
     *    SSLIP( 706) /0.4000000000E+00/
     *    DSLIP( 706) /0.0000000000E+00/
     *    DIP( 706) /0.1570796327E+01/
     *    DEPTH( 706) /0.4000000000E+04/
     *    WIDTH( 706) /0.1000000000E+04/
      DATA STRIKE( 707) /0.2426007660E+01/
     *    HL( 707) /0.1000000000E+04/
     *    EQLAT( 707) /0.6266672747E+00/
     *    EQLON( 707) /0.2102294463E+01/
     *    SSLIP( 707) /0.3730000000E+00/
     *    DSLIP( 707) /0.0000000000E+00/
     *    DIP( 707) /0.1570796327E+01/
     *    DEPTH( 707) /0.4000000000E+04/
     *    WIDTH( 707) /0.1000000000E+04/
      DATA STRIKE( 708) /0.2426007660E+01/
     *    HL( 708) /0.1000000000E+04/
     *    EQLAT( 708) /0.6269042904E+00/
     *    EQLON( 708) /0.2102547710E+01/
     *    SSLIP( 708) /0.3410000000E+00/
     *    DSLIP( 708) /0.0000000000E+00/
     *    DIP( 708) /0.1570796327E+01/
     *    DEPTH( 708) /0.4000000000E+04/
     *    WIDTH( 708) /0.1000000000E+04/
      DATA STRIKE( 709) /0.2426007660E+01/
     *    HL( 709) /0.1000000000E+04/
     *    EQLAT( 709) /0.6271413061E+00/
     *    EQLON( 709) /0.2102800957E+01/
     *    SSLIP( 709) /0.4620000000E+00/
     *    DSLIP( 709) /0.0000000000E+00/
     *    DIP( 709) /0.1570796327E+01/
     *    DEPTH( 709) /0.4000000000E+04/
     *    WIDTH( 709) /0.1000000000E+04/
      DATA STRIKE( 710) /0.2426007660E+01/
     *    HL( 710) /0.1000000000E+04/
     *    EQLAT( 710) /0.6273783218E+00/
     *    EQLON( 710) /0.2103054204E+01/
     *    SSLIP( 710) /0.4500000000E+00/
     *    DSLIP( 710) /0.0000000000E+00/
     *    DIP( 710) /0.1570796327E+01/
     *    DEPTH( 710) /0.4000000000E+04/
     *    WIDTH( 710) /0.1000000000E+04/
      DATA STRIKE( 711) /0.2426007660E+01/
     *    HL( 711) /0.1000000000E+04/
     *    EQLAT( 711) /0.6276153376E+00/
     *    EQLON( 711) /0.2103307452E+01/
     *    SSLIP( 711) /0.2790000000E+00/
     *    DSLIP( 711) /0.0000000000E+00/
     *    DIP( 711) /0.1570796327E+01/
     *    DEPTH( 711) /0.4000000000E+04/
     *    WIDTH( 711) /0.1000000000E+04/
      DATA STRIKE( 712) /0.2426007660E+01/
     *    HL( 712) /0.1000000000E+04/
     *    EQLAT( 712) /0.6278525278E+00/
     *    EQLON( 712) /0.2103560699E+01/
     *    SSLIP( 712) /0.1430000000E+00/
     *    DSLIP( 712) /0.0000000000E+00/
     *    DIP( 712) /0.1570796327E+01/
     *    DEPTH( 712) /0.4000000000E+04/
     *    WIDTH( 712) /0.1000000000E+04/
      DATA STRIKE( 713) /0.2426007660E+01/
     *    HL( 713) /0.1000000000E+04/
     *    EQLAT( 713) /0.6280895435E+00/
     *    EQLON( 713) /0.2103813946E+01/
     *    SSLIP( 713) /0.1160000000E+00/
     *    DSLIP( 713) /0.0000000000E+00/
     *    DIP( 713) /0.1570796327E+01/
     *    DEPTH( 713) /0.4000000000E+04/
     *    WIDTH( 713) /0.1000000000E+04/
      DATA STRIKE( 714) /0.2426007660E+01/
     *    HL( 714) /0.1000000000E+04/
     *    EQLAT( 714) /0.6283265592E+00/
     *    EQLON( 714) /0.2104067194E+01/
     *    SSLIP( 714) /0.1080000000E+00/
     *    DSLIP( 714) /0.0000000000E+00/
     *    DIP( 714) /0.1570796327E+01/
     *    DEPTH( 714) /0.4000000000E+04/
     *    WIDTH( 714) /0.1000000000E+04/
      DATA STRIKE( 715) /0.2426007660E+01/
     *    HL( 715) /0.1000000000E+04/
     *    EQLAT( 715) /0.6285635749E+00/
     *    EQLON( 715) /0.2104320441E+01/
     *    SSLIP( 715) /0.8300000000E-01/
     *    DSLIP( 715) /0.0000000000E+00/
     *    DIP( 715) /0.1570796327E+01/
     *    DEPTH( 715) /0.4000000000E+04/
     *    WIDTH( 715) /0.1000000000E+04/
      DATA STRIKE( 716) /0.2424262331E+01/
     *    HL( 716) /0.1000000000E+04/
     *    EQLAT( 716) /0.6240597528E+00/
     *    EQLON( 716) /0.2099508917E+01/
     *    SSLIP( 716) /0.0000000000E+00/
     *    DSLIP( 716) /0.0000000000E+00/
     *    DIP( 716) /0.1570796327E+01/
     *    DEPTH( 716) /0.5000000000E+04/
     *    WIDTH( 716) /0.1000000000E+04/
      DATA STRIKE( 717) /0.2426007660E+01/
     *    HL( 717) /0.1000000000E+04/
     *    EQLAT( 717) /0.6242967685E+00/
     *    EQLON( 717) /0.2099762164E+01/
     *    SSLIP( 717) /0.0000000000E+00/
     *    DSLIP( 717) /0.0000000000E+00/
     *    DIP( 717) /0.1570796327E+01/
     *    DEPTH( 717) /0.5000000000E+04/
     *    WIDTH( 717) /0.1000000000E+04/
      DATA STRIKE( 718) /0.2426007660E+01/
     *    HL( 718) /0.1000000000E+04/
     *    EQLAT( 718) /0.6245337842E+00/
     *    EQLON( 718) /0.2100015412E+01/
     *    SSLIP( 718) /0.1400000000E-01/
     *    DSLIP( 718) /0.0000000000E+00/
     *    DIP( 718) /0.1570796327E+01/
     *    DEPTH( 718) /0.5000000000E+04/
     *    WIDTH( 718) /0.1000000000E+04/
      DATA STRIKE( 719) /0.2426007660E+01/
     *    HL( 719) /0.1000000000E+04/
     *    EQLAT( 719) /0.6247707999E+00/
     *    EQLON( 719) /0.2100268484E+01/
     *    SSLIP( 719) /0.1070000000E+00/
     *    DSLIP( 719) /0.0000000000E+00/
     *    DIP( 719) /0.1570796327E+01/
     *    DEPTH( 719) /0.5000000000E+04/
     *    WIDTH( 719) /0.1000000000E+04/
      DATA STRIKE( 720) /0.2426007660E+01/
     *    HL( 720) /0.1000000000E+04/
     *    EQLAT( 720) /0.6250079902E+00/
     *    EQLON( 720) /0.2100521732E+01/
     *    SSLIP( 720) /0.1720000000E+00/
     *    DSLIP( 720) /0.0000000000E+00/
     *    DIP( 720) /0.1570796327E+01/
     *    DEPTH( 720) /0.5000000000E+04/
     *    WIDTH( 720) /0.1000000000E+04/
      DATA STRIKE( 721) /0.2426007660E+01/
     *    HL( 721) /0.1000000000E+04/
     *    EQLAT( 721) /0.6252450059E+00/
     *    EQLON( 721) /0.2100774979E+01/
     *    SSLIP( 721) /0.1940000000E+00/
     *    DSLIP( 721) /0.0000000000E+00/
     *    DIP( 721) /0.1570796327E+01/
     *    DEPTH( 721) /0.5000000000E+04/
     *    WIDTH( 721) /0.1000000000E+04/
      DATA STRIKE( 722) /0.2426007660E+01/
     *    HL( 722) /0.1000000000E+04/
     *    EQLAT( 722) /0.6254820216E+00/
     *    EQLON( 722) /0.2101028226E+01/
     *    SSLIP( 722) /0.2350000000E+00/
     *    DSLIP( 722) /0.0000000000E+00/
     *    DIP( 722) /0.1570796327E+01/
     *    DEPTH( 722) /0.5000000000E+04/
     *    WIDTH( 722) /0.1000000000E+04/
      DATA STRIKE( 723) /0.2426007660E+01/
     *    HL( 723) /0.1000000000E+04/
     *    EQLAT( 723) /0.6257190373E+00/
     *    EQLON( 723) /0.2101281473E+01/
     *    SSLIP( 723) /0.2500000000E+00/
     *    DSLIP( 723) /0.0000000000E+00/
     *    DIP( 723) /0.1570796327E+01/
     *    DEPTH( 723) /0.5000000000E+04/
     *    WIDTH( 723) /0.1000000000E+04/
      DATA STRIKE( 724) /0.2426007660E+01/
     *    HL( 724) /0.1000000000E+04/
     *    EQLAT( 724) /0.6259560530E+00/
     *    EQLON( 724) /0.2101534721E+01/
     *    SSLIP( 724) /0.1900000000E+00/
     *    DSLIP( 724) /0.0000000000E+00/
     *    DIP( 724) /0.1570796327E+01/
     *    DEPTH( 724) /0.5000000000E+04/
     *    WIDTH( 724) /0.1000000000E+04/
      DATA STRIKE( 725) /0.2426007660E+01/
     *    HL( 725) /0.1000000000E+04/
     *    EQLAT( 725) /0.6261930688E+00/
     *    EQLON( 725) /0.2101787968E+01/
     *    SSLIP( 725) /0.2660000000E+00/
     *    DSLIP( 725) /0.0000000000E+00/
     *    DIP( 725) /0.1570796327E+01/
     *    DEPTH( 725) /0.5000000000E+04/
     *    WIDTH( 725) /0.1000000000E+04/
      DATA STRIKE( 726) /0.2426007660E+01/
     *    HL( 726) /0.1000000000E+04/
     *    EQLAT( 726) /0.6264302590E+00/
     *    EQLON( 726) /0.2102041215E+01/
     *    SSLIP( 726) /0.4050000000E+00/
     *    DSLIP( 726) /0.0000000000E+00/
     *    DIP( 726) /0.1570796327E+01/
     *    DEPTH( 726) /0.5000000000E+04/
     *    WIDTH( 726) /0.1000000000E+04/
      DATA STRIKE( 727) /0.2426007660E+01/
     *    HL( 727) /0.1000000000E+04/
     *    EQLAT( 727) /0.6266672747E+00/
     *    EQLON( 727) /0.2102294463E+01/
     *    SSLIP( 727) /0.3820000000E+00/
     *    DSLIP( 727) /0.0000000000E+00/
     *    DIP( 727) /0.1570796327E+01/
     *    DEPTH( 727) /0.5000000000E+04/
     *    WIDTH( 727) /0.1000000000E+04/
      DATA STRIKE( 728) /0.2426007660E+01/
     *    HL( 728) /0.1000000000E+04/
     *    EQLAT( 728) /0.6269042904E+00/
     *    EQLON( 728) /0.2102547710E+01/
     *    SSLIP( 728) /0.3670000000E+00/
     *    DSLIP( 728) /0.0000000000E+00/
     *    DIP( 728) /0.1570796327E+01/
     *    DEPTH( 728) /0.5000000000E+04/
     *    WIDTH( 728) /0.1000000000E+04/
      DATA STRIKE( 729) /0.2426007660E+01/
     *    HL( 729) /0.1000000000E+04/
     *    EQLAT( 729) /0.6271413061E+00/
     *    EQLON( 729) /0.2102800957E+01/
     *    SSLIP( 729) /0.4770000000E+00/
     *    DSLIP( 729) /0.0000000000E+00/
     *    DIP( 729) /0.1570796327E+01/
     *    DEPTH( 729) /0.5000000000E+04/
     *    WIDTH( 729) /0.1000000000E+04/
      DATA STRIKE( 730) /0.2426007660E+01/
     *    HL( 730) /0.1000000000E+04/
     *    EQLAT( 730) /0.6273783218E+00/
     *    EQLON( 730) /0.2103054204E+01/
     *    SSLIP( 730) /0.4550000000E+00/
     *    DSLIP( 730) /0.0000000000E+00/
     *    DIP( 730) /0.1570796327E+01/
     *    DEPTH( 730) /0.5000000000E+04/
     *    WIDTH( 730) /0.1000000000E+04/
      DATA STRIKE( 731) /0.2426007660E+01/
     *    HL( 731) /0.1000000000E+04/
     *    EQLAT( 731) /0.6276153376E+00/
     *    EQLON( 731) /0.2103307452E+01/
     *    SSLIP( 731) /0.2820000000E+00/
     *    DSLIP( 731) /0.0000000000E+00/
     *    DIP( 731) /0.1570796327E+01/
     *    DEPTH( 731) /0.5000000000E+04/
     *    WIDTH( 731) /0.1000000000E+04/
      DATA STRIKE( 732) /0.2426007660E+01/
     *    HL( 732) /0.1000000000E+04/
     *    EQLAT( 732) /0.6278525278E+00/
     *    EQLON( 732) /0.2103560699E+01/
     *    SSLIP( 732) /0.1520000000E+00/
     *    DSLIP( 732) /0.0000000000E+00/
     *    DIP( 732) /0.1570796327E+01/
     *    DEPTH( 732) /0.5000000000E+04/
     *    WIDTH( 732) /0.1000000000E+04/
      DATA STRIKE( 733) /0.2426007660E+01/
     *    HL( 733) /0.1000000000E+04/
     *    EQLAT( 733) /0.6280895435E+00/
     *    EQLON( 733) /0.2103813946E+01/
     *    SSLIP( 733) /0.1330000000E+00/
     *    DSLIP( 733) /0.0000000000E+00/
     *    DIP( 733) /0.1570796327E+01/
     *    DEPTH( 733) /0.5000000000E+04/
     *    WIDTH( 733) /0.1000000000E+04/
      DATA STRIKE( 734) /0.2426007660E+01/
     *    HL( 734) /0.1000000000E+04/
     *    EQLAT( 734) /0.6283265592E+00/
     *    EQLON( 734) /0.2104067194E+01/
     *    SSLIP( 734) /0.1440000000E+00/
     *    DSLIP( 734) /0.0000000000E+00/
     *    DIP( 734) /0.1570796327E+01/
     *    DEPTH( 734) /0.5000000000E+04/
     *    WIDTH( 734) /0.1000000000E+04/
      DATA STRIKE( 735) /0.2426007660E+01/
     *    HL( 735) /0.1000000000E+04/
     *    EQLAT( 735) /0.6285635749E+00/
     *    EQLON( 735) /0.2104320441E+01/
     *    SSLIP( 735) /0.1120000000E+00/
     *    DSLIP( 735) /0.0000000000E+00/
     *    DIP( 735) /0.1570796327E+01/
     *    DEPTH( 735) /0.5000000000E+04/
     *    WIDTH( 735) /0.1000000000E+04/
      DATA STRIKE( 736) /0.2424262331E+01/
     *    HL( 736) /0.1000000000E+04/
     *    EQLAT( 736) /0.6240597528E+00/
     *    EQLON( 736) /0.2099508917E+01/
     *    SSLIP( 736) /0.0000000000E+00/
     *    DSLIP( 736) /0.0000000000E+00/
     *    DIP( 736) /0.1570796327E+01/
     *    DEPTH( 736) /0.6000000000E+04/
     *    WIDTH( 736) /0.1000000000E+04/
      DATA STRIKE( 737) /0.2426007660E+01/
     *    HL( 737) /0.1000000000E+04/
     *    EQLAT( 737) /0.6242967685E+00/
     *    EQLON( 737) /0.2099762164E+01/
     *    SSLIP( 737) /0.0000000000E+00/
     *    DSLIP( 737) /0.0000000000E+00/
     *    DIP( 737) /0.1570796327E+01/
     *    DEPTH( 737) /0.6000000000E+04/
     *    WIDTH( 737) /0.1000000000E+04/
      DATA STRIKE( 738) /0.2426007660E+01/
     *    HL( 738) /0.1000000000E+04/
     *    EQLAT( 738) /0.6245337842E+00/
     *    EQLON( 738) /0.2100015412E+01/
     *    SSLIP( 738) /0.2000000000E-02/
     *    DSLIP( 738) /0.0000000000E+00/
     *    DIP( 738) /0.1570796327E+01/
     *    DEPTH( 738) /0.6000000000E+04/
     *    WIDTH( 738) /0.1000000000E+04/
      DATA STRIKE( 739) /0.2426007660E+01/
     *    HL( 739) /0.1000000000E+04/
     *    EQLAT( 739) /0.6247707999E+00/
     *    EQLON( 739) /0.2100268484E+01/
     *    SSLIP( 739) /0.7700000000E-01/
     *    DSLIP( 739) /0.0000000000E+00/
     *    DIP( 739) /0.1570796327E+01/
     *    DEPTH( 739) /0.6000000000E+04/
     *    WIDTH( 739) /0.1000000000E+04/
      DATA STRIKE( 740) /0.2426007660E+01/
     *    HL( 740) /0.1000000000E+04/
     *    EQLAT( 740) /0.6250079902E+00/
     *    EQLON( 740) /0.2100521732E+01/
     *    SSLIP( 740) /0.1560000000E+00/
     *    DSLIP( 740) /0.0000000000E+00/
     *    DIP( 740) /0.1570796327E+01/
     *    DEPTH( 740) /0.6000000000E+04/
     *    WIDTH( 740) /0.1000000000E+04/
      DATA STRIKE( 741) /0.2426007660E+01/
     *    HL( 741) /0.1000000000E+04/
     *    EQLAT( 741) /0.6252450059E+00/
     *    EQLON( 741) /0.2100774979E+01/
     *    SSLIP( 741) /0.2000000000E+00/
     *    DSLIP( 741) /0.0000000000E+00/
     *    DIP( 741) /0.1570796327E+01/
     *    DEPTH( 741) /0.6000000000E+04/
     *    WIDTH( 741) /0.1000000000E+04/
      DATA STRIKE( 742) /0.2426007660E+01/
     *    HL( 742) /0.1000000000E+04/
     *    EQLAT( 742) /0.6254820216E+00/
     *    EQLON( 742) /0.2101028226E+01/
     *    SSLIP( 742) /0.2400000000E+00/
     *    DSLIP( 742) /0.0000000000E+00/
     *    DIP( 742) /0.1570796327E+01/
     *    DEPTH( 742) /0.6000000000E+04/
     *    WIDTH( 742) /0.1000000000E+04/
      DATA STRIKE( 743) /0.2426007660E+01/
     *    HL( 743) /0.1000000000E+04/
     *    EQLAT( 743) /0.6257190373E+00/
     *    EQLON( 743) /0.2101281473E+01/
     *    SSLIP( 743) /0.2540000000E+00/
     *    DSLIP( 743) /0.0000000000E+00/
     *    DIP( 743) /0.1570796327E+01/
     *    DEPTH( 743) /0.6000000000E+04/
     *    WIDTH( 743) /0.1000000000E+04/
      DATA STRIKE( 744) /0.2426007660E+01/
     *    HL( 744) /0.1000000000E+04/
     *    EQLAT( 744) /0.6259560530E+00/
     *    EQLON( 744) /0.2101534721E+01/
     *    SSLIP( 744) /0.2270000000E+00/
     *    DSLIP( 744) /0.0000000000E+00/
     *    DIP( 744) /0.1570796327E+01/
     *    DEPTH( 744) /0.6000000000E+04/
     *    WIDTH( 744) /0.1000000000E+04/
      DATA STRIKE( 745) /0.2426007660E+01/
     *    HL( 745) /0.1000000000E+04/
     *    EQLAT( 745) /0.6261930688E+00/
     *    EQLON( 745) /0.2101787968E+01/
     *    SSLIP( 745) /0.2950000000E+00/
     *    DSLIP( 745) /0.0000000000E+00/
     *    DIP( 745) /0.1570796327E+01/
     *    DEPTH( 745) /0.6000000000E+04/
     *    WIDTH( 745) /0.1000000000E+04/
      DATA STRIKE( 746) /0.2426007660E+01/
     *    HL( 746) /0.1000000000E+04/
     *    EQLAT( 746) /0.6264302590E+00/
     *    EQLON( 746) /0.2102041215E+01/
     *    SSLIP( 746) /0.3950000000E+00/
     *    DSLIP( 746) /0.0000000000E+00/
     *    DIP( 746) /0.1570796327E+01/
     *    DEPTH( 746) /0.6000000000E+04/
     *    WIDTH( 746) /0.1000000000E+04/
      DATA STRIKE( 747) /0.2426007660E+01/
     *    HL( 747) /0.1000000000E+04/
     *    EQLAT( 747) /0.6266672747E+00/
     *    EQLON( 747) /0.2102294463E+01/
     *    SSLIP( 747) /0.3770000000E+00/
     *    DSLIP( 747) /0.0000000000E+00/
     *    DIP( 747) /0.1570796327E+01/
     *    DEPTH( 747) /0.6000000000E+04/
     *    WIDTH( 747) /0.1000000000E+04/
      DATA STRIKE( 748) /0.2426007660E+01/
     *    HL( 748) /0.1000000000E+04/
     *    EQLAT( 748) /0.6269042904E+00/
     *    EQLON( 748) /0.2102547710E+01/
     *    SSLIP( 748) /0.3750000000E+00/
     *    DSLIP( 748) /0.0000000000E+00/
     *    DIP( 748) /0.1570796327E+01/
     *    DEPTH( 748) /0.6000000000E+04/
     *    WIDTH( 748) /0.1000000000E+04/
      DATA STRIKE( 749) /0.2426007660E+01/
     *    HL( 749) /0.1000000000E+04/
     *    EQLAT( 749) /0.6271413061E+00/
     *    EQLON( 749) /0.2102800957E+01/
     *    SSLIP( 749) /0.4630000000E+00/
     *    DSLIP( 749) /0.0000000000E+00/
     *    DIP( 749) /0.1570796327E+01/
     *    DEPTH( 749) /0.6000000000E+04/
     *    WIDTH( 749) /0.1000000000E+04/
      DATA STRIKE( 750) /0.2426007660E+01/
     *    HL( 750) /0.1000000000E+04/
     *    EQLAT( 750) /0.6273783218E+00/
     *    EQLON( 750) /0.2103054204E+01/
     *    SSLIP( 750) /0.4370000000E+00/
     *    DSLIP( 750) /0.0000000000E+00/
     *    DIP( 750) /0.1570796327E+01/
     *    DEPTH( 750) /0.6000000000E+04/
     *    WIDTH( 750) /0.1000000000E+04/
      DATA STRIKE( 751) /0.2426007660E+01/
     *    HL( 751) /0.1000000000E+04/
     *    EQLAT( 751) /0.6276153376E+00/
     *    EQLON( 751) /0.2103307452E+01/
     *    SSLIP( 751) /0.2830000000E+00/
     *    DSLIP( 751) /0.0000000000E+00/
     *    DIP( 751) /0.1570796327E+01/
     *    DEPTH( 751) /0.6000000000E+04/
     *    WIDTH( 751) /0.1000000000E+04/
      DATA STRIKE( 752) /0.2426007660E+01/
     *    HL( 752) /0.1000000000E+04/
     *    EQLAT( 752) /0.6278525278E+00/
     *    EQLON( 752) /0.2103560699E+01/
     *    SSLIP( 752) /0.1690000000E+00/
     *    DSLIP( 752) /0.0000000000E+00/
     *    DIP( 752) /0.1570796327E+01/
     *    DEPTH( 752) /0.6000000000E+04/
     *    WIDTH( 752) /0.1000000000E+04/
      DATA STRIKE( 753) /0.2426007660E+01/
     *    HL( 753) /0.1000000000E+04/
     *    EQLAT( 753) /0.6280895435E+00/
     *    EQLON( 753) /0.2103813946E+01/
     *    SSLIP( 753) /0.1600000000E+00/
     *    DSLIP( 753) /0.0000000000E+00/
     *    DIP( 753) /0.1570796327E+01/
     *    DEPTH( 753) /0.6000000000E+04/
     *    WIDTH( 753) /0.1000000000E+04/
      DATA STRIKE( 754) /0.2426007660E+01/
     *    HL( 754) /0.1000000000E+04/
     *    EQLAT( 754) /0.6283265592E+00/
     *    EQLON( 754) /0.2104067194E+01/
     *    SSLIP( 754) /0.1810000000E+00/
     *    DSLIP( 754) /0.0000000000E+00/
     *    DIP( 754) /0.1570796327E+01/
     *    DEPTH( 754) /0.6000000000E+04/
     *    WIDTH( 754) /0.1000000000E+04/
      DATA STRIKE( 755) /0.2426007660E+01/
     *    HL( 755) /0.1000000000E+04/
     *    EQLAT( 755) /0.6285635749E+00/
     *    EQLON( 755) /0.2104320441E+01/
     *    SSLIP( 755) /0.1380000000E+00/
     *    DSLIP( 755) /0.0000000000E+00/
     *    DIP( 755) /0.1570796327E+01/
     *    DEPTH( 755) /0.6000000000E+04/
     *    WIDTH( 755) /0.1000000000E+04/
      DATA STRIKE( 756) /0.2424262331E+01/
     *    HL( 756) /0.1000000000E+04/
     *    EQLAT( 756) /0.6240597528E+00/
     *    EQLON( 756) /0.2099508917E+01/
     *    SSLIP( 756) /0.0000000000E+00/
     *    DSLIP( 756) /0.0000000000E+00/
     *    DIP( 756) /0.1570796327E+01/
     *    DEPTH( 756) /0.7000000000E+04/
     *    WIDTH( 756) /0.1000000000E+04/
      DATA STRIKE( 757) /0.2426007660E+01/
     *    HL( 757) /0.1000000000E+04/
     *    EQLAT( 757) /0.6242967685E+00/
     *    EQLON( 757) /0.2099762164E+01/
     *    SSLIP( 757) /0.0000000000E+00/
     *    DSLIP( 757) /0.0000000000E+00/
     *    DIP( 757) /0.1570796327E+01/
     *    DEPTH( 757) /0.7000000000E+04/
     *    WIDTH( 757) /0.1000000000E+04/
      DATA STRIKE( 758) /0.2426007660E+01/
     *    HL( 758) /0.1000000000E+04/
     *    EQLAT( 758) /0.6245337842E+00/
     *    EQLON( 758) /0.2100015412E+01/
     *    SSLIP( 758) /0.2300000000E-01/
     *    DSLIP( 758) /0.0000000000E+00/
     *    DIP( 758) /0.1570796327E+01/
     *    DEPTH( 758) /0.7000000000E+04/
     *    WIDTH( 758) /0.1000000000E+04/
      DATA STRIKE( 759) /0.2426007660E+01/
     *    HL( 759) /0.1000000000E+04/
     *    EQLAT( 759) /0.6247707999E+00/
     *    EQLON( 759) /0.2100268484E+01/
     *    SSLIP( 759) /0.9200000000E-01/
     *    DSLIP( 759) /0.0000000000E+00/
     *    DIP( 759) /0.1570796327E+01/
     *    DEPTH( 759) /0.7000000000E+04/
     *    WIDTH( 759) /0.1000000000E+04/
      DATA STRIKE( 760) /0.2426007660E+01/
     *    HL( 760) /0.1000000000E+04/
     *    EQLAT( 760) /0.6250079902E+00/
     *    EQLON( 760) /0.2100521732E+01/
     *    SSLIP( 760) /0.1800000000E+00/
     *    DSLIP( 760) /0.0000000000E+00/
     *    DIP( 760) /0.1570796327E+01/
     *    DEPTH( 760) /0.7000000000E+04/
     *    WIDTH( 760) /0.1000000000E+04/
      DATA STRIKE( 761) /0.2426007660E+01/
     *    HL( 761) /0.1000000000E+04/
     *    EQLAT( 761) /0.6252450059E+00/
     *    EQLON( 761) /0.2100774979E+01/
     *    SSLIP( 761) /0.2410000000E+00/
     *    DSLIP( 761) /0.0000000000E+00/
     *    DIP( 761) /0.1570796327E+01/
     *    DEPTH( 761) /0.7000000000E+04/
     *    WIDTH( 761) /0.1000000000E+04/
      DATA STRIKE( 762) /0.2426007660E+01/
     *    HL( 762) /0.1000000000E+04/
     *    EQLAT( 762) /0.6254820216E+00/
     *    EQLON( 762) /0.2101028226E+01/
     *    SSLIP( 762) /0.2800000000E+00/
     *    DSLIP( 762) /0.0000000000E+00/
     *    DIP( 762) /0.1570796327E+01/
     *    DEPTH( 762) /0.7000000000E+04/
     *    WIDTH( 762) /0.1000000000E+04/
      DATA STRIKE( 763) /0.2426007660E+01/
     *    HL( 763) /0.1000000000E+04/
     *    EQLAT( 763) /0.6257190373E+00/
     *    EQLON( 763) /0.2101281473E+01/
     *    SSLIP( 763) /0.2900000000E+00/
     *    DSLIP( 763) /0.0000000000E+00/
     *    DIP( 763) /0.1570796327E+01/
     *    DEPTH( 763) /0.7000000000E+04/
     *    WIDTH( 763) /0.1000000000E+04/
      DATA STRIKE( 764) /0.2426007660E+01/
     *    HL( 764) /0.1000000000E+04/
     *    EQLAT( 764) /0.6259560530E+00/
     *    EQLON( 764) /0.2101534721E+01/
     *    SSLIP( 764) /0.2760000000E+00/
     *    DSLIP( 764) /0.0000000000E+00/
     *    DIP( 764) /0.1570796327E+01/
     *    DEPTH( 764) /0.7000000000E+04/
     *    WIDTH( 764) /0.1000000000E+04/
      DATA STRIKE( 765) /0.2426007660E+01/
     *    HL( 765) /0.1000000000E+04/
     *    EQLAT( 765) /0.6261930688E+00/
     *    EQLON( 765) /0.2101787968E+01/
     *    SSLIP( 765) /0.3200000000E+00/
     *    DSLIP( 765) /0.0000000000E+00/
     *    DIP( 765) /0.1570796327E+01/
     *    DEPTH( 765) /0.7000000000E+04/
     *    WIDTH( 765) /0.1000000000E+04/
      DATA STRIKE( 766) /0.2426007660E+01/
     *    HL( 766) /0.1000000000E+04/
     *    EQLAT( 766) /0.6264302590E+00/
     *    EQLON( 766) /0.2102041215E+01/
     *    SSLIP( 766) /0.3780000000E+00/
     *    DSLIP( 766) /0.0000000000E+00/
     *    DIP( 766) /0.1570796327E+01/
     *    DEPTH( 766) /0.7000000000E+04/
     *    WIDTH( 766) /0.1000000000E+04/
      DATA STRIKE( 767) /0.2426007660E+01/
     *    HL( 767) /0.1000000000E+04/
     *    EQLAT( 767) /0.6266672747E+00/
     *    EQLON( 767) /0.2102294463E+01/
     *    SSLIP( 767) /0.3610000000E+00/
     *    DSLIP( 767) /0.0000000000E+00/
     *    DIP( 767) /0.1570796327E+01/
     *    DEPTH( 767) /0.7000000000E+04/
     *    WIDTH( 767) /0.1000000000E+04/
      DATA STRIKE( 768) /0.2426007660E+01/
     *    HL( 768) /0.1000000000E+04/
     *    EQLAT( 768) /0.6269042904E+00/
     *    EQLON( 768) /0.2102547710E+01/
     *    SSLIP( 768) /0.3650000000E+00/
     *    DSLIP( 768) /0.0000000000E+00/
     *    DIP( 768) /0.1570796327E+01/
     *    DEPTH( 768) /0.7000000000E+04/
     *    WIDTH( 768) /0.1000000000E+04/
      DATA STRIKE( 769) /0.2426007660E+01/
     *    HL( 769) /0.1000000000E+04/
     *    EQLAT( 769) /0.6271413061E+00/
     *    EQLON( 769) /0.2102800957E+01/
     *    SSLIP( 769) /0.4300000000E+00/
     *    DSLIP( 769) /0.0000000000E+00/
     *    DIP( 769) /0.1570796327E+01/
     *    DEPTH( 769) /0.7000000000E+04/
     *    WIDTH( 769) /0.1000000000E+04/
      DATA STRIKE( 770) /0.2426007660E+01/
     *    HL( 770) /0.1000000000E+04/
     *    EQLAT( 770) /0.6273783218E+00/
     *    EQLON( 770) /0.2103054204E+01/
     *    SSLIP( 770) /0.4050000000E+00/
     *    DSLIP( 770) /0.0000000000E+00/
     *    DIP( 770) /0.1570796327E+01/
     *    DEPTH( 770) /0.7000000000E+04/
     *    WIDTH( 770) /0.1000000000E+04/
      DATA STRIKE( 771) /0.2426007660E+01/
     *    HL( 771) /0.1000000000E+04/
     *    EQLAT( 771) /0.6276153376E+00/
     *    EQLON( 771) /0.2103307452E+01/
     *    SSLIP( 771) /0.2800000000E+00/
     *    DSLIP( 771) /0.0000000000E+00/
     *    DIP( 771) /0.1570796327E+01/
     *    DEPTH( 771) /0.7000000000E+04/
     *    WIDTH( 771) /0.1000000000E+04/
      DATA STRIKE( 772) /0.2426007660E+01/
     *    HL( 772) /0.1000000000E+04/
     *    EQLAT( 772) /0.6278525278E+00/
     *    EQLON( 772) /0.2103560699E+01/
     *    SSLIP( 772) /0.1890000000E+00/
     *    DSLIP( 772) /0.0000000000E+00/
     *    DIP( 772) /0.1570796327E+01/
     *    DEPTH( 772) /0.7000000000E+04/
     *    WIDTH( 772) /0.1000000000E+04/
      DATA STRIKE( 773) /0.2426007660E+01/
     *    HL( 773) /0.1000000000E+04/
     *    EQLAT( 773) /0.6280895435E+00/
     *    EQLON( 773) /0.2103813946E+01/
     *    SSLIP( 773) /0.1920000000E+00/
     *    DSLIP( 773) /0.0000000000E+00/
     *    DIP( 773) /0.1570796327E+01/
     *    DEPTH( 773) /0.7000000000E+04/
     *    WIDTH( 773) /0.1000000000E+04/
      DATA STRIKE( 774) /0.2426007660E+01/
     *    HL( 774) /0.1000000000E+04/
     *    EQLAT( 774) /0.6283265592E+00/
     *    EQLON( 774) /0.2104067194E+01/
     *    SSLIP( 774) /0.2140000000E+00/
     *    DSLIP( 774) /0.0000000000E+00/
     *    DIP( 774) /0.1570796327E+01/
     *    DEPTH( 774) /0.7000000000E+04/
     *    WIDTH( 774) /0.1000000000E+04/
      DATA STRIKE( 775) /0.2426007660E+01/
     *    HL( 775) /0.1000000000E+04/
     *    EQLAT( 775) /0.6285635749E+00/
     *    EQLON( 775) /0.2104320441E+01/
     *    SSLIP( 775) /0.1580000000E+00/
     *    DSLIP( 775) /0.0000000000E+00/
     *    DIP( 775) /0.1570796327E+01/
     *    DEPTH( 775) /0.7000000000E+04/
     *    WIDTH( 775) /0.1000000000E+04/
      DATA STRIKE( 776) /0.2424262331E+01/
     *    HL( 776) /0.1000000000E+04/
     *    EQLAT( 776) /0.6240597528E+00/
     *    EQLON( 776) /0.2099508917E+01/
     *    SSLIP( 776) /0.0000000000E+00/
     *    DSLIP( 776) /0.0000000000E+00/
     *    DIP( 776) /0.1570796327E+01/
     *    DEPTH( 776) /0.8000000000E+04/
     *    WIDTH( 776) /0.1000000000E+04/
      DATA STRIKE( 777) /0.2426007660E+01/
     *    HL( 777) /0.1000000000E+04/
     *    EQLAT( 777) /0.6242967685E+00/
     *    EQLON( 777) /0.2099762164E+01/
     *    SSLIP( 777) /0.1700000000E-01/
     *    DSLIP( 777) /0.0000000000E+00/
     *    DIP( 777) /0.1570796327E+01/
     *    DEPTH( 777) /0.8000000000E+04/
     *    WIDTH( 777) /0.1000000000E+04/
      DATA STRIKE( 778) /0.2426007660E+01/
     *    HL( 778) /0.1000000000E+04/
     *    EQLAT( 778) /0.6245337842E+00/
     *    EQLON( 778) /0.2100015412E+01/
     *    SSLIP( 778) /0.6500000000E-01/
     *    DSLIP( 778) /0.0000000000E+00/
     *    DIP( 778) /0.1570796327E+01/
     *    DEPTH( 778) /0.8000000000E+04/
     *    WIDTH( 778) /0.1000000000E+04/
      DATA STRIKE( 779) /0.2426007660E+01/
     *    HL( 779) /0.1000000000E+04/
     *    EQLAT( 779) /0.6247707999E+00/
     *    EQLON( 779) /0.2100268484E+01/
     *    SSLIP( 779) /0.1400000000E+00/
     *    DSLIP( 779) /0.0000000000E+00/
     *    DIP( 779) /0.1570796327E+01/
     *    DEPTH( 779) /0.8000000000E+04/
     *    WIDTH( 779) /0.1000000000E+04/
      DATA STRIKE( 780) /0.2426007660E+01/
     *    HL( 780) /0.1000000000E+04/
     *    EQLAT( 780) /0.6250079902E+00/
     *    EQLON( 780) /0.2100521732E+01/
     *    SSLIP( 780) /0.2360000000E+00/
     *    DSLIP( 780) /0.0000000000E+00/
     *    DIP( 780) /0.1570796327E+01/
     *    DEPTH( 780) /0.8000000000E+04/
     *    WIDTH( 780) /0.1000000000E+04/
      DATA STRIKE( 781) /0.2426007660E+01/
     *    HL( 781) /0.1000000000E+04/
     *    EQLAT( 781) /0.6252450059E+00/
     *    EQLON( 781) /0.2100774979E+01/
     *    SSLIP( 781) /0.3070000000E+00/
     *    DSLIP( 781) /0.0000000000E+00/
     *    DIP( 781) /0.1570796327E+01/
     *    DEPTH( 781) /0.8000000000E+04/
     *    WIDTH( 781) /0.1000000000E+04/
      DATA STRIKE( 782) /0.2426007660E+01/
     *    HL( 782) /0.1000000000E+04/
     *    EQLAT( 782) /0.6254820216E+00/
     *    EQLON( 782) /0.2101028226E+01/
     *    SSLIP( 782) /0.3430000000E+00/
     *    DSLIP( 782) /0.0000000000E+00/
     *    DIP( 782) /0.1570796327E+01/
     *    DEPTH( 782) /0.8000000000E+04/
     *    WIDTH( 782) /0.1000000000E+04/
      DATA STRIKE( 783) /0.2426007660E+01/
     *    HL( 783) /0.1000000000E+04/
     *    EQLAT( 783) /0.6257190373E+00/
     *    EQLON( 783) /0.2101281473E+01/
     *    SSLIP( 783) /0.3430000000E+00/
     *    DSLIP( 783) /0.0000000000E+00/
     *    DIP( 783) /0.1570796327E+01/
     *    DEPTH( 783) /0.8000000000E+04/
     *    WIDTH( 783) /0.1000000000E+04/
      DATA STRIKE( 784) /0.2426007660E+01/
     *    HL( 784) /0.1000000000E+04/
     *    EQLAT( 784) /0.6259560530E+00/
     *    EQLON( 784) /0.2101534721E+01/
     *    SSLIP( 784) /0.3250000000E+00/
     *    DSLIP( 784) /0.0000000000E+00/
     *    DIP( 784) /0.1570796327E+01/
     *    DEPTH( 784) /0.8000000000E+04/
     *    WIDTH( 784) /0.1000000000E+04/
      DATA STRIKE( 785) /0.2426007660E+01/
     *    HL( 785) /0.1000000000E+04/
     *    EQLAT( 785) /0.6261930688E+00/
     *    EQLON( 785) /0.2101787968E+01/
     *    SSLIP( 785) /0.3380000000E+00/
     *    DSLIP( 785) /0.0000000000E+00/
     *    DIP( 785) /0.1570796327E+01/
     *    DEPTH( 785) /0.8000000000E+04/
     *    WIDTH( 785) /0.1000000000E+04/
      DATA STRIKE( 786) /0.2426007660E+01/
     *    HL( 786) /0.1000000000E+04/
     *    EQLAT( 786) /0.6264302590E+00/
     *    EQLON( 786) /0.2102041215E+01/
     *    SSLIP( 786) /0.3570000000E+00/
     *    DSLIP( 786) /0.0000000000E+00/
     *    DIP( 786) /0.1570796327E+01/
     *    DEPTH( 786) /0.8000000000E+04/
     *    WIDTH( 786) /0.1000000000E+04/
      DATA STRIKE( 787) /0.2426007660E+01/
     *    HL( 787) /0.1000000000E+04/
     *    EQLAT( 787) /0.6266672747E+00/
     *    EQLON( 787) /0.2102294463E+01/
     *    SSLIP( 787) /0.3360000000E+00/
     *    DSLIP( 787) /0.0000000000E+00/
     *    DIP( 787) /0.1570796327E+01/
     *    DEPTH( 787) /0.8000000000E+04/
     *    WIDTH( 787) /0.1000000000E+04/
      DATA STRIKE( 788) /0.2426007660E+01/
     *    HL( 788) /0.1000000000E+04/
     *    EQLAT( 788) /0.6269042904E+00/
     *    EQLON( 788) /0.2102547710E+01/
     *    SSLIP( 788) /0.3400000000E+00/
     *    DSLIP( 788) /0.0000000000E+00/
     *    DIP( 788) /0.1570796327E+01/
     *    DEPTH( 788) /0.8000000000E+04/
     *    WIDTH( 788) /0.1000000000E+04/
      DATA STRIKE( 789) /0.2426007660E+01/
     *    HL( 789) /0.1000000000E+04/
     *    EQLAT( 789) /0.6271413061E+00/
     *    EQLON( 789) /0.2102800957E+01/
     *    SSLIP( 789) /0.3850000000E+00/
     *    DSLIP( 789) /0.0000000000E+00/
     *    DIP( 789) /0.1570796327E+01/
     *    DEPTH( 789) /0.8000000000E+04/
     *    WIDTH( 789) /0.1000000000E+04/
      DATA STRIKE( 790) /0.2426007660E+01/
     *    HL( 790) /0.1000000000E+04/
     *    EQLAT( 790) /0.6273783218E+00/
     *    EQLON( 790) /0.2103054204E+01/
     *    SSLIP( 790) /0.3650000000E+00/
     *    DSLIP( 790) /0.0000000000E+00/
     *    DIP( 790) /0.1570796327E+01/
     *    DEPTH( 790) /0.8000000000E+04/
     *    WIDTH( 790) /0.1000000000E+04/
      DATA STRIKE( 791) /0.2426007660E+01/
     *    HL( 791) /0.1000000000E+04/
     *    EQLAT( 791) /0.6276153376E+00/
     *    EQLON( 791) /0.2103307452E+01/
     *    SSLIP( 791) /0.2700000000E+00/
     *    DSLIP( 791) /0.0000000000E+00/
     *    DIP( 791) /0.1570796327E+01/
     *    DEPTH( 791) /0.8000000000E+04/
     *    WIDTH( 791) /0.1000000000E+04/
      DATA STRIKE( 792) /0.2426007660E+01/
     *    HL( 792) /0.1000000000E+04/
     *    EQLAT( 792) /0.6278525278E+00/
     *    EQLON( 792) /0.2103560699E+01/
     *    SSLIP( 792) /0.2050000000E+00/
     *    DSLIP( 792) /0.0000000000E+00/
     *    DIP( 792) /0.1570796327E+01/
     *    DEPTH( 792) /0.8000000000E+04/
     *    WIDTH( 792) /0.1000000000E+04/
      DATA STRIKE( 793) /0.2426007660E+01/
     *    HL( 793) /0.1000000000E+04/
     *    EQLAT( 793) /0.6280895435E+00/
     *    EQLON( 793) /0.2103813946E+01/
     *    SSLIP( 793) /0.2210000000E+00/
     *    DSLIP( 793) /0.0000000000E+00/
     *    DIP( 793) /0.1570796327E+01/
     *    DEPTH( 793) /0.8000000000E+04/
     *    WIDTH( 793) /0.1000000000E+04/
      DATA STRIKE( 794) /0.2426007660E+01/
     *    HL( 794) /0.1000000000E+04/
     *    EQLAT( 794) /0.6283265592E+00/
     *    EQLON( 794) /0.2104067194E+01/
     *    SSLIP( 794) /0.2370000000E+00/
     *    DSLIP( 794) /0.0000000000E+00/
     *    DIP( 794) /0.1570796327E+01/
     *    DEPTH( 794) /0.8000000000E+04/
     *    WIDTH( 794) /0.1000000000E+04/
      DATA STRIKE( 795) /0.2426007660E+01/
     *    HL( 795) /0.1000000000E+04/
     *    EQLAT( 795) /0.6285635749E+00/
     *    EQLON( 795) /0.2104320441E+01/
     *    SSLIP( 795) /0.1710000000E+00/
     *    DSLIP( 795) /0.0000000000E+00/
     *    DIP( 795) /0.1570796327E+01/
     *    DEPTH( 795) /0.8000000000E+04/
     *    WIDTH( 795) /0.1000000000E+04/
      DATA STRIKE( 796) /0.2424262331E+01/
     *    HL( 796) /0.1000000000E+04/
     *    EQLAT( 796) /0.6240597528E+00/
     *    EQLON( 796) /0.2099508917E+01/
     *    SSLIP( 796) /0.1100000000E-01/
     *    DSLIP( 796) /0.0000000000E+00/
     *    DIP( 796) /0.1570796327E+01/
     *    DEPTH( 796) /0.9000000000E+04/
     *    WIDTH( 796) /0.1000000000E+04/
      DATA STRIKE( 797) /0.2426007660E+01/
     *    HL( 797) /0.1000000000E+04/
     *    EQLAT( 797) /0.6242967685E+00/
     *    EQLON( 797) /0.2099762164E+01/
     *    SSLIP( 797) /0.5000000000E-01/
     *    DSLIP( 797) /0.0000000000E+00/
     *    DIP( 797) /0.1570796327E+01/
     *    DEPTH( 797) /0.9000000000E+04/
     *    WIDTH( 797) /0.1000000000E+04/
      DATA STRIKE( 798) /0.2426007660E+01/
     *    HL( 798) /0.1000000000E+04/
     *    EQLAT( 798) /0.6245337842E+00/
     *    EQLON( 798) /0.2100015412E+01/
     *    SSLIP( 798) /0.1180000000E+00/
     *    DSLIP( 798) /0.0000000000E+00/
     *    DIP( 798) /0.1570796327E+01/
     *    DEPTH( 798) /0.9000000000E+04/
     *    WIDTH( 798) /0.1000000000E+04/
      DATA STRIKE( 799) /0.2426007660E+01/
     *    HL( 799) /0.1000000000E+04/
     *    EQLAT( 799) /0.6247707999E+00/
     *    EQLON( 799) /0.2100268484E+01/
     *    SSLIP( 799) /0.2050000000E+00/
     *    DSLIP( 799) /0.0000000000E+00/
     *    DIP( 799) /0.1570796327E+01/
     *    DEPTH( 799) /0.9000000000E+04/
     *    WIDTH( 799) /0.1000000000E+04/
      DATA STRIKE( 800) /0.2426007660E+01/
     *    HL( 800) /0.1000000000E+04/
     *    EQLAT( 800) /0.6250079902E+00/
     *    EQLON( 800) /0.2100521732E+01/
     *    SSLIP( 800) /0.3070000000E+00/
     *    DSLIP( 800) /0.0000000000E+00/
     *    DIP( 800) /0.1570796327E+01/
     *    DEPTH( 800) /0.9000000000E+04/
     *    WIDTH( 800) /0.1000000000E+04/
      DATA STRIKE( 801) /0.2426007660E+01/
     *    HL( 801) /0.1000000000E+04/
     *    EQLAT( 801) /0.6252450059E+00/
     *    EQLON( 801) /0.2100774979E+01/
     *    SSLIP( 801) /0.3800000000E+00/
     *    DSLIP( 801) /0.0000000000E+00/
     *    DIP( 801) /0.1570796327E+01/
     *    DEPTH( 801) /0.9000000000E+04/
     *    WIDTH( 801) /0.1000000000E+04/
      DATA STRIKE( 802) /0.2426007660E+01/
     *    HL( 802) /0.1000000000E+04/
     *    EQLAT( 802) /0.6254820216E+00/
     *    EQLON( 802) /0.2101028226E+01/
     *    SSLIP( 802) /0.4090000000E+00/
     *    DSLIP( 802) /0.0000000000E+00/
     *    DIP( 802) /0.1570796327E+01/
     *    DEPTH( 802) /0.9000000000E+04/
     *    WIDTH( 802) /0.1000000000E+04/
      DATA STRIKE( 803) /0.2426007660E+01/
     *    HL( 803) /0.1000000000E+04/
     *    EQLAT( 803) /0.6257190373E+00/
     *    EQLON( 803) /0.2101281473E+01/
     *    SSLIP( 803) /0.3970000000E+00/
     *    DSLIP( 803) /0.0000000000E+00/
     *    DIP( 803) /0.1570796327E+01/
     *    DEPTH( 803) /0.9000000000E+04/
     *    WIDTH( 803) /0.1000000000E+04/
      DATA STRIKE( 804) /0.2426007660E+01/
     *    HL( 804) /0.1000000000E+04/
     *    EQLAT( 804) /0.6259560530E+00/
     *    EQLON( 804) /0.2101534721E+01/
     *    SSLIP( 804) /0.3640000000E+00/
     *    DSLIP( 804) /0.0000000000E+00/
     *    DIP( 804) /0.1570796327E+01/
     *    DEPTH( 804) /0.9000000000E+04/
     *    WIDTH( 804) /0.1000000000E+04/
      DATA STRIKE( 805) /0.2426007660E+01/
     *    HL( 805) /0.1000000000E+04/
     *    EQLAT( 805) /0.6261930688E+00/
     *    EQLON( 805) /0.2101787968E+01/
     *    SSLIP( 805) /0.3460000000E+00/
     *    DSLIP( 805) /0.0000000000E+00/
     *    DIP( 805) /0.1570796327E+01/
     *    DEPTH( 805) /0.9000000000E+04/
     *    WIDTH( 805) /0.1000000000E+04/
      DATA STRIKE( 806) /0.2426007660E+01/
     *    HL( 806) /0.1000000000E+04/
     *    EQLAT( 806) /0.6264302590E+00/
     *    EQLON( 806) /0.2102041215E+01/
     *    SSLIP( 806) /0.3320000000E+00/
     *    DSLIP( 806) /0.0000000000E+00/
     *    DIP( 806) /0.1570796327E+01/
     *    DEPTH( 806) /0.9000000000E+04/
     *    WIDTH( 806) /0.1000000000E+04/
      DATA STRIKE( 807) /0.2426007660E+01/
     *    HL( 807) /0.1000000000E+04/
     *    EQLAT( 807) /0.6266672747E+00/
     *    EQLON( 807) /0.2102294463E+01/
     *    SSLIP( 807) /0.3040000000E+00/
     *    DSLIP( 807) /0.0000000000E+00/
     *    DIP( 807) /0.1570796327E+01/
     *    DEPTH( 807) /0.9000000000E+04/
     *    WIDTH( 807) /0.1000000000E+04/
      DATA STRIKE( 808) /0.2426007660E+01/
     *    HL( 808) /0.1000000000E+04/
     *    EQLAT( 808) /0.6269042904E+00/
     *    EQLON( 808) /0.2102547710E+01/
     *    SSLIP( 808) /0.3050000000E+00/
     *    DSLIP( 808) /0.0000000000E+00/
     *    DIP( 808) /0.1570796327E+01/
     *    DEPTH( 808) /0.9000000000E+04/
     *    WIDTH( 808) /0.1000000000E+04/
      DATA STRIKE( 809) /0.2426007660E+01/
     *    HL( 809) /0.1000000000E+04/
     *    EQLAT( 809) /0.6271413061E+00/
     *    EQLON( 809) /0.2102800957E+01/
     *    SSLIP( 809) /0.3350000000E+00/
     *    DSLIP( 809) /0.0000000000E+00/
     *    DIP( 809) /0.1570796327E+01/
     *    DEPTH( 809) /0.9000000000E+04/
     *    WIDTH( 809) /0.1000000000E+04/
      DATA STRIKE( 810) /0.2426007660E+01/
     *    HL( 810) /0.1000000000E+04/
     *    EQLAT( 810) /0.6273783218E+00/
     *    EQLON( 810) /0.2103054204E+01/
     *    SSLIP( 810) /0.3190000000E+00/
     *    DSLIP( 810) /0.0000000000E+00/
     *    DIP( 810) /0.1570796327E+01/
     *    DEPTH( 810) /0.9000000000E+04/
     *    WIDTH( 810) /0.1000000000E+04/
      DATA STRIKE( 811) /0.2426007660E+01/
     *    HL( 811) /0.1000000000E+04/
     *    EQLAT( 811) /0.6276153376E+00/
     *    EQLON( 811) /0.2103307452E+01/
     *    SSLIP( 811) /0.2530000000E+00/
     *    DSLIP( 811) /0.0000000000E+00/
     *    DIP( 811) /0.1570796327E+01/
     *    DEPTH( 811) /0.9000000000E+04/
     *    WIDTH( 811) /0.1000000000E+04/
      DATA STRIKE( 812) /0.2426007660E+01/
     *    HL( 812) /0.1000000000E+04/
     *    EQLAT( 812) /0.6278525278E+00/
     *    EQLON( 812) /0.2103560699E+01/
     *    SSLIP( 812) /0.2130000000E+00/
     *    DSLIP( 812) /0.0000000000E+00/
     *    DIP( 812) /0.1570796327E+01/
     *    DEPTH( 812) /0.9000000000E+04/
     *    WIDTH( 812) /0.1000000000E+04/
      DATA STRIKE( 813) /0.2426007660E+01/
     *    HL( 813) /0.1000000000E+04/
     *    EQLAT( 813) /0.6280895435E+00/
     *    EQLON( 813) /0.2103813946E+01/
     *    SSLIP( 813) /0.2380000000E+00/
     *    DSLIP( 813) /0.0000000000E+00/
     *    DIP( 813) /0.1570796327E+01/
     *    DEPTH( 813) /0.9000000000E+04/
     *    WIDTH( 813) /0.1000000000E+04/
      DATA STRIKE( 814) /0.2426007660E+01/
     *    HL( 814) /0.1000000000E+04/
     *    EQLAT( 814) /0.6283265592E+00/
     *    EQLON( 814) /0.2104067194E+01/
     *    SSLIP( 814) /0.2480000000E+00/
     *    DSLIP( 814) /0.0000000000E+00/
     *    DIP( 814) /0.1570796327E+01/
     *    DEPTH( 814) /0.9000000000E+04/
     *    WIDTH( 814) /0.1000000000E+04/
      DATA STRIKE( 815) /0.2426007660E+01/
     *    HL( 815) /0.1000000000E+04/
     *    EQLAT( 815) /0.6285635749E+00/
     *    EQLON( 815) /0.2104320441E+01/
     *    SSLIP( 815) /0.1740000000E+00/
     *    DSLIP( 815) /0.0000000000E+00/
     *    DIP( 815) /0.1570796327E+01/
     *    DEPTH( 815) /0.9000000000E+04/
     *    WIDTH( 815) /0.1000000000E+04/
      DATA STRIKE( 816) /0.2424262331E+01/
     *    HL( 816) /0.1000000000E+04/
     *    EQLAT( 816) /0.6240597528E+00/
     *    EQLON( 816) /0.2099508917E+01/
     *    SSLIP( 816) /0.3000000000E-01/
     *    DSLIP( 816) /0.0000000000E+00/
     *    DIP( 816) /0.1570796327E+01/
     *    DEPTH( 816) /0.1000000000E+05/
     *    WIDTH( 816) /0.1000000000E+04/
      DATA STRIKE( 817) /0.2426007660E+01/
     *    HL( 817) /0.1000000000E+04/
     *    EQLAT( 817) /0.6242967685E+00/
     *    EQLON( 817) /0.2099762164E+01/
     *    SSLIP( 817) /0.8800000000E-01/
     *    DSLIP( 817) /0.0000000000E+00/
     *    DIP( 817) /0.1570796327E+01/
     *    DEPTH( 817) /0.1000000000E+05/
     *    WIDTH( 817) /0.1000000000E+04/
      DATA STRIKE( 818) /0.2426007660E+01/
     *    HL( 818) /0.1000000000E+04/
     *    EQLAT( 818) /0.6245337842E+00/
     *    EQLON( 818) /0.2100015412E+01/
     *    SSLIP( 818) /0.1680000000E+00/
     *    DSLIP( 818) /0.0000000000E+00/
     *    DIP( 818) /0.1570796327E+01/
     *    DEPTH( 818) /0.1000000000E+05/
     *    WIDTH( 818) /0.1000000000E+04/
      DATA STRIKE( 819) /0.2426007660E+01/
     *    HL( 819) /0.1000000000E+04/
     *    EQLAT( 819) /0.6247707999E+00/
     *    EQLON( 819) /0.2100268484E+01/
     *    SSLIP( 819) /0.2660000000E+00/
     *    DSLIP( 819) /0.0000000000E+00/
     *    DIP( 819) /0.1570796327E+01/
     *    DEPTH( 819) /0.1000000000E+05/
     *    WIDTH( 819) /0.1000000000E+04/
      DATA STRIKE( 820) /0.2426007660E+01/
     *    HL( 820) /0.1000000000E+04/
     *    EQLAT( 820) /0.6250079902E+00/
     *    EQLON( 820) /0.2100521732E+01/
     *    SSLIP( 820) /0.3690000000E+00/
     *    DSLIP( 820) /0.0000000000E+00/
     *    DIP( 820) /0.1570796327E+01/
     *    DEPTH( 820) /0.1000000000E+05/
     *    WIDTH( 820) /0.1000000000E+04/
      DATA STRIKE( 821) /0.2426007660E+01/
     *    HL( 821) /0.1000000000E+04/
     *    EQLAT( 821) /0.6252450059E+00/
     *    EQLON( 821) /0.2100774979E+01/
     *    SSLIP( 821) /0.4370000000E+00/
     *    DSLIP( 821) /0.0000000000E+00/
     *    DIP( 821) /0.1570796327E+01/
     *    DEPTH( 821) /0.1000000000E+05/
     *    WIDTH( 821) /0.1000000000E+04/
      DATA STRIKE( 822) /0.2426007660E+01/
     *    HL( 822) /0.1000000000E+04/
     *    EQLAT( 822) /0.6254820216E+00/
     *    EQLON( 822) /0.2101028226E+01/
     *    SSLIP( 822) /0.4570000000E+00/
     *    DSLIP( 822) /0.0000000000E+00/
     *    DIP( 822) /0.1570796327E+01/
     *    DEPTH( 822) /0.1000000000E+05/
     *    WIDTH( 822) /0.1000000000E+04/
      DATA STRIKE( 823) /0.2426007660E+01/
     *    HL( 823) /0.1000000000E+04/
     *    EQLAT( 823) /0.6257190373E+00/
     *    EQLON( 823) /0.2101281473E+01/
     *    SSLIP( 823) /0.4330000000E+00/
     *    DSLIP( 823) /0.0000000000E+00/
     *    DIP( 823) /0.1570796327E+01/
     *    DEPTH( 823) /0.1000000000E+05/
     *    WIDTH( 823) /0.1000000000E+04/
      DATA STRIKE( 824) /0.2426007660E+01/
     *    HL( 824) /0.1000000000E+04/
     *    EQLAT( 824) /0.6259560530E+00/
     *    EQLON( 824) /0.2101534721E+01/
     *    SSLIP( 824) /0.3850000000E+00/
     *    DSLIP( 824) /0.0000000000E+00/
     *    DIP( 824) /0.1570796327E+01/
     *    DEPTH( 824) /0.1000000000E+05/
     *    WIDTH( 824) /0.1000000000E+04/
      DATA STRIKE( 825) /0.2426007660E+01/
     *    HL( 825) /0.1000000000E+04/
     *    EQLAT( 825) /0.6261930688E+00/
     *    EQLON( 825) /0.2101787968E+01/
     *    SSLIP( 825) /0.3410000000E+00/
     *    DSLIP( 825) /0.0000000000E+00/
     *    DIP( 825) /0.1570796327E+01/
     *    DEPTH( 825) /0.1000000000E+05/
     *    WIDTH( 825) /0.1000000000E+04/
      DATA STRIKE( 826) /0.2426007660E+01/
     *    HL( 826) /0.1000000000E+04/
     *    EQLAT( 826) /0.6264302590E+00/
     *    EQLON( 826) /0.2102041215E+01/
     *    SSLIP( 826) /0.3020000000E+00/
     *    DSLIP( 826) /0.0000000000E+00/
     *    DIP( 826) /0.1570796327E+01/
     *    DEPTH( 826) /0.1000000000E+05/
     *    WIDTH( 826) /0.1000000000E+04/
      DATA STRIKE( 827) /0.2426007660E+01/
     *    HL( 827) /0.1000000000E+04/
     *    EQLAT( 827) /0.6266672747E+00/
     *    EQLON( 827) /0.2102294463E+01/
     *    SSLIP( 827) /0.2670000000E+00/
     *    DSLIP( 827) /0.0000000000E+00/
     *    DIP( 827) /0.1570796327E+01/
     *    DEPTH( 827) /0.1000000000E+05/
     *    WIDTH( 827) /0.1000000000E+04/
      DATA STRIKE( 828) /0.2426007660E+01/
     *    HL( 828) /0.1000000000E+04/
     *    EQLAT( 828) /0.6269042904E+00/
     *    EQLON( 828) /0.2102547710E+01/
     *    SSLIP( 828) /0.2630000000E+00/
     *    DSLIP( 828) /0.0000000000E+00/
     *    DIP( 828) /0.1570796327E+01/
     *    DEPTH( 828) /0.1000000000E+05/
     *    WIDTH( 828) /0.1000000000E+04/
      DATA STRIKE( 829) /0.2426007660E+01/
     *    HL( 829) /0.1000000000E+04/
     *    EQLAT( 829) /0.6271413061E+00/
     *    EQLON( 829) /0.2102800957E+01/
     *    SSLIP( 829) /0.2810000000E+00/
     *    DSLIP( 829) /0.0000000000E+00/
     *    DIP( 829) /0.1570796327E+01/
     *    DEPTH( 829) /0.1000000000E+05/
     *    WIDTH( 829) /0.1000000000E+04/
      DATA STRIKE( 830) /0.2426007660E+01/
     *    HL( 830) /0.1000000000E+04/
     *    EQLAT( 830) /0.6273783218E+00/
     *    EQLON( 830) /0.2103054204E+01/
     *    SSLIP( 830) /0.2690000000E+00/
     *    DSLIP( 830) /0.0000000000E+00/
     *    DIP( 830) /0.1570796327E+01/
     *    DEPTH( 830) /0.1000000000E+05/
     *    WIDTH( 830) /0.1000000000E+04/
      DATA STRIKE( 831) /0.2426007660E+01/
     *    HL( 831) /0.1000000000E+04/
     *    EQLAT( 831) /0.6276153376E+00/
     *    EQLON( 831) /0.2103307452E+01/
     *    SSLIP( 831) /0.2270000000E+00/
     *    DSLIP( 831) /0.0000000000E+00/
     *    DIP( 831) /0.1570796327E+01/
     *    DEPTH( 831) /0.1000000000E+05/
     *    WIDTH( 831) /0.1000000000E+04/
      DATA STRIKE( 832) /0.2426007660E+01/
     *    HL( 832) /0.1000000000E+04/
     *    EQLAT( 832) /0.6278525278E+00/
     *    EQLON( 832) /0.2103560699E+01/
     *    SSLIP( 832) /0.2090000000E+00/
     *    DSLIP( 832) /0.0000000000E+00/
     *    DIP( 832) /0.1570796327E+01/
     *    DEPTH( 832) /0.1000000000E+05/
     *    WIDTH( 832) /0.1000000000E+04/
      DATA STRIKE( 833) /0.2426007660E+01/
     *    HL( 833) /0.1000000000E+04/
     *    EQLAT( 833) /0.6280895435E+00/
     *    EQLON( 833) /0.2103813946E+01/
     *    SSLIP( 833) /0.2400000000E+00/
     *    DSLIP( 833) /0.0000000000E+00/
     *    DIP( 833) /0.1570796327E+01/
     *    DEPTH( 833) /0.1000000000E+05/
     *    WIDTH( 833) /0.1000000000E+04/
      DATA STRIKE( 834) /0.2426007660E+01/
     *    HL( 834) /0.1000000000E+04/
     *    EQLAT( 834) /0.6283265592E+00/
     *    EQLON( 834) /0.2104067194E+01/
     *    SSLIP( 834) /0.2440000000E+00/
     *    DSLIP( 834) /0.0000000000E+00/
     *    DIP( 834) /0.1570796327E+01/
     *    DEPTH( 834) /0.1000000000E+05/
     *    WIDTH( 834) /0.1000000000E+04/
      DATA STRIKE( 835) /0.2426007660E+01/
     *    HL( 835) /0.1000000000E+04/
     *    EQLAT( 835) /0.6285635749E+00/
     *    EQLON( 835) /0.2104320441E+01/
     *    SSLIP( 835) /0.1670000000E+00/
     *    DSLIP( 835) /0.0000000000E+00/
     *    DIP( 835) /0.1570796327E+01/
     *    DEPTH( 835) /0.1000000000E+05/
     *    WIDTH( 835) /0.1000000000E+04/
      DATA STRIKE( 836) /0.2424262331E+01/
     *    HL( 836) /0.1000000000E+04/
     *    EQLAT( 836) /0.6240597528E+00/
     *    EQLON( 836) /0.2099508917E+01/
     *    SSLIP( 836) /0.4800000000E-01/
     *    DSLIP( 836) /0.0000000000E+00/
     *    DIP( 836) /0.1570796327E+01/
     *    DEPTH( 836) /0.1100000000E+05/
     *    WIDTH( 836) /0.1000000000E+04/
      DATA STRIKE( 837) /0.2426007660E+01/
     *    HL( 837) /0.1000000000E+04/
     *    EQLAT( 837) /0.6242967685E+00/
     *    EQLON( 837) /0.2099762164E+01/
     *    SSLIP( 837) /0.1190000000E+00/
     *    DSLIP( 837) /0.0000000000E+00/
     *    DIP( 837) /0.1570796327E+01/
     *    DEPTH( 837) /0.1100000000E+05/
     *    WIDTH( 837) /0.1000000000E+04/
      DATA STRIKE( 838) /0.2426007660E+01/
     *    HL( 838) /0.1000000000E+04/
     *    EQLAT( 838) /0.6245337842E+00/
     *    EQLON( 838) /0.2100015412E+01/
     *    SSLIP( 838) /0.2040000000E+00/
     *    DSLIP( 838) /0.0000000000E+00/
     *    DIP( 838) /0.1570796327E+01/
     *    DEPTH( 838) /0.1100000000E+05/
     *    WIDTH( 838) /0.1000000000E+04/
      DATA STRIKE( 839) /0.2426007660E+01/
     *    HL( 839) /0.1000000000E+04/
     *    EQLAT( 839) /0.6247707999E+00/
     *    EQLON( 839) /0.2100268484E+01/
     *    SSLIP( 839) /0.3040000000E+00/
     *    DSLIP( 839) /0.0000000000E+00/
     *    DIP( 839) /0.1570796327E+01/
     *    DEPTH( 839) /0.1100000000E+05/
     *    WIDTH( 839) /0.1000000000E+04/
      DATA STRIKE( 840) /0.2426007660E+01/
     *    HL( 840) /0.1000000000E+04/
     *    EQLAT( 840) /0.6250079902E+00/
     *    EQLON( 840) /0.2100521732E+01/
     *    SSLIP( 840) /0.3990000000E+00/
     *    DSLIP( 840) /0.0000000000E+00/
     *    DIP( 840) /0.1570796327E+01/
     *    DEPTH( 840) /0.1100000000E+05/
     *    WIDTH( 840) /0.1000000000E+04/
      DATA STRIKE( 841) /0.2426007660E+01/
     *    HL( 841) /0.1000000000E+04/
     *    EQLAT( 841) /0.6252450059E+00/
     *    EQLON( 841) /0.2100774979E+01/
     *    SSLIP( 841) /0.4590000000E+00/
     *    DSLIP( 841) /0.0000000000E+00/
     *    DIP( 841) /0.1570796327E+01/
     *    DEPTH( 841) /0.1100000000E+05/
     *    WIDTH( 841) /0.1000000000E+04/
      DATA STRIKE( 842) /0.2426007660E+01/
     *    HL( 842) /0.1000000000E+04/
     *    EQLAT( 842) /0.6254820216E+00/
     *    EQLON( 842) /0.2101028226E+01/
     *    SSLIP( 842) /0.4690000000E+00/
     *    DSLIP( 842) /0.0000000000E+00/
     *    DIP( 842) /0.1570796327E+01/
     *    DEPTH( 842) /0.1100000000E+05/
     *    WIDTH( 842) /0.1000000000E+04/
      DATA STRIKE( 843) /0.2426007660E+01/
     *    HL( 843) /0.1000000000E+04/
     *    EQLAT( 843) /0.6257190373E+00/
     *    EQLON( 843) /0.2101281473E+01/
     *    SSLIP( 843) /0.4350000000E+00/
     *    DSLIP( 843) /0.0000000000E+00/
     *    DIP( 843) /0.1570796327E+01/
     *    DEPTH( 843) /0.1100000000E+05/
     *    WIDTH( 843) /0.1000000000E+04/
      DATA STRIKE( 844) /0.2426007660E+01/
     *    HL( 844) /0.1000000000E+04/
     *    EQLAT( 844) /0.6259560530E+00/
     *    EQLON( 844) /0.2101534721E+01/
     *    SSLIP( 844) /0.3760000000E+00/
     *    DSLIP( 844) /0.0000000000E+00/
     *    DIP( 844) /0.1570796327E+01/
     *    DEPTH( 844) /0.1100000000E+05/
     *    WIDTH( 844) /0.1000000000E+04/
      DATA STRIKE( 845) /0.2426007660E+01/
     *    HL( 845) /0.1000000000E+04/
     *    EQLAT( 845) /0.6261930688E+00/
     *    EQLON( 845) /0.2101787968E+01/
     *    SSLIP( 845) /0.3170000000E+00/
     *    DSLIP( 845) /0.0000000000E+00/
     *    DIP( 845) /0.1570796327E+01/
     *    DEPTH( 845) /0.1100000000E+05/
     *    WIDTH( 845) /0.1000000000E+04/
      DATA STRIKE( 846) /0.2426007660E+01/
     *    HL( 846) /0.1000000000E+04/
     *    EQLAT( 846) /0.6264302590E+00/
     *    EQLON( 846) /0.2102041215E+01/
     *    SSLIP( 846) /0.2650000000E+00/
     *    DSLIP( 846) /0.0000000000E+00/
     *    DIP( 846) /0.1570796327E+01/
     *    DEPTH( 846) /0.1100000000E+05/
     *    WIDTH( 846) /0.1000000000E+04/
      DATA STRIKE( 847) /0.2426007660E+01/
     *    HL( 847) /0.1000000000E+04/
     *    EQLAT( 847) /0.6266672747E+00/
     *    EQLON( 847) /0.2102294463E+01/
     *    SSLIP( 847) /0.2260000000E+00/
     *    DSLIP( 847) /0.0000000000E+00/
     *    DIP( 847) /0.1570796327E+01/
     *    DEPTH( 847) /0.1100000000E+05/
     *    WIDTH( 847) /0.1000000000E+04/
      DATA STRIKE( 848) /0.2426007660E+01/
     *    HL( 848) /0.1000000000E+04/
     *    EQLAT( 848) /0.6269042904E+00/
     *    EQLON( 848) /0.2102547710E+01/
     *    SSLIP( 848) /0.2160000000E+00/
     *    DSLIP( 848) /0.0000000000E+00/
     *    DIP( 848) /0.1570796327E+01/
     *    DEPTH( 848) /0.1100000000E+05/
     *    WIDTH( 848) /0.1000000000E+04/
      DATA STRIKE( 849) /0.2426007660E+01/
     *    HL( 849) /0.1000000000E+04/
     *    EQLAT( 849) /0.6271413061E+00/
     *    EQLON( 849) /0.2102800957E+01/
     *    SSLIP( 849) /0.2250000000E+00/
     *    DSLIP( 849) /0.0000000000E+00/
     *    DIP( 849) /0.1570796327E+01/
     *    DEPTH( 849) /0.1100000000E+05/
     *    WIDTH( 849) /0.1000000000E+04/
      DATA STRIKE( 850) /0.2426007660E+01/
     *    HL( 850) /0.1000000000E+04/
     *    EQLAT( 850) /0.6273783218E+00/
     *    EQLON( 850) /0.2103054204E+01/
     *    SSLIP( 850) /0.2170000000E+00/
     *    DSLIP( 850) /0.0000000000E+00/
     *    DIP( 850) /0.1570796327E+01/
     *    DEPTH( 850) /0.1100000000E+05/
     *    WIDTH( 850) /0.1000000000E+04/
      DATA STRIKE( 851) /0.2426007660E+01/
     *    HL( 851) /0.1000000000E+04/
     *    EQLAT( 851) /0.6276153376E+00/
     *    EQLON( 851) /0.2103307452E+01/
     *    SSLIP( 851) /0.1930000000E+00/
     *    DSLIP( 851) /0.0000000000E+00/
     *    DIP( 851) /0.1570796327E+01/
     *    DEPTH( 851) /0.1100000000E+05/
     *    WIDTH( 851) /0.1000000000E+04/
      DATA STRIKE( 852) /0.2426007660E+01/
     *    HL( 852) /0.1000000000E+04/
     *    EQLAT( 852) /0.6278525278E+00/
     *    EQLON( 852) /0.2103560699E+01/
     *    SSLIP( 852) /0.1930000000E+00/
     *    DSLIP( 852) /0.0000000000E+00/
     *    DIP( 852) /0.1570796327E+01/
     *    DEPTH( 852) /0.1100000000E+05/
     *    WIDTH( 852) /0.1000000000E+04/
      DATA STRIKE( 853) /0.2426007660E+01/
     *    HL( 853) /0.1000000000E+04/
     *    EQLAT( 853) /0.6280895435E+00/
     *    EQLON( 853) /0.2103813946E+01/
     *    SSLIP( 853) /0.2240000000E+00/
     *    DSLIP( 853) /0.0000000000E+00/
     *    DIP( 853) /0.1570796327E+01/
     *    DEPTH( 853) /0.1100000000E+05/
     *    WIDTH( 853) /0.1000000000E+04/
      DATA STRIKE( 854) /0.2426007660E+01/
     *    HL( 854) /0.1000000000E+04/
     *    EQLAT( 854) /0.6283265592E+00/
     *    EQLON( 854) /0.2104067194E+01/
     *    SSLIP( 854) /0.2230000000E+00/
     *    DSLIP( 854) /0.0000000000E+00/
     *    DIP( 854) /0.1570796327E+01/
     *    DEPTH( 854) /0.1100000000E+05/
     *    WIDTH( 854) /0.1000000000E+04/
      DATA STRIKE( 855) /0.2426007660E+01/
     *    HL( 855) /0.1000000000E+04/
     *    EQLAT( 855) /0.6285635749E+00/
     *    EQLON( 855) /0.2104320441E+01/
     *    SSLIP( 855) /0.1500000000E+00/
     *    DSLIP( 855) /0.0000000000E+00/
     *    DIP( 855) /0.1570796327E+01/
     *    DEPTH( 855) /0.1100000000E+05/
     *    WIDTH( 855) /0.1000000000E+04/
      DATA STRIKE( 856) /0.2424262331E+01/
     *    HL( 856) /0.1000000000E+04/
     *    EQLAT( 856) /0.6240597528E+00/
     *    EQLON( 856) /0.2099508917E+01/
     *    SSLIP( 856) /0.5800000000E-01/
     *    DSLIP( 856) /0.0000000000E+00/
     *    DIP( 856) /0.1570796327E+01/
     *    DEPTH( 856) /0.1200000000E+05/
     *    WIDTH( 856) /0.1000000000E+04/
      DATA STRIKE( 857) /0.2426007660E+01/
     *    HL( 857) /0.1000000000E+04/
     *    EQLAT( 857) /0.6242967685E+00/
     *    EQLON( 857) /0.2099762164E+01/
     *    SSLIP( 857) /0.1290000000E+00/
     *    DSLIP( 857) /0.0000000000E+00/
     *    DIP( 857) /0.1570796327E+01/
     *    DEPTH( 857) /0.1200000000E+05/
     *    WIDTH( 857) /0.1000000000E+04/
      DATA STRIKE( 858) /0.2426007660E+01/
     *    HL( 858) /0.1000000000E+04/
     *    EQLAT( 858) /0.6245337842E+00/
     *    EQLON( 858) /0.2100015412E+01/
     *    SSLIP( 858) /0.2090000000E+00/
     *    DSLIP( 858) /0.0000000000E+00/
     *    DIP( 858) /0.1570796327E+01/
     *    DEPTH( 858) /0.1200000000E+05/
     *    WIDTH( 858) /0.1000000000E+04/
      DATA STRIKE( 859) /0.2426007660E+01/
     *    HL( 859) /0.1000000000E+04/
     *    EQLAT( 859) /0.6247707999E+00/
     *    EQLON( 859) /0.2100268484E+01/
     *    SSLIP( 859) /0.3000000000E+00/
     *    DSLIP( 859) /0.0000000000E+00/
     *    DIP( 859) /0.1570796327E+01/
     *    DEPTH( 859) /0.1200000000E+05/
     *    WIDTH( 859) /0.1000000000E+04/
      DATA STRIKE( 860) /0.2426007660E+01/
     *    HL( 860) /0.1000000000E+04/
     *    EQLAT( 860) /0.6250079902E+00/
     *    EQLON( 860) /0.2100521732E+01/
     *    SSLIP( 860) /0.3810000000E+00/
     *    DSLIP( 860) /0.0000000000E+00/
     *    DIP( 860) /0.1570796327E+01/
     *    DEPTH( 860) /0.1200000000E+05/
     *    WIDTH( 860) /0.1000000000E+04/
      DATA STRIKE( 861) /0.2426007660E+01/
     *    HL( 861) /0.1000000000E+04/
     *    EQLAT( 861) /0.6252450059E+00/
     *    EQLON( 861) /0.2100774979E+01/
     *    SSLIP( 861) /0.4280000000E+00/
     *    DSLIP( 861) /0.0000000000E+00/
     *    DIP( 861) /0.1570796327E+01/
     *    DEPTH( 861) /0.1200000000E+05/
     *    WIDTH( 861) /0.1000000000E+04/
      DATA STRIKE( 862) /0.2426007660E+01/
     *    HL( 862) /0.1000000000E+04/
     *    EQLAT( 862) /0.6254820216E+00/
     *    EQLON( 862) /0.2101028226E+01/
     *    SSLIP( 862) /0.4300000000E+00/
     *    DSLIP( 862) /0.0000000000E+00/
     *    DIP( 862) /0.1570796327E+01/
     *    DEPTH( 862) /0.1200000000E+05/
     *    WIDTH( 862) /0.1000000000E+04/
      DATA STRIKE( 863) /0.2426007660E+01/
     *    HL( 863) /0.1000000000E+04/
     *    EQLAT( 863) /0.6257190373E+00/
     *    EQLON( 863) /0.2101281473E+01/
     *    SSLIP( 863) /0.3930000000E+00/
     *    DSLIP( 863) /0.0000000000E+00/
     *    DIP( 863) /0.1570796327E+01/
     *    DEPTH( 863) /0.1200000000E+05/
     *    WIDTH( 863) /0.1000000000E+04/
      DATA STRIKE( 864) /0.2426007660E+01/
     *    HL( 864) /0.1000000000E+04/
     *    EQLAT( 864) /0.6259560530E+00/
     *    EQLON( 864) /0.2101534721E+01/
     *    SSLIP( 864) /0.3330000000E+00/
     *    DSLIP( 864) /0.0000000000E+00/
     *    DIP( 864) /0.1570796327E+01/
     *    DEPTH( 864) /0.1200000000E+05/
     *    WIDTH( 864) /0.1000000000E+04/
      DATA STRIKE( 865) /0.2426007660E+01/
     *    HL( 865) /0.1000000000E+04/
     *    EQLAT( 865) /0.6261930688E+00/
     *    EQLON( 865) /0.2101787968E+01/
     *    SSLIP( 865) /0.2700000000E+00/
     *    DSLIP( 865) /0.0000000000E+00/
     *    DIP( 865) /0.1570796327E+01/
     *    DEPTH( 865) /0.1200000000E+05/
     *    WIDTH( 865) /0.1000000000E+04/
      DATA STRIKE( 866) /0.2426007660E+01/
     *    HL( 866) /0.1000000000E+04/
     *    EQLAT( 866) /0.6264302590E+00/
     *    EQLON( 866) /0.2102041215E+01/
     *    SSLIP( 866) /0.2160000000E+00/
     *    DSLIP( 866) /0.0000000000E+00/
     *    DIP( 866) /0.1570796327E+01/
     *    DEPTH( 866) /0.1200000000E+05/
     *    WIDTH( 866) /0.1000000000E+04/
      DATA STRIKE( 867) /0.2426007660E+01/
     *    HL( 867) /0.1000000000E+04/
     *    EQLAT( 867) /0.6266672747E+00/
     *    EQLON( 867) /0.2102294463E+01/
     *    SSLIP( 867) /0.1780000000E+00/
     *    DSLIP( 867) /0.0000000000E+00/
     *    DIP( 867) /0.1570796327E+01/
     *    DEPTH( 867) /0.1200000000E+05/
     *    WIDTH( 867) /0.1000000000E+04/
      DATA STRIKE( 868) /0.2426007660E+01/
     *    HL( 868) /0.1000000000E+04/
     *    EQLAT( 868) /0.6269042904E+00/
     *    EQLON( 868) /0.2102547710E+01/
     *    SSLIP( 868) /0.1650000000E+00/
     *    DSLIP( 868) /0.0000000000E+00/
     *    DIP( 868) /0.1570796327E+01/
     *    DEPTH( 868) /0.1200000000E+05/
     *    WIDTH( 868) /0.1000000000E+04/
      DATA STRIKE( 869) /0.2426007660E+01/
     *    HL( 869) /0.1000000000E+04/
     *    EQLAT( 869) /0.6271413061E+00/
     *    EQLON( 869) /0.2102800957E+01/
     *    SSLIP( 869) /0.1680000000E+00/
     *    DSLIP( 869) /0.0000000000E+00/
     *    DIP( 869) /0.1570796327E+01/
     *    DEPTH( 869) /0.1200000000E+05/
     *    WIDTH( 869) /0.1000000000E+04/
      DATA STRIKE( 870) /0.2426007660E+01/
     *    HL( 870) /0.1000000000E+04/
     *    EQLAT( 870) /0.6273783218E+00/
     *    EQLON( 870) /0.2103054204E+01/
     *    SSLIP( 870) /0.1630000000E+00/
     *    DSLIP( 870) /0.0000000000E+00/
     *    DIP( 870) /0.1570796327E+01/
     *    DEPTH( 870) /0.1200000000E+05/
     *    WIDTH( 870) /0.1000000000E+04/
      DATA STRIKE( 871) /0.2426007660E+01/
     *    HL( 871) /0.1000000000E+04/
     *    EQLAT( 871) /0.6276153376E+00/
     *    EQLON( 871) /0.2103307452E+01/
     *    SSLIP( 871) /0.1520000000E+00/
     *    DSLIP( 871) /0.0000000000E+00/
     *    DIP( 871) /0.1570796327E+01/
     *    DEPTH( 871) /0.1200000000E+05/
     *    WIDTH( 871) /0.1000000000E+04/
      DATA STRIKE( 872) /0.2426007660E+01/
     *    HL( 872) /0.1000000000E+04/
     *    EQLAT( 872) /0.6278525278E+00/
     *    EQLON( 872) /0.2103560699E+01/
     *    SSLIP( 872) /0.1640000000E+00/
     *    DSLIP( 872) /0.0000000000E+00/
     *    DIP( 872) /0.1570796327E+01/
     *    DEPTH( 872) /0.1200000000E+05/
     *    WIDTH( 872) /0.1000000000E+04/
      DATA STRIKE( 873) /0.2426007660E+01/
     *    HL( 873) /0.1000000000E+04/
     *    EQLAT( 873) /0.6280895435E+00/
     *    EQLON( 873) /0.2103813946E+01/
     *    SSLIP( 873) /0.1900000000E+00/
     *    DSLIP( 873) /0.0000000000E+00/
     *    DIP( 873) /0.1570796327E+01/
     *    DEPTH( 873) /0.1200000000E+05/
     *    WIDTH( 873) /0.1000000000E+04/
      DATA STRIKE( 874) /0.2426007660E+01/
     *    HL( 874) /0.1000000000E+04/
     *    EQLAT( 874) /0.6283265592E+00/
     *    EQLON( 874) /0.2104067194E+01/
     *    SSLIP( 874) /0.1850000000E+00/
     *    DSLIP( 874) /0.0000000000E+00/
     *    DIP( 874) /0.1570796327E+01/
     *    DEPTH( 874) /0.1200000000E+05/
     *    WIDTH( 874) /0.1000000000E+04/
      DATA STRIKE( 875) /0.2426007660E+01/
     *    HL( 875) /0.1000000000E+04/
     *    EQLAT( 875) /0.6285635749E+00/
     *    EQLON( 875) /0.2104320441E+01/
     *    SSLIP( 875) /0.1240000000E+00/
     *    DSLIP( 875) /0.0000000000E+00/
     *    DIP( 875) /0.1570796327E+01/
     *    DEPTH( 875) /0.1200000000E+05/
     *    WIDTH( 875) /0.1000000000E+04/
      DATA STRIKE( 876) /0.2424262331E+01/
     *    HL( 876) /0.1000000000E+04/
     *    EQLAT( 876) /0.6240597528E+00/
     *    EQLON( 876) /0.2099508917E+01/
     *    SSLIP( 876) /0.5300000000E-01/
     *    DSLIP( 876) /0.0000000000E+00/
     *    DIP( 876) /0.1570796327E+01/
     *    DEPTH( 876) /0.1300000000E+05/
     *    WIDTH( 876) /0.1000000000E+04/
      DATA STRIKE( 877) /0.2426007660E+01/
     *    HL( 877) /0.1000000000E+04/
     *    EQLAT( 877) /0.6242967685E+00/
     *    EQLON( 877) /0.2099762164E+01/
     *    SSLIP( 877) /0.1110000000E+00/
     *    DSLIP( 877) /0.0000000000E+00/
     *    DIP( 877) /0.1570796327E+01/
     *    DEPTH( 877) /0.1300000000E+05/
     *    WIDTH( 877) /0.1000000000E+04/
      DATA STRIKE( 878) /0.2426007660E+01/
     *    HL( 878) /0.1000000000E+04/
     *    EQLAT( 878) /0.6245337842E+00/
     *    EQLON( 878) /0.2100015412E+01/
     *    SSLIP( 878) /0.1760000000E+00/
     *    DSLIP( 878) /0.0000000000E+00/
     *    DIP( 878) /0.1570796327E+01/
     *    DEPTH( 878) /0.1300000000E+05/
     *    WIDTH( 878) /0.1000000000E+04/
      DATA STRIKE( 879) /0.2426007660E+01/
     *    HL( 879) /0.1000000000E+04/
     *    EQLAT( 879) /0.6247707999E+00/
     *    EQLON( 879) /0.2100268484E+01/
     *    SSLIP( 879) /0.2450000000E+00/
     *    DSLIP( 879) /0.0000000000E+00/
     *    DIP( 879) /0.1570796327E+01/
     *    DEPTH( 879) /0.1300000000E+05/
     *    WIDTH( 879) /0.1000000000E+04/
      DATA STRIKE( 880) /0.2426007660E+01/
     *    HL( 880) /0.1000000000E+04/
     *    EQLAT( 880) /0.6250079902E+00/
     *    EQLON( 880) /0.2100521732E+01/
     *    SSLIP( 880) /0.3030000000E+00/
     *    DSLIP( 880) /0.0000000000E+00/
     *    DIP( 880) /0.1570796327E+01/
     *    DEPTH( 880) /0.1300000000E+05/
     *    WIDTH( 880) /0.1000000000E+04/
      DATA STRIKE( 881) /0.2426007660E+01/
     *    HL( 881) /0.1000000000E+04/
     *    EQLAT( 881) /0.6252450059E+00/
     *    EQLON( 881) /0.2100774979E+01/
     *    SSLIP( 881) /0.3360000000E+00/
     *    DSLIP( 881) /0.0000000000E+00/
     *    DIP( 881) /0.1570796327E+01/
     *    DEPTH( 881) /0.1300000000E+05/
     *    WIDTH( 881) /0.1000000000E+04/
      DATA STRIKE( 882) /0.2426007660E+01/
     *    HL( 882) /0.1000000000E+04/
     *    EQLAT( 882) /0.6254820216E+00/
     *    EQLON( 882) /0.2101028226E+01/
     *    SSLIP( 882) /0.3330000000E+00/
     *    DSLIP( 882) /0.0000000000E+00/
     *    DIP( 882) /0.1570796327E+01/
     *    DEPTH( 882) /0.1300000000E+05/
     *    WIDTH( 882) /0.1000000000E+04/
      DATA STRIKE( 883) /0.2426007660E+01/
     *    HL( 883) /0.1000000000E+04/
     *    EQLAT( 883) /0.6257190373E+00/
     *    EQLON( 883) /0.2101281473E+01/
     *    SSLIP( 883) /0.3010000000E+00/
     *    DSLIP( 883) /0.0000000000E+00/
     *    DIP( 883) /0.1570796327E+01/
     *    DEPTH( 883) /0.1300000000E+05/
     *    WIDTH( 883) /0.1000000000E+04/
      DATA STRIKE( 884) /0.2426007660E+01/
     *    HL( 884) /0.1000000000E+04/
     *    EQLAT( 884) /0.6259560530E+00/
     *    EQLON( 884) /0.2101534721E+01/
     *    SSLIP( 884) /0.2520000000E+00/
     *    DSLIP( 884) /0.0000000000E+00/
     *    DIP( 884) /0.1570796327E+01/
     *    DEPTH( 884) /0.1300000000E+05/
     *    WIDTH( 884) /0.1000000000E+04/
      DATA STRIKE( 885) /0.2426007660E+01/
     *    HL( 885) /0.1000000000E+04/
     *    EQLAT( 885) /0.6261930688E+00/
     *    EQLON( 885) /0.2101787968E+01/
     *    SSLIP( 885) /0.2000000000E+00/
     *    DSLIP( 885) /0.0000000000E+00/
     *    DIP( 885) /0.1570796327E+01/
     *    DEPTH( 885) /0.1300000000E+05/
     *    WIDTH( 885) /0.1000000000E+04/
      DATA STRIKE( 886) /0.2426007660E+01/
     *    HL( 886) /0.1000000000E+04/
     *    EQLAT( 886) /0.6264302590E+00/
     *    EQLON( 886) /0.2102041215E+01/
     *    SSLIP( 886) /0.1550000000E+00/
     *    DSLIP( 886) /0.0000000000E+00/
     *    DIP( 886) /0.1570796327E+01/
     *    DEPTH( 886) /0.1300000000E+05/
     *    WIDTH( 886) /0.1000000000E+04/
      DATA STRIKE( 887) /0.2426007660E+01/
     *    HL( 887) /0.1000000000E+04/
     *    EQLAT( 887) /0.6266672747E+00/
     *    EQLON( 887) /0.2102294463E+01/
     *    SSLIP( 887) /0.1240000000E+00/
     *    DSLIP( 887) /0.0000000000E+00/
     *    DIP( 887) /0.1570796327E+01/
     *    DEPTH( 887) /0.1300000000E+05/
     *    WIDTH( 887) /0.1000000000E+04/
      DATA STRIKE( 888) /0.2426007660E+01/
     *    HL( 888) /0.1000000000E+04/
     *    EQLAT( 888) /0.6269042904E+00/
     *    EQLON( 888) /0.2102547710E+01/
     *    SSLIP( 888) /0.1120000000E+00/
     *    DSLIP( 888) /0.0000000000E+00/
     *    DIP( 888) /0.1570796327E+01/
     *    DEPTH( 888) /0.1300000000E+05/
     *    WIDTH( 888) /0.1000000000E+04/
      DATA STRIKE( 889) /0.2426007660E+01/
     *    HL( 889) /0.1000000000E+04/
     *    EQLAT( 889) /0.6271413061E+00/
     *    EQLON( 889) /0.2102800957E+01/
     *    SSLIP( 889) /0.1120000000E+00/
     *    DSLIP( 889) /0.0000000000E+00/
     *    DIP( 889) /0.1570796327E+01/
     *    DEPTH( 889) /0.1300000000E+05/
     *    WIDTH( 889) /0.1000000000E+04/
      DATA STRIKE( 890) /0.2426007660E+01/
     *    HL( 890) /0.1000000000E+04/
     *    EQLAT( 890) /0.6273783218E+00/
     *    EQLON( 890) /0.2103054204E+01/
     *    SSLIP( 890) /0.1080000000E+00/
     *    DSLIP( 890) /0.0000000000E+00/
     *    DIP( 890) /0.1570796327E+01/
     *    DEPTH( 890) /0.1300000000E+05/
     *    WIDTH( 890) /0.1000000000E+04/
      DATA STRIKE( 891) /0.2426007660E+01/
     *    HL( 891) /0.1000000000E+04/
     *    EQLAT( 891) /0.6276153376E+00/
     *    EQLON( 891) /0.2103307452E+01/
     *    SSLIP( 891) /0.1050000000E+00/
     *    DSLIP( 891) /0.0000000000E+00/
     *    DIP( 891) /0.1570796327E+01/
     *    DEPTH( 891) /0.1300000000E+05/
     *    WIDTH( 891) /0.1000000000E+04/
      DATA STRIKE( 892) /0.2426007660E+01/
     *    HL( 892) /0.1000000000E+04/
     *    EQLAT( 892) /0.6278525278E+00/
     *    EQLON( 892) /0.2103560699E+01/
     *    SSLIP( 892) /0.1210000000E+00/
     *    DSLIP( 892) /0.0000000000E+00/
     *    DIP( 892) /0.1570796327E+01/
     *    DEPTH( 892) /0.1300000000E+05/
     *    WIDTH( 892) /0.1000000000E+04/
      DATA STRIKE( 893) /0.2426007660E+01/
     *    HL( 893) /0.1000000000E+04/
     *    EQLAT( 893) /0.6280895435E+00/
     *    EQLON( 893) /0.2103813946E+01/
     *    SSLIP( 893) /0.1380000000E+00/
     *    DSLIP( 893) /0.0000000000E+00/
     *    DIP( 893) /0.1570796327E+01/
     *    DEPTH( 893) /0.1300000000E+05/
     *    WIDTH( 893) /0.1000000000E+04/
      DATA STRIKE( 894) /0.2426007660E+01/
     *    HL( 894) /0.1000000000E+04/
     *    EQLAT( 894) /0.6283265592E+00/
     *    EQLON( 894) /0.2104067194E+01/
     *    SSLIP( 894) /0.1340000000E+00/
     *    DSLIP( 894) /0.0000000000E+00/
     *    DIP( 894) /0.1570796327E+01/
     *    DEPTH( 894) /0.1300000000E+05/
     *    WIDTH( 894) /0.1000000000E+04/
      DATA STRIKE( 895) /0.2426007660E+01/
     *    HL( 895) /0.1000000000E+04/
     *    EQLAT( 895) /0.6285635749E+00/
     *    EQLON( 895) /0.2104320441E+01/
     *    SSLIP( 895) /0.8900000000E-01/
     *    DSLIP( 895) /0.0000000000E+00/
     *    DIP( 895) /0.1570796327E+01/
     *    DEPTH( 895) /0.1300000000E+05/
     *    WIDTH( 895) /0.1000000000E+04/
      DATA STRIKE( 896) /0.2424262331E+01/
     *    HL( 896) /0.1000000000E+04/
     *    EQLAT( 896) /0.6240597528E+00/
     *    EQLON( 896) /0.2099508917E+01/
     *    SSLIP( 896) /0.3200000000E-01/
     *    DSLIP( 896) /0.0000000000E+00/
     *    DIP( 896) /0.1570796327E+01/
     *    DEPTH( 896) /0.1400000000E+05/
     *    WIDTH( 896) /0.1000000000E+04/
      DATA STRIKE( 897) /0.2426007660E+01/
     *    HL( 897) /0.1000000000E+04/
     *    EQLAT( 897) /0.6242967685E+00/
     *    EQLON( 897) /0.2099762164E+01/
     *    SSLIP( 897) /0.6600000000E-01/
     *    DSLIP( 897) /0.0000000000E+00/
     *    DIP( 897) /0.1570796327E+01/
     *    DEPTH( 897) /0.1400000000E+05/
     *    WIDTH( 897) /0.1000000000E+04/
      DATA STRIKE( 898) /0.2426007660E+01/
     *    HL( 898) /0.1000000000E+04/
     *    EQLAT( 898) /0.6245337842E+00/
     *    EQLON( 898) /0.2100015412E+01/
     *    SSLIP( 898) /0.1020000000E+00/
     *    DSLIP( 898) /0.0000000000E+00/
     *    DIP( 898) /0.1570796327E+01/
     *    DEPTH( 898) /0.1400000000E+05/
     *    WIDTH( 898) /0.1000000000E+04/
      DATA STRIKE( 899) /0.2426007660E+01/
     *    HL( 899) /0.1000000000E+04/
     *    EQLAT( 899) /0.6247707999E+00/
     *    EQLON( 899) /0.2100268484E+01/
     *    SSLIP( 899) /0.1390000000E+00/
     *    DSLIP( 899) /0.0000000000E+00/
     *    DIP( 899) /0.1570796327E+01/
     *    DEPTH( 899) /0.1400000000E+05/
     *    WIDTH( 899) /0.1000000000E+04/
      DATA STRIKE( 900) /0.2426007660E+01/
     *    HL( 900) /0.1000000000E+04/
     *    EQLAT( 900) /0.6250079902E+00/
     *    EQLON( 900) /0.2100521732E+01/
     *    SSLIP( 900) /0.1710000000E+00/
     *    DSLIP( 900) /0.0000000000E+00/
     *    DIP( 900) /0.1570796327E+01/
     *    DEPTH( 900) /0.1400000000E+05/
     *    WIDTH( 900) /0.1000000000E+04/
      DATA STRIKE( 901) /0.2426007660E+01/
     *    HL( 901) /0.1000000000E+04/
     *    EQLAT( 901) /0.6252450059E+00/
     *    EQLON( 901) /0.2100774979E+01/
     *    SSLIP( 901) /0.1870000000E+00/
     *    DSLIP( 901) /0.0000000000E+00/
     *    DIP( 901) /0.1570796327E+01/
     *    DEPTH( 901) /0.1400000000E+05/
     *    WIDTH( 901) /0.1000000000E+04/
      DATA STRIKE( 902) /0.2426007660E+01/
     *    HL( 902) /0.1000000000E+04/
     *    EQLAT( 902) /0.6254820216E+00/
     *    EQLON( 902) /0.2101028226E+01/
     *    SSLIP( 902) /0.1840000000E+00/
     *    DSLIP( 902) /0.0000000000E+00/
     *    DIP( 902) /0.1570796327E+01/
     *    DEPTH( 902) /0.1400000000E+05/
     *    WIDTH( 902) /0.1000000000E+04/
      DATA STRIKE( 903) /0.2426007660E+01/
     *    HL( 903) /0.1000000000E+04/
     *    EQLAT( 903) /0.6257190373E+00/
     *    EQLON( 903) /0.2101281473E+01/
     *    SSLIP( 903) /0.1650000000E+00/
     *    DSLIP( 903) /0.0000000000E+00/
     *    DIP( 903) /0.1570796327E+01/
     *    DEPTH( 903) /0.1400000000E+05/
     *    WIDTH( 903) /0.1000000000E+04/
      DATA STRIKE( 904) /0.2426007660E+01/
     *    HL( 904) /0.1000000000E+04/
     *    EQLAT( 904) /0.6259560530E+00/
     *    EQLON( 904) /0.2101534721E+01/
     *    SSLIP( 904) /0.1370000000E+00/
     *    DSLIP( 904) /0.0000000000E+00/
     *    DIP( 904) /0.1570796327E+01/
     *    DEPTH( 904) /0.1400000000E+05/
     *    WIDTH( 904) /0.1000000000E+04/
      DATA STRIKE( 905) /0.2426007660E+01/
     *    HL( 905) /0.1000000000E+04/
     *    EQLAT( 905) /0.6261930688E+00/
     *    EQLON( 905) /0.2101787968E+01/
     *    SSLIP( 905) /0.1070000000E+00/
     *    DSLIP( 905) /0.0000000000E+00/
     *    DIP( 905) /0.1570796327E+01/
     *    DEPTH( 905) /0.1400000000E+05/
     *    WIDTH( 905) /0.1000000000E+04/
      DATA STRIKE( 906) /0.2426007660E+01/
     *    HL( 906) /0.1000000000E+04/
     *    EQLAT( 906) /0.6264302590E+00/
     *    EQLON( 906) /0.2102041215E+01/
     *    SSLIP( 906) /0.8200000000E-01/
     *    DSLIP( 906) /0.0000000000E+00/
     *    DIP( 906) /0.1570796327E+01/
     *    DEPTH( 906) /0.1400000000E+05/
     *    WIDTH( 906) /0.1000000000E+04/
      DATA STRIKE( 907) /0.2426007660E+01/
     *    HL( 907) /0.1000000000E+04/
     *    EQLAT( 907) /0.6266672747E+00/
     *    EQLON( 907) /0.2102294463E+01/
     *    SSLIP( 907) /0.6400000000E-01/
     *    DSLIP( 907) /0.0000000000E+00/
     *    DIP( 907) /0.1570796327E+01/
     *    DEPTH( 907) /0.1400000000E+05/
     *    WIDTH( 907) /0.1000000000E+04/
      DATA STRIKE( 908) /0.2426007660E+01/
     *    HL( 908) /0.1000000000E+04/
     *    EQLAT( 908) /0.6269042904E+00/
     *    EQLON( 908) /0.2102547710E+01/
     *    SSLIP( 908) /0.5700000000E-01/
     *    DSLIP( 908) /0.0000000000E+00/
     *    DIP( 908) /0.1570796327E+01/
     *    DEPTH( 908) /0.1400000000E+05/
     *    WIDTH( 908) /0.1000000000E+04/
      DATA STRIKE( 909) /0.2426007660E+01/
     *    HL( 909) /0.1000000000E+04/
     *    EQLAT( 909) /0.6271413061E+00/
     *    EQLON( 909) /0.2102800957E+01/
     *    SSLIP( 909) /0.5600000000E-01/
     *    DSLIP( 909) /0.0000000000E+00/
     *    DIP( 909) /0.1570796327E+01/
     *    DEPTH( 909) /0.1400000000E+05/
     *    WIDTH( 909) /0.1000000000E+04/
      DATA STRIKE( 910) /0.2426007660E+01/
     *    HL( 910) /0.1000000000E+04/
     *    EQLAT( 910) /0.6273783218E+00/
     *    EQLON( 910) /0.2103054204E+01/
     *    SSLIP( 910) /0.5400000000E-01/
     *    DSLIP( 910) /0.0000000000E+00/
     *    DIP( 910) /0.1570796327E+01/
     *    DEPTH( 910) /0.1400000000E+05/
     *    WIDTH( 910) /0.1000000000E+04/
      DATA STRIKE( 911) /0.2426007660E+01/
     *    HL( 911) /0.1000000000E+04/
     *    EQLAT( 911) /0.6276153376E+00/
     *    EQLON( 911) /0.2103307452E+01/
     *    SSLIP( 911) /0.5300000000E-01/
     *    DSLIP( 911) /0.0000000000E+00/
     *    DIP( 911) /0.1570796327E+01/
     *    DEPTH( 911) /0.1400000000E+05/
     *    WIDTH( 911) /0.1000000000E+04/
      DATA STRIKE( 912) /0.2426007660E+01/
     *    HL( 912) /0.1000000000E+04/
     *    EQLAT( 912) /0.6278525278E+00/
     *    EQLON( 912) /0.2103560699E+01/
     *    SSLIP( 912) /0.6400000000E-01/
     *    DSLIP( 912) /0.0000000000E+00/
     *    DIP( 912) /0.1570796327E+01/
     *    DEPTH( 912) /0.1400000000E+05/
     *    WIDTH( 912) /0.1000000000E+04/
      DATA STRIKE( 913) /0.2426007660E+01/
     *    HL( 913) /0.1000000000E+04/
     *    EQLAT( 913) /0.6280895435E+00/
     *    EQLON( 913) /0.2103813946E+01/
     *    SSLIP( 913) /0.7300000000E-01/
     *    DSLIP( 913) /0.0000000000E+00/
     *    DIP( 913) /0.1570796327E+01/
     *    DEPTH( 913) /0.1400000000E+05/
     *    WIDTH( 913) /0.1000000000E+04/
      DATA STRIKE( 914) /0.2426007660E+01/
     *    HL( 914) /0.1000000000E+04/
     *    EQLAT( 914) /0.6283265592E+00/
     *    EQLON( 914) /0.2104067194E+01/
     *    SSLIP( 914) /0.7000000000E-01/
     *    DSLIP( 914) /0.0000000000E+00/
     *    DIP( 914) /0.1570796327E+01/
     *    DEPTH( 914) /0.1400000000E+05/
     *    WIDTH( 914) /0.1000000000E+04/
      DATA STRIKE( 915) /0.2426007660E+01/
     *    HL( 915) /0.1000000000E+04/
     *    EQLAT( 915) /0.6285635749E+00/
     *    EQLON( 915) /0.2104320441E+01/
     *    SSLIP( 915) /0.4600000000E-01/
     *    DSLIP( 915) /0.0000000000E+00/
     *    DIP( 915) /0.1570796327E+01/
     *    DEPTH( 915) /0.1400000000E+05/
     *    WIDTH( 915) /0.1000000000E+04/
      DATA EQLATR( 29)  /0.1108633141E+01/
     *   EQLONR( 29)  /0.2574884245E+01/
     *   EQRAD( 29)   /0.2000000000E+07/
     *   ITEQK( 29)   /    75716640/
     *   NLOC( 29)    / 916/
     *   NFP( 29)     / 911/
      DATA STRIKE( 916) /0.4543092043E+01/
     *    HL( 916) /0.1500600000E+04/
     *    EQLAT( 916) /0.1108284599E+01/
     *    EQLON( 916) /0.2578255000E+01/
     *    SSLIP( 916) /0.0000000000E+00/
     *    DSLIP( 916) /0.0000000000E+00/
     *    DIP( 916) /0.1570796327E+01/
     *    DEPTH( 916) /0.0000000000E+00/
     *    WIDTH( 916) /0.3000000000E+04/
      DATA STRIKE( 917) /0.4544837372E+01/
     *    HL( 917) /0.1500600000E+04/
     *    EQLAT( 917) /0.1108363138E+01/
     *    EQLON( 917) /0.2577217925E+01/
     *    SSLIP( 917) /0.0000000000E+00/
     *    DSLIP( 917) /0.0000000000E+00/
     *    DIP( 917) /0.1570796327E+01/
     *    DEPTH( 917) /0.0000000000E+00/
     *    WIDTH( 917) /0.3000000000E+04/
      DATA STRIKE( 918) /0.4546582701E+01/
     *    HL( 918) /0.1500600000E+04/
     *    EQLAT( 918) /0.1108441329E+01/
     *    EQLON( 918) /0.2576180502E+01/
     *    SSLIP( 918) /0.0000000000E+00/
     *    DSLIP( 918) /0.0000000000E+00/
     *    DIP( 918) /0.1570796327E+01/
     *    DEPTH( 918) /0.0000000000E+00/
     *    WIDTH( 918) /0.3000000000E+04/
      DATA STRIKE( 919) /0.4546582701E+01/
     *    HL( 919) /0.1500600000E+04/
     *    EQLAT( 919) /0.1108518996E+01/
     *    EQLON( 919) /0.2575142903E+01/
     *    SSLIP( 919) /0.0000000000E+00/
     *    DSLIP( 919) /0.0000000000E+00/
     *    DIP( 919) /0.1570796327E+01/
     *    DEPTH( 919) /0.0000000000E+00/
     *    WIDTH( 919) /0.3000000000E+04/
      DATA STRIKE( 920) /0.4548328031E+01/
     *    HL( 920) /0.1500600000E+04/
     *    EQLAT( 920) /0.1108596140E+01/
     *    EQLON( 920) /0.2574104956E+01/
     *    SSLIP( 920) /0.0000000000E+00/
     *    DSLIP( 920) /0.0000000000E+00/
     *    DIP( 920) /0.1570796327E+01/
     *    DEPTH( 920) /0.0000000000E+00/
     *    WIDTH( 920) /0.3000000000E+04/
      DATA STRIKE( 921) /0.4548328031E+01/
     *    HL( 921) /0.1500600000E+04/
     *    EQLAT( 921) /0.1108673109E+01/
     *    EQLON( 921) /0.2573066660E+01/
     *    SSLIP( 921) /0.0000000000E+00/
     *    DSLIP( 921) /0.0000000000E+00/
     *    DIP( 921) /0.1570796327E+01/
     *    DEPTH( 921) /0.0000000000E+00/
     *    WIDTH( 921) /0.3000000000E+04/
      DATA STRIKE( 922) /0.4550073360E+01/
     *    HL( 922) /0.1500600000E+04/
     *    EQLAT( 922) /0.1108749380E+01/
     *    EQLON( 922) /0.2572028014E+01/
     *    SSLIP( 922) /0.0000000000E+00/
     *    DSLIP( 922) /0.0000000000E+00/
     *    DIP( 922) /0.1570796327E+01/
     *    DEPTH( 922) /0.0000000000E+00/
     *    WIDTH( 922) /0.3000000000E+04/
      DATA STRIKE( 923) /0.4551818689E+01/
     *    HL( 923) /0.1500600000E+04/
     *    EQLAT( 923) /0.1108825476E+01/
     *    EQLON( 923) /0.2570989020E+01/
     *    SSLIP( 923) /0.0000000000E+00/
     *    DSLIP( 923) /0.0000000000E+00/
     *    DIP( 923) /0.1570796327E+01/
     *    DEPTH( 923) /0.0000000000E+00/
     *    WIDTH( 923) /0.3000000000E+04/
      DATA STRIKE( 924) /0.4551818689E+01/
     *    HL( 924) /0.1500600000E+04/
     *    EQLAT( 924) /0.1108900874E+01/
     *    EQLON( 924) /0.2569949851E+01/
     *    SSLIP( 924) /0.0000000000E+00/
     *    DSLIP( 924) /0.0000000000E+00/
     *    DIP( 924) /0.1570796327E+01/
     *    DEPTH( 924) /0.0000000000E+00/
     *    WIDTH( 924) /0.3000000000E+04/
      DATA STRIKE( 925) /0.4862487296E+01/
     *    HL( 925) /0.1468400000E+04/
     *    EQLAT( 925) /0.1108904540E+01/
     *    EQLON( 925) /0.2568920630E+01/
     *    SSLIP( 925) /0.2320000000E+00/
     *    DSLIP( 925) /0.0000000000E+00/
     *    DIP( 925) /0.1570796327E+01/
     *    DEPTH( 925) /0.0000000000E+00/
     *    WIDTH( 925) /0.3000000000E+04/
      DATA STRIKE( 926) /0.4862487296E+01/
     *    HL( 926) /0.1468600000E+04/
     *    EQLAT( 926) /0.1108836297E+01/
     *    EQLON( 926) /0.2567901532E+01/
     *    SSLIP( 926) /0.6880000000E+00/
     *    DSLIP( 926) /0.0000000000E+00/
     *    DIP( 926) /0.1570796327E+01/
     *    DEPTH( 926) /0.0000000000E+00/
     *    WIDTH( 926) /0.3000000000E+04/
      DATA STRIKE( 927) /0.4862487296E+01/
     *    HL( 927) /0.1468800000E+04/
     *    EQLAT( 927) /0.1108768055E+01/
     *    EQLON( 927) /0.2566882434E+01/
     *    SSLIP( 927) /0.1398000000E+01/
     *    DSLIP( 927) /0.0000000000E+00/
     *    DIP( 927) /0.1570796327E+01/
     *    DEPTH( 927) /0.0000000000E+00/
     *    WIDTH( 927) /0.3000000000E+04/
      DATA STRIKE( 928) /0.4860741967E+01/
     *    HL( 928) /0.1469000000E+04/
     *    EQLAT( 928) /0.1108699987E+01/
     *    EQLON( 928) /0.2565863337E+01/
     *    SSLIP( 928) /0.1802000000E+01/
     *    DSLIP( 928) /0.0000000000E+00/
     *    DIP( 928) /0.1570796327E+01/
     *    DEPTH( 928) /0.0000000000E+00/
     *    WIDTH( 928) /0.3000000000E+04/
      DATA STRIKE( 929) /0.4858996638E+01/
     *    HL( 929) /0.1469200000E+04/
     *    EQLAT( 929) /0.1108631745E+01/
     *    EQLON( 929) /0.2564844413E+01/
     *    SSLIP( 929) /0.1253000000E+01/
     *    DSLIP( 929) /-.5000000000E+00/
     *    DIP( 929) /0.1570796327E+01/
     *    DEPTH( 929) /0.0000000000E+00/
     *    WIDTH( 929) /0.3000000000E+04/
      DATA STRIKE( 930) /0.4857251308E+01/
     *    HL( 930) /0.1469400000E+04/
     *    EQLAT( 930) /0.1108563677E+01/
     *    EQLON( 930) /0.2563825316E+01/
     *    SSLIP( 930) /0.8530000000E+00/
     *    DSLIP( 930) /-.1250000000E+01/
     *    DIP( 930) /0.1570796327E+01/
     *    DEPTH( 930) /0.0000000000E+00/
     *    WIDTH( 930) /0.3000000000E+04/
      DATA STRIKE( 931) /0.4855505979E+01/
     *    HL( 931) /0.1469600000E+04/
     *    EQLAT( 931) /0.1108495434E+01/
     *    EQLON( 931) /0.2562806218E+01/
     *    SSLIP( 931) /0.9840000000E+00/
     *    DSLIP( 931) /-.2050000000E+01/
     *    DIP( 931) /0.1570796327E+01/
     *    DEPTH( 931) /0.0000000000E+00/
     *    WIDTH( 931) /0.3000000000E+04/
      DATA STRIKE( 932) /0.4853760650E+01/
     *    HL( 932) /0.1469800000E+04/
     *    EQLAT( 932) /0.1108427192E+01/
     *    EQLON( 932) /0.2561787120E+01/
     *    SSLIP( 932) /0.1681000000E+01/
     *    DSLIP( 932) /-.2670000000E+01/
     *    DIP( 932) /0.1570796327E+01/
     *    DEPTH( 932) /0.0000000000E+00/
     *    WIDTH( 932) /0.3000000000E+04/
      DATA STRIKE( 933) /0.4852015321E+01/
     *    HL( 933) /0.1470000000E+04/
     *    EQLAT( 933) /0.1108359124E+01/
     *    EQLON( 933) /0.2560768197E+01/
     *    SSLIP( 933) /0.2709000000E+01/
     *    DSLIP( 933) /-.2920000000E+01/
     *    DIP( 933) /0.1570796327E+01/
     *    DEPTH( 933) /0.0000000000E+00/
     *    WIDTH( 933) /0.3000000000E+04/
      DATA STRIKE( 934) /0.4850269991E+01/
     *    HL( 934) /0.1470200000E+04/
     *    EQLAT( 934) /0.1108290882E+01/
     *    EQLON( 934) /0.2559749099E+01/
     *    SSLIP( 934) /0.3628000000E+01/
     *    DSLIP( 934) /-.2640000000E+01/
     *    DIP( 934) /0.1570796327E+01/
     *    DEPTH( 934) /0.0000000000E+00/
     *    WIDTH( 934) /0.3000000000E+04/
      DATA STRIKE( 935) /0.4848524662E+01/
     *    HL( 935) /0.1470400000E+04/
     *    EQLAT( 935) /0.1108222639E+01/
     *    EQLON( 935) /0.2558730002E+01/
     *    SSLIP( 935) /0.3908000000E+01/
     *    DSLIP( 935) /-.1640000000E+01/
     *    DIP( 935) /0.1570796327E+01/
     *    DEPTH( 935) /0.0000000000E+00/
     *    WIDTH( 935) /0.3000000000E+04/
      DATA STRIKE( 936) /0.4846779333E+01/
     *    HL( 936) /0.1470600000E+04/
     *    EQLAT( 936) /0.1108154572E+01/
     *    EQLON( 936) /0.2557710904E+01/
     *    SSLIP( 936) /0.3475000000E+01/
     *    DSLIP( 936) /-.1600000000E+00/
     *    DIP( 936) /0.1570796327E+01/
     *    DEPTH( 936) /0.0000000000E+00/
     *    WIDTH( 936) /0.3000000000E+04/
      DATA STRIKE( 937) /0.4845034004E+01/
     *    HL( 937) /0.1470800000E+04/
     *    EQLAT( 937) /0.1108086329E+01/
     *    EQLON( 937) /0.2556691981E+01/
     *    SSLIP( 937) /0.4285000000E+01/
     *    DSLIP( 937) /-.4700000000E+00/
     *    DIP( 937) /0.1570796327E+01/
     *    DEPTH( 937) /0.0000000000E+00/
     *    WIDTH( 937) /0.3000000000E+04/
      DATA STRIKE( 938) /0.4843288674E+01/
     *    HL( 938) /0.1470900000E+04/
     *    EQLAT( 938) /0.1108018261E+01/
     *    EQLON( 938) /0.2555672883E+01/
     *    SSLIP( 938) /0.4612000000E+01/
     *    DSLIP( 938) /-.6100000000E+00/
     *    DIP( 938) /0.1570796327E+01/
     *    DEPTH( 938) /0.0000000000E+00/
     *    WIDTH( 938) /0.3000000000E+04/
      DATA STRIKE( 939) /0.4841543345E+01/
     *    HL( 939) /0.1471100000E+04/
     *    EQLAT( 939) /0.1107950019E+01/
     *    EQLON( 939) /0.2554653785E+01/
     *    SSLIP( 939) /0.3818000000E+01/
     *    DSLIP( 939) /0.0000000000E+00/
     *    DIP( 939) /0.1570796327E+01/
     *    DEPTH( 939) /0.0000000000E+00/
     *    WIDTH( 939) /0.3000000000E+04/
      DATA STRIKE( 940) /0.4839798016E+01/
     *    HL( 940) /0.1471300000E+04/
     *    EQLAT( 940) /0.1107881777E+01/
     *    EQLON( 940) /0.2553634687E+01/
     *    SSLIP( 940) /0.3448000000E+01/
     *    DSLIP( 940) /0.0000000000E+00/
     *    DIP( 940) /0.1570796327E+01/
     *    DEPTH( 940) /0.0000000000E+00/
     *    WIDTH( 940) /0.3000000000E+04/
      DATA STRIKE( 941) /0.4967207051E+01/
     *    HL( 941) /0.1450200000E+04/
     *    EQLAT( 941) /0.1107785434E+01/
     *    EQLON( 941) /0.2552637057E+01/
     *    SSLIP( 941) /0.4177000000E+01/
     *    DSLIP( 941) /-.1000000000E-01/
     *    DIP( 941) /0.1570796327E+01/
     *    DEPTH( 941) /0.0000000000E+00/
     *    WIDTH( 941) /0.3000000000E+04/
      DATA STRIKE( 942) /0.4965461722E+01/
     *    HL( 942) /0.1450500000E+04/
     *    EQLAT( 942) /0.1107660818E+01/
     *    EQLON( 942) /0.2551660720E+01/
     *    SSLIP( 942) /0.5152000000E+01/
     *    DSLIP( 942) /-.2000000000E-01/
     *    DIP( 942) /0.1570796327E+01/
     *    DEPTH( 942) /0.0000000000E+00/
     *    WIDTH( 942) /0.3000000000E+04/
      DATA STRIKE( 943) /0.4963716393E+01/
     *    HL( 943) /0.1450900000E+04/
     *    EQLAT( 943) /0.1107536027E+01/
     *    EQLON( 943) /0.2550684208E+01/
     *    SSLIP( 943) /0.5834000000E+01/
     *    DSLIP( 943) /-.2600000000E+00/
     *    DIP( 943) /0.1570796327E+01/
     *    DEPTH( 943) /0.0000000000E+00/
     *    WIDTH( 943) /0.3000000000E+04/
      DATA STRIKE( 944) /0.4961971063E+01/
     *    HL( 944) /0.1451200000E+04/
     *    EQLAT( 944) /0.1107411410E+01/
     *    EQLON( 944) /0.2549707871E+01/
     *    SSLIP( 944) /0.5743000000E+01/
     *    DSLIP( 944) /-.9600000000E+00/
     *    DIP( 944) /0.1570796327E+01/
     *    DEPTH( 944) /0.0000000000E+00/
     *    WIDTH( 944) /0.3000000000E+04/
      DATA STRIKE( 945) /0.4960225734E+01/
     *    HL( 945) /0.1451500000E+04/
     *    EQLAT( 945) /0.1107286794E+01/
     *    EQLON( 945) /0.2548731534E+01/
     *    SSLIP( 945) /0.4541000000E+01/
     *    DSLIP( 945) /-.1480000000E+01/
     *    DIP( 945) /0.1570796327E+01/
     *    DEPTH( 945) /0.0000000000E+00/
     *    WIDTH( 945) /0.3000000000E+04/
      DATA STRIKE( 946) /0.4956735076E+01/
     *    HL( 946) /0.1451900000E+04/
     *    EQLAT( 946) /0.1107162003E+01/
     *    EQLON( 946) /0.2547755022E+01/
     *    SSLIP( 946) /0.4394000000E+01/
     *    DSLIP( 946) /-.1550000000E+01/
     *    DIP( 946) /0.1570796327E+01/
     *    DEPTH( 946) /0.0000000000E+00/
     *    WIDTH( 946) /0.3000000000E+04/
      DATA STRIKE( 947) /0.4954989746E+01/
     *    HL( 947) /0.1452200000E+04/
     *    EQLAT( 947) /0.1107037386E+01/
     *    EQLON( 947) /0.2546778685E+01/
     *    SSLIP( 947) /0.4319000000E+01/
     *    DSLIP( 947) /-.1300000000E+01/
     *    DIP( 947) /0.1570796327E+01/
     *    DEPTH( 947) /0.0000000000E+00/
     *    WIDTH( 947) /0.3000000000E+04/
      DATA STRIKE( 948) /0.5239478414E+01/
     *    HL( 948) /0.1384800000E+04/
     *    EQLAT( 948) /0.1106865995E+01/
     *    EQLON( 948) /0.2545872335E+01/
     *    SSLIP( 948) /0.5155000000E+01/
     *    DSLIP( 948) /-.1420000000E+01/
     *    DIP( 948) /0.1570796327E+01/
     *    DEPTH( 948) /0.0000000000E+00/
     *    WIDTH( 948) /0.3000000000E+04/
      DATA STRIKE( 949) /0.5237733085E+01/
     *    HL( 949) /0.1385300000E+04/
     *    EQLAT( 949) /0.1106647829E+01/
     *    EQLON( 949) /0.2545035799E+01/
     *    SSLIP( 949) /0.6970000000E+01/
     *    DSLIP( 949) /-.1660000000E+01/
     *    DIP( 949) /0.1570796327E+01/
     *    DEPTH( 949) /0.0000000000E+00/
     *    WIDTH( 949) /0.3000000000E+04/
      DATA STRIKE( 950) /0.5235987756E+01/
     *    HL( 950) /0.1385700000E+04/
     *    EQLAT( 950) /0.1106429663E+01/
     *    EQLON( 950) /0.2544199437E+01/
     *    SSLIP( 950) /0.6259000000E+01/
     *    DSLIP( 950) /-.6700000000E+00/
     *    DIP( 950) /0.1570796327E+01/
     *    DEPTH( 950) /0.0000000000E+00/
     *    WIDTH( 950) /0.3000000000E+04/
      DATA STRIKE( 951) /0.5234242427E+01/
     *    HL( 951) /0.1386200000E+04/
     *    EQLAT( 951) /0.1106211497E+01/
     *    EQLON( 951) /0.2543362901E+01/
     *    SSLIP( 951) /0.5773000000E+01/
     *    DSLIP( 951) /-.3900000000E+00/
     *    DIP( 951) /0.1570796327E+01/
     *    DEPTH( 951) /0.0000000000E+00/
     *    WIDTH( 951) /0.3000000000E+04/
      DATA STRIKE( 952) /0.5232497097E+01/
     *    HL( 952) /0.1386600000E+04/
     *    EQLAT( 952) /0.1105993330E+01/
     *    EQLON( 952) /0.2542526539E+01/
     *    SSLIP( 952) /0.5426000000E+01/
     *    DSLIP( 952) /-.7000000000E+00/
     *    DIP( 952) /0.1570796327E+01/
     *    DEPTH( 952) /0.0000000000E+00/
     *    WIDTH( 952) /0.3000000000E+04/
      DATA STRIKE( 953) /0.5230751768E+01/
     *    HL( 953) /0.1387100000E+04/
     *    EQLAT( 953) /0.1105775164E+01/
     *    EQLON( 953) /0.2541690003E+01/
     *    SSLIP( 953) /0.4472000000E+01/
     *    DSLIP( 953) /-.7500000000E+00/
     *    DIP( 953) /0.1570796327E+01/
     *    DEPTH( 953) /0.0000000000E+00/
     *    WIDTH( 953) /0.3000000000E+04/
      DATA STRIKE( 954) /0.5229006439E+01/
     *    HL( 954) /0.1387500000E+04/
     *    EQLAT( 954) /0.1105556998E+01/
     *    EQLON( 954) /0.2540853641E+01/
     *    SSLIP( 954) /0.4419000000E+01/
     *    DSLIP( 954) /-.6900000000E+00/
     *    DIP( 954) /0.1570796327E+01/
     *    DEPTH( 954) /0.0000000000E+00/
     *    WIDTH( 954) /0.3000000000E+04/
      DATA STRIKE( 955) /0.5227261110E+01/
     *    HL( 955) /0.1388000000E+04/
     *    EQLAT( 955) /0.1105338832E+01/
     *    EQLON( 955) /0.2540017105E+01/
     *    SSLIP( 955) /0.6162000000E+01/
     *    DSLIP( 955) /-.5400000000E+00/
     *    DIP( 955) /0.1570796327E+01/
     *    DEPTH( 955) /0.0000000000E+00/
     *    WIDTH( 955) /0.3000000000E+04/
      DATA STRIKE( 956) /0.5047492197E+01/
     *    HL( 956) /0.1434000000E+04/
     *    EQLAT( 956) /0.1105152954E+01/
     *    EQLON( 956) /0.2539129605E+01/
     *    SSLIP( 956) /0.8344000000E+01/
     *    DSLIP( 956) /0.0000000000E+00/
     *    DIP( 956) /0.1570796327E+01/
     *    DEPTH( 956) /0.0000000000E+00/
     *    WIDTH( 956) /0.3000000000E+04/
      DATA STRIKE( 957) /0.5045746868E+01/
     *    HL( 957) /0.1434400000E+04/
     *    EQLAT( 957) /0.1104999540E+01/
     *    EQLON( 957) /0.2538190967E+01/
     *    SSLIP( 957) /0.7663000000E+01/
     *    DSLIP( 957) /0.0000000000E+00/
     *    DIP( 957) /0.1570796327E+01/
     *    DEPTH( 957) /0.0000000000E+00/
     *    WIDTH( 957) /0.3000000000E+04/
      DATA STRIKE( 958) /0.5044001538E+01/
     *    HL( 958) /0.1434700000E+04/
     *    EQLAT( 958) /0.1104846125E+01/
     *    EQLON( 958) /0.2537252329E+01/
     *    SSLIP( 958) /0.5705000000E+01/
     *    DSLIP( 958) /0.0000000000E+00/
     *    DIP( 958) /0.1570796327E+01/
     *    DEPTH( 958) /0.0000000000E+00/
     *    WIDTH( 958) /0.3000000000E+04/
      DATA STRIKE( 959) /0.5042256209E+01/
     *    HL( 959) /0.1435100000E+04/
     *    EQLAT( 959) /0.1104692711E+01/
     *    EQLON( 959) /0.2536313516E+01/
     *    SSLIP( 959) /0.3637000000E+01/
     *    DSLIP( 959) /-.1400000000E+00/
     *    DIP( 959) /0.1570796327E+01/
     *    DEPTH( 959) /0.0000000000E+00/
     *    WIDTH( 959) /0.3000000000E+04/
      DATA STRIKE( 960) /0.5040510880E+01/
     *    HL( 960) /0.1435500000E+04/
     *    EQLAT( 960) /0.1104539297E+01/
     *    EQLON( 960) /0.2535374878E+01/
     *    SSLIP( 960) /0.2382000000E+01/
     *    DSLIP( 960) /-.6500000000E+00/
     *    DIP( 960) /0.1570796327E+01/
     *    DEPTH( 960) /0.0000000000E+00/
     *    WIDTH( 960) /0.3000000000E+04/
      DATA STRIKE( 961) /0.5038765551E+01/
     *    HL( 961) /0.1435900000E+04/
     *    EQLAT( 961) /0.1104385882E+01/
     *    EQLON( 961) /0.2534436240E+01/
     *    SSLIP( 961) /0.2174000000E+01/
     *    DSLIP( 961) /-.1090000000E+01/
     *    DIP( 961) /0.1570796327E+01/
     *    DEPTH( 961) /0.0000000000E+00/
     *    WIDTH( 961) /0.3000000000E+04/
      DATA STRIKE( 962) /0.5037020221E+01/
     *    HL( 962) /0.1436300000E+04/
     *    EQLAT( 962) /0.1104232468E+01/
     *    EQLON( 962) /0.2533497602E+01/
     *    SSLIP( 962) /0.2862000000E+01/
     *    DSLIP( 962) /-.7400000000E+00/
     *    DIP( 962) /0.1570796327E+01/
     *    DEPTH( 962) /0.0000000000E+00/
     *    WIDTH( 962) /0.3000000000E+04/
      DATA STRIKE( 963) /0.5035274892E+01/
     *    HL( 963) /0.1436700000E+04/
     *    EQLAT( 963) /0.1104079053E+01/
     *    EQLON( 963) /0.2532558964E+01/
     *    SSLIP( 963) /0.4251000000E+01/
     *    DSLIP( 963) /-.3400000000E+00/
     *    DIP( 963) /0.1570796327E+01/
     *    DEPTH( 963) /0.0000000000E+00/
     *    WIDTH( 963) /0.3000000000E+04/
      DATA STRIKE( 964) /0.5033529563E+01/
     *    HL( 964) /0.1437100000E+04/
     *    EQLAT( 964) /0.1103925639E+01/
     *    EQLON( 964) /0.2531620151E+01/
     *    SSLIP( 964) /0.5731000000E+01/
     *    DSLIP( 964) /-.1000000000E+00/
     *    DIP( 964) /0.1570796327E+01/
     *    DEPTH( 964) /0.0000000000E+00/
     *    WIDTH( 964) /0.3000000000E+04/
      DATA STRIKE( 965) /0.5031784233E+01/
     *    HL( 965) /0.1437400000E+04/
     *    EQLAT( 965) /0.1103772224E+01/
     *    EQLON( 965) /0.2530681513E+01/
     *    SSLIP( 965) /0.6568000000E+01/
     *    DSLIP( 965) /-.1000000000E-01/
     *    DIP( 965) /0.1570796327E+01/
     *    DEPTH( 965) /0.0000000000E+00/
     *    WIDTH( 965) /0.3000000000E+04/
      DATA STRIKE( 966) /0.5030038904E+01/
     *    HL( 966) /0.1437800000E+04/
     *    EQLAT( 966) /0.1103618810E+01/
     *    EQLON( 966) /0.2529742875E+01/
     *    SSLIP( 966) /0.6325000000E+01/
     *    DSLIP( 966) /0.0000000000E+00/
     *    DIP( 966) /0.1570796327E+01/
     *    DEPTH( 966) /0.0000000000E+00/
     *    WIDTH( 966) /0.3000000000E+04/
      DATA STRIKE( 967) /0.5153957281E+01/
     *    HL( 967) /0.1412200000E+04/
     *    EQLAT( 967) /0.1103441310E+01/
     *    EQLON( 967) /0.2528837224E+01/
     *    SSLIP( 967) /0.5200000000E+01/
     *    DSLIP( 967) /0.0000000000E+00/
     *    DIP( 967) /0.1570796327E+01/
     *    DEPTH( 967) /0.0000000000E+00/
     *    WIDTH( 967) /0.3000000000E+04/
      DATA STRIKE( 968) /0.5152211952E+01/
     *    HL( 968) /0.1412700000E+04/
     *    EQLAT( 968) /0.1103239899E+01/
     *    EQLON( 968) /0.2527964559E+01/
     *    SSLIP( 968) /0.5279000000E+01/
     *    DSLIP( 968) /0.0000000000E+00/
     *    DIP( 968) /0.1570796327E+01/
     *    DEPTH( 968) /0.0000000000E+00/
     *    WIDTH( 968) /0.3000000000E+04/
      DATA STRIKE( 969) /0.5150466623E+01/
     *    HL( 969) /0.1413100000E+04/
     *    EQLAT( 969) /0.1103038313E+01/
     *    EQLON( 969) /0.2527091895E+01/
     *    SSLIP( 969) /0.4949000000E+01/
     *    DSLIP( 969) /0.0000000000E+00/
     *    DIP( 969) /0.1570796327E+01/
     *    DEPTH( 969) /0.0000000000E+00/
     *    WIDTH( 969) /0.3000000000E+04/
      DATA STRIKE( 970) /0.5183627878E+01/
     *    HL( 970) /0.1413500000E+04/
     *    EQLAT( 970) /0.1102836902E+01/
     *    EQLON( 970) /0.2526219230E+01/
     *    SSLIP( 970) /0.5245000000E+01/
     *    DSLIP( 970) /0.0000000000E+00/
     *    DIP( 970) /0.1570796327E+01/
     *    DEPTH( 970) /0.0000000000E+00/
     *    WIDTH( 970) /0.3000000000E+04/
      DATA STRIKE( 971) /0.5181882549E+01/
     *    HL( 971) /0.1414000000E+04/
     *    EQLAT( 971) /0.1102635491E+01/
     *    EQLON( 971) /0.2525346565E+01/
     *    SSLIP( 971) /0.5576000000E+01/
     *    DSLIP( 971) /-.4000000000E-01/
     *    DIP( 971) /0.1570796327E+01/
     *    DEPTH( 971) /0.0000000000E+00/
     *    WIDTH( 971) /0.3000000000E+04/
      DATA STRIKE( 972) /0.5180137220E+01/
     *    HL( 972) /0.1414400000E+04/
     *    EQLAT( 972) /0.1102433906E+01/
     *    EQLON( 972) /0.2524473901E+01/
     *    SSLIP( 972) /0.5678000000E+01/
     *    DSLIP( 972) /-.2200000000E+00/
     *    DIP( 972) /0.1570796327E+01/
     *    DEPTH( 972) /0.0000000000E+00/
     *    WIDTH( 972) /0.3000000000E+04/
      DATA STRIKE( 973) /0.5178391891E+01/
     *    HL( 973) /0.1414900000E+04/
     *    EQLAT( 973) /0.1102232495E+01/
     *    EQLON( 973) /0.2523601236E+01/
     *    SSLIP( 973) /0.5520000000E+01/
     *    DSLIP( 973) /-.5300000000E+00/
     *    DIP( 973) /0.1570796327E+01/
     *    DEPTH( 973) /0.0000000000E+00/
     *    WIDTH( 973) /0.3000000000E+04/
      DATA STRIKE( 974) /0.5176646561E+01/
     *    HL( 974) /0.1415300000E+04/
     *    EQLAT( 974) /0.1102031084E+01/
     *    EQLON( 974) /0.2522728571E+01/
     *    SSLIP( 974) /0.5393000000E+01/
     *    DSLIP( 974) /-.6800000000E+00/
     *    DIP( 974) /0.1570796327E+01/
     *    DEPTH( 974) /0.0000000000E+00/
     *    WIDTH( 974) /0.3000000000E+04/
      DATA STRIKE( 975) /0.5174901232E+01/
     *    HL( 975) /0.1415800000E+04/
     *    EQLAT( 975) /0.1101829673E+01/
     *    EQLON( 975) /0.2521855907E+01/
     *    SSLIP( 975) /0.4930000000E+01/
     *    DSLIP( 975) /-.4400000000E+00/
     *    DIP( 975) /0.1570796327E+01/
     *    DEPTH( 975) /0.0000000000E+00/
     *    WIDTH( 975) /0.3000000000E+04/
      DATA STRIKE( 976) /0.5173155903E+01/
     *    HL( 976) /0.1416200000E+04/
     *    EQLAT( 976) /0.1101628087E+01/
     *    EQLON( 976) /0.2520983242E+01/
     *    SSLIP( 976) /0.4492000000E+01/
     *    DSLIP( 976) /-.3000000000E+00/
     *    DIP( 976) /0.1570796327E+01/
     *    DEPTH( 976) /0.0000000000E+00/
     *    WIDTH( 976) /0.3000000000E+04/
      DATA STRIKE( 977) /0.5171410574E+01/
     *    HL( 977) /0.1416700000E+04/
     *    EQLAT( 977) /0.1101426676E+01/
     *    EQLON( 977) /0.2520110578E+01/
     *    SSLIP( 977) /0.4544000000E+01/
     *    DSLIP( 977) /-.5000000000E+00/
     *    DIP( 977) /0.1570796327E+01/
     *    DEPTH( 977) /0.0000000000E+00/
     *    WIDTH( 977) /0.3000000000E+04/
      DATA STRIKE( 978) /0.5169665244E+01/
     *    HL( 978) /0.1417100000E+04/
     *    EQLAT( 978) /0.1101225265E+01/
     *    EQLON( 978) /0.2519237913E+01/
     *    SSLIP( 978) /0.5187000000E+01/
     *    DSLIP( 978) /-.1080000000E+01/
     *    DIP( 978) /0.1570796327E+01/
     *    DEPTH( 978) /0.0000000000E+00/
     *    WIDTH( 978) /0.3000000000E+04/
      DATA STRIKE( 979) /0.5167919915E+01/
     *    HL( 979) /0.1417600000E+04/
     *    EQLAT( 979) /0.1101023680E+01/
     *    EQLON( 979) /0.2518365248E+01/
     *    SSLIP( 979) /0.6364000000E+01/
     *    DSLIP( 979) /-.1790000000E+01/
     *    DIP( 979) /0.1570796327E+01/
     *    DEPTH( 979) /0.0000000000E+00/
     *    WIDTH( 979) /0.3000000000E+04/
      DATA STRIKE( 980) /0.5166174586E+01/
     *    HL( 980) /0.1418000000E+04/
     *    EQLAT( 980) /0.1100822269E+01/
     *    EQLON( 980) /0.2517492584E+01/
     *    SSLIP( 980) /0.7210000000E+01/
     *    DSLIP( 980) /-.1360000000E+01/
     *    DIP( 980) /0.1570796327E+01/
     *    DEPTH( 980) /0.0000000000E+00/
     *    WIDTH( 980) /0.3000000000E+04/
      DATA STRIKE( 981) /0.5213298476E+01/
     *    HL( 981) /0.1426200000E+04/
     *    EQLAT( 981) /0.1100610909E+01/
     *    EQLON( 981) /0.2516628820E+01/
     *    SSLIP( 981) /0.7675000000E+01/
     *    DSLIP( 981) /-.1020000000E+01/
     *    DIP( 981) /0.1570796327E+01/
     *    DEPTH( 981) /0.0000000000E+00/
     *    WIDTH( 981) /0.3000000000E+04/
      DATA STRIKE( 982) /0.5211553146E+01/
     *    HL( 982) /0.1426600000E+04/
     *    EQLAT( 982) /0.1100389427E+01/
     *    EQLON( 982) /0.2515773958E+01/
     *    SSLIP( 982) /0.7905000000E+01/
     *    DSLIP( 982) /-.9900000000E+00/
     *    DIP( 982) /0.1570796327E+01/
     *    DEPTH( 982) /0.0000000000E+00/
     *    WIDTH( 982) /0.3000000000E+04/
      DATA STRIKE( 983) /0.5209807817E+01/
     *    HL( 983) /0.1427100000E+04/
     *    EQLAT( 983) /0.1100167945E+01/
     *    EQLON( 983) /0.2514918921E+01/
     *    SSLIP( 983) /0.8318000000E+01/
     *    DSLIP( 983) /-.1210000000E+01/
     *    DIP( 983) /0.1570796327E+01/
     *    DEPTH( 983) /0.0000000000E+00/
     *    WIDTH( 983) /0.3000000000E+04/
      DATA STRIKE( 984) /0.5208062488E+01/
     *    HL( 984) /0.1427600000E+04/
     *    EQLAT( 984) /0.1099946463E+01/
     *    EQLON( 984) /0.2514064059E+01/
     *    SSLIP( 984) /0.8648000000E+01/
     *    DSLIP( 984) /-.1490000000E+01/
     *    DIP( 984) /0.1570796327E+01/
     *    DEPTH( 984) /0.0000000000E+00/
     *    WIDTH( 984) /0.3000000000E+04/
      DATA STRIKE( 985) /0.5206317159E+01/
     *    HL( 985) /0.1428000000E+04/
     *    EQLAT( 985) /0.1099724980E+01/
     *    EQLON( 985) /0.2513209197E+01/
     *    SSLIP( 985) /0.9064000000E+01/
     *    DSLIP( 985) /-.1320000000E+01/
     *    DIP( 985) /0.1570796327E+01/
     *    DEPTH( 985) /0.0000000000E+00/
     *    WIDTH( 985) /0.3000000000E+04/
      DATA STRIKE( 986) /0.5204571829E+01/
     *    HL( 986) /0.1428500000E+04/
     *    EQLAT( 986) /0.1099503498E+01/
     *    EQLON( 986) /0.2512354160E+01/
     *    SSLIP( 986) /0.8769000000E+01/
     *    DSLIP( 986) /-.1000000000E+01/
     *    DIP( 986) /0.1570796327E+01/
     *    DEPTH( 986) /0.0000000000E+00/
     *    WIDTH( 986) /0.3000000000E+04/
      DATA STRIKE( 987) /0.5202826500E+01/
     *    HL( 987) /0.1429000000E+04/
     *    EQLAT( 987) /0.1099282016E+01/
     *    EQLON( 987) /0.2511499298E+01/
     *    SSLIP( 987) /0.6664000000E+01/
     *    DSLIP( 987) /-.5900000000E+00/
     *    DIP( 987) /0.1570796327E+01/
     *    DEPTH( 987) /0.0000000000E+00/
     *    WIDTH( 987) /0.3000000000E+04/
      DATA STRIKE( 988) /0.5201081171E+01/
     *    HL( 988) /0.1429500000E+04/
     *    EQLAT( 988) /0.1099060534E+01/
     *    EQLON( 988) /0.2510644435E+01/
     *    SSLIP( 988) /0.5552000000E+01/
     *    DSLIP( 988) /-.1640000000E+01/
     *    DIP( 988) /0.1570796327E+01/
     *    DEPTH( 988) /0.0000000000E+00/
     *    WIDTH( 988) /0.3000000000E+04/
      DATA STRIKE( 989) /0.5199335842E+01/
     *    HL( 989) /0.1429900000E+04/
     *    EQLAT( 989) /0.1098839051E+01/
     *    EQLON( 989) /0.2509789398E+01/
     *    SSLIP( 989) /0.6335000000E+01/
     *    DSLIP( 989) /-.2110000000E+01/
     *    DIP( 989) /0.1570796327E+01/
     *    DEPTH( 989) /0.0000000000E+00/
     *    WIDTH( 989) /0.3000000000E+04/
      DATA STRIKE( 990) /0.5197590512E+01/
     *    HL( 990) /0.1430400000E+04/
     *    EQLAT( 990) /0.1098617743E+01/
     *    EQLON( 990) /0.2508934536E+01/
     *    SSLIP( 990) /0.6413000000E+01/
     *    DSLIP( 990) /-.1330000000E+01/
     *    DIP( 990) /0.1570796327E+01/
     *    DEPTH( 990) /0.0000000000E+00/
     *    WIDTH( 990) /0.3000000000E+04/
      DATA STRIKE( 991) /0.5195845183E+01/
     *    HL( 991) /0.1430900000E+04/
     *    EQLAT( 991) /0.1098396261E+01/
     *    EQLON( 991) /0.2508079674E+01/
     *    SSLIP( 991) /0.6595000000E+01/
     *    DSLIP( 991) /-.1180000000E+01/
     *    DIP( 991) /0.1570796327E+01/
     *    DEPTH( 991) /0.0000000000E+00/
     *    WIDTH( 991) /0.3000000000E+04/
      DATA STRIKE( 992) /0.5229006439E+01/
     *    HL( 992) /0.1431300000E+04/
     *    EQLAT( 992) /0.1098174779E+01/
     *    EQLON( 992) /0.2507224637E+01/
     *    SSLIP( 992) /0.6821000000E+01/
     *    DSLIP( 992) /-.7300000000E+00/
     *    DIP( 992) /0.1570796327E+01/
     *    DEPTH( 992) /0.0000000000E+00/
     *    WIDTH( 992) /0.3000000000E+04/
      DATA STRIKE( 993) /0.5227261110E+01/
     *    HL( 993) /0.1431800000E+04/
     *    EQLAT( 993) /0.1097953297E+01/
     *    EQLON( 993) /0.2506369775E+01/
     *    SSLIP( 993) /0.6841000000E+01/
     *    DSLIP( 993) /-.6700000000E+00/
     *    DIP( 993) /0.1570796327E+01/
     *    DEPTH( 993) /0.0000000000E+00/
     *    WIDTH( 993) /0.3000000000E+04/
      DATA STRIKE( 994) /0.5225515780E+01/
     *    HL( 994) /0.1432300000E+04/
     *    EQLAT( 994) /0.1097731814E+01/
     *    EQLON( 994) /0.2505514913E+01/
     *    SSLIP( 994) /0.6030000000E+01/
     *    DSLIP( 994) /-.1490000000E+01/
     *    DIP( 994) /0.1570796327E+01/
     *    DEPTH( 994) /0.0000000000E+00/
     *    WIDTH( 994) /0.3000000000E+04/
      DATA STRIKE( 995) /0.5223770451E+01/
     *    HL( 995) /0.1432700000E+04/
     *    EQLAT( 995) /0.1097510332E+01/
     *    EQLON( 995) /0.2504659876E+01/
     *    SSLIP( 995) /0.5788000000E+01/
     *    DSLIP( 995) /-.6800000000E+00/
     *    DIP( 995) /0.1570796327E+01/
     *    DEPTH( 995) /0.0000000000E+00/
     *    WIDTH( 995) /0.3000000000E+04/
      DATA STRIKE( 996) /0.5222025122E+01/
     *    HL( 996) /0.1433200000E+04/
     *    EQLAT( 996) /0.1097288850E+01/
     *    EQLON( 996) /0.2503805014E+01/
     *    SSLIP( 996) /0.5570000000E+01/
     *    DSLIP( 996) /-.1300000000E+00/
     *    DIP( 996) /0.1570796327E+01/
     *    DEPTH( 996) /0.0000000000E+00/
     *    WIDTH( 996) /0.3000000000E+04/
      DATA STRIKE( 997) /0.5220279793E+01/
     *    HL( 997) /0.1433700000E+04/
     *    EQLAT( 997) /0.1097067368E+01/
     *    EQLON( 997) /0.2502950151E+01/
     *    SSLIP( 997) /0.5339000000E+01/
     *    DSLIP( 997) /0.0000000000E+00/
     *    DIP( 997) /0.1570796327E+01/
     *    DEPTH( 997) /0.3000000000E+04/
     *    WIDTH( 997) /0.3000000000E+04/
      DATA STRIKE( 998) /0.5218534463E+01/
     *    HL( 998) /0.1434100000E+04/
     *    EQLAT( 998) /0.1096845885E+01/
     *    EQLON( 998) /0.2502095114E+01/
     *    SSLIP( 998) /0.5087000000E+01/
     *    DSLIP( 998) /0.0000000000E+00/
     *    DIP( 998) /0.1570796327E+01/
     *    DEPTH( 998) /0.3000000000E+04/
     *    WIDTH( 998) /0.3000000000E+04/
      DATA STRIKE( 999) /0.4544837372E+01/
     *    HL( 999) /0.1500600000E+04/
     *    EQLAT( 999) /0.1108284599E+01/
     *    EQLON( 999) /0.2578255000E+01/
     *    SSLIP( 999) /0.0000000000E+00/
     *    DSLIP( 999) /0.0000000000E+00/
     *    DIP( 999) /0.1570796327E+01/
     *    DEPTH( 999) /0.3000000000E+04/
     *    WIDTH( 999) /0.3000000000E+04/
      DATA STRIKE(1000) /0.4544837372E+01/
     *    HL(1000) /0.1500600000E+04/
     *    EQLAT(1000) /0.1108363138E+01/
     *    EQLON(1000) /0.2577217925E+01/
     *    SSLIP(1000) /0.0000000000E+00/
     *    DSLIP(1000) /0.0000000000E+00/
     *    DIP(1000) /0.1570796327E+01/
     *    DEPTH(1000) /0.3000000000E+04/
     *    WIDTH(1000) /0.3000000000E+04/
      DATA STRIKE(1001) /0.4546582701E+01/
     *    HL(1001) /0.1500600000E+04/
     *    EQLAT(1001) /0.1108441329E+01/
     *    EQLON(1001) /0.2576180502E+01/
     *    SSLIP(1001) /0.4500000000E-01/
     *    DSLIP(1001) /0.0000000000E+00/
     *    DIP(1001) /0.1570796327E+01/
     *    DEPTH(1001) /0.3000000000E+04/
     *    WIDTH(1001) /0.3000000000E+04/
      DATA STRIKE(1002) /0.4546582701E+01/
     *    HL(1002) /0.1500600000E+04/
     *    EQLAT(1002) /0.1108518996E+01/
     *    EQLON(1002) /0.2575142903E+01/
     *    SSLIP(1002) /0.7600000000E-01/
     *    DSLIP(1002) /0.0000000000E+00/
     *    DIP(1002) /0.1570796327E+01/
     *    DEPTH(1002) /0.3000000000E+04/
     *    WIDTH(1002) /0.3000000000E+04/
      DATA STRIKE(1003) /0.4548328031E+01/
     *    HL(1003) /0.1500600000E+04/
     *    EQLAT(1003) /0.1108596140E+01/
     *    EQLON(1003) /0.2574104956E+01/
     *    SSLIP(1003) /0.5100000000E-01/
     *    DSLIP(1003) /0.0000000000E+00/
     *    DIP(1003) /0.1570796327E+01/
     *    DEPTH(1003) /0.3000000000E+04/
     *    WIDTH(1003) /0.3000000000E+04/
      DATA STRIKE(1004) /0.4548328031E+01/
     *    HL(1004) /0.1500600000E+04/
     *    EQLAT(1004) /0.1108673109E+01/
     *    EQLON(1004) /0.2573066660E+01/
     *    SSLIP(1004) /0.1000000000E-02/
     *    DSLIP(1004) /0.0000000000E+00/
     *    DIP(1004) /0.1570796327E+01/
     *    DEPTH(1004) /0.3000000000E+04/
     *    WIDTH(1004) /0.3000000000E+04/
      DATA STRIKE(1005) /0.4550073360E+01/
     *    HL(1005) /0.1500600000E+04/
     *    EQLAT(1005) /0.1108749380E+01/
     *    EQLON(1005) /0.2572028014E+01/
     *    SSLIP(1005) /0.0000000000E+00/
     *    DSLIP(1005) /0.0000000000E+00/
     *    DIP(1005) /0.1570796327E+01/
     *    DEPTH(1005) /0.3000000000E+04/
     *    WIDTH(1005) /0.3000000000E+04/
      DATA STRIKE(1006) /0.4551818689E+01/
     *    HL(1006) /0.1500600000E+04/
     *    EQLAT(1006) /0.1108825476E+01/
     *    EQLON(1006) /0.2570989020E+01/
     *    SSLIP(1006) /0.0000000000E+00/
     *    DSLIP(1006) /0.0000000000E+00/
     *    DIP(1006) /0.1570796327E+01/
     *    DEPTH(1006) /0.3000000000E+04/
     *    WIDTH(1006) /0.3000000000E+04/
      DATA STRIKE(1007) /0.4551818689E+01/
     *    HL(1007) /0.1500600000E+04/
     *    EQLAT(1007) /0.1108900874E+01/
     *    EQLON(1007) /0.2569949851E+01/
     *    SSLIP(1007) /0.0000000000E+00/
     *    DSLIP(1007) /0.0000000000E+00/
     *    DIP(1007) /0.1570796327E+01/
     *    DEPTH(1007) /0.3000000000E+04/
     *    WIDTH(1007) /0.3000000000E+04/
      DATA STRIKE(1008) /0.4862487296E+01/
     *    HL(1008) /0.1468400000E+04/
     *    EQLAT(1008) /0.1108904540E+01/
     *    EQLON(1008) /0.2568920630E+01/
     *    SSLIP(1008) /0.2320000000E+00/
     *    DSLIP(1008) /0.0000000000E+00/
     *    DIP(1008) /0.1570796327E+01/
     *    DEPTH(1008) /0.3000000000E+04/
     *    WIDTH(1008) /0.3000000000E+04/
      DATA STRIKE(1009) /0.4862487296E+01/
     *    HL(1009) /0.1468600000E+04/
     *    EQLAT(1009) /0.1108836297E+01/
     *    EQLON(1009) /0.2567901532E+01/
     *    SSLIP(1009) /0.6720000000E+00/
     *    DSLIP(1009) /0.0000000000E+00/
     *    DIP(1009) /0.1570796327E+01/
     *    DEPTH(1009) /0.3000000000E+04/
     *    WIDTH(1009) /0.3000000000E+04/
      DATA STRIKE(1010) /0.4862487296E+01/
     *    HL(1010) /0.1468800000E+04/
     *    EQLAT(1010) /0.1108768055E+01/
     *    EQLON(1010) /0.2566882434E+01/
     *    SSLIP(1010) /0.1245000000E+01/
     *    DSLIP(1010) /0.0000000000E+00/
     *    DIP(1010) /0.1570796327E+01/
     *    DEPTH(1010) /0.3000000000E+04/
     *    WIDTH(1010) /0.3000000000E+04/
      DATA STRIKE(1011) /0.4860741967E+01/
     *    HL(1011) /0.1469000000E+04/
     *    EQLAT(1011) /0.1108699987E+01/
     *    EQLON(1011) /0.2565863337E+01/
     *    SSLIP(1011) /0.1499000000E+01/
     *    DSLIP(1011) /-.3000000000E-01/
     *    DIP(1011) /0.1570796327E+01/
     *    DEPTH(1011) /0.3000000000E+04/
     *    WIDTH(1011) /0.3000000000E+04/
      DATA STRIKE(1012) /0.4858996638E+01/
     *    HL(1012) /0.1469200000E+04/
     *    EQLAT(1012) /0.1108631745E+01/
     *    EQLON(1012) /0.2564844413E+01/
     *    SSLIP(1012) /0.1070000000E+01/
     *    DSLIP(1012) /-.4900000000E+00/
     *    DIP(1012) /0.1570796327E+01/
     *    DEPTH(1012) /0.3000000000E+04/
     *    WIDTH(1012) /0.3000000000E+04/
      DATA STRIKE(1013) /0.4857251308E+01/
     *    HL(1013) /0.1469400000E+04/
     *    EQLAT(1013) /0.1108563677E+01/
     *    EQLON(1013) /0.2563825316E+01/
     *    SSLIP(1013) /0.7160000000E+00/
     *    DSLIP(1013) /-.1250000000E+01/
     *    DIP(1013) /0.1570796327E+01/
     *    DEPTH(1013) /0.3000000000E+04/
     *    WIDTH(1013) /0.3000000000E+04/
      DATA STRIKE(1014) /0.4855505979E+01/
     *    HL(1014) /0.1469600000E+04/
     *    EQLAT(1014) /0.1108495434E+01/
     *    EQLON(1014) /0.2562806218E+01/
     *    SSLIP(1014) /0.8570000000E+00/
     *    DSLIP(1014) /-.2080000000E+01/
     *    DIP(1014) /0.1570796327E+01/
     *    DEPTH(1014) /0.3000000000E+04/
     *    WIDTH(1014) /0.3000000000E+04/
      DATA STRIKE(1015) /0.4853760650E+01/
     *    HL(1015) /0.1469800000E+04/
     *    EQLAT(1015) /0.1108427192E+01/
     *    EQLON(1015) /0.2561787120E+01/
     *    SSLIP(1015) /0.1548000000E+01/
     *    DSLIP(1015) /-.2730000000E+01/
     *    DIP(1015) /0.1570796327E+01/
     *    DEPTH(1015) /0.3000000000E+04/
     *    WIDTH(1015) /0.3000000000E+04/
      DATA STRIKE(1016) /0.4852015321E+01/
     *    HL(1016) /0.1470000000E+04/
     *    EQLAT(1016) /0.1108359124E+01/
     *    EQLON(1016) /0.2560768197E+01/
     *    SSLIP(1016) /0.2550000000E+01/
     *    DSLIP(1016) /-.3000000000E+01/
     *    DIP(1016) /0.1570796327E+01/
     *    DEPTH(1016) /0.3000000000E+04/
     *    WIDTH(1016) /0.3000000000E+04/
      DATA STRIKE(1017) /0.4850269991E+01/
     *    HL(1017) /0.1470200000E+04/
     *    EQLAT(1017) /0.1108290882E+01/
     *    EQLON(1017) /0.2559749099E+01/
     *    SSLIP(1017) /0.3410000000E+01/
     *    DSLIP(1017) /-.2760000000E+01/
     *    DIP(1017) /0.1570796327E+01/
     *    DEPTH(1017) /0.3000000000E+04/
     *    WIDTH(1017) /0.3000000000E+04/
      DATA STRIKE(1018) /0.4848524662E+01/
     *    HL(1018) /0.1470400000E+04/
     *    EQLAT(1018) /0.1108222639E+01/
     *    EQLON(1018) /0.2558730002E+01/
     *    SSLIP(1018) /0.3671000000E+01/
     *    DSLIP(1018) /-.1800000000E+01/
     *    DIP(1018) /0.1570796327E+01/
     *    DEPTH(1018) /0.3000000000E+04/
     *    WIDTH(1018) /0.3000000000E+04/
      DATA STRIKE(1019) /0.4846779333E+01/
     *    HL(1019) /0.1470600000E+04/
     *    EQLAT(1019) /0.1108154572E+01/
     *    EQLON(1019) /0.2557710904E+01/
     *    SSLIP(1019) /0.3438000000E+01/
     *    DSLIP(1019) /-.5100000000E+00/
     *    DIP(1019) /0.1570796327E+01/
     *    DEPTH(1019) /0.3000000000E+04/
     *    WIDTH(1019) /0.3000000000E+04/
      DATA STRIKE(1020) /0.4845034004E+01/
     *    HL(1020) /0.1470800000E+04/
     *    EQLAT(1020) /0.1108086329E+01/
     *    EQLON(1020) /0.2556691981E+01/
     *    SSLIP(1020) /0.3834000000E+01/
     *    DSLIP(1020) /-.3700000000E+00/
     *    DIP(1020) /0.1570796327E+01/
     *    DEPTH(1020) /0.3000000000E+04/
     *    WIDTH(1020) /0.3000000000E+04/
      DATA STRIKE(1021) /0.4843288674E+01/
     *    HL(1021) /0.1470900000E+04/
     *    EQLAT(1021) /0.1108018261E+01/
     *    EQLON(1021) /0.2555672883E+01/
     *    SSLIP(1021) /0.3842000000E+01/
     *    DSLIP(1021) /-.2700000000E+00/
     *    DIP(1021) /0.1570796327E+01/
     *    DEPTH(1021) /0.3000000000E+04/
     *    WIDTH(1021) /0.3000000000E+04/
      DATA STRIKE(1022) /0.4841543345E+01/
     *    HL(1022) /0.1471100000E+04/
     *    EQLAT(1022) /0.1107950019E+01/
     *    EQLON(1022) /0.2554653785E+01/
     *    SSLIP(1022) /0.3208000000E+01/
     *    DSLIP(1022) /0.0000000000E+00/
     *    DIP(1022) /0.1570796327E+01/
     *    DEPTH(1022) /0.3000000000E+04/
     *    WIDTH(1022) /0.3000000000E+04/
      DATA STRIKE(1023) /0.4839798016E+01/
     *    HL(1023) /0.1471300000E+04/
     *    EQLAT(1023) /0.1107881777E+01/
     *    EQLON(1023) /0.2553634687E+01/
     *    SSLIP(1023) /0.2986000000E+01/
     *    DSLIP(1023) /0.0000000000E+00/
     *    DIP(1023) /0.1570796327E+01/
     *    DEPTH(1023) /0.3000000000E+04/
     *    WIDTH(1023) /0.3000000000E+04/
      DATA STRIKE(1024) /0.4967207051E+01/
     *    HL(1024) /0.1450200000E+04/
     *    EQLAT(1024) /0.1107785434E+01/
     *    EQLON(1024) /0.2552637057E+01/
     *    SSLIP(1024) /0.3872000000E+01/
     *    DSLIP(1024) /-.1200000000E+00/
     *    DIP(1024) /0.1570796327E+01/
     *    DEPTH(1024) /0.3000000000E+04/
     *    WIDTH(1024) /0.3000000000E+04/
      DATA STRIKE(1025) /0.4965461722E+01/
     *    HL(1025) /0.1450500000E+04/
     *    EQLAT(1025) /0.1107660818E+01/
     *    EQLON(1025) /0.2551660720E+01/
     *    SSLIP(1025) /0.4960000000E+01/
     *    DSLIP(1025) /-.1500000000E+00/
     *    DIP(1025) /0.1570796327E+01/
     *    DEPTH(1025) /0.3000000000E+04/
     *    WIDTH(1025) /0.3000000000E+04/
      DATA STRIKE(1026) /0.4963716393E+01/
     *    HL(1026) /0.1450900000E+04/
     *    EQLAT(1026) /0.1107536027E+01/
     *    EQLON(1026) /0.2550684208E+01/
     *    SSLIP(1026) /0.5807000000E+01/
     *    DSLIP(1026) /-.3700000000E+00/
     *    DIP(1026) /0.1570796327E+01/
     *    DEPTH(1026) /0.3000000000E+04/
     *    WIDTH(1026) /0.3000000000E+04/
      DATA STRIKE(1027) /0.4961971063E+01/
     *    HL(1027) /0.1451200000E+04/
     *    EQLAT(1027) /0.1107411410E+01/
     *    EQLON(1027) /0.2549707871E+01/
     *    SSLIP(1027) /0.5990000000E+01/
     *    DSLIP(1027) /-.1090000000E+01/
     *    DIP(1027) /0.1570796327E+01/
     *    DEPTH(1027) /0.3000000000E+04/
     *    WIDTH(1027) /0.3000000000E+04/
      DATA STRIKE(1028) /0.4960225734E+01/
     *    HL(1028) /0.1451500000E+04/
     *    EQLAT(1028) /0.1107286794E+01/
     *    EQLON(1028) /0.2548731534E+01/
     *    SSLIP(1028) /0.5254000000E+01/
     *    DSLIP(1028) /-.1820000000E+01/
     *    DIP(1028) /0.1570796327E+01/
     *    DEPTH(1028) /0.3000000000E+04/
     *    WIDTH(1028) /0.3000000000E+04/
      DATA STRIKE(1029) /0.4956735076E+01/
     *    HL(1029) /0.1451900000E+04/
     *    EQLAT(1029) /0.1107162003E+01/
     *    EQLON(1029) /0.2547755022E+01/
     *    SSLIP(1029) /0.4722000000E+01/
     *    DSLIP(1029) /-.2040000000E+01/
     *    DIP(1029) /0.1570796327E+01/
     *    DEPTH(1029) /0.3000000000E+04/
     *    WIDTH(1029) /0.3000000000E+04/
      DATA STRIKE(1030) /0.4954989746E+01/
     *    HL(1030) /0.1452200000E+04/
     *    EQLAT(1030) /0.1107037386E+01/
     *    EQLON(1030) /0.2546778685E+01/
     *    SSLIP(1030) /0.4444000000E+01/
     *    DSLIP(1030) /-.1750000000E+01/
     *    DIP(1030) /0.1570796327E+01/
     *    DEPTH(1030) /0.3000000000E+04/
     *    WIDTH(1030) /0.3000000000E+04/
      DATA STRIKE(1031) /0.5239478414E+01/
     *    HL(1031) /0.1384800000E+04/
     *    EQLAT(1031) /0.1106865995E+01/
     *    EQLON(1031) /0.2545872335E+01/
     *    SSLIP(1031) /0.6031000000E+01/
     *    DSLIP(1031) /-.2060000000E+01/
     *    DIP(1031) /0.1570796327E+01/
     *    DEPTH(1031) /0.3000000000E+04/
     *    WIDTH(1031) /0.3000000000E+04/
      DATA STRIKE(1032) /0.5237733085E+01/
     *    HL(1032) /0.1385300000E+04/
     *    EQLAT(1032) /0.1106647829E+01/
     *    EQLON(1032) /0.2545035799E+01/
     *    SSLIP(1032) /0.7351000000E+01/
     *    DSLIP(1032) /-.1830000000E+01/
     *    DIP(1032) /0.1570796327E+01/
     *    DEPTH(1032) /0.3000000000E+04/
     *    WIDTH(1032) /0.3000000000E+04/
      DATA STRIKE(1033) /0.5235987756E+01/
     *    HL(1033) /0.1385700000E+04/
     *    EQLAT(1033) /0.1106429663E+01/
     *    EQLON(1033) /0.2544199437E+01/
     *    SSLIP(1033) /0.6327000000E+01/
     *    DSLIP(1033) /-.2900000000E+00/
     *    DIP(1033) /0.1570796327E+01/
     *    DEPTH(1033) /0.3000000000E+04/
     *    WIDTH(1033) /0.3000000000E+04/
      DATA STRIKE(1034) /0.5234242427E+01/
     *    HL(1034) /0.1386200000E+04/
     *    EQLAT(1034) /0.1106211497E+01/
     *    EQLON(1034) /0.2543362901E+01/
     *    SSLIP(1034) /0.6031000000E+01/
     *    DSLIP(1034) /0.0000000000E+00/
     *    DIP(1034) /0.1570796327E+01/
     *    DEPTH(1034) /0.3000000000E+04/
     *    WIDTH(1034) /0.3000000000E+04/
      DATA STRIKE(1035) /0.5232497097E+01/
     *    HL(1035) /0.1386600000E+04/
     *    EQLAT(1035) /0.1105993330E+01/
     *    EQLON(1035) /0.2542526539E+01/
     *    SSLIP(1035) /0.5536000000E+01/
     *    DSLIP(1035) /-.8000000000E-01/
     *    DIP(1035) /0.1570796327E+01/
     *    DEPTH(1035) /0.3000000000E+04/
     *    WIDTH(1035) /0.3000000000E+04/
      DATA STRIKE(1036) /0.5230751768E+01/
     *    HL(1036) /0.1387100000E+04/
     *    EQLAT(1036) /0.1105775164E+01/
     *    EQLON(1036) /0.2541690003E+01/
     *    SSLIP(1036) /0.4143000000E+01/
     *    DSLIP(1036) /-.5200000000E+00/
     *    DIP(1036) /0.1570796327E+01/
     *    DEPTH(1036) /0.3000000000E+04/
     *    WIDTH(1036) /0.3000000000E+04/
      DATA STRIKE(1037) /0.5229006439E+01/
     *    HL(1037) /0.1387500000E+04/
     *    EQLAT(1037) /0.1105556998E+01/
     *    EQLON(1037) /0.2540853641E+01/
     *    SSLIP(1037) /0.3833000000E+01/
     *    DSLIP(1037) /-.5900000000E+00/
     *    DIP(1037) /0.1570796327E+01/
     *    DEPTH(1037) /0.3000000000E+04/
     *    WIDTH(1037) /0.3000000000E+04/
      DATA STRIKE(1038) /0.5227261110E+01/
     *    HL(1038) /0.1388000000E+04/
     *    EQLAT(1038) /0.1105338832E+01/
     *    EQLON(1038) /0.2540017105E+01/
     *    SSLIP(1038) /0.5671000000E+01/
     *    DSLIP(1038) /-.3600000000E+00/
     *    DIP(1038) /0.1570796327E+01/
     *    DEPTH(1038) /0.3000000000E+04/
     *    WIDTH(1038) /0.3000000000E+04/
      DATA STRIKE(1039) /0.5047492197E+01/
     *    HL(1039) /0.1434000000E+04/
     *    EQLAT(1039) /0.1105152954E+01/
     *    EQLON(1039) /0.2539129605E+01/
     *    SSLIP(1039) /0.8404000000E+01/
     *    DSLIP(1039) /0.0000000000E+00/
     *    DIP(1039) /0.1570796327E+01/
     *    DEPTH(1039) /0.3000000000E+04/
     *    WIDTH(1039) /0.3000000000E+04/
      DATA STRIKE(1040) /0.5045746868E+01/
     *    HL(1040) /0.1434400000E+04/
     *    EQLAT(1040) /0.1104999540E+01/
     *    EQLON(1040) /0.2538190967E+01/
     *    SSLIP(1040) /0.8203000000E+01/
     *    DSLIP(1040) /0.0000000000E+00/
     *    DIP(1040) /0.1570796327E+01/
     *    DEPTH(1040) /0.3000000000E+04/
     *    WIDTH(1040) /0.3000000000E+04/
      DATA STRIKE(1041) /0.5044001538E+01/
     *    HL(1041) /0.1434700000E+04/
     *    EQLAT(1041) /0.1104846125E+01/
     *    EQLON(1041) /0.2537252329E+01/
     *    SSLIP(1041) /0.6285000000E+01/
     *    DSLIP(1041) /0.0000000000E+00/
     *    DIP(1041) /0.1570796327E+01/
     *    DEPTH(1041) /0.3000000000E+04/
     *    WIDTH(1041) /0.3000000000E+04/
      DATA STRIKE(1042) /0.5042256209E+01/
     *    HL(1042) /0.1435100000E+04/
     *    EQLAT(1042) /0.1104692711E+01/
     *    EQLON(1042) /0.2536313516E+01/
     *    SSLIP(1042) /0.4044000000E+01/
     *    DSLIP(1042) /0.0000000000E+00/
     *    DIP(1042) /0.1570796327E+01/
     *    DEPTH(1042) /0.3000000000E+04/
     *    WIDTH(1042) /0.3000000000E+04/
      DATA STRIKE(1043) /0.5040510880E+01/
     *    HL(1043) /0.1435500000E+04/
     *    EQLAT(1043) /0.1104539297E+01/
     *    EQLON(1043) /0.2535374878E+01/
     *    SSLIP(1043) /0.2573000000E+01/
     *    DSLIP(1043) /-.3800000000E+00/
     *    DIP(1043) /0.1570796327E+01/
     *    DEPTH(1043) /0.3000000000E+04/
     *    WIDTH(1043) /0.3000000000E+04/
      DATA STRIKE(1044) /0.5038765551E+01/
     *    HL(1044) /0.1435900000E+04/
     *    EQLAT(1044) /0.1104385882E+01/
     *    EQLON(1044) /0.2534436240E+01/
     *    SSLIP(1044) /0.2242000000E+01/
     *    DSLIP(1044) /-.7400000000E+00/
     *    DIP(1044) /0.1570796327E+01/
     *    DEPTH(1044) /0.3000000000E+04/
     *    WIDTH(1044) /0.3000000000E+04/
      DATA STRIKE(1045) /0.5037020221E+01/
     *    HL(1045) /0.1436300000E+04/
     *    EQLAT(1045) /0.1104232468E+01/
     *    EQLON(1045) /0.2533497602E+01/
     *    SSLIP(1045) /0.2973000000E+01/
     *    DSLIP(1045) /-.5200000000E+00/
     *    DIP(1045) /0.1570796327E+01/
     *    DEPTH(1045) /0.3000000000E+04/
     *    WIDTH(1045) /0.3000000000E+04/
      DATA STRIKE(1046) /0.5035274892E+01/
     *    HL(1046) /0.1436700000E+04/
     *    EQLAT(1046) /0.1104079053E+01/
     *    EQLON(1046) /0.2532558964E+01/
     *    SSLIP(1046) /0.4450000000E+01/
     *    DSLIP(1046) /-.2100000000E+00/
     *    DIP(1046) /0.1570796327E+01/
     *    DEPTH(1046) /0.3000000000E+04/
     *    WIDTH(1046) /0.3000000000E+04/
      DATA STRIKE(1047) /0.5033529563E+01/
     *    HL(1047) /0.1437100000E+04/
     *    EQLAT(1047) /0.1103925639E+01/
     *    EQLON(1047) /0.2531620151E+01/
     *    SSLIP(1047) /0.5988000000E+01/
     *    DSLIP(1047) /-.4000000000E-01/
     *    DIP(1047) /0.1570796327E+01/
     *    DEPTH(1047) /0.3000000000E+04/
     *    WIDTH(1047) /0.3000000000E+04/
      DATA STRIKE(1048) /0.5031784233E+01/
     *    HL(1048) /0.1437400000E+04/
     *    EQLAT(1048) /0.1103772224E+01/
     *    EQLON(1048) /0.2530681513E+01/
     *    SSLIP(1048) /0.6819000000E+01/
     *    DSLIP(1048) /0.0000000000E+00/
     *    DIP(1048) /0.1570796327E+01/
     *    DEPTH(1048) /0.3000000000E+04/
     *    WIDTH(1048) /0.3000000000E+04/
      DATA STRIKE(1049) /0.5030038904E+01/
     *    HL(1049) /0.1437800000E+04/
     *    EQLAT(1049) /0.1103618810E+01/
     *    EQLON(1049) /0.2529742875E+01/
     *    SSLIP(1049) /0.6502000000E+01/
     *    DSLIP(1049) /0.0000000000E+00/
     *    DIP(1049) /0.1570796327E+01/
     *    DEPTH(1049) /0.3000000000E+04/
     *    WIDTH(1049) /0.3000000000E+04/
      DATA STRIKE(1050) /0.5153957281E+01/
     *    HL(1050) /0.1412200000E+04/
     *    EQLAT(1050) /0.1103441310E+01/
     *    EQLON(1050) /0.2528837224E+01/
     *    SSLIP(1050) /0.5364000000E+01/
     *    DSLIP(1050) /0.0000000000E+00/
     *    DIP(1050) /0.1570796327E+01/
     *    DEPTH(1050) /0.3000000000E+04/
     *    WIDTH(1050) /0.3000000000E+04/
      DATA STRIKE(1051) /0.5152211952E+01/
     *    HL(1051) /0.1412700000E+04/
     *    EQLAT(1051) /0.1103239899E+01/
     *    EQLON(1051) /0.2527964559E+01/
     *    SSLIP(1051) /0.5074000000E+01/
     *    DSLIP(1051) /0.0000000000E+00/
     *    DIP(1051) /0.1570796327E+01/
     *    DEPTH(1051) /0.3000000000E+04/
     *    WIDTH(1051) /0.3000000000E+04/
      DATA STRIKE(1052) /0.5150466623E+01/
     *    HL(1052) /0.1413100000E+04/
     *    EQLAT(1052) /0.1103038313E+01/
     *    EQLON(1052) /0.2527091895E+01/
     *    SSLIP(1052) /0.4863000000E+01/
     *    DSLIP(1052) /0.0000000000E+00/
     *    DIP(1052) /0.1570796327E+01/
     *    DEPTH(1052) /0.3000000000E+04/
     *    WIDTH(1052) /0.3000000000E+04/
      DATA STRIKE(1053) /0.5183627878E+01/
     *    HL(1053) /0.1413500000E+04/
     *    EQLAT(1053) /0.1102836902E+01/
     *    EQLON(1053) /0.2526219230E+01/
     *    SSLIP(1053) /0.5122000000E+01/
     *    DSLIP(1053) /0.0000000000E+00/
     *    DIP(1053) /0.1570796327E+01/
     *    DEPTH(1053) /0.3000000000E+04/
     *    WIDTH(1053) /0.3000000000E+04/
      DATA STRIKE(1054) /0.5181882549E+01/
     *    HL(1054) /0.1414000000E+04/
     *    EQLAT(1054) /0.1102635491E+01/
     *    EQLON(1054) /0.2525346565E+01/
     *    SSLIP(1054) /0.5452000000E+01/
     *    DSLIP(1054) /-.1000000000E-01/
     *    DIP(1054) /0.1570796327E+01/
     *    DEPTH(1054) /0.3000000000E+04/
     *    WIDTH(1054) /0.3000000000E+04/
      DATA STRIKE(1055) /0.5180137220E+01/
     *    HL(1055) /0.1414400000E+04/
     *    EQLAT(1055) /0.1102433906E+01/
     *    EQLON(1055) /0.2524473901E+01/
     *    SSLIP(1055) /0.5573000000E+01/
     *    DSLIP(1055) /-.1300000000E+00/
     *    DIP(1055) /0.1570796327E+01/
     *    DEPTH(1055) /0.3000000000E+04/
     *    WIDTH(1055) /0.3000000000E+04/
      DATA STRIKE(1056) /0.5178391891E+01/
     *    HL(1056) /0.1414900000E+04/
     *    EQLAT(1056) /0.1102232495E+01/
     *    EQLON(1056) /0.2523601236E+01/
     *    SSLIP(1056) /0.5446000000E+01/
     *    DSLIP(1056) /-.3600000000E+00/
     *    DIP(1056) /0.1570796327E+01/
     *    DEPTH(1056) /0.3000000000E+04/
     *    WIDTH(1056) /0.3000000000E+04/
      DATA STRIKE(1057) /0.5176646561E+01/
     *    HL(1057) /0.1415300000E+04/
     *    EQLAT(1057) /0.1102031084E+01/
     *    EQLON(1057) /0.2522728571E+01/
     *    SSLIP(1057) /0.5229000000E+01/
     *    DSLIP(1057) /-.4700000000E+00/
     *    DIP(1057) /0.1570796327E+01/
     *    DEPTH(1057) /0.3000000000E+04/
     *    WIDTH(1057) /0.3000000000E+04/
      DATA STRIKE(1058) /0.5174901232E+01/
     *    HL(1058) /0.1415800000E+04/
     *    EQLAT(1058) /0.1101829673E+01/
     *    EQLON(1058) /0.2521855907E+01/
     *    SSLIP(1058) /0.4771000000E+01/
     *    DSLIP(1058) /-.3100000000E+00/
     *    DIP(1058) /0.1570796327E+01/
     *    DEPTH(1058) /0.3000000000E+04/
     *    WIDTH(1058) /0.3000000000E+04/
      DATA STRIKE(1059) /0.5173155903E+01/
     *    HL(1059) /0.1416200000E+04/
     *    EQLAT(1059) /0.1101628087E+01/
     *    EQLON(1059) /0.2520983242E+01/
     *    SSLIP(1059) /0.4361000000E+01/
     *    DSLIP(1059) /-.2200000000E+00/
     *    DIP(1059) /0.1570796327E+01/
     *    DEPTH(1059) /0.3000000000E+04/
     *    WIDTH(1059) /0.3000000000E+04/
      DATA STRIKE(1060) /0.5171410574E+01/
     *    HL(1060) /0.1416700000E+04/
     *    EQLAT(1060) /0.1101426676E+01/
     *    EQLON(1060) /0.2520110578E+01/
     *    SSLIP(1060) /0.4399000000E+01/
     *    DSLIP(1060) /-.4500000000E+00/
     *    DIP(1060) /0.1570796327E+01/
     *    DEPTH(1060) /0.3000000000E+04/
     *    WIDTH(1060) /0.3000000000E+04/
      DATA STRIKE(1061) /0.5169665244E+01/
     *    HL(1061) /0.1417100000E+04/
     *    EQLAT(1061) /0.1101225265E+01/
     *    EQLON(1061) /0.2519237913E+01/
     *    SSLIP(1061) /0.5012000000E+01/
     *    DSLIP(1061) /-.1000000000E+01/
     *    DIP(1061) /0.1570796327E+01/
     *    DEPTH(1061) /0.3000000000E+04/
     *    WIDTH(1061) /0.3000000000E+04/
      DATA STRIKE(1062) /0.5167919915E+01/
     *    HL(1062) /0.1417600000E+04/
     *    EQLAT(1062) /0.1101023680E+01/
     *    EQLON(1062) /0.2518365248E+01/
     *    SSLIP(1062) /0.6068000000E+01/
     *    DSLIP(1062) /-.1580000000E+01/
     *    DIP(1062) /0.1570796327E+01/
     *    DEPTH(1062) /0.3000000000E+04/
     *    WIDTH(1062) /0.3000000000E+04/
      DATA STRIKE(1063) /0.5166174586E+01/
     *    HL(1063) /0.1418000000E+04/
     *    EQLAT(1063) /0.1100822269E+01/
     *    EQLON(1063) /0.2517492584E+01/
     *    SSLIP(1063) /0.6944000000E+01/
     *    DSLIP(1063) /-.1410000000E+01/
     *    DIP(1063) /0.1570796327E+01/
     *    DEPTH(1063) /0.3000000000E+04/
     *    WIDTH(1063) /0.3000000000E+04/
      DATA STRIKE(1064) /0.5213298476E+01/
     *    HL(1064) /0.1426200000E+04/
     *    EQLAT(1064) /0.1100610909E+01/
     *    EQLON(1064) /0.2516628820E+01/
     *    SSLIP(1064) /0.7521000000E+01/
     *    DSLIP(1064) /-.1210000000E+01/
     *    DIP(1064) /0.1570796327E+01/
     *    DEPTH(1064) /0.3000000000E+04/
     *    WIDTH(1064) /0.3000000000E+04/
      DATA STRIKE(1065) /0.5211553146E+01/
     *    HL(1065) /0.1426600000E+04/
     *    EQLAT(1065) /0.1100389427E+01/
     *    EQLON(1065) /0.2515773958E+01/
     *    SSLIP(1065) /0.7959000000E+01/
     *    DSLIP(1065) /-.1250000000E+01/
     *    DIP(1065) /0.1570796327E+01/
     *    DEPTH(1065) /0.3000000000E+04/
     *    WIDTH(1065) /0.3000000000E+04/
      DATA STRIKE(1066) /0.5209807817E+01/
     *    HL(1066) /0.1427100000E+04/
     *    EQLAT(1066) /0.1100167945E+01/
     *    EQLON(1066) /0.2514918921E+01/
     *    SSLIP(1066) /0.8537000000E+01/
     *    DSLIP(1066) /-.1510000000E+01/
     *    DIP(1066) /0.1570796327E+01/
     *    DEPTH(1066) /0.3000000000E+04/
     *    WIDTH(1066) /0.3000000000E+04/
      DATA STRIKE(1067) /0.5208062488E+01/
     *    HL(1067) /0.1427600000E+04/
     *    EQLAT(1067) /0.1099946463E+01/
     *    EQLON(1067) /0.2514064059E+01/
     *    SSLIP(1067) /0.9117000000E+01/
     *    DSLIP(1067) /-.1790000000E+01/
     *    DIP(1067) /0.1570796327E+01/
     *    DEPTH(1067) /0.3000000000E+04/
     *    WIDTH(1067) /0.3000000000E+04/
      DATA STRIKE(1068) /0.5206317159E+01/
     *    HL(1068) /0.1428000000E+04/
     *    EQLAT(1068) /0.1099724980E+01/
     *    EQLON(1068) /0.2513209197E+01/
     *    SSLIP(1068) /0.9634000000E+01/
     *    DSLIP(1068) /-.1740000000E+01/
     *    DIP(1068) /0.1570796327E+01/
     *    DEPTH(1068) /0.3000000000E+04/
     *    WIDTH(1068) /0.3000000000E+04/
      DATA STRIKE(1069) /0.5204571829E+01/
     *    HL(1069) /0.1428500000E+04/
     *    EQLAT(1069) /0.1099503498E+01/
     *    EQLON(1069) /0.2512354160E+01/
     *    SSLIP(1069) /0.9409000000E+01/
     *    DSLIP(1069) /-.1540000000E+01/
     *    DIP(1069) /0.1570796327E+01/
     *    DEPTH(1069) /0.3000000000E+04/
     *    WIDTH(1069) /0.3000000000E+04/
      DATA STRIKE(1070) /0.5202826500E+01/
     *    HL(1070) /0.1429000000E+04/
     *    EQLAT(1070) /0.1099282016E+01/
     *    EQLON(1070) /0.2511499298E+01/
     *    SSLIP(1070) /0.7902000000E+01/
     *    DSLIP(1070) /-.1410000000E+01/
     *    DIP(1070) /0.1570796327E+01/
     *    DEPTH(1070) /0.3000000000E+04/
     *    WIDTH(1070) /0.3000000000E+04/
      DATA STRIKE(1071) /0.5201081171E+01/
     *    HL(1071) /0.1429500000E+04/
     *    EQLAT(1071) /0.1099060534E+01/
     *    EQLON(1071) /0.2510644435E+01/
     *    SSLIP(1071) /0.6960000000E+01/
     *    DSLIP(1071) /-.2120000000E+01/
     *    DIP(1071) /0.1570796327E+01/
     *    DEPTH(1071) /0.3000000000E+04/
     *    WIDTH(1071) /0.3000000000E+04/
      DATA STRIKE(1072) /0.5199335842E+01/
     *    HL(1072) /0.1429900000E+04/
     *    EQLAT(1072) /0.1098839051E+01/
     *    EQLON(1072) /0.2509789398E+01/
     *    SSLIP(1072) /0.7172000000E+01/
     *    DSLIP(1072) /-.2280000000E+01/
     *    DIP(1072) /0.1570796327E+01/
     *    DEPTH(1072) /0.3000000000E+04/
     *    WIDTH(1072) /0.3000000000E+04/
      DATA STRIKE(1073) /0.5197590512E+01/
     *    HL(1073) /0.1430400000E+04/
     *    EQLAT(1073) /0.1098617743E+01/
     *    EQLON(1073) /0.2508934536E+01/
     *    SSLIP(1073) /0.7002000000E+01/
     *    DSLIP(1073) /-.1390000000E+01/
     *    DIP(1073) /0.1570796327E+01/
     *    DEPTH(1073) /0.3000000000E+04/
     *    WIDTH(1073) /0.3000000000E+04/
      DATA STRIKE(1074) /0.5195845183E+01/
     *    HL(1074) /0.1430900000E+04/
     *    EQLAT(1074) /0.1098396261E+01/
     *    EQLON(1074) /0.2508079674E+01/
     *    SSLIP(1074) /0.6876000000E+01/
     *    DSLIP(1074) /-.8200000000E+00/
     *    DIP(1074) /0.1570796327E+01/
     *    DEPTH(1074) /0.3000000000E+04/
     *    WIDTH(1074) /0.3000000000E+04/
      DATA STRIKE(1075) /0.5229006439E+01/
     *    HL(1075) /0.1431300000E+04/
     *    EQLAT(1075) /0.1098174779E+01/
     *    EQLON(1075) /0.2507224637E+01/
     *    SSLIP(1075) /0.6752000000E+01/
     *    DSLIP(1075) /-.3700000000E+00/
     *    DIP(1075) /0.1570796327E+01/
     *    DEPTH(1075) /0.3000000000E+04/
     *    WIDTH(1075) /0.3000000000E+04/
      DATA STRIKE(1076) /0.5227261110E+01/
     *    HL(1076) /0.1431800000E+04/
     *    EQLAT(1076) /0.1097953297E+01/
     *    EQLON(1076) /0.2506369775E+01/
     *    SSLIP(1076) /0.6513000000E+01/
     *    DSLIP(1076) /-.2400000000E+00/
     *    DIP(1076) /0.1570796327E+01/
     *    DEPTH(1076) /0.3000000000E+04/
     *    WIDTH(1076) /0.3000000000E+04/
      DATA STRIKE(1077) /0.5225515780E+01/
     *    HL(1077) /0.1432300000E+04/
     *    EQLAT(1077) /0.1097731814E+01/
     *    EQLON(1077) /0.2505514913E+01/
     *    SSLIP(1077) /0.5868000000E+01/
     *    DSLIP(1077) /-.6700000000E+00/
     *    DIP(1077) /0.1570796327E+01/
     *    DEPTH(1077) /0.3000000000E+04/
     *    WIDTH(1077) /0.3000000000E+04/
      DATA STRIKE(1078) /0.5223770451E+01/
     *    HL(1078) /0.1432700000E+04/
     *    EQLAT(1078) /0.1097510332E+01/
     *    EQLON(1078) /0.2504659876E+01/
     *    SSLIP(1078) /0.5568000000E+01/
     *    DSLIP(1078) /-.2800000000E+00/
     *    DIP(1078) /0.1570796327E+01/
     *    DEPTH(1078) /0.3000000000E+04/
     *    WIDTH(1078) /0.3000000000E+04/
      DATA STRIKE(1079) /0.5222025122E+01/
     *    HL(1079) /0.1433200000E+04/
     *    EQLAT(1079) /0.1097288850E+01/
     *    EQLON(1079) /0.2503805014E+01/
     *    SSLIP(1079) /0.5364000000E+01/
     *    DSLIP(1079) /0.0000000000E+00/
     *    DIP(1079) /0.1570796327E+01/
     *    DEPTH(1079) /0.3000000000E+04/
     *    WIDTH(1079) /0.3000000000E+04/
      DATA STRIKE(1080) /0.5220279793E+01/
     *    HL(1080) /0.1433700000E+04/
     *    EQLAT(1080) /0.1097067368E+01/
     *    EQLON(1080) /0.2502950151E+01/
     *    SSLIP(1080) /0.5147000000E+01/
     *    DSLIP(1080) /0.0000000000E+00/
     *    DIP(1080) /0.1570796327E+01/
     *    DEPTH(1080) /0.6000000000E+04/
     *    WIDTH(1080) /0.3000000000E+04/
      DATA STRIKE(1081) /0.5218534463E+01/
     *    HL(1081) /0.1434100000E+04/
     *    EQLAT(1081) /0.1096845885E+01/
     *    EQLON(1081) /0.2502095114E+01/
     *    SSLIP(1081) /0.4908000000E+01/
     *    DSLIP(1081) /0.0000000000E+00/
     *    DIP(1081) /0.1570796327E+01/
     *    DEPTH(1081) /0.6000000000E+04/
     *    WIDTH(1081) /0.3000000000E+04/
      DATA STRIKE(1082) /0.4544837372E+01/
     *    HL(1082) /0.1500600000E+04/
     *    EQLAT(1082) /0.1108284599E+01/
     *    EQLON(1082) /0.2578255000E+01/
     *    SSLIP(1082) /0.1980000000E+00/
     *    DSLIP(1082) /0.0000000000E+00/
     *    DIP(1082) /0.1570796327E+01/
     *    DEPTH(1082) /0.6000000000E+04/
     *    WIDTH(1082) /0.3000000000E+04/
      DATA STRIKE(1083) /0.4544837372E+01/
     *    HL(1083) /0.1500600000E+04/
     *    EQLAT(1083) /0.1108363138E+01/
     *    EQLON(1083) /0.2577217925E+01/
     *    SSLIP(1083) /0.2330000000E+00/
     *    DSLIP(1083) /0.0000000000E+00/
     *    DIP(1083) /0.1570796327E+01/
     *    DEPTH(1083) /0.6000000000E+04/
     *    WIDTH(1083) /0.3000000000E+04/
      DATA STRIKE(1084) /0.4546582701E+01/
     *    HL(1084) /0.1500600000E+04/
     *    EQLAT(1084) /0.1108441329E+01/
     *    EQLON(1084) /0.2576180502E+01/
     *    SSLIP(1084) /0.4040000000E+00/
     *    DSLIP(1084) /0.0000000000E+00/
     *    DIP(1084) /0.1570796327E+01/
     *    DEPTH(1084) /0.6000000000E+04/
     *    WIDTH(1084) /0.3000000000E+04/
      DATA STRIKE(1085) /0.4546582701E+01/
     *    HL(1085) /0.1500600000E+04/
     *    EQLAT(1085) /0.1108518996E+01/
     *    EQLON(1085) /0.2575142903E+01/
     *    SSLIP(1085) /0.4790000000E+00/
     *    DSLIP(1085) /0.0000000000E+00/
     *    DIP(1085) /0.1570796327E+01/
     *    DEPTH(1085) /0.6000000000E+04/
     *    WIDTH(1085) /0.3000000000E+04/
      DATA STRIKE(1086) /0.4548328031E+01/
     *    HL(1086) /0.1500600000E+04/
     *    EQLAT(1086) /0.1108596140E+01/
     *    EQLON(1086) /0.2574104956E+01/
     *    SSLIP(1086) /0.3820000000E+00/
     *    DSLIP(1086) /0.0000000000E+00/
     *    DIP(1086) /0.1570796327E+01/
     *    DEPTH(1086) /0.6000000000E+04/
     *    WIDTH(1086) /0.3000000000E+04/
      DATA STRIKE(1087) /0.4548328031E+01/
     *    HL(1087) /0.1500600000E+04/
     *    EQLAT(1087) /0.1108673109E+01/
     *    EQLON(1087) /0.2573066660E+01/
     *    SSLIP(1087) /0.1810000000E+00/
     *    DSLIP(1087) /0.0000000000E+00/
     *    DIP(1087) /0.1570796327E+01/
     *    DEPTH(1087) /0.6000000000E+04/
     *    WIDTH(1087) /0.3000000000E+04/
      DATA STRIKE(1088) /0.4550073360E+01/
     *    HL(1088) /0.1500600000E+04/
     *    EQLAT(1088) /0.1108749380E+01/
     *    EQLON(1088) /0.2572028014E+01/
     *    SSLIP(1088) /0.2400000000E-01/
     *    DSLIP(1088) /0.0000000000E+00/
     *    DIP(1088) /0.1570796327E+01/
     *    DEPTH(1088) /0.6000000000E+04/
     *    WIDTH(1088) /0.3000000000E+04/
      DATA STRIKE(1089) /0.4551818689E+01/
     *    HL(1089) /0.1500600000E+04/
     *    EQLAT(1089) /0.1108825476E+01/
     *    EQLON(1089) /0.2570989020E+01/
     *    SSLIP(1089) /0.0000000000E+00/
     *    DSLIP(1089) /0.0000000000E+00/
     *    DIP(1089) /0.1570796327E+01/
     *    DEPTH(1089) /0.6000000000E+04/
     *    WIDTH(1089) /0.3000000000E+04/
      DATA STRIKE(1090) /0.4551818689E+01/
     *    HL(1090) /0.1500600000E+04/
     *    EQLAT(1090) /0.1108900874E+01/
     *    EQLON(1090) /0.2569949851E+01/
     *    SSLIP(1090) /0.0000000000E+00/
     *    DSLIP(1090) /0.0000000000E+00/
     *    DIP(1090) /0.1570796327E+01/
     *    DEPTH(1090) /0.6000000000E+04/
     *    WIDTH(1090) /0.3000000000E+04/
      DATA STRIKE(1091) /0.4862487296E+01/
     *    HL(1091) /0.1468400000E+04/
     *    EQLAT(1091) /0.1108904540E+01/
     *    EQLON(1091) /0.2568920630E+01/
     *    SSLIP(1091) /0.2440000000E+00/
     *    DSLIP(1091) /0.0000000000E+00/
     *    DIP(1091) /0.1570796327E+01/
     *    DEPTH(1091) /0.6000000000E+04/
     *    WIDTH(1091) /0.3000000000E+04/
      DATA STRIKE(1092) /0.4862487296E+01/
     *    HL(1092) /0.1468600000E+04/
     *    EQLAT(1092) /0.1108836297E+01/
     *    EQLON(1092) /0.2567901532E+01/
     *    SSLIP(1092) /0.5880000000E+00/
     *    DSLIP(1092) /0.0000000000E+00/
     *    DIP(1092) /0.1570796327E+01/
     *    DEPTH(1092) /0.6000000000E+04/
     *    WIDTH(1092) /0.3000000000E+04/
      DATA STRIKE(1093) /0.4862487296E+01/
     *    HL(1093) /0.1468800000E+04/
     *    EQLAT(1093) /0.1108768055E+01/
     *    EQLON(1093) /0.2566882434E+01/
     *    SSLIP(1093) /0.9090000000E+00/
     *    DSLIP(1093) /0.0000000000E+00/
     *    DIP(1093) /0.1570796327E+01/
     *    DEPTH(1093) /0.6000000000E+04/
     *    WIDTH(1093) /0.3000000000E+04/
      DATA STRIKE(1094) /0.4860741967E+01/
     *    HL(1094) /0.1469000000E+04/
     *    EQLAT(1094) /0.1108699987E+01/
     *    EQLON(1094) /0.2565863337E+01/
     *    SSLIP(1094) /0.9770000000E+00/
     *    DSLIP(1094) /-.7000000000E-01/
     *    DIP(1094) /0.1570796327E+01/
     *    DEPTH(1094) /0.6000000000E+04/
     *    WIDTH(1094) /0.3000000000E+04/
      DATA STRIKE(1095) /0.4858996638E+01/
     *    HL(1095) /0.1469200000E+04/
     *    EQLAT(1095) /0.1108631745E+01/
     *    EQLON(1095) /0.2564844413E+01/
     *    SSLIP(1095) /0.7000000000E+00/
     *    DSLIP(1095) /-.5000000000E+00/
     *    DIP(1095) /0.1570796327E+01/
     *    DEPTH(1095) /0.6000000000E+04/
     *    WIDTH(1095) /0.3000000000E+04/
      DATA STRIKE(1096) /0.4857251308E+01/
     *    HL(1096) /0.1469400000E+04/
     *    EQLAT(1096) /0.1108563677E+01/
     *    EQLON(1096) /0.2563825316E+01/
     *    SSLIP(1096) /0.4810000000E+00/
     *    DSLIP(1096) /-.1230000000E+01/
     *    DIP(1096) /0.1570796327E+01/
     *    DEPTH(1096) /0.6000000000E+04/
     *    WIDTH(1096) /0.3000000000E+04/
      DATA STRIKE(1097) /0.4855505979E+01/
     *    HL(1097) /0.1469600000E+04/
     *    EQLAT(1097) /0.1108495434E+01/
     *    EQLON(1097) /0.2562806218E+01/
     *    SSLIP(1097) /0.6300000000E+00/
     *    DSLIP(1097) /-.2050000000E+01/
     *    DIP(1097) /0.1570796327E+01/
     *    DEPTH(1097) /0.6000000000E+04/
     *    WIDTH(1097) /0.3000000000E+04/
      DATA STRIKE(1098) /0.4853760650E+01/
     *    HL(1098) /0.1469800000E+04/
     *    EQLAT(1098) /0.1108427192E+01/
     *    EQLON(1098) /0.2561787120E+01/
     *    SSLIP(1098) /0.1194000000E+01/
     *    DSLIP(1098) /-.2710000000E+01/
     *    DIP(1098) /0.1570796327E+01/
     *    DEPTH(1098) /0.6000000000E+04/
     *    WIDTH(1098) /0.3000000000E+04/
      DATA STRIKE(1099) /0.4852015321E+01/
     *    HL(1099) /0.1470000000E+04/
     *    EQLAT(1099) /0.1108359124E+01/
     *    EQLON(1099) /0.2560768197E+01/
     *    SSLIP(1099) /0.1973000000E+01/
     *    DSLIP(1099) /-.3000000000E+01/
     *    DIP(1099) /0.1570796327E+01/
     *    DEPTH(1099) /0.6000000000E+04/
     *    WIDTH(1099) /0.3000000000E+04/
      DATA STRIKE(1100) /0.4850269991E+01/
     *    HL(1100) /0.1470200000E+04/
     *    EQLAT(1100) /0.1108290882E+01/
     *    EQLON(1100) /0.2559749099E+01/
     *    SSLIP(1100) /0.2617000000E+01/
     *    DSLIP(1100) /-.2890000000E+01/
     *    DIP(1100) /0.1570796327E+01/
     *    DEPTH(1100) /0.6000000000E+04/
     *    WIDTH(1100) /0.3000000000E+04/
      DATA STRIKE(1101) /0.4848524662E+01/
     *    HL(1101) /0.1470400000E+04/
     *    EQLAT(1101) /0.1108222639E+01/
     *    EQLON(1101) /0.2558730002E+01/
     *    SSLIP(1101) /0.2828000000E+01/
     *    DSLIP(1101) /-.2260000000E+01/
     *    DIP(1101) /0.1570796327E+01/
     *    DEPTH(1101) /0.6000000000E+04/
     *    WIDTH(1101) /0.3000000000E+04/
      DATA STRIKE(1102) /0.4846779333E+01/
     *    HL(1102) /0.1470600000E+04/
     *    EQLAT(1102) /0.1108154572E+01/
     *    EQLON(1102) /0.2557710904E+01/
     *    SSLIP(1102) /0.2681000000E+01/
     *    DSLIP(1102) /-.1380000000E+01/
     *    DIP(1102) /0.1570796327E+01/
     *    DEPTH(1102) /0.6000000000E+04/
     *    WIDTH(1102) /0.3000000000E+04/
      DATA STRIKE(1103) /0.4845034004E+01/
     *    HL(1103) /0.1470800000E+04/
     *    EQLAT(1103) /0.1108086329E+01/
     *    EQLON(1103) /0.2556691981E+01/
     *    SSLIP(1103) /0.2595000000E+01/
     *    DSLIP(1103) /-.9200000000E+00/
     *    DIP(1103) /0.1570796327E+01/
     *    DEPTH(1103) /0.6000000000E+04/
     *    WIDTH(1103) /0.3000000000E+04/
      DATA STRIKE(1104) /0.4843288674E+01/
     *    HL(1104) /0.1470900000E+04/
     *    EQLAT(1104) /0.1108018261E+01/
     *    EQLON(1104) /0.2555672883E+01/
     *    SSLIP(1104) /0.2277000000E+01/
     *    DSLIP(1104) /-.5900000000E+00/
     *    DIP(1104) /0.1570796327E+01/
     *    DEPTH(1104) /0.6000000000E+04/
     *    WIDTH(1104) /0.3000000000E+04/
      DATA STRIKE(1105) /0.4841543345E+01/
     *    HL(1105) /0.1471100000E+04/
     *    EQLAT(1105) /0.1107950019E+01/
     *    EQLON(1105) /0.2554653785E+01/
     *    SSLIP(1105) /0.1792000000E+01/
     *    DSLIP(1105) /-.3400000000E+00/
     *    DIP(1105) /0.1570796327E+01/
     *    DEPTH(1105) /0.6000000000E+04/
     *    WIDTH(1105) /0.3000000000E+04/
      DATA STRIKE(1106) /0.4839798016E+01/
     *    HL(1106) /0.1471300000E+04/
     *    EQLAT(1106) /0.1107881777E+01/
     *    EQLON(1106) /0.2553634687E+01/
     *    SSLIP(1106) /0.1790000000E+01/
     *    DSLIP(1106) /-.4100000000E+00/
     *    DIP(1106) /0.1570796327E+01/
     *    DEPTH(1106) /0.6000000000E+04/
     *    WIDTH(1106) /0.3000000000E+04/
      DATA STRIKE(1107) /0.4967207051E+01/
     *    HL(1107) /0.1450200000E+04/
     *    EQLAT(1107) /0.1107785434E+01/
     *    EQLON(1107) /0.2552637057E+01/
     *    SSLIP(1107) /0.2748000000E+01/
     *    DSLIP(1107) /-.7000000000E+00/
     *    DIP(1107) /0.1570796327E+01/
     *    DEPTH(1107) /0.6000000000E+04/
     *    WIDTH(1107) /0.3000000000E+04/
      DATA STRIKE(1108) /0.4965461722E+01/
     *    HL(1108) /0.1450500000E+04/
     *    EQLAT(1108) /0.1107660818E+01/
     *    EQLON(1108) /0.2551660720E+01/
     *    SSLIP(1108) /0.3766000000E+01/
     *    DSLIP(1108) /-.7500000000E+00/
     *    DIP(1108) /0.1570796327E+01/
     *    DEPTH(1108) /0.6000000000E+04/
     *    WIDTH(1108) /0.3000000000E+04/
      DATA STRIKE(1109) /0.4963716393E+01/
     *    HL(1109) /0.1450900000E+04/
     *    EQLAT(1109) /0.1107536027E+01/
     *    EQLON(1109) /0.2550684208E+01/
     *    SSLIP(1109) /0.4521000000E+01/
     *    DSLIP(1109) /-.7500000000E+00/
     *    DIP(1109) /0.1570796327E+01/
     *    DEPTH(1109) /0.6000000000E+04/
     *    WIDTH(1109) /0.3000000000E+04/
      DATA STRIKE(1110) /0.4961971063E+01/
     *    HL(1110) /0.1451200000E+04/
     *    EQLAT(1110) /0.1107411410E+01/
     *    EQLON(1110) /0.2549707871E+01/
     *    SSLIP(1110) /0.4769000000E+01/
     *    DSLIP(1110) /-.1010000000E+01/
     *    DIP(1110) /0.1570796327E+01/
     *    DEPTH(1110) /0.6000000000E+04/
     *    WIDTH(1110) /0.3000000000E+04/
      DATA STRIKE(1111) /0.4960225734E+01/
     *    HL(1111) /0.1451500000E+04/
     *    EQLAT(1111) /0.1107286794E+01/
     *    EQLON(1111) /0.2548731534E+01/
     *    SSLIP(1111) /0.4422000000E+01/
     *    DSLIP(1111) /-.1310000000E+01/
     *    DIP(1111) /0.1570796327E+01/
     *    DEPTH(1111) /0.6000000000E+04/
     *    WIDTH(1111) /0.3000000000E+04/
      DATA STRIKE(1112) /0.4956735076E+01/
     *    HL(1112) /0.1451900000E+04/
     *    EQLAT(1112) /0.1107162003E+01/
     *    EQLON(1112) /0.2547755022E+01/
     *    SSLIP(1112) /0.4089000000E+01/
     *    DSLIP(1112) /-.1260000000E+01/
     *    DIP(1112) /0.1570796327E+01/
     *    DEPTH(1112) /0.6000000000E+04/
     *    WIDTH(1112) /0.3000000000E+04/
      DATA STRIKE(1113) /0.4954989746E+01/
     *    HL(1113) /0.1452200000E+04/
     *    EQLAT(1113) /0.1107037386E+01/
     *    EQLON(1113) /0.2546778685E+01/
     *    SSLIP(1113) /0.4525000000E+01/
     *    DSLIP(1113) /-.9100000000E+00/
     *    DIP(1113) /0.1570796327E+01/
     *    DEPTH(1113) /0.6000000000E+04/
     *    WIDTH(1113) /0.3000000000E+04/
      DATA STRIKE(1114) /0.5239478414E+01/
     *    HL(1114) /0.1384800000E+04/
     *    EQLAT(1114) /0.1106865995E+01/
     *    EQLON(1114) /0.2545872335E+01/
     *    SSLIP(1114) /0.6711000000E+01/
     *    DSLIP(1114) /-.1150000000E+01/
     *    DIP(1114) /0.1570796327E+01/
     *    DEPTH(1114) /0.6000000000E+04/
     *    WIDTH(1114) /0.3000000000E+04/
      DATA STRIKE(1115) /0.5237733085E+01/
     *    HL(1115) /0.1385300000E+04/
     *    EQLAT(1115) /0.1106647829E+01/
     *    EQLON(1115) /0.2545035799E+01/
     *    SSLIP(1115) /0.7768000000E+01/
     *    DSLIP(1115) /-.7600000000E+00/
     *    DIP(1115) /0.1570796327E+01/
     *    DEPTH(1115) /0.6000000000E+04/
     *    WIDTH(1115) /0.3000000000E+04/
      DATA STRIKE(1116) /0.5235987756E+01/
     *    HL(1116) /0.1385700000E+04/
     *    EQLAT(1116) /0.1106429663E+01/
     *    EQLON(1116) /0.2544199437E+01/
     *    SSLIP(1116) /0.7035000000E+01/
     *    DSLIP(1116) /0.0000000000E+00/
     *    DIP(1116) /0.1570796327E+01/
     *    DEPTH(1116) /0.6000000000E+04/
     *    WIDTH(1116) /0.3000000000E+04/
      DATA STRIKE(1117) /0.5234242427E+01/
     *    HL(1117) /0.1386200000E+04/
     *    EQLAT(1117) /0.1106211497E+01/
     *    EQLON(1117) /0.2543362901E+01/
     *    SSLIP(1117) /0.6230000000E+01/
     *    DSLIP(1117) /0.0000000000E+00/
     *    DIP(1117) /0.1570796327E+01/
     *    DEPTH(1117) /0.6000000000E+04/
     *    WIDTH(1117) /0.3000000000E+04/
      DATA STRIKE(1118) /0.5232497097E+01/
     *    HL(1118) /0.1386600000E+04/
     *    EQLAT(1118) /0.1105993330E+01/
     *    EQLON(1118) /0.2542526539E+01/
     *    SSLIP(1118) /0.5108000000E+01/
     *    DSLIP(1118) /0.0000000000E+00/
     *    DIP(1118) /0.1570796327E+01/
     *    DEPTH(1118) /0.6000000000E+04/
     *    WIDTH(1118) /0.3000000000E+04/
      DATA STRIKE(1119) /0.5230751768E+01/
     *    HL(1119) /0.1387100000E+04/
     *    EQLAT(1119) /0.1105775164E+01/
     *    EQLON(1119) /0.2541690003E+01/
     *    SSLIP(1119) /0.3591000000E+01/
     *    DSLIP(1119) /0.0000000000E+00/
     *    DIP(1119) /0.1570796327E+01/
     *    DEPTH(1119) /0.6000000000E+04/
     *    WIDTH(1119) /0.3000000000E+04/
      DATA STRIKE(1120) /0.5229006439E+01/
     *    HL(1120) /0.1387500000E+04/
     *    EQLAT(1120) /0.1105556998E+01/
     *    EQLON(1120) /0.2540853641E+01/
     *    SSLIP(1120) /0.3253000000E+01/
     *    DSLIP(1120) /0.0000000000E+00/
     *    DIP(1120) /0.1570796327E+01/
     *    DEPTH(1120) /0.6000000000E+04/
     *    WIDTH(1120) /0.3000000000E+04/
      DATA STRIKE(1121) /0.5227261110E+01/
     *    HL(1121) /0.1388000000E+04/
     *    EQLAT(1121) /0.1105338832E+01/
     *    EQLON(1121) /0.2540017105E+01/
     *    SSLIP(1121) /0.5020000000E+01/
     *    DSLIP(1121) /0.0000000000E+00/
     *    DIP(1121) /0.1570796327E+01/
     *    DEPTH(1121) /0.6000000000E+04/
     *    WIDTH(1121) /0.3000000000E+04/
      DATA STRIKE(1122) /0.5047492197E+01/
     *    HL(1122) /0.1434000000E+04/
     *    EQLAT(1122) /0.1105152954E+01/
     *    EQLON(1122) /0.2539129605E+01/
     *    SSLIP(1122) /0.7834000000E+01/
     *    DSLIP(1122) /0.0000000000E+00/
     *    DIP(1122) /0.1570796327E+01/
     *    DEPTH(1122) /0.6000000000E+04/
     *    WIDTH(1122) /0.3000000000E+04/
      DATA STRIKE(1123) /0.5045746868E+01/
     *    HL(1123) /0.1434400000E+04/
     *    EQLAT(1123) /0.1104999540E+01/
     *    EQLON(1123) /0.2538190967E+01/
     *    SSLIP(1123) /0.8290000000E+01/
     *    DSLIP(1123) /0.0000000000E+00/
     *    DIP(1123) /0.1570796327E+01/
     *    DEPTH(1123) /0.6000000000E+04/
     *    WIDTH(1123) /0.3000000000E+04/
      DATA STRIKE(1124) /0.5044001538E+01/
     *    HL(1124) /0.1434700000E+04/
     *    EQLAT(1124) /0.1104846125E+01/
     *    EQLON(1124) /0.2537252329E+01/
     *    SSLIP(1124) /0.6865000000E+01/
     *    DSLIP(1124) /0.0000000000E+00/
     *    DIP(1124) /0.1570796327E+01/
     *    DEPTH(1124) /0.6000000000E+04/
     *    WIDTH(1124) /0.3000000000E+04/
      DATA STRIKE(1125) /0.5042256209E+01/
     *    HL(1125) /0.1435100000E+04/
     *    EQLAT(1125) /0.1104692711E+01/
     *    EQLON(1125) /0.2536313516E+01/
     *    SSLIP(1125) /0.4856000000E+01/
     *    DSLIP(1125) /0.0000000000E+00/
     *    DIP(1125) /0.1570796327E+01/
     *    DEPTH(1125) /0.6000000000E+04/
     *    WIDTH(1125) /0.3000000000E+04/
      DATA STRIKE(1126) /0.5040510880E+01/
     *    HL(1126) /0.1435500000E+04/
     *    EQLAT(1126) /0.1104539297E+01/
     *    EQLON(1126) /0.2535374878E+01/
     *    SSLIP(1126) /0.3382000000E+01/
     *    DSLIP(1126) /0.0000000000E+00/
     *    DIP(1126) /0.1570796327E+01/
     *    DEPTH(1126) /0.6000000000E+04/
     *    WIDTH(1126) /0.3000000000E+04/
      DATA STRIKE(1127) /0.5038765551E+01/
     *    HL(1127) /0.1435900000E+04/
     *    EQLAT(1127) /0.1104385882E+01/
     *    EQLON(1127) /0.2534436240E+01/
     *    SSLIP(1127) /0.2974000000E+01/
     *    DSLIP(1127) /-.1100000000E+00/
     *    DIP(1127) /0.1570796327E+01/
     *    DEPTH(1127) /0.6000000000E+04/
     *    WIDTH(1127) /0.3000000000E+04/
      DATA STRIKE(1128) /0.5037020221E+01/
     *    HL(1128) /0.1436300000E+04/
     *    EQLAT(1128) /0.1104232468E+01/
     *    EQLON(1128) /0.2533497602E+01/
     *    SSLIP(1128) /0.3642000000E+01/
     *    DSLIP(1128) /-.6000000000E-01/
     *    DIP(1128) /0.1570796327E+01/
     *    DEPTH(1128) /0.6000000000E+04/
     *    WIDTH(1128) /0.3000000000E+04/
      DATA STRIKE(1129) /0.5035274892E+01/
     *    HL(1129) /0.1436700000E+04/
     *    EQLAT(1129) /0.1104079053E+01/
     *    EQLON(1129) /0.2532558964E+01/
     *    SSLIP(1129) /0.5000000000E+01/
     *    DSLIP(1129) /0.0000000000E+00/
     *    DIP(1129) /0.1570796327E+01/
     *    DEPTH(1129) /0.6000000000E+04/
     *    WIDTH(1129) /0.3000000000E+04/
      DATA STRIKE(1130) /0.5033529563E+01/
     *    HL(1130) /0.1437100000E+04/
     *    EQLAT(1130) /0.1103925639E+01/
     *    EQLON(1130) /0.2531620151E+01/
     *    SSLIP(1130) /0.6351000000E+01/
     *    DSLIP(1130) /0.0000000000E+00/
     *    DIP(1130) /0.1570796327E+01/
     *    DEPTH(1130) /0.6000000000E+04/
     *    WIDTH(1130) /0.3000000000E+04/
      DATA STRIKE(1131) /0.5031784233E+01/
     *    HL(1131) /0.1437400000E+04/
     *    EQLAT(1131) /0.1103772224E+01/
     *    EQLON(1131) /0.2530681513E+01/
     *    SSLIP(1131) /0.6975000000E+01/
     *    DSLIP(1131) /0.0000000000E+00/
     *    DIP(1131) /0.1570796327E+01/
     *    DEPTH(1131) /0.6000000000E+04/
     *    WIDTH(1131) /0.3000000000E+04/
      DATA STRIKE(1132) /0.5030038904E+01/
     *    HL(1132) /0.1437800000E+04/
     *    EQLAT(1132) /0.1103618810E+01/
     *    EQLON(1132) /0.2529742875E+01/
     *    SSLIP(1132) /0.6504000000E+01/
     *    DSLIP(1132) /0.0000000000E+00/
     *    DIP(1132) /0.1570796327E+01/
     *    DEPTH(1132) /0.6000000000E+04/
     *    WIDTH(1132) /0.3000000000E+04/
      DATA STRIKE(1133) /0.5153957281E+01/
     *    HL(1133) /0.1412200000E+04/
     *    EQLAT(1133) /0.1103441310E+01/
     *    EQLON(1133) /0.2528837224E+01/
     *    SSLIP(1133) /0.5274000000E+01/
     *    DSLIP(1133) /0.0000000000E+00/
     *    DIP(1133) /0.1570796327E+01/
     *    DEPTH(1133) /0.6000000000E+04/
     *    WIDTH(1133) /0.3000000000E+04/
      DATA STRIKE(1134) /0.5152211952E+01/
     *    HL(1134) /0.1412700000E+04/
     *    EQLAT(1134) /0.1103239899E+01/
     *    EQLON(1134) /0.2527964559E+01/
     *    SSLIP(1134) /0.4568000000E+01/
     *    DSLIP(1134) /0.0000000000E+00/
     *    DIP(1134) /0.1570796327E+01/
     *    DEPTH(1134) /0.6000000000E+04/
     *    WIDTH(1134) /0.3000000000E+04/
      DATA STRIKE(1135) /0.5150466623E+01/
     *    HL(1135) /0.1413100000E+04/
     *    EQLAT(1135) /0.1103038313E+01/
     *    EQLON(1135) /0.2527091895E+01/
     *    SSLIP(1135) /0.4298000000E+01/
     *    DSLIP(1135) /0.0000000000E+00/
     *    DIP(1135) /0.1570796327E+01/
     *    DEPTH(1135) /0.6000000000E+04/
     *    WIDTH(1135) /0.3000000000E+04/
      DATA STRIKE(1136) /0.5183627878E+01/
     *    HL(1136) /0.1413500000E+04/
     *    EQLAT(1136) /0.1102836902E+01/
     *    EQLON(1136) /0.2526219230E+01/
     *    SSLIP(1136) /0.4443000000E+01/
     *    DSLIP(1136) /0.0000000000E+00/
     *    DIP(1136) /0.1570796327E+01/
     *    DEPTH(1136) /0.6000000000E+04/
     *    WIDTH(1136) /0.3000000000E+04/
      DATA STRIKE(1137) /0.5181882549E+01/
     *    HL(1137) /0.1414000000E+04/
     *    EQLAT(1137) /0.1102635491E+01/
     *    EQLON(1137) /0.2525346565E+01/
     *    SSLIP(1137) /0.4700000000E+01/
     *    DSLIP(1137) /0.0000000000E+00/
     *    DIP(1137) /0.1570796327E+01/
     *    DEPTH(1137) /0.6000000000E+04/
     *    WIDTH(1137) /0.3000000000E+04/
      DATA STRIKE(1138) /0.5180137220E+01/
     *    HL(1138) /0.1414400000E+04/
     *    EQLAT(1138) /0.1102433906E+01/
     *    EQLON(1138) /0.2524473901E+01/
     *    SSLIP(1138) /0.4816000000E+01/
     *    DSLIP(1138) /-.1000000000E-01/
     *    DIP(1138) /0.1570796327E+01/
     *    DEPTH(1138) /0.6000000000E+04/
     *    WIDTH(1138) /0.3000000000E+04/
      DATA STRIKE(1139) /0.5178391891E+01/
     *    HL(1139) /0.1414900000E+04/
     *    EQLAT(1139) /0.1102232495E+01/
     *    EQLON(1139) /0.2523601236E+01/
     *    SSLIP(1139) /0.4713000000E+01/
     *    DSLIP(1139) /-.9000000000E-01/
     *    DIP(1139) /0.1570796327E+01/
     *    DEPTH(1139) /0.6000000000E+04/
     *    WIDTH(1139) /0.3000000000E+04/
      DATA STRIKE(1140) /0.5176646561E+01/
     *    HL(1140) /0.1415300000E+04/
     *    EQLAT(1140) /0.1102031084E+01/
     *    EQLON(1140) /0.2522728571E+01/
     *    SSLIP(1140) /0.4452000000E+01/
     *    DSLIP(1140) /-.1400000000E+00/
     *    DIP(1140) /0.1570796327E+01/
     *    DEPTH(1140) /0.6000000000E+04/
     *    WIDTH(1140) /0.3000000000E+04/
      DATA STRIKE(1141) /0.5174901232E+01/
     *    HL(1141) /0.1415800000E+04/
     *    EQLAT(1141) /0.1101829673E+01/
     *    EQLON(1141) /0.2521855907E+01/
     *    SSLIP(1141) /0.4050000000E+01/
     *    DSLIP(1141) /-.9000000000E-01/
     *    DIP(1141) /0.1570796327E+01/
     *    DEPTH(1141) /0.6000000000E+04/
     *    WIDTH(1141) /0.3000000000E+04/
      DATA STRIKE(1142) /0.5173155903E+01/
     *    HL(1142) /0.1416200000E+04/
     *    EQLAT(1142) /0.1101628087E+01/
     *    EQLON(1142) /0.2520983242E+01/
     *    SSLIP(1142) /0.3722000000E+01/
     *    DSLIP(1142) /-.8000000000E-01/
     *    DIP(1142) /0.1570796327E+01/
     *    DEPTH(1142) /0.6000000000E+04/
     *    WIDTH(1142) /0.3000000000E+04/
      DATA STRIKE(1143) /0.5171410574E+01/
     *    HL(1143) /0.1416700000E+04/
     *    EQLAT(1143) /0.1101426676E+01/
     *    EQLON(1143) /0.2520110578E+01/
     *    SSLIP(1143) /0.3735000000E+01/
     *    DSLIP(1143) /-.2900000000E+00/
     *    DIP(1143) /0.1570796327E+01/
     *    DEPTH(1143) /0.6000000000E+04/
     *    WIDTH(1143) /0.3000000000E+04/
      DATA STRIKE(1144) /0.5169665244E+01/
     *    HL(1144) /0.1417100000E+04/
     *    EQLAT(1144) /0.1101225265E+01/
     *    EQLON(1144) /0.2519237913E+01/
     *    SSLIP(1144) /0.4195000000E+01/
     *    DSLIP(1144) /-.7500000000E+00/
     *    DIP(1144) /0.1570796327E+01/
     *    DEPTH(1144) /0.6000000000E+04/
     *    WIDTH(1144) /0.3000000000E+04/
      DATA STRIKE(1145) /0.5167919915E+01/
     *    HL(1145) /0.1417600000E+04/
     *    EQLAT(1145) /0.1101023680E+01/
     *    EQLON(1145) /0.2518365248E+01/
     *    SSLIP(1145) /0.4994000000E+01/
     *    DSLIP(1145) /-.1250000000E+01/
     *    DIP(1145) /0.1570796327E+01/
     *    DEPTH(1145) /0.6000000000E+04/
     *    WIDTH(1145) /0.3000000000E+04/
      DATA STRIKE(1146) /0.5166174586E+01/
     *    HL(1146) /0.1418000000E+04/
     *    EQLAT(1146) /0.1100822269E+01/
     *    EQLON(1146) /0.2517492584E+01/
     *    SSLIP(1146) /0.5811000000E+01/
     *    DSLIP(1146) /-.1440000000E+01/
     *    DIP(1146) /0.1570796327E+01/
     *    DEPTH(1146) /0.6000000000E+04/
     *    WIDTH(1146) /0.3000000000E+04/
      DATA STRIKE(1147) /0.5213298476E+01/
     *    HL(1147) /0.1426200000E+04/
     *    EQLAT(1147) /0.1100610909E+01/
     *    EQLON(1147) /0.2516628820E+01/
     *    SSLIP(1147) /0.6536000000E+01/
     *    DSLIP(1147) /-.1580000000E+01/
     *    DIP(1147) /0.1570796327E+01/
     *    DEPTH(1147) /0.6000000000E+04/
     *    WIDTH(1147) /0.3000000000E+04/
      DATA STRIKE(1148) /0.5211553146E+01/
     *    HL(1148) /0.1426600000E+04/
     *    EQLAT(1148) /0.1100389427E+01/
     *    EQLON(1148) /0.2515773958E+01/
     *    SSLIP(1148) /0.7266000000E+01/
     *    DSLIP(1148) /-.1830000000E+01/
     *    DIP(1148) /0.1570796327E+01/
     *    DEPTH(1148) /0.6000000000E+04/
     *    WIDTH(1148) /0.3000000000E+04/
      DATA STRIKE(1149) /0.5209807817E+01/
     *    HL(1149) /0.1427100000E+04/
     *    EQLAT(1149) /0.1100167945E+01/
     *    EQLON(1149) /0.2514918921E+01/
     *    SSLIP(1149) /0.8101000000E+01/
     *    DSLIP(1149) /-.2170000000E+01/
     *    DIP(1149) /0.1570796327E+01/
     *    DEPTH(1149) /0.6000000000E+04/
     *    WIDTH(1149) /0.3000000000E+04/
      DATA STRIKE(1150) /0.5208062488E+01/
     *    HL(1150) /0.1427600000E+04/
     *    EQLAT(1150) /0.1099946463E+01/
     *    EQLON(1150) /0.2514064059E+01/
     *    SSLIP(1150) /0.8928000000E+01/
     *    DSLIP(1150) /-.2450000000E+01/
     *    DIP(1150) /0.1570796327E+01/
     *    DEPTH(1150) /0.6000000000E+04/
     *    WIDTH(1150) /0.3000000000E+04/
      DATA STRIKE(1151) /0.5206317159E+01/
     *    HL(1151) /0.1428000000E+04/
     *    EQLAT(1151) /0.1099724980E+01/
     *    EQLON(1151) /0.2513209197E+01/
     *    SSLIP(1151) /0.9538000000E+01/
     *    DSLIP(1151) /-.2530000000E+01/
     *    DIP(1151) /0.1570796327E+01/
     *    DEPTH(1151) /0.6000000000E+04/
     *    WIDTH(1151) /0.3000000000E+04/
      DATA STRIKE(1152) /0.5204571829E+01/
     *    HL(1152) /0.1428500000E+04/
     *    EQLAT(1152) /0.1099503498E+01/
     *    EQLON(1152) /0.2512354160E+01/
     *    SSLIP(1152) /0.9493000000E+01/
     *    DSLIP(1152) /-.2490000000E+01/
     *    DIP(1152) /0.1570796327E+01/
     *    DEPTH(1152) /0.6000000000E+04/
     *    WIDTH(1152) /0.3000000000E+04/
      DATA STRIKE(1153) /0.5202826500E+01/
     *    HL(1153) /0.1429000000E+04/
     *    EQLAT(1153) /0.1099282016E+01/
     *    EQLON(1153) /0.2511499298E+01/
     *    SSLIP(1153) /0.8627000000E+01/
     *    DSLIP(1153) /-.2450000000E+01/
     *    DIP(1153) /0.1570796327E+01/
     *    DEPTH(1153) /0.6000000000E+04/
     *    WIDTH(1153) /0.3000000000E+04/
      DATA STRIKE(1154) /0.5201081171E+01/
     *    HL(1154) /0.1429500000E+04/
     *    EQLAT(1154) /0.1099060534E+01/
     *    EQLON(1154) /0.2510644435E+01/
     *    SSLIP(1154) /0.7763000000E+01/
     *    DSLIP(1154) /-.2520000000E+01/
     *    DIP(1154) /0.1570796327E+01/
     *    DEPTH(1154) /0.6000000000E+04/
     *    WIDTH(1154) /0.3000000000E+04/
      DATA STRIKE(1155) /0.5199335842E+01/
     *    HL(1155) /0.1429900000E+04/
     *    EQLAT(1155) /0.1098839051E+01/
     *    EQLON(1155) /0.2509789398E+01/
     *    SSLIP(1155) /0.7284000000E+01/
     *    DSLIP(1155) /-.2040000000E+01/
     *    DIP(1155) /0.1570796327E+01/
     *    DEPTH(1155) /0.6000000000E+04/
     *    WIDTH(1155) /0.3000000000E+04/
      DATA STRIKE(1156) /0.5197590512E+01/
     *    HL(1156) /0.1430400000E+04/
     *    EQLAT(1156) /0.1098617743E+01/
     *    EQLON(1156) /0.2508934536E+01/
     *    SSLIP(1156) /0.6746000000E+01/
     *    DSLIP(1156) /-.9800000000E+00/
     *    DIP(1156) /0.1570796327E+01/
     *    DEPTH(1156) /0.6000000000E+04/
     *    WIDTH(1156) /0.3000000000E+04/
      DATA STRIKE(1157) /0.5195845183E+01/
     *    HL(1157) /0.1430900000E+04/
     *    EQLAT(1157) /0.1098396261E+01/
     *    EQLON(1157) /0.2508079674E+01/
     *    SSLIP(1157) /0.6239000000E+01/
     *    DSLIP(1157) /-.2200000000E+00/
     *    DIP(1157) /0.1570796327E+01/
     *    DEPTH(1157) /0.6000000000E+04/
     *    WIDTH(1157) /0.3000000000E+04/
      DATA STRIKE(1158) /0.5229006439E+01/
     *    HL(1158) /0.1431300000E+04/
     *    EQLAT(1158) /0.1098174779E+01/
     *    EQLON(1158) /0.2507224637E+01/
     *    SSLIP(1158) /0.5713000000E+01/
     *    DSLIP(1158) /0.0000000000E+00/
     *    DIP(1158) /0.1570796327E+01/
     *    DEPTH(1158) /0.6000000000E+04/
     *    WIDTH(1158) /0.3000000000E+04/
      DATA STRIKE(1159) /0.5227261110E+01/
     *    HL(1159) /0.1431800000E+04/
     *    EQLAT(1159) /0.1097953297E+01/
     *    EQLON(1159) /0.2506369775E+01/
     *    SSLIP(1159) /0.5184000000E+01/
     *    DSLIP(1159) /0.0000000000E+00/
     *    DIP(1159) /0.1570796327E+01/
     *    DEPTH(1159) /0.6000000000E+04/
     *    WIDTH(1159) /0.3000000000E+04/
      DATA STRIKE(1160) /0.5225515780E+01/
     *    HL(1160) /0.1432300000E+04/
     *    EQLAT(1160) /0.1097731814E+01/
     *    EQLON(1160) /0.2505514913E+01/
     *    SSLIP(1160) /0.4650000000E+01/
     *    DSLIP(1160) /-.3000000000E-01/
     *    DIP(1160) /0.1570796327E+01/
     *    DEPTH(1160) /0.6000000000E+04/
     *    WIDTH(1160) /0.3000000000E+04/
      DATA STRIKE(1161) /0.5223770451E+01/
     *    HL(1161) /0.1432700000E+04/
     *    EQLAT(1161) /0.1097510332E+01/
     *    EQLON(1161) /0.2504659876E+01/
     *    SSLIP(1161) /0.4361000000E+01/
     *    DSLIP(1161) /0.0000000000E+00/
     *    DIP(1161) /0.1570796327E+01/
     *    DEPTH(1161) /0.6000000000E+04/
     *    WIDTH(1161) /0.3000000000E+04/
      DATA STRIKE(1162) /0.5222025122E+01/
     *    HL(1162) /0.1433200000E+04/
     *    EQLAT(1162) /0.1097288850E+01/
     *    EQLON(1162) /0.2503805014E+01/
     *    SSLIP(1162) /0.4204000000E+01/
     *    DSLIP(1162) /0.0000000000E+00/
     *    DIP(1162) /0.1570796327E+01/
     *    DEPTH(1162) /0.6000000000E+04/
     *    WIDTH(1162) /0.3000000000E+04/
      DATA STRIKE(1163) /0.5220279793E+01/
     *    HL(1163) /0.1433700000E+04/
     *    EQLAT(1163) /0.1097067368E+01/
     *    EQLON(1163) /0.2502950151E+01/
     *    SSLIP(1163) /0.4061000000E+01/
     *    DSLIP(1163) /0.0000000000E+00/
     *    DIP(1163) /0.1570796327E+01/
     *    DEPTH(1163) /0.9000000000E+04/
     *    WIDTH(1163) /0.3000000000E+04/
      DATA STRIKE(1164) /0.5218534463E+01/
     *    HL(1164) /0.1434100000E+04/
     *    EQLAT(1164) /0.1096845885E+01/
     *    EQLON(1164) /0.2502095114E+01/
     *    SSLIP(1164) /0.3920000000E+01/
     *    DSLIP(1164) /0.0000000000E+00/
     *    DIP(1164) /0.1570796327E+01/
     *    DEPTH(1164) /0.9000000000E+04/
     *    WIDTH(1164) /0.3000000000E+04/
      DATA STRIKE(1165) /0.4544837372E+01/
     *    HL(1165) /0.1500600000E+04/
     *    EQLAT(1165) /0.1108284599E+01/
     *    EQLON(1165) /0.2578255000E+01/
     *    SSLIP(1165) /0.8340000000E+00/
     *    DSLIP(1165) /0.0000000000E+00/
     *    DIP(1165) /0.1570796327E+01/
     *    DEPTH(1165) /0.9000000000E+04/
     *    WIDTH(1165) /0.3000000000E+04/
      DATA STRIKE(1166) /0.4544837372E+01/
     *    HL(1166) /0.1500600000E+04/
     *    EQLAT(1166) /0.1108363138E+01/
     *    EQLON(1166) /0.2577217925E+01/
     *    SSLIP(1166) /0.9030000000E+00/
     *    DSLIP(1166) /0.0000000000E+00/
     *    DIP(1166) /0.1570796327E+01/
     *    DEPTH(1166) /0.9000000000E+04/
     *    WIDTH(1166) /0.3000000000E+04/
      DATA STRIKE(1167) /0.4546582701E+01/
     *    HL(1167) /0.1500600000E+04/
     *    EQLAT(1167) /0.1108441329E+01/
     *    EQLON(1167) /0.2576180502E+01/
     *    SSLIP(1167) /0.1110000000E+01/
     *    DSLIP(1167) /0.0000000000E+00/
     *    DIP(1167) /0.1570796327E+01/
     *    DEPTH(1167) /0.9000000000E+04/
     *    WIDTH(1167) /0.3000000000E+04/
      DATA STRIKE(1168) /0.4546582701E+01/
     *    HL(1168) /0.1500600000E+04/
     *    EQLAT(1168) /0.1108518996E+01/
     *    EQLON(1168) /0.2575142903E+01/
     *    SSLIP(1168) /0.1154000000E+01/
     *    DSLIP(1168) /0.0000000000E+00/
     *    DIP(1168) /0.1570796327E+01/
     *    DEPTH(1168) /0.9000000000E+04/
     *    WIDTH(1168) /0.3000000000E+04/
      DATA STRIKE(1169) /0.4548328031E+01/
     *    HL(1169) /0.1500600000E+04/
     *    EQLAT(1169) /0.1108596140E+01/
     *    EQLON(1169) /0.2574104956E+01/
     *    SSLIP(1169) /0.9310000000E+00/
     *    DSLIP(1169) /0.0000000000E+00/
     *    DIP(1169) /0.1570796327E+01/
     *    DEPTH(1169) /0.9000000000E+04/
     *    WIDTH(1169) /0.3000000000E+04/
      DATA STRIKE(1170) /0.4548328031E+01/
     *    HL(1170) /0.1500600000E+04/
     *    EQLAT(1170) /0.1108673109E+01/
     *    EQLON(1170) /0.2573066660E+01/
     *    SSLIP(1170) /0.5300000000E+00/
     *    DSLIP(1170) /0.0000000000E+00/
     *    DIP(1170) /0.1570796327E+01/
     *    DEPTH(1170) /0.9000000000E+04/
     *    WIDTH(1170) /0.3000000000E+04/
      DATA STRIKE(1171) /0.4550073360E+01/
     *    HL(1171) /0.1500600000E+04/
     *    EQLAT(1171) /0.1108749380E+01/
     *    EQLON(1171) /0.2572028014E+01/
     *    SSLIP(1171) /0.1600000000E+00/
     *    DSLIP(1171) /0.0000000000E+00/
     *    DIP(1171) /0.1570796327E+01/
     *    DEPTH(1171) /0.9000000000E+04/
     *    WIDTH(1171) /0.3000000000E+04/
      DATA STRIKE(1172) /0.4551818689E+01/
     *    HL(1172) /0.1500600000E+04/
     *    EQLAT(1172) /0.1108825476E+01/
     *    EQLON(1172) /0.2570989020E+01/
     *    SSLIP(1172) /0.0000000000E+00/
     *    DSLIP(1172) /0.0000000000E+00/
     *    DIP(1172) /0.1570796327E+01/
     *    DEPTH(1172) /0.9000000000E+04/
     *    WIDTH(1172) /0.3000000000E+04/
      DATA STRIKE(1173) /0.4551818689E+01/
     *    HL(1173) /0.1500600000E+04/
     *    EQLAT(1173) /0.1108900874E+01/
     *    EQLON(1173) /0.2569949851E+01/
     *    SSLIP(1173) /0.0000000000E+00/
     *    DSLIP(1173) /0.0000000000E+00/
     *    DIP(1173) /0.1570796327E+01/
     *    DEPTH(1173) /0.9000000000E+04/
     *    WIDTH(1173) /0.3000000000E+04/
      DATA STRIKE(1174) /0.4862487296E+01/
     *    HL(1174) /0.1468400000E+04/
     *    EQLAT(1174) /0.1108904540E+01/
     *    EQLON(1174) /0.2568920630E+01/
     *    SSLIP(1174) /0.2410000000E+00/
     *    DSLIP(1174) /0.0000000000E+00/
     *    DIP(1174) /0.1570796327E+01/
     *    DEPTH(1174) /0.9000000000E+04/
     *    WIDTH(1174) /0.3000000000E+04/
      DATA STRIKE(1175) /0.4862487296E+01/
     *    HL(1175) /0.1468600000E+04/
     *    EQLAT(1175) /0.1108836297E+01/
     *    EQLON(1175) /0.2567901532E+01/
     *    SSLIP(1175) /0.4980000000E+00/
     *    DSLIP(1175) /0.0000000000E+00/
     *    DIP(1175) /0.1570796327E+01/
     *    DEPTH(1175) /0.9000000000E+04/
     *    WIDTH(1175) /0.3000000000E+04/
      DATA STRIKE(1176) /0.4862487296E+01/
     *    HL(1176) /0.1468800000E+04/
     *    EQLAT(1176) /0.1108768055E+01/
     *    EQLON(1176) /0.2566882434E+01/
     *    SSLIP(1176) /0.6480000000E+00/
     *    DSLIP(1176) /0.0000000000E+00/
     *    DIP(1176) /0.1570796327E+01/
     *    DEPTH(1176) /0.9000000000E+04/
     *    WIDTH(1176) /0.3000000000E+04/
      DATA STRIKE(1177) /0.4860741967E+01/
     *    HL(1177) /0.1469000000E+04/
     *    EQLAT(1177) /0.1108699987E+01/
     *    EQLON(1177) /0.2565863337E+01/
     *    SSLIP(1177) /0.6020000000E+00/
     *    DSLIP(1177) /-.7000000000E-01/
     *    DIP(1177) /0.1570796327E+01/
     *    DEPTH(1177) /0.9000000000E+04/
     *    WIDTH(1177) /0.3000000000E+04/
      DATA STRIKE(1178) /0.4858996638E+01/
     *    HL(1178) /0.1469200000E+04/
     *    EQLAT(1178) /0.1108631745E+01/
     *    EQLON(1178) /0.2564844413E+01/
     *    SSLIP(1178) /0.3920000000E+00/
     *    DSLIP(1178) /-.4700000000E+00/
     *    DIP(1178) /0.1570796327E+01/
     *    DEPTH(1178) /0.9000000000E+04/
     *    WIDTH(1178) /0.3000000000E+04/
      DATA STRIKE(1179) /0.4857251308E+01/
     *    HL(1179) /0.1469400000E+04/
     *    EQLAT(1179) /0.1108563677E+01/
     *    EQLON(1179) /0.2563825316E+01/
     *    SSLIP(1179) /0.2480000000E+00/
     *    DSLIP(1179) /-.1160000000E+01/
     *    DIP(1179) /0.1570796327E+01/
     *    DEPTH(1179) /0.9000000000E+04/
     *    WIDTH(1179) /0.3000000000E+04/
      DATA STRIKE(1180) /0.4855505979E+01/
     *    HL(1180) /0.1469600000E+04/
     *    EQLAT(1180) /0.1108495434E+01/
     *    EQLON(1180) /0.2562806218E+01/
     *    SSLIP(1180) /0.3630000000E+00/
     *    DSLIP(1180) /-.1970000000E+01/
     *    DIP(1180) /0.1570796327E+01/
     *    DEPTH(1180) /0.9000000000E+04/
     *    WIDTH(1180) /0.3000000000E+04/
      DATA STRIKE(1181) /0.4853760650E+01/
     *    HL(1181) /0.1469800000E+04/
     *    EQLAT(1181) /0.1108427192E+01/
     *    EQLON(1181) /0.2561787120E+01/
     *    SSLIP(1181) /0.7600000000E+00/
     *    DSLIP(1181) /-.2650000000E+01/
     *    DIP(1181) /0.1570796327E+01/
     *    DEPTH(1181) /0.9000000000E+04/
     *    WIDTH(1181) /0.3000000000E+04/
      DATA STRIKE(1182) /0.4852015321E+01/
     *    HL(1182) /0.1470000000E+04/
     *    EQLAT(1182) /0.1108359124E+01/
     *    EQLON(1182) /0.2560768197E+01/
     *    SSLIP(1182) /0.1292000000E+01/
     *    DSLIP(1182) /-.3000000000E+01/
     *    DIP(1182) /0.1570796327E+01/
     *    DEPTH(1182) /0.9000000000E+04/
     *    WIDTH(1182) /0.3000000000E+04/
      DATA STRIKE(1183) /0.4850269991E+01/
     *    HL(1183) /0.1470200000E+04/
     *    EQLAT(1183) /0.1108290882E+01/
     *    EQLON(1183) /0.2559749099E+01/
     *    SSLIP(1183) /0.1716000000E+01/
     *    DSLIP(1183) /-.3000000000E+01/
     *    DIP(1183) /0.1570796327E+01/
     *    DEPTH(1183) /0.9000000000E+04/
     *    WIDTH(1183) /0.3000000000E+04/
      DATA STRIKE(1184) /0.4848524662E+01/
     *    HL(1184) /0.1470400000E+04/
     *    EQLAT(1184) /0.1108222639E+01/
     *    EQLON(1184) /0.2558730002E+01/
     *    SSLIP(1184) /0.1841000000E+01/
     *    DSLIP(1184) /-.2720000000E+01/
     *    DIP(1184) /0.1570796327E+01/
     *    DEPTH(1184) /0.9000000000E+04/
     *    WIDTH(1184) /0.3000000000E+04/
      DATA STRIKE(1185) /0.4846779333E+01/
     *    HL(1185) /0.1470600000E+04/
     *    EQLAT(1185) /0.1108154572E+01/
     *    EQLON(1185) /0.2557710904E+01/
     *    SSLIP(1185) /0.1675000000E+01/
     *    DSLIP(1185) /-.2250000000E+01/
     *    DIP(1185) /0.1570796327E+01/
     *    DEPTH(1185) /0.9000000000E+04/
     *    WIDTH(1185) /0.3000000000E+04/
      DATA STRIKE(1186) /0.4845034004E+01/
     *    HL(1186) /0.1470800000E+04/
     *    EQLAT(1186) /0.1108086329E+01/
     *    EQLON(1186) /0.2556691981E+01/
     *    SSLIP(1186) /0.1378000000E+01/
     *    DSLIP(1186) /-.1860000000E+01/
     *    DIP(1186) /0.1570796327E+01/
     *    DEPTH(1186) /0.9000000000E+04/
     *    WIDTH(1186) /0.3000000000E+04/
      DATA STRIKE(1187) /0.4843288674E+01/
     *    HL(1187) /0.1470900000E+04/
     *    EQLAT(1187) /0.1108018261E+01/
     *    EQLON(1187) /0.2555672883E+01/
     *    SSLIP(1187) /0.9530000000E+00/
     *    DSLIP(1187) /-.1530000000E+01/
     *    DIP(1187) /0.1570796327E+01/
     *    DEPTH(1187) /0.9000000000E+04/
     *    WIDTH(1187) /0.3000000000E+04/
      DATA STRIKE(1188) /0.4841543345E+01/
     *    HL(1188) /0.1471100000E+04/
     *    EQLAT(1188) /0.1107950019E+01/
     *    EQLON(1188) /0.2554653785E+01/
     *    SSLIP(1188) /0.5710000000E+00/
     *    DSLIP(1188) /-.1330000000E+01/
     *    DIP(1188) /0.1570796327E+01/
     *    DEPTH(1188) /0.9000000000E+04/
     *    WIDTH(1188) /0.3000000000E+04/
      DATA STRIKE(1189) /0.4839798016E+01/
     *    HL(1189) /0.1471300000E+04/
     *    EQLAT(1189) /0.1107881777E+01/
     *    EQLON(1189) /0.2553634687E+01/
     *    SSLIP(1189) /0.6170000000E+00/
     *    DSLIP(1189) /-.1390000000E+01/
     *    DIP(1189) /0.1570796327E+01/
     *    DEPTH(1189) /0.9000000000E+04/
     *    WIDTH(1189) /0.3000000000E+04/
      DATA STRIKE(1190) /0.4967207051E+01/
     *    HL(1190) /0.1450200000E+04/
     *    EQLAT(1190) /0.1107785434E+01/
     *    EQLON(1190) /0.2552637057E+01/
     *    SSLIP(1190) /0.1380000000E+01/
     *    DSLIP(1190) /-.1630000000E+01/
     *    DIP(1190) /0.1570796327E+01/
     *    DEPTH(1190) /0.9000000000E+04/
     *    WIDTH(1190) /0.3000000000E+04/
      DATA STRIKE(1191) /0.4965461722E+01/
     *    HL(1191) /0.1450500000E+04/
     *    EQLAT(1191) /0.1107660818E+01/
     *    EQLON(1191) /0.2551660720E+01/
     *    SSLIP(1191) /0.2079000000E+01/
     *    DSLIP(1191) /-.1490000000E+01/
     *    DIP(1191) /0.1570796327E+01/
     *    DEPTH(1191) /0.9000000000E+04/
     *    WIDTH(1191) /0.3000000000E+04/
      DATA STRIKE(1192) /0.4963716393E+01/
     *    HL(1192) /0.1450900000E+04/
     *    EQLAT(1192) /0.1107536027E+01/
     *    EQLON(1192) /0.2550684208E+01/
     *    SSLIP(1192) /0.2511000000E+01/
     *    DSLIP(1192) /-.1050000000E+01/
     *    DIP(1192) /0.1570796327E+01/
     *    DEPTH(1192) /0.9000000000E+04/
     *    WIDTH(1192) /0.3000000000E+04/
      DATA STRIKE(1193) /0.4961971063E+01/
     *    HL(1193) /0.1451200000E+04/
     *    EQLAT(1193) /0.1107411410E+01/
     *    EQLON(1193) /0.2549707871E+01/
     *    SSLIP(1193) /0.2613000000E+01/
     *    DSLIP(1193) /-.6500000000E+00/
     *    DIP(1193) /0.1570796327E+01/
     *    DEPTH(1193) /0.9000000000E+04/
     *    WIDTH(1193) /0.3000000000E+04/
      DATA STRIKE(1194) /0.4960225734E+01/
     *    HL(1194) /0.1451500000E+04/
     *    EQLAT(1194) /0.1107286794E+01/
     *    EQLON(1194) /0.2548731534E+01/
     *    SSLIP(1194) /0.2474000000E+01/
     *    DSLIP(1194) /-.3900000000E+00/
     *    DIP(1194) /0.1570796327E+01/
     *    DEPTH(1194) /0.9000000000E+04/
     *    WIDTH(1194) /0.3000000000E+04/
      DATA STRIKE(1195) /0.4956735076E+01/
     *    HL(1195) /0.1451900000E+04/
     *    EQLAT(1195) /0.1107162003E+01/
     *    EQLON(1195) /0.2547755022E+01/
     *    SSLIP(1195) /0.2643000000E+01/
     *    DSLIP(1195) /-.1800000000E+00/
     *    DIP(1195) /0.1570796327E+01/
     *    DEPTH(1195) /0.9000000000E+04/
     *    WIDTH(1195) /0.3000000000E+04/
      DATA STRIKE(1196) /0.4954989746E+01/
     *    HL(1196) /0.1452200000E+04/
     *    EQLAT(1196) /0.1107037386E+01/
     *    EQLON(1196) /0.2546778685E+01/
     *    SSLIP(1196) /0.3940000000E+01/
     *    DSLIP(1196) /0.0000000000E+00/
     *    DIP(1196) /0.1570796327E+01/
     *    DEPTH(1196) /0.9000000000E+04/
     *    WIDTH(1196) /0.3000000000E+04/
      DATA STRIKE(1197) /0.5239478414E+01/
     *    HL(1197) /0.1384800000E+04/
     *    EQLAT(1197) /0.1106865995E+01/
     *    EQLON(1197) /0.2545872335E+01/
     *    SSLIP(1197) /0.6576000000E+01/
     *    DSLIP(1197) /-.1100000000E+00/
     *    DIP(1197) /0.1570796327E+01/
     *    DEPTH(1197) /0.9000000000E+04/
     *    WIDTH(1197) /0.3000000000E+04/
      DATA STRIKE(1198) /0.5237733085E+01/
     *    HL(1198) /0.1385300000E+04/
     *    EQLAT(1198) /0.1106647829E+01/
     *    EQLON(1198) /0.2545035799E+01/
     *    SSLIP(1198) /0.7847000000E+01/
     *    DSLIP(1198) /0.0000000000E+00/
     *    DIP(1198) /0.1570796327E+01/
     *    DEPTH(1198) /0.9000000000E+04/
     *    WIDTH(1198) /0.3000000000E+04/
      DATA STRIKE(1199) /0.5235987756E+01/
     *    HL(1199) /0.1385700000E+04/
     *    EQLAT(1199) /0.1106429663E+01/
     *    EQLON(1199) /0.2544199437E+01/
     *    SSLIP(1199) /0.7393000000E+01/
     *    DSLIP(1199) /0.0000000000E+00/
     *    DIP(1199) /0.1570796327E+01/
     *    DEPTH(1199) /0.9000000000E+04/
     *    WIDTH(1199) /0.3000000000E+04/
      DATA STRIKE(1200) /0.5234242427E+01/
     *    HL(1200) /0.1386200000E+04/
     *    EQLAT(1200) /0.1106211497E+01/
     *    EQLON(1200) /0.2543362901E+01/
     *    SSLIP(1200) /0.6169000000E+01/
     *    DSLIP(1200) /0.0000000000E+00/
     *    DIP(1200) /0.1570796327E+01/
     *    DEPTH(1200) /0.9000000000E+04/
     *    WIDTH(1200) /0.3000000000E+04/
      DATA STRIKE(1201) /0.5232497097E+01/
     *    HL(1201) /0.1386600000E+04/
     *    EQLAT(1201) /0.1105993330E+01/
     *    EQLON(1201) /0.2542526539E+01/
     *    SSLIP(1201) /0.4549000000E+01/
     *    DSLIP(1201) /0.0000000000E+00/
     *    DIP(1201) /0.1570796327E+01/
     *    DEPTH(1201) /0.9000000000E+04/
     *    WIDTH(1201) /0.3000000000E+04/
      DATA STRIKE(1202) /0.5230751768E+01/
     *    HL(1202) /0.1387100000E+04/
     *    EQLAT(1202) /0.1105775164E+01/
     *    EQLON(1202) /0.2541690003E+01/
     *    SSLIP(1202) /0.3016000000E+01/
     *    DSLIP(1202) /0.0000000000E+00/
     *    DIP(1202) /0.1570796327E+01/
     *    DEPTH(1202) /0.9000000000E+04/
     *    WIDTH(1202) /0.3000000000E+04/
      DATA STRIKE(1203) /0.5229006439E+01/
     *    HL(1203) /0.1387500000E+04/
     *    EQLAT(1203) /0.1105556998E+01/
     *    EQLON(1203) /0.2540853641E+01/
     *    SSLIP(1203) /0.2723000000E+01/
     *    DSLIP(1203) /0.0000000000E+00/
     *    DIP(1203) /0.1570796327E+01/
     *    DEPTH(1203) /0.9000000000E+04/
     *    WIDTH(1203) /0.3000000000E+04/
      DATA STRIKE(1204) /0.5227261110E+01/
     *    HL(1204) /0.1388000000E+04/
     *    EQLAT(1204) /0.1105338832E+01/
     *    EQLON(1204) /0.2540017105E+01/
     *    SSLIP(1204) /0.4289000000E+01/
     *    DSLIP(1204) /0.0000000000E+00/
     *    DIP(1204) /0.1570796327E+01/
     *    DEPTH(1204) /0.9000000000E+04/
     *    WIDTH(1204) /0.3000000000E+04/
      DATA STRIKE(1205) /0.5047492197E+01/
     *    HL(1205) /0.1434000000E+04/
     *    EQLAT(1205) /0.1105152954E+01/
     *    EQLON(1205) /0.2539129605E+01/
     *    SSLIP(1205) /0.6827000000E+01/
     *    DSLIP(1205) /0.0000000000E+00/
     *    DIP(1205) /0.1570796327E+01/
     *    DEPTH(1205) /0.9000000000E+04/
     *    WIDTH(1205) /0.3000000000E+04/
      DATA STRIKE(1206) /0.5045746868E+01/
     *    HL(1206) /0.1434400000E+04/
     *    EQLAT(1206) /0.1104999540E+01/
     *    EQLON(1206) /0.2538190967E+01/
     *    SSLIP(1206) /0.7628000000E+01/
     *    DSLIP(1206) /0.0000000000E+00/
     *    DIP(1206) /0.1570796327E+01/
     *    DEPTH(1206) /0.9000000000E+04/
     *    WIDTH(1206) /0.3000000000E+04/
      DATA STRIKE(1207) /0.5044001538E+01/
     *    HL(1207) /0.1434700000E+04/
     *    EQLAT(1207) /0.1104846125E+01/
     *    EQLON(1207) /0.2537252329E+01/
     *    SSLIP(1207) /0.6720000000E+01/
     *    DSLIP(1207) /0.0000000000E+00/
     *    DIP(1207) /0.1570796327E+01/
     *    DEPTH(1207) /0.9000000000E+04/
     *    WIDTH(1207) /0.3000000000E+04/
      DATA STRIKE(1208) /0.5042256209E+01/
     *    HL(1208) /0.1435100000E+04/
     *    EQLAT(1208) /0.1104692711E+01/
     *    EQLON(1208) /0.2536313516E+01/
     *    SSLIP(1208) /0.5128000000E+01/
     *    DSLIP(1208) /0.0000000000E+00/
     *    DIP(1208) /0.1570796327E+01/
     *    DEPTH(1208) /0.9000000000E+04/
     *    WIDTH(1208) /0.3000000000E+04/
      DATA STRIKE(1209) /0.5040510880E+01/
     *    HL(1209) /0.1435500000E+04/
     *    EQLAT(1209) /0.1104539297E+01/
     *    EQLON(1209) /0.2535374878E+01/
     *    SSLIP(1209) /0.3871000000E+01/
     *    DSLIP(1209) /0.0000000000E+00/
     *    DIP(1209) /0.1570796327E+01/
     *    DEPTH(1209) /0.9000000000E+04/
     *    WIDTH(1209) /0.3000000000E+04/
      DATA STRIKE(1210) /0.5038765551E+01/
     *    HL(1210) /0.1435900000E+04/
     *    EQLAT(1210) /0.1104385882E+01/
     *    EQLON(1210) /0.2534436240E+01/
     *    SSLIP(1210) /0.3518000000E+01/
     *    DSLIP(1210) /0.0000000000E+00/
     *    DIP(1210) /0.1570796327E+01/
     *    DEPTH(1210) /0.9000000000E+04/
     *    WIDTH(1210) /0.3000000000E+04/
      DATA STRIKE(1211) /0.5037020221E+01/
     *    HL(1211) /0.1436300000E+04/
     *    EQLAT(1211) /0.1104232468E+01/
     *    EQLON(1211) /0.2533497602E+01/
     *    SSLIP(1211) /0.4121000000E+01/
     *    DSLIP(1211) /0.0000000000E+00/
     *    DIP(1211) /0.1570796327E+01/
     *    DEPTH(1211) /0.9000000000E+04/
     *    WIDTH(1211) /0.3000000000E+04/
      DATA STRIKE(1212) /0.5035274892E+01/
     *    HL(1212) /0.1436700000E+04/
     *    EQLAT(1212) /0.1104079053E+01/
     *    EQLON(1212) /0.2532558964E+01/
     *    SSLIP(1212) /0.5295000000E+01/
     *    DSLIP(1212) /0.0000000000E+00/
     *    DIP(1212) /0.1570796327E+01/
     *    DEPTH(1212) /0.9000000000E+04/
     *    WIDTH(1212) /0.3000000000E+04/
      DATA STRIKE(1213) /0.5033529563E+01/
     *    HL(1213) /0.1437100000E+04/
     *    EQLAT(1213) /0.1103925639E+01/
     *    EQLON(1213) /0.2531620151E+01/
     *    SSLIP(1213) /0.6381000000E+01/
     *    DSLIP(1213) /0.0000000000E+00/
     *    DIP(1213) /0.1570796327E+01/
     *    DEPTH(1213) /0.9000000000E+04/
     *    WIDTH(1213) /0.3000000000E+04/
      DATA STRIKE(1214) /0.5031784233E+01/
     *    HL(1214) /0.1437400000E+04/
     *    EQLAT(1214) /0.1103772224E+01/
     *    EQLON(1214) /0.2530681513E+01/
     *    SSLIP(1214) /0.6734000000E+01/
     *    DSLIP(1214) /0.0000000000E+00/
     *    DIP(1214) /0.1570796327E+01/
     *    DEPTH(1214) /0.9000000000E+04/
     *    WIDTH(1214) /0.3000000000E+04/
      DATA STRIKE(1215) /0.5030038904E+01/
     *    HL(1215) /0.1437800000E+04/
     *    EQLAT(1215) /0.1103618810E+01/
     *    EQLON(1215) /0.2529742875E+01/
     *    SSLIP(1215) /0.6045000000E+01/
     *    DSLIP(1215) /0.0000000000E+00/
     *    DIP(1215) /0.1570796327E+01/
     *    DEPTH(1215) /0.9000000000E+04/
     *    WIDTH(1215) /0.3000000000E+04/
      DATA STRIKE(1216) /0.5153957281E+01/
     *    HL(1216) /0.1412200000E+04/
     *    EQLAT(1216) /0.1103441310E+01/
     *    EQLON(1216) /0.2528837224E+01/
     *    SSLIP(1216) /0.4639000000E+01/
     *    DSLIP(1216) /0.0000000000E+00/
     *    DIP(1216) /0.1570796327E+01/
     *    DEPTH(1216) /0.9000000000E+04/
     *    WIDTH(1216) /0.3000000000E+04/
      DATA STRIKE(1217) /0.5152211952E+01/
     *    HL(1217) /0.1412700000E+04/
     *    EQLAT(1217) /0.1103239899E+01/
     *    EQLON(1217) /0.2527964559E+01/
     *    SSLIP(1217) /0.3653000000E+01/
     *    DSLIP(1217) /0.0000000000E+00/
     *    DIP(1217) /0.1570796327E+01/
     *    DEPTH(1217) /0.9000000000E+04/
     *    WIDTH(1217) /0.3000000000E+04/
      DATA STRIKE(1218) /0.5150466623E+01/
     *    HL(1218) /0.1413100000E+04/
     *    EQLAT(1218) /0.1103038313E+01/
     *    EQLON(1218) /0.2527091895E+01/
     *    SSLIP(1218) /0.3247000000E+01/
     *    DSLIP(1218) /0.0000000000E+00/
     *    DIP(1218) /0.1570796327E+01/
     *    DEPTH(1218) /0.9000000000E+04/
     *    WIDTH(1218) /0.3000000000E+04/
      DATA STRIKE(1219) /0.5183627878E+01/
     *    HL(1219) /0.1413500000E+04/
     *    EQLAT(1219) /0.1102836902E+01/
     *    EQLON(1219) /0.2526219230E+01/
     *    SSLIP(1219) /0.3278000000E+01/
     *    DSLIP(1219) /0.0000000000E+00/
     *    DIP(1219) /0.1570796327E+01/
     *    DEPTH(1219) /0.9000000000E+04/
     *    WIDTH(1219) /0.3000000000E+04/
      DATA STRIKE(1220) /0.5181882549E+01/
     *    HL(1220) /0.1414000000E+04/
     *    EQLAT(1220) /0.1102635491E+01/
     *    EQLON(1220) /0.2525346565E+01/
     *    SSLIP(1220) /0.3460000000E+01/
     *    DSLIP(1220) /0.0000000000E+00/
     *    DIP(1220) /0.1570796327E+01/
     *    DEPTH(1220) /0.9000000000E+04/
     *    WIDTH(1220) /0.3000000000E+04/
      DATA STRIKE(1221) /0.5180137220E+01/
     *    HL(1221) /0.1414400000E+04/
     *    EQLAT(1221) /0.1102433906E+01/
     *    EQLON(1221) /0.2524473901E+01/
     *    SSLIP(1221) /0.3559000000E+01/
     *    DSLIP(1221) /0.0000000000E+00/
     *    DIP(1221) /0.1570796327E+01/
     *    DEPTH(1221) /0.9000000000E+04/
     *    WIDTH(1221) /0.3000000000E+04/
      DATA STRIKE(1222) /0.5178391891E+01/
     *    HL(1222) /0.1414900000E+04/
     *    EQLAT(1222) /0.1102232495E+01/
     *    EQLON(1222) /0.2523601236E+01/
     *    SSLIP(1222) /0.3480000000E+01/
     *    DSLIP(1222) /0.0000000000E+00/
     *    DIP(1222) /0.1570796327E+01/
     *    DEPTH(1222) /0.9000000000E+04/
     *    WIDTH(1222) /0.3000000000E+04/
      DATA STRIKE(1223) /0.5176646561E+01/
     *    HL(1223) /0.1415300000E+04/
     *    EQLAT(1223) /0.1102031084E+01/
     *    EQLON(1223) /0.2522728571E+01/
     *    SSLIP(1223) /0.3242000000E+01/
     *    DSLIP(1223) /0.0000000000E+00/
     *    DIP(1223) /0.1570796327E+01/
     *    DEPTH(1223) /0.9000000000E+04/
     *    WIDTH(1223) /0.3000000000E+04/
      DATA STRIKE(1224) /0.5174901232E+01/
     *    HL(1224) /0.1415800000E+04/
     *    EQLAT(1224) /0.1101829673E+01/
     *    EQLON(1224) /0.2521855907E+01/
     *    SSLIP(1224) /0.2912000000E+01/
     *    DSLIP(1224) /0.0000000000E+00/
     *    DIP(1224) /0.1570796327E+01/
     *    DEPTH(1224) /0.9000000000E+04/
     *    WIDTH(1224) /0.3000000000E+04/
      DATA STRIKE(1225) /0.5173155903E+01/
     *    HL(1225) /0.1416200000E+04/
     *    EQLAT(1225) /0.1101628087E+01/
     *    EQLON(1225) /0.2520983242E+01/
     *    SSLIP(1225) /0.2647000000E+01/
     *    DSLIP(1225) /0.0000000000E+00/
     *    DIP(1225) /0.1570796327E+01/
     *    DEPTH(1225) /0.9000000000E+04/
     *    WIDTH(1225) /0.3000000000E+04/
      DATA STRIKE(1226) /0.5171410574E+01/
     *    HL(1226) /0.1416700000E+04/
     *    EQLAT(1226) /0.1101426676E+01/
     *    EQLON(1226) /0.2520110578E+01/
     *    SSLIP(1226) /0.2622000000E+01/
     *    DSLIP(1226) /-.1400000000E+00/
     *    DIP(1226) /0.1570796327E+01/
     *    DEPTH(1226) /0.9000000000E+04/
     *    WIDTH(1226) /0.3000000000E+04/
      DATA STRIKE(1227) /0.5169665244E+01/
     *    HL(1227) /0.1417100000E+04/
     *    EQLAT(1227) /0.1101225265E+01/
     *    EQLON(1227) /0.2519237913E+01/
     *    SSLIP(1227) /0.2914000000E+01/
     *    DSLIP(1227) /-.5000000000E+00/
     *    DIP(1227) /0.1570796327E+01/
     *    DEPTH(1227) /0.9000000000E+04/
     *    WIDTH(1227) /0.3000000000E+04/
      DATA STRIKE(1228) /0.5167919915E+01/
     *    HL(1228) /0.1417600000E+04/
     *    EQLAT(1228) /0.1101023680E+01/
     *    EQLON(1228) /0.2518365248E+01/
     *    SSLIP(1228) /0.3469000000E+01/
     *    DSLIP(1228) /-.9800000000E+00/
     *    DIP(1228) /0.1570796327E+01/
     *    DEPTH(1228) /0.9000000000E+04/
     *    WIDTH(1228) /0.3000000000E+04/
      DATA STRIKE(1229) /0.5166174586E+01/
     *    HL(1229) /0.1418000000E+04/
     *    EQLAT(1229) /0.1100822269E+01/
     *    EQLON(1229) /0.2517492584E+01/
     *    SSLIP(1229) /0.4140000000E+01/
     *    DSLIP(1229) /-.1430000000E+01/
     *    DIP(1229) /0.1570796327E+01/
     *    DEPTH(1229) /0.9000000000E+04/
     *    WIDTH(1229) /0.3000000000E+04/
      DATA STRIKE(1230) /0.5213298476E+01/
     *    HL(1230) /0.1426200000E+04/
     *    EQLAT(1230) /0.1100610909E+01/
     *    EQLON(1230) /0.2516628820E+01/
     *    SSLIP(1230) /0.4861000000E+01/
     *    DSLIP(1230) /-.1850000000E+01/
     *    DIP(1230) /0.1570796327E+01/
     *    DEPTH(1230) /0.9000000000E+04/
     *    WIDTH(1230) /0.3000000000E+04/
      DATA STRIKE(1231) /0.5211553146E+01/
     *    HL(1231) /0.1426600000E+04/
     *    EQLAT(1231) /0.1100389427E+01/
     *    EQLON(1231) /0.2515773958E+01/
     *    SSLIP(1231) /0.5680000000E+01/
     *    DSLIP(1231) /-.2290000000E+01/
     *    DIP(1231) /0.1570796327E+01/
     *    DEPTH(1231) /0.9000000000E+04/
     *    WIDTH(1231) /0.3000000000E+04/
      DATA STRIKE(1232) /0.5209807817E+01/
     *    HL(1232) /0.1427100000E+04/
     *    EQLAT(1232) /0.1100167945E+01/
     *    EQLON(1232) /0.2514918921E+01/
     *    SSLIP(1232) /0.6601000000E+01/
     *    DSLIP(1232) /-.2670000000E+01/
     *    DIP(1232) /0.1570796327E+01/
     *    DEPTH(1232) /0.9000000000E+04/
     *    WIDTH(1232) /0.3000000000E+04/
      DATA STRIKE(1233) /0.5208062488E+01/
     *    HL(1233) /0.1427600000E+04/
     *    EQLAT(1233) /0.1099946463E+01/
     *    EQLON(1233) /0.2514064059E+01/
     *    SSLIP(1233) /0.7495000000E+01/
     *    DSLIP(1233) /-.2910000000E+01/
     *    DIP(1233) /0.1570796327E+01/
     *    DEPTH(1233) /0.9000000000E+04/
     *    WIDTH(1233) /0.3000000000E+04/
      DATA STRIKE(1234) /0.5206317159E+01/
     *    HL(1234) /0.1428000000E+04/
     *    EQLAT(1234) /0.1099724980E+01/
     *    EQLON(1234) /0.2513209197E+01/
     *    SSLIP(1234) /0.8130000000E+01/
     *    DSLIP(1234) /-.2990000000E+01/
     *    DIP(1234) /0.1570796327E+01/
     *    DEPTH(1234) /0.9000000000E+04/
     *    WIDTH(1234) /0.3000000000E+04/
      DATA STRIKE(1235) /0.5204571829E+01/
     *    HL(1235) /0.1428500000E+04/
     *    EQLAT(1235) /0.1099503498E+01/
     *    EQLON(1235) /0.2512354160E+01/
     *    SSLIP(1235) /0.8217000000E+01/
     *    DSLIP(1235) /-.3000000000E+01/
     *    DIP(1235) /0.1570796327E+01/
     *    DEPTH(1235) /0.9000000000E+04/
     *    WIDTH(1235) /0.3000000000E+04/
      DATA STRIKE(1236) /0.5202826500E+01/
     *    HL(1236) /0.1429000000E+04/
     *    EQLAT(1236) /0.1099282016E+01/
     *    EQLON(1236) /0.2511499298E+01/
     *    SSLIP(1236) /0.7683000000E+01/
     *    DSLIP(1236) /-.2950000000E+01/
     *    DIP(1236) /0.1570796327E+01/
     *    DEPTH(1236) /0.9000000000E+04/
     *    WIDTH(1236) /0.3000000000E+04/
      DATA STRIKE(1237) /0.5201081171E+01/
     *    HL(1237) /0.1429500000E+04/
     *    EQLAT(1237) /0.1099060534E+01/
     *    EQLON(1237) /0.2510644435E+01/
     *    SSLIP(1237) /0.6889000000E+01/
     *    DSLIP(1237) /-.2750000000E+01/
     *    DIP(1237) /0.1570796327E+01/
     *    DEPTH(1237) /0.9000000000E+04/
     *    WIDTH(1237) /0.3000000000E+04/
      DATA STRIKE(1238) /0.5199335842E+01/
     *    HL(1238) /0.1429900000E+04/
     *    EQLAT(1238) /0.1098839051E+01/
     *    EQLON(1238) /0.2509789398E+01/
     *    SSLIP(1238) /0.6113000000E+01/
     *    DSLIP(1238) /-.2040000000E+01/
     *    DIP(1238) /0.1570796327E+01/
     *    DEPTH(1238) /0.9000000000E+04/
     *    WIDTH(1238) /0.3000000000E+04/
      DATA STRIKE(1239) /0.5197590512E+01/
     *    HL(1239) /0.1430400000E+04/
     *    EQLAT(1239) /0.1098617743E+01/
     *    EQLON(1239) /0.2508934536E+01/
     *    SSLIP(1239) /0.5341000000E+01/
     *    DSLIP(1239) /-.9900000000E+00/
     *    DIP(1239) /0.1570796327E+01/
     *    DEPTH(1239) /0.9000000000E+04/
     *    WIDTH(1239) /0.3000000000E+04/
      DATA STRIKE(1240) /0.5195845183E+01/
     *    HL(1240) /0.1430900000E+04/
     *    EQLAT(1240) /0.1098396261E+01/
     *    EQLON(1240) /0.2508079674E+01/
     *    SSLIP(1240) /0.4614000000E+01/
     *    DSLIP(1240) /-.2200000000E+00/
     *    DIP(1240) /0.1570796327E+01/
     *    DEPTH(1240) /0.9000000000E+04/
     *    WIDTH(1240) /0.3000000000E+04/
      DATA STRIKE(1241) /0.5229006439E+01/
     *    HL(1241) /0.1431300000E+04/
     *    EQLAT(1241) /0.1098174779E+01/
     *    EQLON(1241) /0.2507224637E+01/
     *    SSLIP(1241) /0.3922000000E+01/
     *    DSLIP(1241) /0.0000000000E+00/
     *    DIP(1241) /0.1570796327E+01/
     *    DEPTH(1241) /0.9000000000E+04/
     *    WIDTH(1241) /0.3000000000E+04/
      DATA STRIKE(1242) /0.5227261110E+01/
     *    HL(1242) /0.1431800000E+04/
     *    EQLAT(1242) /0.1097953297E+01/
     *    EQLON(1242) /0.2506369775E+01/
     *    SSLIP(1242) /0.3315000000E+01/
     *    DSLIP(1242) /0.0000000000E+00/
     *    DIP(1242) /0.1570796327E+01/
     *    DEPTH(1242) /0.9000000000E+04/
     *    WIDTH(1242) /0.3000000000E+04/
      DATA STRIKE(1243) /0.5225515780E+01/
     *    HL(1243) /0.1432300000E+04/
     *    EQLAT(1243) /0.1097731814E+01/
     *    EQLON(1243) /0.2505514913E+01/
     *    SSLIP(1243) /0.2856000000E+01/
     *    DSLIP(1243) /0.0000000000E+00/
     *    DIP(1243) /0.1570796327E+01/
     *    DEPTH(1243) /0.9000000000E+04/
     *    WIDTH(1243) /0.3000000000E+04/
      DATA STRIKE(1244) /0.5223770451E+01/
     *    HL(1244) /0.1432700000E+04/
     *    EQLAT(1244) /0.1097510332E+01/
     *    EQLON(1244) /0.2504659876E+01/
     *    SSLIP(1244) /0.2615000000E+01/
     *    DSLIP(1244) /0.0000000000E+00/
     *    DIP(1244) /0.1570796327E+01/
     *    DEPTH(1244) /0.9000000000E+04/
     *    WIDTH(1244) /0.3000000000E+04/
      DATA STRIKE(1245) /0.5222025122E+01/
     *    HL(1245) /0.1433200000E+04/
     *    EQLAT(1245) /0.1097288850E+01/
     *    EQLON(1245) /0.2503805014E+01/
     *    SSLIP(1245) /0.2502000000E+01/
     *    DSLIP(1245) /0.0000000000E+00/
     *    DIP(1245) /0.1570796327E+01/
     *    DEPTH(1245) /0.9000000000E+04/
     *    WIDTH(1245) /0.3000000000E+04/
      DATA STRIKE(1246) /0.5220279793E+01/
     *    HL(1246) /0.1433700000E+04/
     *    EQLAT(1246) /0.1097067368E+01/
     *    EQLON(1246) /0.2502950151E+01/
     *    SSLIP(1246) /0.2426000000E+01/
     *    DSLIP(1246) /0.0000000000E+00/
     *    DIP(1246) /0.1570796327E+01/
     *    DEPTH(1246) /0.1200000000E+05/
     *    WIDTH(1246) /0.3000000000E+04/
      DATA STRIKE(1247) /0.5218534463E+01/
     *    HL(1247) /0.1434100000E+04/
     *    EQLAT(1247) /0.1096845885E+01/
     *    EQLON(1247) /0.2502095114E+01/
     *    SSLIP(1247) /0.2403000000E+01/
     *    DSLIP(1247) /0.0000000000E+00/
     *    DIP(1247) /0.1570796327E+01/
     *    DEPTH(1247) /0.1200000000E+05/
     *    WIDTH(1247) /0.3000000000E+04/
      DATA STRIKE(1248) /0.4544837372E+01/
     *    HL(1248) /0.1500600000E+04/
     *    EQLAT(1248) /0.1108284599E+01/
     *    EQLON(1248) /0.2578255000E+01/
     *    SSLIP(1248) /0.1765000000E+01/
     *    DSLIP(1248) /0.0000000000E+00/
     *    DIP(1248) /0.1570796327E+01/
     *    DEPTH(1248) /0.1200000000E+05/
     *    WIDTH(1248) /0.3000000000E+04/
      DATA STRIKE(1249) /0.4544837372E+01/
     *    HL(1249) /0.1500600000E+04/
     *    EQLAT(1249) /0.1108363138E+01/
     *    EQLON(1249) /0.2577217925E+01/
     *    SSLIP(1249) /0.1860000000E+01/
     *    DSLIP(1249) /0.0000000000E+00/
     *    DIP(1249) /0.1570796327E+01/
     *    DEPTH(1249) /0.1200000000E+05/
     *    WIDTH(1249) /0.3000000000E+04/
      DATA STRIKE(1250) /0.4546582701E+01/
     *    HL(1250) /0.1500600000E+04/
     *    EQLAT(1250) /0.1108441329E+01/
     *    EQLON(1250) /0.2576180502E+01/
     *    SSLIP(1250) /0.2019000000E+01/
     *    DSLIP(1250) /0.0000000000E+00/
     *    DIP(1250) /0.1570796327E+01/
     *    DEPTH(1250) /0.1200000000E+05/
     *    WIDTH(1250) /0.3000000000E+04/
      DATA STRIKE(1251) /0.4546582701E+01/
     *    HL(1251) /0.1500600000E+04/
     *    EQLAT(1251) /0.1108518996E+01/
     *    EQLON(1251) /0.2575142903E+01/
     *    SSLIP(1251) /0.1956000000E+01/
     *    DSLIP(1251) /0.0000000000E+00/
     *    DIP(1251) /0.1570796327E+01/
     *    DEPTH(1251) /0.1200000000E+05/
     *    WIDTH(1251) /0.3000000000E+04/
      DATA STRIKE(1252) /0.4548328031E+01/
     *    HL(1252) /0.1500600000E+04/
     *    EQLAT(1252) /0.1108596140E+01/
     *    EQLON(1252) /0.2574104956E+01/
     *    SSLIP(1252) /0.1566000000E+01/
     *    DSLIP(1252) /0.0000000000E+00/
     *    DIP(1252) /0.1570796327E+01/
     *    DEPTH(1252) /0.1200000000E+05/
     *    WIDTH(1252) /0.3000000000E+04/
      DATA STRIKE(1253) /0.4548328031E+01/
     *    HL(1253) /0.1500600000E+04/
     *    EQLAT(1253) /0.1108673109E+01/
     *    EQLON(1253) /0.2573066660E+01/
     *    SSLIP(1253) /0.9500000000E+00/
     *    DSLIP(1253) /0.0000000000E+00/
     *    DIP(1253) /0.1570796327E+01/
     *    DEPTH(1253) /0.1200000000E+05/
     *    WIDTH(1253) /0.3000000000E+04/
      DATA STRIKE(1254) /0.4550073360E+01/
     *    HL(1254) /0.1500600000E+04/
     *    EQLAT(1254) /0.1108749380E+01/
     *    EQLON(1254) /0.2572028014E+01/
     *    SSLIP(1254) /0.3480000000E+00/
     *    DSLIP(1254) /0.0000000000E+00/
     *    DIP(1254) /0.1570796327E+01/
     *    DEPTH(1254) /0.1200000000E+05/
     *    WIDTH(1254) /0.3000000000E+04/
      DATA STRIKE(1255) /0.4551818689E+01/
     *    HL(1255) /0.1500600000E+04/
     *    EQLAT(1255) /0.1108825476E+01/
     *    EQLON(1255) /0.2570989020E+01/
     *    SSLIP(1255) /0.2000000000E-02/
     *    DSLIP(1255) /0.0000000000E+00/
     *    DIP(1255) /0.1570796327E+01/
     *    DEPTH(1255) /0.1200000000E+05/
     *    WIDTH(1255) /0.3000000000E+04/
      DATA STRIKE(1256) /0.4551818689E+01/
     *    HL(1256) /0.1500600000E+04/
     *    EQLAT(1256) /0.1108900874E+01/
     *    EQLON(1256) /0.2569949851E+01/
     *    SSLIP(1256) /0.0000000000E+00/
     *    DSLIP(1256) /0.0000000000E+00/
     *    DIP(1256) /0.1570796327E+01/
     *    DEPTH(1256) /0.1200000000E+05/
     *    WIDTH(1256) /0.3000000000E+04/
      DATA STRIKE(1257) /0.4862487296E+01/
     *    HL(1257) /0.1468400000E+04/
     *    EQLAT(1257) /0.1108904540E+01/
     *    EQLON(1257) /0.2568920630E+01/
     *    SSLIP(1257) /0.2310000000E+00/
     *    DSLIP(1257) /0.0000000000E+00/
     *    DIP(1257) /0.1570796327E+01/
     *    DEPTH(1257) /0.1200000000E+05/
     *    WIDTH(1257) /0.3000000000E+04/
      DATA STRIKE(1258) /0.4862487296E+01/
     *    HL(1258) /0.1468600000E+04/
     *    EQLAT(1258) /0.1108836297E+01/
     *    EQLON(1258) /0.2567901532E+01/
     *    SSLIP(1258) /0.4350000000E+00/
     *    DSLIP(1258) /0.0000000000E+00/
     *    DIP(1258) /0.1570796327E+01/
     *    DEPTH(1258) /0.1200000000E+05/
     *    WIDTH(1258) /0.3000000000E+04/
      DATA STRIKE(1259) /0.4862487296E+01/
     *    HL(1259) /0.1468800000E+04/
     *    EQLAT(1259) /0.1108768055E+01/
     *    EQLON(1259) /0.2566882434E+01/
     *    SSLIP(1259) /0.4970000000E+00/
     *    DSLIP(1259) /0.0000000000E+00/
     *    DIP(1259) /0.1570796327E+01/
     *    DEPTH(1259) /0.1200000000E+05/
     *    WIDTH(1259) /0.3000000000E+04/
      DATA STRIKE(1260) /0.4860741967E+01/
     *    HL(1260) /0.1469000000E+04/
     *    EQLAT(1260) /0.1108699987E+01/
     *    EQLON(1260) /0.2565863337E+01/
     *    SSLIP(1260) /0.3950000000E+00/
     *    DSLIP(1260) /-.4000000000E-01/
     *    DIP(1260) /0.1570796327E+01/
     *    DEPTH(1260) /0.1200000000E+05/
     *    WIDTH(1260) /0.3000000000E+04/
      DATA STRIKE(1261) /0.4858996638E+01/
     *    HL(1261) /0.1469200000E+04/
     *    EQLAT(1261) /0.1108631745E+01/
     *    EQLON(1261) /0.2564844413E+01/
     *    SSLIP(1261) /0.2070000000E+00/
     *    DSLIP(1261) /-.3900000000E+00/
     *    DIP(1261) /0.1570796327E+01/
     *    DEPTH(1261) /0.1200000000E+05/
     *    WIDTH(1261) /0.3000000000E+04/
      DATA STRIKE(1262) /0.4857251308E+01/
     *    HL(1262) /0.1469400000E+04/
     *    EQLAT(1262) /0.1108563677E+01/
     *    EQLON(1262) /0.2563825316E+01/
     *    SSLIP(1262) /0.8500000000E-01/
     *    DSLIP(1262) /-.1050000000E+01/
     *    DIP(1262) /0.1570796327E+01/
     *    DEPTH(1262) /0.1200000000E+05/
     *    WIDTH(1262) /0.3000000000E+04/
      DATA STRIKE(1263) /0.4855505979E+01/
     *    HL(1263) /0.1469600000E+04/
     *    EQLAT(1263) /0.1108495434E+01/
     *    EQLON(1263) /0.2562806218E+01/
     *    SSLIP(1263) /0.1430000000E+00/
     *    DSLIP(1263) /-.1860000000E+01/
     *    DIP(1263) /0.1570796327E+01/
     *    DEPTH(1263) /0.1200000000E+05/
     *    WIDTH(1263) /0.3000000000E+04/
      DATA STRIKE(1264) /0.4853760650E+01/
     *    HL(1264) /0.1469800000E+04/
     *    EQLAT(1264) /0.1108427192E+01/
     *    EQLON(1264) /0.2561787120E+01/
     *    SSLIP(1264) /0.3780000000E+00/
     *    DSLIP(1264) /-.2560000000E+01/
     *    DIP(1264) /0.1570796327E+01/
     *    DEPTH(1264) /0.1200000000E+05/
     *    WIDTH(1264) /0.3000000000E+04/
      DATA STRIKE(1265) /0.4852015321E+01/
     *    HL(1265) /0.1470000000E+04/
     *    EQLAT(1265) /0.1108359124E+01/
     *    EQLON(1265) /0.2560768197E+01/
     *    SSLIP(1265) /0.6940000000E+00/
     *    DSLIP(1265) /-.2960000000E+01/
     *    DIP(1265) /0.1570796327E+01/
     *    DEPTH(1265) /0.1200000000E+05/
     *    WIDTH(1265) /0.3000000000E+04/
      DATA STRIKE(1266) /0.4850269991E+01/
     *    HL(1266) /0.1470200000E+04/
     *    EQLAT(1266) /0.1108290882E+01/
     *    EQLON(1266) /0.2559749099E+01/
     *    SSLIP(1266) /0.9370000000E+00/
     *    DSLIP(1266) /-.3000000000E+01/
     *    DIP(1266) /0.1570796327E+01/
     *    DEPTH(1266) /0.1200000000E+05/
     *    WIDTH(1266) /0.3000000000E+04/
      DATA STRIKE(1267) /0.4848524662E+01/
     *    HL(1267) /0.1470400000E+04/
     *    EQLAT(1267) /0.1108222639E+01/
     *    EQLON(1267) /0.2558730002E+01/
     *    SSLIP(1267) /0.9870000000E+00/
     *    DSLIP(1267) /-.2980000000E+01/
     *    DIP(1267) /0.1570796327E+01/
     *    DEPTH(1267) /0.1200000000E+05/
     *    WIDTH(1267) /0.3000000000E+04/
      DATA STRIKE(1268) /0.4846779333E+01/
     *    HL(1268) /0.1470600000E+04/
     *    EQLAT(1268) /0.1108154572E+01/
     *    EQLON(1268) /0.2557710904E+01/
     *    SSLIP(1268) /0.8280000000E+00/
     *    DSLIP(1268) /-.2830000000E+01/
     *    DIP(1268) /0.1570796327E+01/
     *    DEPTH(1268) /0.1200000000E+05/
     *    WIDTH(1268) /0.3000000000E+04/
      DATA STRIKE(1269) /0.4845034004E+01/
     *    HL(1269) /0.1470800000E+04/
     *    EQLAT(1269) /0.1108086329E+01/
     *    EQLON(1269) /0.2556691981E+01/
     *    SSLIP(1269) /0.5410000000E+00/
     *    DSLIP(1269) /-.2650000000E+01/
     *    DIP(1269) /0.1570796327E+01/
     *    DEPTH(1269) /0.1200000000E+05/
     *    WIDTH(1269) /0.3000000000E+04/
      DATA STRIKE(1270) /0.4843288674E+01/
     *    HL(1270) /0.1470900000E+04/
     *    EQLAT(1270) /0.1108018261E+01/
     *    EQLON(1270) /0.2555672883E+01/
     *    SSLIP(1270) /0.2140000000E+00/
     *    DSLIP(1270) /-.2480000000E+01/
     *    DIP(1270) /0.1570796327E+01/
     *    DEPTH(1270) /0.1200000000E+05/
     *    WIDTH(1270) /0.3000000000E+04/
      DATA STRIKE(1271) /0.4841543345E+01/
     *    HL(1271) /0.1471100000E+04/
     *    EQLAT(1271) /0.1107950019E+01/
     *    EQLON(1271) /0.2554653785E+01/
     *    SSLIP(1271) /0.0000000000E+00/
     *    DSLIP(1271) /-.2360000000E+01/
     *    DIP(1271) /0.1570796327E+01/
     *    DEPTH(1271) /0.1200000000E+05/
     *    WIDTH(1271) /0.3000000000E+04/
      DATA STRIKE(1272) /0.4839798016E+01/
     *    HL(1272) /0.1471300000E+04/
     *    EQLAT(1272) /0.1107881777E+01/
     *    EQLON(1272) /0.2553634687E+01/
     *    SSLIP(1272) /0.0000000000E+00/
     *    DSLIP(1272) /-.2390000000E+01/
     *    DIP(1272) /0.1570796327E+01/
     *    DEPTH(1272) /0.1200000000E+05/
     *    WIDTH(1272) /0.3000000000E+04/
      DATA STRIKE(1273) /0.4967207051E+01/
     *    HL(1273) /0.1450200000E+04/
     *    EQLAT(1273) /0.1107785434E+01/
     *    EQLON(1273) /0.2552637057E+01/
     *    SSLIP(1273) /0.3860000000E+00/
     *    DSLIP(1273) /-.2510000000E+01/
     *    DIP(1273) /0.1570796327E+01/
     *    DEPTH(1273) /0.1200000000E+05/
     *    WIDTH(1273) /0.3000000000E+04/
      DATA STRIKE(1274) /0.4965461722E+01/
     *    HL(1274) /0.1450500000E+04/
     *    EQLAT(1274) /0.1107660818E+01/
     *    EQLON(1274) /0.2551660720E+01/
     *    SSLIP(1274) /0.6770000000E+00/
     *    DSLIP(1274) /-.2140000000E+01/
     *    DIP(1274) /0.1570796327E+01/
     *    DEPTH(1274) /0.1200000000E+05/
     *    WIDTH(1274) /0.3000000000E+04/
      DATA STRIKE(1275) /0.4963716393E+01/
     *    HL(1275) /0.1450900000E+04/
     *    EQLAT(1275) /0.1107536027E+01/
     *    EQLON(1275) /0.2550684208E+01/
     *    SSLIP(1275) /0.7910000000E+00/
     *    DSLIP(1275) /-.1310000000E+01/
     *    DIP(1275) /0.1570796327E+01/
     *    DEPTH(1275) /0.1200000000E+05/
     *    WIDTH(1275) /0.3000000000E+04/
      DATA STRIKE(1276) /0.4961971063E+01/
     *    HL(1276) /0.1451200000E+04/
     *    EQLAT(1276) /0.1107411410E+01/
     *    EQLON(1276) /0.2549707871E+01/
     *    SSLIP(1276) /0.7710000000E+00/
     *    DSLIP(1276) /-.4500000000E+00/
     *    DIP(1276) /0.1570796327E+01/
     *    DEPTH(1276) /0.1200000000E+05/
     *    WIDTH(1276) /0.3000000000E+04/
      DATA STRIKE(1277) /0.4960225734E+01/
     *    HL(1277) /0.1451500000E+04/
     *    EQLAT(1277) /0.1107286794E+01/
     *    EQLON(1277) /0.2548731534E+01/
     *    SSLIP(1277) /0.7410000000E+00/
     *    DSLIP(1277) /0.0000000000E+00/
     *    DIP(1277) /0.1570796327E+01/
     *    DEPTH(1277) /0.1200000000E+05/
     *    WIDTH(1277) /0.3000000000E+04/
      DATA STRIKE(1278) /0.4956735076E+01/
     *    HL(1278) /0.1451900000E+04/
     *    EQLAT(1278) /0.1107162003E+01/
     *    EQLON(1278) /0.2547755022E+01/
     *    SSLIP(1278) /0.1198000000E+01/
     *    DSLIP(1278) /0.0000000000E+00/
     *    DIP(1278) /0.1570796327E+01/
     *    DEPTH(1278) /0.1200000000E+05/
     *    WIDTH(1278) /0.3000000000E+04/
      DATA STRIKE(1279) /0.4954989746E+01/
     *    HL(1279) /0.1452200000E+04/
     *    EQLAT(1279) /0.1107037386E+01/
     *    EQLON(1279) /0.2546778685E+01/
     *    SSLIP(1279) /0.2938000000E+01/
     *    DSLIP(1279) /0.0000000000E+00/
     *    DIP(1279) /0.1570796327E+01/
     *    DEPTH(1279) /0.1200000000E+05/
     *    WIDTH(1279) /0.3000000000E+04/
      DATA STRIKE(1280) /0.5239478414E+01/
     *    HL(1280) /0.1384800000E+04/
     *    EQLAT(1280) /0.1106865995E+01/
     *    EQLON(1280) /0.2545872335E+01/
     *    SSLIP(1280) /0.5735000000E+01/
     *    DSLIP(1280) /0.0000000000E+00/
     *    DIP(1280) /0.1570796327E+01/
     *    DEPTH(1280) /0.1200000000E+05/
     *    WIDTH(1280) /0.3000000000E+04/
      DATA STRIKE(1281) /0.5237733085E+01/
     *    HL(1281) /0.1385300000E+04/
     *    EQLAT(1281) /0.1106647829E+01/
     *    EQLON(1281) /0.2545035799E+01/
     *    SSLIP(1281) /0.7253000000E+01/
     *    DSLIP(1281) /0.0000000000E+00/
     *    DIP(1281) /0.1570796327E+01/
     *    DEPTH(1281) /0.1200000000E+05/
     *    WIDTH(1281) /0.3000000000E+04/
      DATA STRIKE(1282) /0.5235987756E+01/
     *    HL(1282) /0.1385700000E+04/
     *    EQLAT(1282) /0.1106429663E+01/
     *    EQLON(1282) /0.2544199437E+01/
     *    SSLIP(1282) /0.7050000000E+01/
     *    DSLIP(1282) /0.0000000000E+00/
     *    DIP(1282) /0.1570796327E+01/
     *    DEPTH(1282) /0.1200000000E+05/
     *    WIDTH(1282) /0.3000000000E+04/
      DATA STRIKE(1283) /0.5234242427E+01/
     *    HL(1283) /0.1386200000E+04/
     *    EQLAT(1283) /0.1106211497E+01/
     *    EQLON(1283) /0.2543362901E+01/
     *    SSLIP(1283) /0.5718000000E+01/
     *    DSLIP(1283) /0.0000000000E+00/
     *    DIP(1283) /0.1570796327E+01/
     *    DEPTH(1283) /0.1200000000E+05/
     *    WIDTH(1283) /0.3000000000E+04/
      DATA STRIKE(1284) /0.5232497097E+01/
     *    HL(1284) /0.1386600000E+04/
     *    EQLAT(1284) /0.1105993330E+01/
     *    EQLON(1284) /0.2542526539E+01/
     *    SSLIP(1284) /0.3920000000E+01/
     *    DSLIP(1284) /0.0000000000E+00/
     *    DIP(1284) /0.1570796327E+01/
     *    DEPTH(1284) /0.1200000000E+05/
     *    WIDTH(1284) /0.3000000000E+04/
      DATA STRIKE(1285) /0.5230751768E+01/
     *    HL(1285) /0.1387100000E+04/
     *    EQLAT(1285) /0.1105775164E+01/
     *    EQLON(1285) /0.2541690003E+01/
     *    SSLIP(1285) /0.2415000000E+01/
     *    DSLIP(1285) /0.0000000000E+00/
     *    DIP(1285) /0.1570796327E+01/
     *    DEPTH(1285) /0.1200000000E+05/
     *    WIDTH(1285) /0.3000000000E+04/
      DATA STRIKE(1286) /0.5229006439E+01/
     *    HL(1286) /0.1387500000E+04/
     *    EQLAT(1286) /0.1105556998E+01/
     *    EQLON(1286) /0.2540853641E+01/
     *    SSLIP(1286) /0.2099000000E+01/
     *    DSLIP(1286) /0.0000000000E+00/
     *    DIP(1286) /0.1570796327E+01/
     *    DEPTH(1286) /0.1200000000E+05/
     *    WIDTH(1286) /0.3000000000E+04/
      DATA STRIKE(1287) /0.5227261110E+01/
     *    HL(1287) /0.1388000000E+04/
     *    EQLAT(1287) /0.1105338832E+01/
     *    EQLON(1287) /0.2540017105E+01/
     *    SSLIP(1287) /0.3350000000E+01/
     *    DSLIP(1287) /0.0000000000E+00/
     *    DIP(1287) /0.1570796327E+01/
     *    DEPTH(1287) /0.1200000000E+05/
     *    WIDTH(1287) /0.3000000000E+04/
      DATA STRIKE(1288) /0.5047492197E+01/
     *    HL(1288) /0.1434000000E+04/
     *    EQLAT(1288) /0.1105152954E+01/
     *    EQLON(1288) /0.2539129605E+01/
     *    SSLIP(1288) /0.5436000000E+01/
     *    DSLIP(1288) /0.0000000000E+00/
     *    DIP(1288) /0.1570796327E+01/
     *    DEPTH(1288) /0.1200000000E+05/
     *    WIDTH(1288) /0.3000000000E+04/
      DATA STRIKE(1289) /0.5045746868E+01/
     *    HL(1289) /0.1434400000E+04/
     *    EQLAT(1289) /0.1104999540E+01/
     *    EQLON(1289) /0.2538190967E+01/
     *    SSLIP(1289) /0.6317000000E+01/
     *    DSLIP(1289) /0.0000000000E+00/
     *    DIP(1289) /0.1570796327E+01/
     *    DEPTH(1289) /0.1200000000E+05/
     *    WIDTH(1289) /0.3000000000E+04/
      DATA STRIKE(1290) /0.5044001538E+01/
     *    HL(1290) /0.1434700000E+04/
     *    EQLAT(1290) /0.1104846125E+01/
     *    EQLON(1290) /0.2537252329E+01/
     *    SSLIP(1290) /0.5810000000E+01/
     *    DSLIP(1290) /0.0000000000E+00/
     *    DIP(1290) /0.1570796327E+01/
     *    DEPTH(1290) /0.1200000000E+05/
     *    WIDTH(1290) /0.3000000000E+04/
      DATA STRIKE(1291) /0.5042256209E+01/
     *    HL(1291) /0.1435100000E+04/
     *    EQLAT(1291) /0.1104692711E+01/
     *    EQLON(1291) /0.2536313516E+01/
     *    SSLIP(1291) /0.4650000000E+01/
     *    DSLIP(1291) /0.0000000000E+00/
     *    DIP(1291) /0.1570796327E+01/
     *    DEPTH(1291) /0.1200000000E+05/
     *    WIDTH(1291) /0.3000000000E+04/
      DATA STRIKE(1292) /0.5040510880E+01/
     *    HL(1292) /0.1435500000E+04/
     *    EQLAT(1292) /0.1104539297E+01/
     *    EQLON(1292) /0.2535374878E+01/
     *    SSLIP(1292) /0.3695000000E+01/
     *    DSLIP(1292) /0.0000000000E+00/
     *    DIP(1292) /0.1570796327E+01/
     *    DEPTH(1292) /0.1200000000E+05/
     *    WIDTH(1292) /0.3000000000E+04/
      DATA STRIKE(1293) /0.5038765551E+01/
     *    HL(1293) /0.1435900000E+04/
     *    EQLAT(1293) /0.1104385882E+01/
     *    EQLON(1293) /0.2534436240E+01/
     *    SSLIP(1293) /0.3471000000E+01/
     *    DSLIP(1293) /0.0000000000E+00/
     *    DIP(1293) /0.1570796327E+01/
     *    DEPTH(1293) /0.1200000000E+05/
     *    WIDTH(1293) /0.3000000000E+04/
      DATA STRIKE(1294) /0.5037020221E+01/
     *    HL(1294) /0.1436300000E+04/
     *    EQLAT(1294) /0.1104232468E+01/
     *    EQLON(1294) /0.2533497602E+01/
     *    SSLIP(1294) /0.4039000000E+01/
     *    DSLIP(1294) /0.0000000000E+00/
     *    DIP(1294) /0.1570796327E+01/
     *    DEPTH(1294) /0.1200000000E+05/
     *    WIDTH(1294) /0.3000000000E+04/
      DATA STRIKE(1295) /0.5035274892E+01/
     *    HL(1295) /0.1436700000E+04/
     *    EQLAT(1295) /0.1104079053E+01/
     *    EQLON(1295) /0.2532558964E+01/
     *    SSLIP(1295) /0.5043000000E+01/
     *    DSLIP(1295) /0.0000000000E+00/
     *    DIP(1295) /0.1570796327E+01/
     *    DEPTH(1295) /0.1200000000E+05/
     *    WIDTH(1295) /0.3000000000E+04/
      DATA STRIKE(1296) /0.5033529563E+01/
     *    HL(1296) /0.1437100000E+04/
     *    EQLAT(1296) /0.1103925639E+01/
     *    EQLON(1296) /0.2531620151E+01/
     *    SSLIP(1296) /0.5883000000E+01/
     *    DSLIP(1296) /0.0000000000E+00/
     *    DIP(1296) /0.1570796327E+01/
     *    DEPTH(1296) /0.1200000000E+05/
     *    WIDTH(1296) /0.3000000000E+04/
      DATA STRIKE(1297) /0.5031784233E+01/
     *    HL(1297) /0.1437400000E+04/
     *    EQLAT(1297) /0.1103772224E+01/
     *    EQLON(1297) /0.2530681513E+01/
     *    SSLIP(1297) /0.5988000000E+01/
     *    DSLIP(1297) /0.0000000000E+00/
     *    DIP(1297) /0.1570796327E+01/
     *    DEPTH(1297) /0.1200000000E+05/
     *    WIDTH(1297) /0.3000000000E+04/
      DATA STRIKE(1298) /0.5030038904E+01/
     *    HL(1298) /0.1437800000E+04/
     *    EQLAT(1298) /0.1103618810E+01/
     *    EQLON(1298) /0.2529742875E+01/
     *    SSLIP(1298) /0.5103000000E+01/
     *    DSLIP(1298) /0.0000000000E+00/
     *    DIP(1298) /0.1570796327E+01/
     *    DEPTH(1298) /0.1200000000E+05/
     *    WIDTH(1298) /0.3000000000E+04/
      DATA STRIKE(1299) /0.5153957281E+01/
     *    HL(1299) /0.1412200000E+04/
     *    EQLAT(1299) /0.1103441310E+01/
     *    EQLON(1299) /0.2528837224E+01/
     *    SSLIP(1299) /0.3555000000E+01/
     *    DSLIP(1299) /0.0000000000E+00/
     *    DIP(1299) /0.1570796327E+01/
     *    DEPTH(1299) /0.1200000000E+05/
     *    WIDTH(1299) /0.3000000000E+04/
      DATA STRIKE(1300) /0.5152211952E+01/
     *    HL(1300) /0.1412700000E+04/
     *    EQLAT(1300) /0.1103239899E+01/
     *    EQLON(1300) /0.2527964559E+01/
     *    SSLIP(1300) /0.2424000000E+01/
     *    DSLIP(1300) /0.0000000000E+00/
     *    DIP(1300) /0.1570796327E+01/
     *    DEPTH(1300) /0.1200000000E+05/
     *    WIDTH(1300) /0.3000000000E+04/
      DATA STRIKE(1301) /0.5150466623E+01/
     *    HL(1301) /0.1413100000E+04/
     *    EQLAT(1301) /0.1103038313E+01/
     *    EQLON(1301) /0.2527091895E+01/
     *    SSLIP(1301) /0.1933000000E+01/
     *    DSLIP(1301) /0.0000000000E+00/
     *    DIP(1301) /0.1570796327E+01/
     *    DEPTH(1301) /0.1200000000E+05/
     *    WIDTH(1301) /0.3000000000E+04/
      DATA STRIKE(1302) /0.5183627878E+01/
     *    HL(1302) /0.1413500000E+04/
     *    EQLAT(1302) /0.1102836902E+01/
     *    EQLON(1302) /0.2526219230E+01/
     *    SSLIP(1302) /0.1899000000E+01/
     *    DSLIP(1302) /0.0000000000E+00/
     *    DIP(1302) /0.1570796327E+01/
     *    DEPTH(1302) /0.1200000000E+05/
     *    WIDTH(1302) /0.3000000000E+04/
      DATA STRIKE(1303) /0.5181882549E+01/
     *    HL(1303) /0.1414000000E+04/
     *    EQLAT(1303) /0.1102635491E+01/
     *    EQLON(1303) /0.2525346565E+01/
     *    SSLIP(1303) /0.2029000000E+01/
     *    DSLIP(1303) /0.0000000000E+00/
     *    DIP(1303) /0.1570796327E+01/
     *    DEPTH(1303) /0.1200000000E+05/
     *    WIDTH(1303) /0.3000000000E+04/
      DATA STRIKE(1304) /0.5180137220E+01/
     *    HL(1304) /0.1414400000E+04/
     *    EQLAT(1304) /0.1102433906E+01/
     *    EQLON(1304) /0.2524473901E+01/
     *    SSLIP(1304) /0.2115000000E+01/
     *    DSLIP(1304) /0.0000000000E+00/
     *    DIP(1304) /0.1570796327E+01/
     *    DEPTH(1304) /0.1200000000E+05/
     *    WIDTH(1304) /0.3000000000E+04/
      DATA STRIKE(1305) /0.5178391891E+01/
     *    HL(1305) /0.1414900000E+04/
     *    EQLAT(1305) /0.1102232495E+01/
     *    EQLON(1305) /0.2523601236E+01/
     *    SSLIP(1305) /0.2067000000E+01/
     *    DSLIP(1305) /0.0000000000E+00/
     *    DIP(1305) /0.1570796327E+01/
     *    DEPTH(1305) /0.1200000000E+05/
     *    WIDTH(1305) /0.3000000000E+04/
      DATA STRIKE(1306) /0.5176646561E+01/
     *    HL(1306) /0.1415300000E+04/
     *    EQLAT(1306) /0.1102031084E+01/
     *    EQLON(1306) /0.2522728571E+01/
     *    SSLIP(1306) /0.1890000000E+01/
     *    DSLIP(1306) /0.0000000000E+00/
     *    DIP(1306) /0.1570796327E+01/
     *    DEPTH(1306) /0.1200000000E+05/
     *    WIDTH(1306) /0.3000000000E+04/
      DATA STRIKE(1307) /0.5174901232E+01/
     *    HL(1307) /0.1415800000E+04/
     *    EQLAT(1307) /0.1101829673E+01/
     *    EQLON(1307) /0.2521855907E+01/
     *    SSLIP(1307) /0.1647000000E+01/
     *    DSLIP(1307) /0.0000000000E+00/
     *    DIP(1307) /0.1570796327E+01/
     *    DEPTH(1307) /0.1200000000E+05/
     *    WIDTH(1307) /0.3000000000E+04/
      DATA STRIKE(1308) /0.5173155903E+01/
     *    HL(1308) /0.1416200000E+04/
     *    EQLAT(1308) /0.1101628087E+01/
     *    EQLON(1308) /0.2520983242E+01/
     *    SSLIP(1308) /0.1447000000E+01/
     *    DSLIP(1308) /0.0000000000E+00/
     *    DIP(1308) /0.1570796327E+01/
     *    DEPTH(1308) /0.1200000000E+05/
     *    WIDTH(1308) /0.3000000000E+04/
      DATA STRIKE(1309) /0.5171410574E+01/
     *    HL(1309) /0.1416700000E+04/
     *    EQLAT(1309) /0.1101426676E+01/
     *    EQLON(1309) /0.2520110578E+01/
     *    SSLIP(1309) /0.1395000000E+01/
     *    DSLIP(1309) /-.5000000000E-01/
     *    DIP(1309) /0.1570796327E+01/
     *    DEPTH(1309) /0.1200000000E+05/
     *    WIDTH(1309) /0.3000000000E+04/
      DATA STRIKE(1310) /0.5169665244E+01/
     *    HL(1310) /0.1417100000E+04/
     *    EQLAT(1310) /0.1101225265E+01/
     *    EQLON(1310) /0.2519237913E+01/
     *    SSLIP(1310) /0.1543000000E+01/
     *    DSLIP(1310) /-.3100000000E+00/
     *    DIP(1310) /0.1570796327E+01/
     *    DEPTH(1310) /0.1200000000E+05/
     *    WIDTH(1310) /0.3000000000E+04/
      DATA STRIKE(1311) /0.5167919915E+01/
     *    HL(1311) /0.1417600000E+04/
     *    EQLAT(1311) /0.1101023680E+01/
     *    EQLON(1311) /0.2518365248E+01/
     *    SSLIP(1311) /0.1874000000E+01/
     *    DSLIP(1311) /-.7800000000E+00/
     *    DIP(1311) /0.1570796327E+01/
     *    DEPTH(1311) /0.1200000000E+05/
     *    WIDTH(1311) /0.3000000000E+04/
      DATA STRIKE(1312) /0.5166174586E+01/
     *    HL(1312) /0.1418000000E+04/
     *    EQLAT(1312) /0.1100822269E+01/
     *    EQLON(1312) /0.2517492584E+01/
     *    SSLIP(1312) /0.2332000000E+01/
     *    DSLIP(1312) /-.1350000000E+01/
     *    DIP(1312) /0.1570796327E+01/
     *    DEPTH(1312) /0.1200000000E+05/
     *    WIDTH(1312) /0.3000000000E+04/
      DATA STRIKE(1313) /0.5213298476E+01/
     *    HL(1313) /0.1426200000E+04/
     *    EQLAT(1313) /0.1100610909E+01/
     *    EQLON(1313) /0.2516628820E+01/
     *    SSLIP(1313) /0.2888000000E+01/
     *    DSLIP(1313) /-.1960000000E+01/
     *    DIP(1313) /0.1570796327E+01/
     *    DEPTH(1313) /0.1200000000E+05/
     *    WIDTH(1313) /0.3000000000E+04/
      DATA STRIKE(1314) /0.5211553146E+01/
     *    HL(1314) /0.1426600000E+04/
     *    EQLAT(1314) /0.1100389427E+01/
     *    EQLON(1314) /0.2515773958E+01/
     *    SSLIP(1314) /0.3575000000E+01/
     *    DSLIP(1314) /-.2500000000E+01/
     *    DIP(1314) /0.1570796327E+01/
     *    DEPTH(1314) /0.1200000000E+05/
     *    WIDTH(1314) /0.3000000000E+04/
      DATA STRIKE(1315) /0.5209807817E+01/
     *    HL(1315) /0.1427100000E+04/
     *    EQLAT(1315) /0.1100167945E+01/
     *    EQLON(1315) /0.2514918921E+01/
     *    SSLIP(1315) /0.4372000000E+01/
     *    DSLIP(1315) /-.2870000000E+01/
     *    DIP(1315) /0.1570796327E+01/
     *    DEPTH(1315) /0.1200000000E+05/
     *    WIDTH(1315) /0.3000000000E+04/
      DATA STRIKE(1316) /0.5208062488E+01/
     *    HL(1316) /0.1427600000E+04/
     *    EQLAT(1316) /0.1099946463E+01/
     *    EQLON(1316) /0.2514064059E+01/
     *    SSLIP(1316) /0.5159000000E+01/
     *    DSLIP(1316) /-.3000000000E+01/
     *    DIP(1316) /0.1570796327E+01/
     *    DEPTH(1316) /0.1200000000E+05/
     *    WIDTH(1316) /0.3000000000E+04/
      DATA STRIKE(1317) /0.5206317159E+01/
     *    HL(1317) /0.1428000000E+04/
     *    EQLAT(1317) /0.1099724980E+01/
     *    EQLON(1317) /0.2513209197E+01/
     *    SSLIP(1317) /0.5730000000E+01/
     *    DSLIP(1317) /-.3000000000E+01/
     *    DIP(1317) /0.1570796327E+01/
     *    DEPTH(1317) /0.1200000000E+05/
     *    WIDTH(1317) /0.3000000000E+04/
      DATA STRIKE(1318) /0.5204571829E+01/
     *    HL(1318) /0.1428500000E+04/
     *    EQLAT(1318) /0.1099503498E+01/
     *    EQLON(1318) /0.2512354160E+01/
     *    SSLIP(1318) /0.5870000000E+01/
     *    DSLIP(1318) /-.3000000000E+01/
     *    DIP(1318) /0.1570796327E+01/
     *    DEPTH(1318) /0.1200000000E+05/
     *    WIDTH(1318) /0.3000000000E+04/
      DATA STRIKE(1319) /0.5202826500E+01/
     *    HL(1319) /0.1429000000E+04/
     *    EQLAT(1319) /0.1099282016E+01/
     *    EQLON(1319) /0.2511499298E+01/
     *    SSLIP(1319) /0.5523000000E+01/
     *    DSLIP(1319) /-.3000000000E+01/
     *    DIP(1319) /0.1570796327E+01/
     *    DEPTH(1319) /0.1200000000E+05/
     *    WIDTH(1319) /0.3000000000E+04/
      DATA STRIKE(1320) /0.5201081171E+01/
     *    HL(1320) /0.1429500000E+04/
     *    EQLAT(1320) /0.1099060534E+01/
     *    EQLON(1320) /0.2510644435E+01/
     *    SSLIP(1320) /0.4859000000E+01/
     *    DSLIP(1320) /-.2880000000E+01/
     *    DIP(1320) /0.1570796327E+01/
     *    DEPTH(1320) /0.1200000000E+05/
     *    WIDTH(1320) /0.3000000000E+04/
      DATA STRIKE(1321) /0.5199335842E+01/
     *    HL(1321) /0.1429900000E+04/
     *    EQLAT(1321) /0.1098839051E+01/
     *    EQLON(1321) /0.2509789398E+01/
     *    SSLIP(1321) /0.4091000000E+01/
     *    DSLIP(1321) /-.2340000000E+01/
     *    DIP(1321) /0.1570796327E+01/
     *    DEPTH(1321) /0.1200000000E+05/
     *    WIDTH(1321) /0.3000000000E+04/
      DATA STRIKE(1322) /0.5197590512E+01/
     *    HL(1322) /0.1430400000E+04/
     *    EQLAT(1322) /0.1098617743E+01/
     *    EQLON(1322) /0.2508934536E+01/
     *    SSLIP(1322) /0.3330000000E+01/
     *    DSLIP(1322) /-.1490000000E+01/
     *    DIP(1322) /0.1570796327E+01/
     *    DEPTH(1322) /0.1200000000E+05/
     *    WIDTH(1322) /0.3000000000E+04/
      DATA STRIKE(1323) /0.5195845183E+01/
     *    HL(1323) /0.1430900000E+04/
     *    EQLAT(1323) /0.1098396261E+01/
     *    EQLON(1323) /0.2508079674E+01/
     *    SSLIP(1323) /0.2635000000E+01/
     *    DSLIP(1323) /-.7200000000E+00/
     *    DIP(1323) /0.1570796327E+01/
     *    DEPTH(1323) /0.1200000000E+05/
     *    WIDTH(1323) /0.3000000000E+04/
      DATA STRIKE(1324) /0.5229006439E+01/
     *    HL(1324) /0.1431300000E+04/
     *    EQLAT(1324) /0.1098174779E+01/
     *    EQLON(1324) /0.2507224637E+01/
     *    SSLIP(1324) /0.2020000000E+01/
     *    DSLIP(1324) /-.2700000000E+00/
     *    DIP(1324) /0.1570796327E+01/
     *    DEPTH(1324) /0.1200000000E+05/
     *    WIDTH(1324) /0.3000000000E+04/
      DATA STRIKE(1325) /0.5227261110E+01/
     *    HL(1325) /0.1431800000E+04/
     *    EQLAT(1325) /0.1097953297E+01/
     *    EQLON(1325) /0.2506369775E+01/
     *    SSLIP(1325) /0.1527000000E+01/
     *    DSLIP(1325) /-.6000000000E-01/
     *    DIP(1325) /0.1570796327E+01/
     *    DEPTH(1325) /0.1200000000E+05/
     *    WIDTH(1325) /0.3000000000E+04/
      DATA STRIKE(1326) /0.5225515780E+01/
     *    HL(1326) /0.1432300000E+04/
     *    EQLAT(1326) /0.1097731814E+01/
     *    EQLON(1326) /0.2505514913E+01/
     *    SSLIP(1326) /0.1191000000E+01/
     *    DSLIP(1326) /0.0000000000E+00/
     *    DIP(1326) /0.1570796327E+01/
     *    DEPTH(1326) /0.1200000000E+05/
     *    WIDTH(1326) /0.3000000000E+04/
      DATA STRIKE(1327) /0.5223770451E+01/
     *    HL(1327) /0.1432700000E+04/
     *    EQLAT(1327) /0.1097510332E+01/
     *    EQLON(1327) /0.2504659876E+01/
     *    SSLIP(1327) /0.1020000000E+01/
     *    DSLIP(1327) /0.0000000000E+00/
     *    DIP(1327) /0.1570796327E+01/
     *    DEPTH(1327) /0.1200000000E+05/
     *    WIDTH(1327) /0.3000000000E+04/
      DATA STRIKE(1328) /0.5222025122E+01/
     *    HL(1328) /0.1433200000E+04/
     *    EQLAT(1328) /0.1097288850E+01/
     *    EQLON(1328) /0.2503805014E+01/
     *    SSLIP(1328) /0.9440000000E+00/
     *    DSLIP(1328) /0.0000000000E+00/
     *    DIP(1328) /0.1570796327E+01/
     *    DEPTH(1328) /0.1200000000E+05/
     *    WIDTH(1328) /0.3000000000E+04/
      DATA STRIKE(1329) /0.5220279793E+01/
     *    HL(1329) /0.1433700000E+04/
     *    EQLAT(1329) /0.1097067368E+01/
     *    EQLON(1329) /0.2502950151E+01/
     *    SSLIP(1329) /0.9080000000E+00/
     *    DSLIP(1329) /0.0000000000E+00/
     *    DIP(1329) /0.1570796327E+01/
     *    DEPTH(1329) /0.1500000000E+05/
     *    WIDTH(1329) /0.3000000000E+04/
      DATA STRIKE(1330) /0.5218534463E+01/
     *    HL(1330) /0.1434100000E+04/
     *    EQLAT(1330) /0.1096845885E+01/
     *    EQLON(1330) /0.2502095114E+01/
     *    SSLIP(1330) /0.9700000000E+00/
     *    DSLIP(1330) /0.0000000000E+00/
     *    DIP(1330) /0.1570796327E+01/
     *    DEPTH(1330) /0.1500000000E+05/
     *    WIDTH(1330) /0.3000000000E+04/
      DATA STRIKE(1331) /0.4544837372E+01/
     *    HL(1331) /0.1500600000E+04/
     *    EQLAT(1331) /0.1108284599E+01/
     *    EQLON(1331) /0.2578255000E+01/
     *    SSLIP(1331) /0.2712000000E+01/
     *    DSLIP(1331) /0.0000000000E+00/
     *    DIP(1331) /0.1570796327E+01/
     *    DEPTH(1331) /0.1500000000E+05/
     *    WIDTH(1331) /0.3000000000E+04/
      DATA STRIKE(1332) /0.4544837372E+01/
     *    HL(1332) /0.1500600000E+04/
     *    EQLAT(1332) /0.1108363138E+01/
     *    EQLON(1332) /0.2577217925E+01/
     *    SSLIP(1332) /0.2823000000E+01/
     *    DSLIP(1332) /0.0000000000E+00/
     *    DIP(1332) /0.1570796327E+01/
     *    DEPTH(1332) /0.1500000000E+05/
     *    WIDTH(1332) /0.3000000000E+04/
      DATA STRIKE(1333) /0.4546582701E+01/
     *    HL(1333) /0.1500600000E+04/
     *    EQLAT(1333) /0.1108441329E+01/
     *    EQLON(1333) /0.2576180502E+01/
     *    SSLIP(1333) /0.2893000000E+01/
     *    DSLIP(1333) /0.0000000000E+00/
     *    DIP(1333) /0.1570796327E+01/
     *    DEPTH(1333) /0.1500000000E+05/
     *    WIDTH(1333) /0.3000000000E+04/
      DATA STRIKE(1334) /0.4546582701E+01/
     *    HL(1334) /0.1500600000E+04/
     *    EQLAT(1334) /0.1108518996E+01/
     *    EQLON(1334) /0.2575142903E+01/
     *    SSLIP(1334) /0.2692000000E+01/
     *    DSLIP(1334) /0.0000000000E+00/
     *    DIP(1334) /0.1570796327E+01/
     *    DEPTH(1334) /0.1500000000E+05/
     *    WIDTH(1334) /0.3000000000E+04/
      DATA STRIKE(1335) /0.4548328031E+01/
     *    HL(1335) /0.1500600000E+04/
     *    EQLAT(1335) /0.1108596140E+01/
     *    EQLON(1335) /0.2574104956E+01/
     *    SSLIP(1335) /0.2135000000E+01/
     *    DSLIP(1335) /0.0000000000E+00/
     *    DIP(1335) /0.1570796327E+01/
     *    DEPTH(1335) /0.1500000000E+05/
     *    WIDTH(1335) /0.3000000000E+04/
      DATA STRIKE(1336) /0.4548328031E+01/
     *    HL(1336) /0.1500600000E+04/
     *    EQLAT(1336) /0.1108673109E+01/
     *    EQLON(1336) /0.2573066660E+01/
     *    SSLIP(1336) /0.1333000000E+01/
     *    DSLIP(1336) /0.0000000000E+00/
     *    DIP(1336) /0.1570796327E+01/
     *    DEPTH(1336) /0.1500000000E+05/
     *    WIDTH(1336) /0.3000000000E+04/
      DATA STRIKE(1337) /0.4550073360E+01/
     *    HL(1337) /0.1500600000E+04/
     *    EQLAT(1337) /0.1108749380E+01/
     *    EQLON(1337) /0.2572028014E+01/
     *    SSLIP(1337) /0.5460000000E+00/
     *    DSLIP(1337) /0.0000000000E+00/
     *    DIP(1337) /0.1570796327E+01/
     *    DEPTH(1337) /0.1500000000E+05/
     *    WIDTH(1337) /0.3000000000E+04/
      DATA STRIKE(1338) /0.4551818689E+01/
     *    HL(1338) /0.1500600000E+04/
     *    EQLAT(1338) /0.1108825476E+01/
     *    EQLON(1338) /0.2570989020E+01/
     *    SSLIP(1338) /0.5300000000E-01/
     *    DSLIP(1338) /0.0000000000E+00/
     *    DIP(1338) /0.1570796327E+01/
     *    DEPTH(1338) /0.1500000000E+05/
     *    WIDTH(1338) /0.3000000000E+04/
      DATA STRIKE(1339) /0.4551818689E+01/
     *    HL(1339) /0.1500600000E+04/
     *    EQLAT(1339) /0.1108900874E+01/
     *    EQLON(1339) /0.2569949851E+01/
     *    SSLIP(1339) /0.0000000000E+00/
     *    DSLIP(1339) /0.0000000000E+00/
     *    DIP(1339) /0.1570796327E+01/
     *    DEPTH(1339) /0.1500000000E+05/
     *    WIDTH(1339) /0.3000000000E+04/
      DATA STRIKE(1340) /0.4862487296E+01/
     *    HL(1340) /0.1468400000E+04/
     *    EQLAT(1340) /0.1108904540E+01/
     *    EQLON(1340) /0.2568920630E+01/
     *    SSLIP(1340) /0.2140000000E+00/
     *    DSLIP(1340) /0.0000000000E+00/
     *    DIP(1340) /0.1570796327E+01/
     *    DEPTH(1340) /0.1500000000E+05/
     *    WIDTH(1340) /0.3000000000E+04/
      DATA STRIKE(1341) /0.4862487296E+01/
     *    HL(1341) /0.1468600000E+04/
     *    EQLAT(1341) /0.1108836297E+01/
     *    EQLON(1341) /0.2567901532E+01/
     *    SSLIP(1341) /0.3950000000E+00/
     *    DSLIP(1341) /0.0000000000E+00/
     *    DIP(1341) /0.1570796327E+01/
     *    DEPTH(1341) /0.1500000000E+05/
     *    WIDTH(1341) /0.3000000000E+04/
      DATA STRIKE(1342) /0.4862487296E+01/
     *    HL(1342) /0.1468800000E+04/
     *    EQLAT(1342) /0.1108768055E+01/
     *    EQLON(1342) /0.2566882434E+01/
     *    SSLIP(1342) /0.4220000000E+00/
     *    DSLIP(1342) /0.0000000000E+00/
     *    DIP(1342) /0.1570796327E+01/
     *    DEPTH(1342) /0.1500000000E+05/
     *    WIDTH(1342) /0.3000000000E+04/
      DATA STRIKE(1343) /0.4860741967E+01/
     *    HL(1343) /0.1469000000E+04/
     *    EQLAT(1343) /0.1108699987E+01/
     *    EQLON(1343) /0.2565863337E+01/
     *    SSLIP(1343) /0.3040000000E+00/
     *    DSLIP(1343) /-.1000000000E-01/
     *    DIP(1343) /0.1570796327E+01/
     *    DEPTH(1343) /0.1500000000E+05/
     *    WIDTH(1343) /0.3000000000E+04/
      DATA STRIKE(1344) /0.4858996638E+01/
     *    HL(1344) /0.1469200000E+04/
     *    EQLAT(1344) /0.1108631745E+01/
     *    EQLON(1344) /0.2564844413E+01/
     *    SSLIP(1344) /0.1280000000E+00/
     *    DSLIP(1344) /-.3100000000E+00/
     *    DIP(1344) /0.1570796327E+01/
     *    DEPTH(1344) /0.1500000000E+05/
     *    WIDTH(1344) /0.3000000000E+04/
      DATA STRIKE(1345) /0.4857251308E+01/
     *    HL(1345) /0.1469400000E+04/
     *    EQLAT(1345) /0.1108563677E+01/
     *    EQLON(1345) /0.2563825316E+01/
     *    SSLIP(1345) /0.1100000000E-01/
     *    DSLIP(1345) /-.9400000000E+00/
     *    DIP(1345) /0.1570796327E+01/
     *    DEPTH(1345) /0.1500000000E+05/
     *    WIDTH(1345) /0.3000000000E+04/
      DATA STRIKE(1346) /0.4855505979E+01/
     *    HL(1346) /0.1469600000E+04/
     *    EQLAT(1346) /0.1108495434E+01/
     *    EQLON(1346) /0.2562806218E+01/
     *    SSLIP(1346) /0.2100000000E-01/
     *    DSLIP(1346) /-.1750000000E+01/
     *    DIP(1346) /0.1570796327E+01/
     *    DEPTH(1346) /0.1500000000E+05/
     *    WIDTH(1346) /0.3000000000E+04/
      DATA STRIKE(1347) /0.4853760650E+01/
     *    HL(1347) /0.1469800000E+04/
     *    EQLAT(1347) /0.1108427192E+01/
     *    EQLON(1347) /0.2561787120E+01/
     *    SSLIP(1347) /0.1220000000E+00/
     *    DSLIP(1347) /-.2480000000E+01/
     *    DIP(1347) /0.1570796327E+01/
     *    DEPTH(1347) /0.1500000000E+05/
     *    WIDTH(1347) /0.3000000000E+04/
      DATA STRIKE(1348) /0.4852015321E+01/
     *    HL(1348) /0.1470000000E+04/
     *    EQLAT(1348) /0.1108359124E+01/
     *    EQLON(1348) /0.2560768197E+01/
     *    SSLIP(1348) /0.2680000000E+00/
     *    DSLIP(1348) /-.2910000000E+01/
     *    DIP(1348) /0.1570796327E+01/
     *    DEPTH(1348) /0.1500000000E+05/
     *    WIDTH(1348) /0.3000000000E+04/
      DATA STRIKE(1349) /0.4850269991E+01/
     *    HL(1349) /0.1470200000E+04/
     *    EQLAT(1349) /0.1108290882E+01/
     *    EQLON(1349) /0.2559749099E+01/
     *    SSLIP(1349) /0.3790000000E+00/
     *    DSLIP(1349) /-.3000000000E+01/
     *    DIP(1349) /0.1570796327E+01/
     *    DEPTH(1349) /0.1500000000E+05/
     *    WIDTH(1349) /0.3000000000E+04/
      DATA STRIKE(1350) /0.4848524662E+01/
     *    HL(1350) /0.1470400000E+04/
     *    EQLAT(1350) /0.1108222639E+01/
     *    EQLON(1350) /0.2558730002E+01/
     *    SSLIP(1350) /0.3880000000E+00/
     *    DSLIP(1350) /-.3000000000E+01/
     *    DIP(1350) /0.1570796327E+01/
     *    DEPTH(1350) /0.1500000000E+05/
     *    WIDTH(1350) /0.3000000000E+04/
      DATA STRIKE(1351) /0.4846779333E+01/
     *    HL(1351) /0.1470600000E+04/
     *    EQLAT(1351) /0.1108154572E+01/
     *    EQLON(1351) /0.2557710904E+01/
     *    SSLIP(1351) /0.2860000000E+00/
     *    DSLIP(1351) /-.3000000000E+01/
     *    DIP(1351) /0.1570796327E+01/
     *    DEPTH(1351) /0.1500000000E+05/
     *    WIDTH(1351) /0.3000000000E+04/
      DATA STRIKE(1352) /0.4845034004E+01/
     *    HL(1352) /0.1470800000E+04/
     *    EQLAT(1352) /0.1108086329E+01/
     *    EQLON(1352) /0.2556691981E+01/
     *    SSLIP(1352) /0.1260000000E+00/
     *    DSLIP(1352) /-.3000000000E+01/
     *    DIP(1352) /0.1570796327E+01/
     *    DEPTH(1352) /0.1500000000E+05/
     *    WIDTH(1352) /0.3000000000E+04/
      DATA STRIKE(1353) /0.4843288674E+01/
     *    HL(1353) /0.1470900000E+04/
     *    EQLAT(1353) /0.1108018261E+01/
     *    EQLON(1353) /0.2555672883E+01/
     *    SSLIP(1353) /0.0000000000E+00/
     *    DSLIP(1353) /-.2980000000E+01/
     *    DIP(1353) /0.1570796327E+01/
     *    DEPTH(1353) /0.1500000000E+05/
     *    WIDTH(1353) /0.3000000000E+04/
      DATA STRIKE(1354) /0.4841543345E+01/
     *    HL(1354) /0.1471100000E+04/
     *    EQLAT(1354) /0.1107950019E+01/
     *    EQLON(1354) /0.2554653785E+01/
     *    SSLIP(1354) /0.0000000000E+00/
     *    DSLIP(1354) /-.2940000000E+01/
     *    DIP(1354) /0.1570796327E+01/
     *    DEPTH(1354) /0.1500000000E+05/
     *    WIDTH(1354) /0.3000000000E+04/
      DATA STRIKE(1355) /0.4839798016E+01/
     *    HL(1355) /0.1471300000E+04/
     *    EQLAT(1355) /0.1107881777E+01/
     *    EQLON(1355) /0.2553634687E+01/
     *    SSLIP(1355) /0.0000000000E+00/
     *    DSLIP(1355) /-.2960000000E+01/
     *    DIP(1355) /0.1570796327E+01/
     *    DEPTH(1355) /0.1500000000E+05/
     *    WIDTH(1355) /0.3000000000E+04/
      DATA STRIKE(1356) /0.4967207051E+01/
     *    HL(1356) /0.1450200000E+04/
     *    EQLAT(1356) /0.1107785434E+01/
     *    EQLON(1356) /0.2552637057E+01/
     *    SSLIP(1356) /0.1900000000E-01/
     *    DSLIP(1356) /-.2990000000E+01/
     *    DIP(1356) /0.1570796327E+01/
     *    DEPTH(1356) /0.1500000000E+05/
     *    WIDTH(1356) /0.3000000000E+04/
      DATA STRIKE(1357) /0.4965461722E+01/
     *    HL(1357) /0.1450500000E+04/
     *    EQLAT(1357) /0.1107660818E+01/
     *    EQLON(1357) /0.2551660720E+01/
     *    SSLIP(1357) /0.2600000000E-01/
     *    DSLIP(1357) /-.2530000000E+01/
     *    DIP(1357) /0.1570796327E+01/
     *    DEPTH(1357) /0.1500000000E+05/
     *    WIDTH(1357) /0.3000000000E+04/
      DATA STRIKE(1358) /0.4963716393E+01/
     *    HL(1358) /0.1450900000E+04/
     *    EQLAT(1358) /0.1107536027E+01/
     *    EQLON(1358) /0.2550684208E+01/
     *    SSLIP(1358) /0.3000000000E-02/
     *    DSLIP(1358) /-.1520000000E+01/
     *    DIP(1358) /0.1570796327E+01/
     *    DEPTH(1358) /0.1500000000E+05/
     *    WIDTH(1358) /0.3000000000E+04/
      DATA STRIKE(1359) /0.4961971063E+01/
     *    HL(1359) /0.1451200000E+04/
     *    EQLAT(1359) /0.1107411410E+01/
     *    EQLON(1359) /0.2549707871E+01/
     *    SSLIP(1359) /0.0000000000E+00/
     *    DSLIP(1359) /-.4700000000E+00/
     *    DIP(1359) /0.1570796327E+01/
     *    DEPTH(1359) /0.1500000000E+05/
     *    WIDTH(1359) /0.3000000000E+04/
      DATA STRIKE(1360) /0.4960225734E+01/
     *    HL(1360) /0.1451500000E+04/
     *    EQLAT(1360) /0.1107286794E+01/
     *    EQLON(1360) /0.2548731534E+01/
     *    SSLIP(1360) /0.0000000000E+00/
     *    DSLIP(1360) /0.0000000000E+00/
     *    DIP(1360) /0.1570796327E+01/
     *    DEPTH(1360) /0.1500000000E+05/
     *    WIDTH(1360) /0.3000000000E+04/
      DATA STRIKE(1361) /0.4956735076E+01/
     *    HL(1361) /0.1451900000E+04/
     *    EQLAT(1361) /0.1107162003E+01/
     *    EQLON(1361) /0.2547755022E+01/
     *    SSLIP(1361) /0.3140000000E+00/
     *    DSLIP(1361) /0.0000000000E+00/
     *    DIP(1361) /0.1570796327E+01/
     *    DEPTH(1361) /0.1500000000E+05/
     *    WIDTH(1361) /0.3000000000E+04/
      DATA STRIKE(1362) /0.4954989746E+01/
     *    HL(1362) /0.1452200000E+04/
     *    EQLAT(1362) /0.1107037386E+01/
     *    EQLON(1362) /0.2546778685E+01/
     *    SSLIP(1362) /0.1970000000E+01/
     *    DSLIP(1362) /0.0000000000E+00/
     *    DIP(1362) /0.1570796327E+01/
     *    DEPTH(1362) /0.1500000000E+05/
     *    WIDTH(1362) /0.3000000000E+04/
      DATA STRIKE(1363) /0.5239478414E+01/
     *    HL(1363) /0.1384800000E+04/
     *    EQLAT(1363) /0.1106865995E+01/
     *    EQLON(1363) /0.2545872335E+01/
     *    SSLIP(1363) /0.4614000000E+01/
     *    DSLIP(1363) /0.0000000000E+00/
     *    DIP(1363) /0.1570796327E+01/
     *    DEPTH(1363) /0.1500000000E+05/
     *    WIDTH(1363) /0.3000000000E+04/
      DATA STRIKE(1364) /0.5237733085E+01/
     *    HL(1364) /0.1385300000E+04/
     *    EQLAT(1364) /0.1106647829E+01/
     *    EQLON(1364) /0.2545035799E+01/
     *    SSLIP(1364) /0.6223000000E+01/
     *    DSLIP(1364) /0.0000000000E+00/
     *    DIP(1364) /0.1570796327E+01/
     *    DEPTH(1364) /0.1500000000E+05/
     *    WIDTH(1364) /0.3000000000E+04/
      DATA STRIKE(1365) /0.5235987756E+01/
     *    HL(1365) /0.1385700000E+04/
     *    EQLAT(1365) /0.1106429663E+01/
     *    EQLON(1365) /0.2544199437E+01/
     *    SSLIP(1365) /0.6227000000E+01/
     *    DSLIP(1365) /0.0000000000E+00/
     *    DIP(1365) /0.1570796327E+01/
     *    DEPTH(1365) /0.1500000000E+05/
     *    WIDTH(1365) /0.3000000000E+04/
      DATA STRIKE(1366) /0.5234242427E+01/
     *    HL(1366) /0.1386200000E+04/
     *    EQLAT(1366) /0.1106211497E+01/
     *    EQLON(1366) /0.2543362901E+01/
     *    SSLIP(1366) /0.4995000000E+01/
     *    DSLIP(1366) /0.0000000000E+00/
     *    DIP(1366) /0.1570796327E+01/
     *    DEPTH(1366) /0.1500000000E+05/
     *    WIDTH(1366) /0.3000000000E+04/
      DATA STRIKE(1367) /0.5232497097E+01/
     *    HL(1367) /0.1386600000E+04/
     *    EQLAT(1367) /0.1105993330E+01/
     *    EQLON(1367) /0.2542526539E+01/
     *    SSLIP(1367) /0.3241000000E+01/
     *    DSLIP(1367) /0.0000000000E+00/
     *    DIP(1367) /0.1570796327E+01/
     *    DEPTH(1367) /0.1500000000E+05/
     *    WIDTH(1367) /0.3000000000E+04/
      DATA STRIKE(1368) /0.5230751768E+01/
     *    HL(1368) /0.1387100000E+04/
     *    EQLAT(1368) /0.1105775164E+01/
     *    EQLON(1368) /0.2541690003E+01/
     *    SSLIP(1368) /0.1795000000E+01/
     *    DSLIP(1368) /0.0000000000E+00/
     *    DIP(1368) /0.1570796327E+01/
     *    DEPTH(1368) /0.1500000000E+05/
     *    WIDTH(1368) /0.3000000000E+04/
      DATA STRIKE(1369) /0.5229006439E+01/
     *    HL(1369) /0.1387500000E+04/
     *    EQLAT(1369) /0.1105556998E+01/
     *    EQLON(1369) /0.2540853641E+01/
     *    SSLIP(1369) /0.1397000000E+01/
     *    DSLIP(1369) /0.0000000000E+00/
     *    DIP(1369) /0.1570796327E+01/
     *    DEPTH(1369) /0.1500000000E+05/
     *    WIDTH(1369) /0.3000000000E+04/
      DATA STRIKE(1370) /0.5227261110E+01/
     *    HL(1370) /0.1388000000E+04/
     *    EQLAT(1370) /0.1105338832E+01/
     *    EQLON(1370) /0.2540017105E+01/
     *    SSLIP(1370) /0.2302000000E+01/
     *    DSLIP(1370) /0.0000000000E+00/
     *    DIP(1370) /0.1570796327E+01/
     *    DEPTH(1370) /0.1500000000E+05/
     *    WIDTH(1370) /0.3000000000E+04/
      DATA STRIKE(1371) /0.5047492197E+01/
     *    HL(1371) /0.1434000000E+04/
     *    EQLAT(1371) /0.1105152954E+01/
     *    EQLON(1371) /0.2539129605E+01/
     *    SSLIP(1371) /0.3924000000E+01/
     *    DSLIP(1371) /0.0000000000E+00/
     *    DIP(1371) /0.1570796327E+01/
     *    DEPTH(1371) /0.1500000000E+05/
     *    WIDTH(1371) /0.3000000000E+04/
      DATA STRIKE(1372) /0.5045746868E+01/
     *    HL(1372) /0.1434400000E+04/
     *    EQLAT(1372) /0.1104999540E+01/
     *    EQLON(1372) /0.2538190967E+01/
     *    SSLIP(1372) /0.4745000000E+01/
     *    DSLIP(1372) /0.0000000000E+00/
     *    DIP(1372) /0.1570796327E+01/
     *    DEPTH(1372) /0.1500000000E+05/
     *    WIDTH(1372) /0.3000000000E+04/
      DATA STRIKE(1373) /0.5044001538E+01/
     *    HL(1373) /0.1434700000E+04/
     *    EQLAT(1373) /0.1104846125E+01/
     *    EQLON(1373) /0.2537252329E+01/
     *    SSLIP(1373) /0.4499000000E+01/
     *    DSLIP(1373) /0.0000000000E+00/
     *    DIP(1373) /0.1570796327E+01/
     *    DEPTH(1373) /0.1500000000E+05/
     *    WIDTH(1373) /0.3000000000E+04/
      DATA STRIKE(1374) /0.5042256209E+01/
     *    HL(1374) /0.1435100000E+04/
     *    EQLAT(1374) /0.1104692711E+01/
     *    EQLON(1374) /0.2536313516E+01/
     *    SSLIP(1374) /0.3695000000E+01/
     *    DSLIP(1374) /0.0000000000E+00/
     *    DIP(1374) /0.1570796327E+01/
     *    DEPTH(1374) /0.1500000000E+05/
     *    WIDTH(1374) /0.3000000000E+04/
      DATA STRIKE(1375) /0.5040510880E+01/
     *    HL(1375) /0.1435500000E+04/
     *    EQLAT(1375) /0.1104539297E+01/
     *    EQLON(1375) /0.2535374878E+01/
     *    SSLIP(1375) /0.3021000000E+01/
     *    DSLIP(1375) /0.0000000000E+00/
     *    DIP(1375) /0.1570796327E+01/
     *    DEPTH(1375) /0.1500000000E+05/
     *    WIDTH(1375) /0.3000000000E+04/
      DATA STRIKE(1376) /0.5038765551E+01/
     *    HL(1376) /0.1435900000E+04/
     *    EQLAT(1376) /0.1104385882E+01/
     *    EQLON(1376) /0.2534436240E+01/
     *    SSLIP(1376) /0.2933000000E+01/
     *    DSLIP(1376) /0.0000000000E+00/
     *    DIP(1376) /0.1570796327E+01/
     *    DEPTH(1376) /0.1500000000E+05/
     *    WIDTH(1376) /0.3000000000E+04/
      DATA STRIKE(1377) /0.5037020221E+01/
     *    HL(1377) /0.1436300000E+04/
     *    EQLAT(1377) /0.1104232468E+01/
     *    EQLON(1377) /0.2533497602E+01/
     *    SSLIP(1377) /0.3489000000E+01/
     *    DSLIP(1377) /0.0000000000E+00/
     *    DIP(1377) /0.1570796327E+01/
     *    DEPTH(1377) /0.1500000000E+05/
     *    WIDTH(1377) /0.3000000000E+04/
      DATA STRIKE(1378) /0.5035274892E+01/
     *    HL(1378) /0.1436700000E+04/
     *    EQLAT(1378) /0.1104079053E+01/
     *    EQLON(1378) /0.2532558964E+01/
     *    SSLIP(1378) /0.4362000000E+01/
     *    DSLIP(1378) /0.0000000000E+00/
     *    DIP(1378) /0.1570796327E+01/
     *    DEPTH(1378) /0.1500000000E+05/
     *    WIDTH(1378) /0.3000000000E+04/
      DATA STRIKE(1379) /0.5033529563E+01/
     *    HL(1379) /0.1437100000E+04/
     *    EQLAT(1379) /0.1103925639E+01/
     *    EQLON(1379) /0.2531620151E+01/
     *    SSLIP(1379) /0.5017000000E+01/
     *    DSLIP(1379) /0.0000000000E+00/
     *    DIP(1379) /0.1570796327E+01/
     *    DEPTH(1379) /0.1500000000E+05/
     *    WIDTH(1379) /0.3000000000E+04/
      DATA STRIKE(1380) /0.5031784233E+01/
     *    HL(1380) /0.1437400000E+04/
     *    EQLAT(1380) /0.1103772224E+01/
     *    EQLON(1380) /0.2530681513E+01/
     *    SSLIP(1380) /0.4944000000E+01/
     *    DSLIP(1380) /0.0000000000E+00/
     *    DIP(1380) /0.1570796327E+01/
     *    DEPTH(1380) /0.1500000000E+05/
     *    WIDTH(1380) /0.3000000000E+04/
      DATA STRIKE(1381) /0.5030038904E+01/
     *    HL(1381) /0.1437800000E+04/
     *    EQLAT(1381) /0.1103618810E+01/
     *    EQLON(1381) /0.2529742875E+01/
     *    SSLIP(1381) /0.3939000000E+01/
     *    DSLIP(1381) /0.0000000000E+00/
     *    DIP(1381) /0.1570796327E+01/
     *    DEPTH(1381) /0.1500000000E+05/
     *    WIDTH(1381) /0.3000000000E+04/
      DATA STRIKE(1382) /0.5153957281E+01/
     *    HL(1382) /0.1412200000E+04/
     *    EQLAT(1382) /0.1103441310E+01/
     *    EQLON(1382) /0.2528837224E+01/
     *    SSLIP(1382) /0.2339000000E+01/
     *    DSLIP(1382) /0.0000000000E+00/
     *    DIP(1382) /0.1570796327E+01/
     *    DEPTH(1382) /0.1500000000E+05/
     *    WIDTH(1382) /0.3000000000E+04/
      DATA STRIKE(1383) /0.5152211952E+01/
     *    HL(1383) /0.1412700000E+04/
     *    EQLAT(1383) /0.1103239899E+01/
     *    EQLON(1383) /0.2527964559E+01/
     *    SSLIP(1383) /0.1194000000E+01/
     *    DSLIP(1383) /0.0000000000E+00/
     *    DIP(1383) /0.1570796327E+01/
     *    DEPTH(1383) /0.1500000000E+05/
     *    WIDTH(1383) /0.3000000000E+04/
      DATA STRIKE(1384) /0.5150466623E+01/
     *    HL(1384) /0.1413100000E+04/
     *    EQLAT(1384) /0.1103038313E+01/
     *    EQLON(1384) /0.2527091895E+01/
     *    SSLIP(1384) /0.7260000000E+00/
     *    DSLIP(1384) /0.0000000000E+00/
     *    DIP(1384) /0.1570796327E+01/
     *    DEPTH(1384) /0.1500000000E+05/
     *    WIDTH(1384) /0.3000000000E+04/
      DATA STRIKE(1385) /0.5183627878E+01/
     *    HL(1385) /0.1413500000E+04/
     *    EQLAT(1385) /0.1102836902E+01/
     *    EQLON(1385) /0.2526219230E+01/
     *    SSLIP(1385) /0.6900000000E+00/
     *    DSLIP(1385) /0.0000000000E+00/
     *    DIP(1385) /0.1570796327E+01/
     *    DEPTH(1385) /0.1500000000E+05/
     *    WIDTH(1385) /0.3000000000E+04/
      DATA STRIKE(1386) /0.5181882549E+01/
     *    HL(1386) /0.1414000000E+04/
     *    EQLAT(1386) /0.1102635491E+01/
     *    EQLON(1386) /0.2525346565E+01/
     *    SSLIP(1386) /0.7890000000E+00/
     *    DSLIP(1386) /0.0000000000E+00/
     *    DIP(1386) /0.1570796327E+01/
     *    DEPTH(1386) /0.1500000000E+05/
     *    WIDTH(1386) /0.3000000000E+04/
      DATA STRIKE(1387) /0.5180137220E+01/
     *    HL(1387) /0.1414400000E+04/
     *    EQLAT(1387) /0.1102433906E+01/
     *    EQLON(1387) /0.2524473901E+01/
     *    SSLIP(1387) /0.8600000000E+00/
     *    DSLIP(1387) /0.0000000000E+00/
     *    DIP(1387) /0.1570796327E+01/
     *    DEPTH(1387) /0.1500000000E+05/
     *    WIDTH(1387) /0.3000000000E+04/
      DATA STRIKE(1388) /0.5178391891E+01/
     *    HL(1388) /0.1414900000E+04/
     *    EQLAT(1388) /0.1102232495E+01/
     *    EQLON(1388) /0.2523601236E+01/
     *    SSLIP(1388) /0.8440000000E+00/
     *    DSLIP(1388) /0.0000000000E+00/
     *    DIP(1388) /0.1570796327E+01/
     *    DEPTH(1388) /0.1500000000E+05/
     *    WIDTH(1388) /0.3000000000E+04/
      DATA STRIKE(1389) /0.5176646561E+01/
     *    HL(1389) /0.1415300000E+04/
     *    EQLAT(1389) /0.1102031084E+01/
     *    EQLON(1389) /0.2522728571E+01/
     *    SSLIP(1389) /0.7450000000E+00/
     *    DSLIP(1389) /0.0000000000E+00/
     *    DIP(1389) /0.1570796327E+01/
     *    DEPTH(1389) /0.1500000000E+05/
     *    WIDTH(1389) /0.3000000000E+04/
      DATA STRIKE(1390) /0.5174901232E+01/
     *    HL(1390) /0.1415800000E+04/
     *    EQLAT(1390) /0.1101829673E+01/
     *    EQLON(1390) /0.2521855907E+01/
     *    SSLIP(1390) /0.6040000000E+00/
     *    DSLIP(1390) /0.0000000000E+00/
     *    DIP(1390) /0.1570796327E+01/
     *    DEPTH(1390) /0.1500000000E+05/
     *    WIDTH(1390) /0.3000000000E+04/
      DATA STRIKE(1391) /0.5173155903E+01/
     *    HL(1391) /0.1416200000E+04/
     *    EQLAT(1391) /0.1101628087E+01/
     *    EQLON(1391) /0.2520983242E+01/
     *    SSLIP(1391) /0.4830000000E+00/
     *    DSLIP(1391) /0.0000000000E+00/
     *    DIP(1391) /0.1570796327E+01/
     *    DEPTH(1391) /0.1500000000E+05/
     *    WIDTH(1391) /0.3000000000E+04/
      DATA STRIKE(1392) /0.5171410574E+01/
     *    HL(1392) /0.1416700000E+04/
     *    EQLAT(1392) /0.1101426676E+01/
     *    EQLON(1392) /0.2520110578E+01/
     *    SSLIP(1392) /0.4370000000E+00/
     *    DSLIP(1392) /0.0000000000E+00/
     *    DIP(1392) /0.1570796327E+01/
     *    DEPTH(1392) /0.1500000000E+05/
     *    WIDTH(1392) /0.3000000000E+04/
      DATA STRIKE(1393) /0.5169665244E+01/
     *    HL(1393) /0.1417100000E+04/
     *    EQLAT(1393) /0.1101225265E+01/
     *    EQLON(1393) /0.2519237913E+01/
     *    SSLIP(1393) /0.4850000000E+00/
     *    DSLIP(1393) /-.1800000000E+00/
     *    DIP(1393) /0.1570796327E+01/
     *    DEPTH(1393) /0.1500000000E+05/
     *    WIDTH(1393) /0.3000000000E+04/
      DATA STRIKE(1394) /0.5167919915E+01/
     *    HL(1394) /0.1417600000E+04/
     *    EQLAT(1394) /0.1101023680E+01/
     *    EQLON(1394) /0.2518365248E+01/
     *    SSLIP(1394) /0.6250000000E+00/
     *    DSLIP(1394) /-.6200000000E+00/
     *    DIP(1394) /0.1570796327E+01/
     *    DEPTH(1394) /0.1500000000E+05/
     *    WIDTH(1394) /0.3000000000E+04/
      DATA STRIKE(1395) /0.5166174586E+01/
     *    HL(1395) /0.1418000000E+04/
     *    EQLAT(1395) /0.1100822269E+01/
     *    EQLON(1395) /0.2517492584E+01/
     *    SSLIP(1395) /0.8480000000E+00/
     *    DSLIP(1395) /-.1250000000E+01/
     *    DIP(1395) /0.1570796327E+01/
     *    DEPTH(1395) /0.1500000000E+05/
     *    WIDTH(1395) /0.3000000000E+04/
      DATA STRIKE(1396) /0.5213298476E+01/
     *    HL(1396) /0.1426200000E+04/
     *    EQLAT(1396) /0.1100610909E+01/
     *    EQLON(1396) /0.2516628820E+01/
     *    SSLIP(1396) /0.1148000000E+01/
     *    DSLIP(1396) /-.1940000000E+01/
     *    DIP(1396) /0.1570796327E+01/
     *    DEPTH(1396) /0.1500000000E+05/
     *    WIDTH(1396) /0.3000000000E+04/
      DATA STRIKE(1397) /0.5211553146E+01/
     *    HL(1397) /0.1426600000E+04/
     *    EQLAT(1397) /0.1100389427E+01/
     *    EQLON(1397) /0.2515773958E+01/
     *    SSLIP(1397) /0.1559000000E+01/
     *    DSLIP(1397) /-.2540000000E+01/
     *    DIP(1397) /0.1570796327E+01/
     *    DEPTH(1397) /0.1500000000E+05/
     *    WIDTH(1397) /0.3000000000E+04/
      DATA STRIKE(1398) /0.5209807817E+01/
     *    HL(1398) /0.1427100000E+04/
     *    EQLAT(1398) /0.1100167945E+01/
     *    EQLON(1398) /0.2514918921E+01/
     *    SSLIP(1398) /0.2091000000E+01/
     *    DSLIP(1398) /-.2910000000E+01/
     *    DIP(1398) /0.1570796327E+01/
     *    DEPTH(1398) /0.1500000000E+05/
     *    WIDTH(1398) /0.3000000000E+04/
      DATA STRIKE(1399) /0.5208062488E+01/
     *    HL(1399) /0.1427600000E+04/
     *    EQLAT(1399) /0.1099946463E+01/
     *    EQLON(1399) /0.2514064059E+01/
     *    SSLIP(1399) /0.2667000000E+01/
     *    DSLIP(1399) /-.3000000000E+01/
     *    DIP(1399) /0.1570796327E+01/
     *    DEPTH(1399) /0.1500000000E+05/
     *    WIDTH(1399) /0.3000000000E+04/
      DATA STRIKE(1400) /0.5206317159E+01/
     *    HL(1400) /0.1428000000E+04/
     *    EQLAT(1400) /0.1099724980E+01/
     *    EQLON(1400) /0.2513209197E+01/
     *    SSLIP(1400) /0.3114000000E+01/
     *    DSLIP(1400) /-.3000000000E+01/
     *    DIP(1400) /0.1570796327E+01/
     *    DEPTH(1400) /0.1500000000E+05/
     *    WIDTH(1400) /0.3000000000E+04/
      DATA STRIKE(1401) /0.5204571829E+01/
     *    HL(1401) /0.1428500000E+04/
     *    EQLAT(1401) /0.1099503498E+01/
     *    EQLON(1401) /0.2512354160E+01/
     *    SSLIP(1401) /0.3258000000E+01/
     *    DSLIP(1401) /-.3000000000E+01/
     *    DIP(1401) /0.1570796327E+01/
     *    DEPTH(1401) /0.1500000000E+05/
     *    WIDTH(1401) /0.3000000000E+04/
      DATA STRIKE(1402) /0.5202826500E+01/
     *    HL(1402) /0.1429000000E+04/
     *    EQLAT(1402) /0.1099282016E+01/
     *    EQLON(1402) /0.2511499298E+01/
     *    SSLIP(1402) /0.3039000000E+01/
     *    DSLIP(1402) /-.3000000000E+01/
     *    DIP(1402) /0.1570796327E+01/
     *    DEPTH(1402) /0.1500000000E+05/
     *    WIDTH(1402) /0.3000000000E+04/
      DATA STRIKE(1403) /0.5201081171E+01/
     *    HL(1403) /0.1429500000E+04/
     *    EQLAT(1403) /0.1099060534E+01/
     *    EQLON(1403) /0.2510644435E+01/
     *    SSLIP(1403) /0.2552000000E+01/
     *    DSLIP(1403) /-.2990000000E+01/
     *    DIP(1403) /0.1570796327E+01/
     *    DEPTH(1403) /0.1500000000E+05/
     *    WIDTH(1403) /0.3000000000E+04/
      DATA STRIKE(1404) /0.5199335842E+01/
     *    HL(1404) /0.1429900000E+04/
     *    EQLAT(1404) /0.1098839051E+01/
     *    EQLON(1404) /0.2509789398E+01/
     *    SSLIP(1404) /0.1968000000E+01/
     *    DSLIP(1404) /-.2730000000E+01/
     *    DIP(1404) /0.1570796327E+01/
     *    DEPTH(1404) /0.1500000000E+05/
     *    WIDTH(1404) /0.3000000000E+04/
      DATA STRIKE(1405) /0.5197590512E+01/
     *    HL(1405) /0.1430400000E+04/
     *    EQLAT(1405) /0.1098617743E+01/
     *    EQLON(1405) /0.2508934536E+01/
     *    SSLIP(1405) /0.1423000000E+01/
     *    DSLIP(1405) /-.2160000000E+01/
     *    DIP(1405) /0.1570796327E+01/
     *    DEPTH(1405) /0.1500000000E+05/
     *    WIDTH(1405) /0.3000000000E+04/
      DATA STRIKE(1406) /0.5195845183E+01/
     *    HL(1406) /0.1430900000E+04/
     *    EQLAT(1406) /0.1098396261E+01/
     *    EQLON(1406) /0.2508079674E+01/
     *    SSLIP(1406) /0.9730000000E+00/
     *    DSLIP(1406) /-.1480000000E+01/
     *    DIP(1406) /0.1570796327E+01/
     *    DEPTH(1406) /0.1500000000E+05/
     *    WIDTH(1406) /0.3000000000E+04/
      DATA STRIKE(1407) /0.5229006439E+01/
     *    HL(1407) /0.1431300000E+04/
     *    EQLAT(1407) /0.1098174779E+01/
     *    EQLON(1407) /0.2507224637E+01/
     *    SSLIP(1407) /0.6130000000E+00/
     *    DSLIP(1407) /-.8900000000E+00/
     *    DIP(1407) /0.1570796327E+01/
     *    DEPTH(1407) /0.1500000000E+05/
     *    WIDTH(1407) /0.3000000000E+04/
      DATA STRIKE(1408) /0.5227261110E+01/
     *    HL(1408) /0.1431800000E+04/
     *    EQLAT(1408) /0.1097953297E+01/
     *    EQLON(1408) /0.2506369775E+01/
     *    SSLIP(1408) /0.3620000000E+00/
     *    DSLIP(1408) /-.4500000000E+00/
     *    DIP(1408) /0.1570796327E+01/
     *    DEPTH(1408) /0.1500000000E+05/
     *    WIDTH(1408) /0.3000000000E+04/
      DATA STRIKE(1409) /0.5225515780E+01/
     *    HL(1409) /0.1432300000E+04/
     *    EQLAT(1409) /0.1097731814E+01/
     *    EQLON(1409) /0.2505514913E+01/
     *    SSLIP(1409) /0.2030000000E+00/
     *    DSLIP(1409) /-.1700000000E+00/
     *    DIP(1409) /0.1570796327E+01/
     *    DEPTH(1409) /0.1500000000E+05/
     *    WIDTH(1409) /0.3000000000E+04/
      DATA STRIKE(1410) /0.5223770451E+01/
     *    HL(1410) /0.1432700000E+04/
     *    EQLAT(1410) /0.1097510332E+01/
     *    EQLON(1410) /0.2504659876E+01/
     *    SSLIP(1410) /0.1230000000E+00/
     *    DSLIP(1410) /-.3000000000E-01/
     *    DIP(1410) /0.1570796327E+01/
     *    DEPTH(1410) /0.1500000000E+05/
     *    WIDTH(1410) /0.3000000000E+04/
      DATA STRIKE(1411) /0.5222025122E+01/
     *    HL(1411) /0.1433200000E+04/
     *    EQLAT(1411) /0.1097288850E+01/
     *    EQLON(1411) /0.2503805014E+01/
     *    SSLIP(1411) /0.8700000000E-01/
     *    DSLIP(1411) /0.0000000000E+00/
     *    DIP(1411) /0.1570796327E+01/
     *    DEPTH(1411) /0.1500000000E+05/
     *    WIDTH(1411) /0.3000000000E+04/
      DATA STRIKE(1412) /0.5220279793E+01/
     *    HL(1412) /0.1433700000E+04/
     *    EQLAT(1412) /0.1097067368E+01/
     *    EQLON(1412) /0.2502950151E+01/
     *    SSLIP(1412) /0.7000000000E-01/
     *    DSLIP(1412) /0.0000000000E+00/
     *    DIP(1412) /0.1570796327E+01/
     *    DEPTH(1412) /0.1800000000E+05/
     *    WIDTH(1412) /0.3000000000E+04/
      DATA STRIKE(1413) /0.5218534463E+01/
     *    HL(1413) /0.1434100000E+04/
     *    EQLAT(1413) /0.1096845885E+01/
     *    EQLON(1413) /0.2502095114E+01/
     *    SSLIP(1413) /0.1400000000E+00/
     *    DSLIP(1413) /0.0000000000E+00/
     *    DIP(1413) /0.1570796327E+01/
     *    DEPTH(1413) /0.1800000000E+05/
     *    WIDTH(1413) /0.3000000000E+04/
      DATA STRIKE(1414) /0.4544837372E+01/
     *    HL(1414) /0.1500600000E+04/
     *    EQLAT(1414) /0.1108284599E+01/
     *    EQLON(1414) /0.2578255000E+01/
     *    SSLIP(1414) /0.3386000000E+01/
     *    DSLIP(1414) /0.0000000000E+00/
     *    DIP(1414) /0.1570796327E+01/
     *    DEPTH(1414) /0.1800000000E+05/
     *    WIDTH(1414) /0.3000000000E+04/
      DATA STRIKE(1415) /0.4544837372E+01/
     *    HL(1415) /0.1500600000E+04/
     *    EQLAT(1415) /0.1108363138E+01/
     *    EQLON(1415) /0.2577217925E+01/
     *    SSLIP(1415) /0.3499000000E+01/
     *    DSLIP(1415) /0.0000000000E+00/
     *    DIP(1415) /0.1570796327E+01/
     *    DEPTH(1415) /0.1800000000E+05/
     *    WIDTH(1415) /0.3000000000E+04/
      DATA STRIKE(1416) /0.4546582701E+01/
     *    HL(1416) /0.1500600000E+04/
     *    EQLAT(1416) /0.1108441329E+01/
     *    EQLON(1416) /0.2576180502E+01/
     *    SSLIP(1416) /0.3484000000E+01/
     *    DSLIP(1416) /0.0000000000E+00/
     *    DIP(1416) /0.1570796327E+01/
     *    DEPTH(1416) /0.1800000000E+05/
     *    WIDTH(1416) /0.3000000000E+04/
      DATA STRIKE(1417) /0.4546582701E+01/
     *    HL(1417) /0.1500600000E+04/
     *    EQLAT(1417) /0.1108518996E+01/
     *    EQLON(1417) /0.2575142903E+01/
     *    SSLIP(1417) /0.3171000000E+01/
     *    DSLIP(1417) /0.0000000000E+00/
     *    DIP(1417) /0.1570796327E+01/
     *    DEPTH(1417) /0.1800000000E+05/
     *    WIDTH(1417) /0.3000000000E+04/
      DATA STRIKE(1418) /0.4548328031E+01/
     *    HL(1418) /0.1500600000E+04/
     *    EQLAT(1418) /0.1108596140E+01/
     *    EQLON(1418) /0.2574104956E+01/
     *    SSLIP(1418) /0.2499000000E+01/
     *    DSLIP(1418) /0.0000000000E+00/
     *    DIP(1418) /0.1570796327E+01/
     *    DEPTH(1418) /0.1800000000E+05/
     *    WIDTH(1418) /0.3000000000E+04/
      DATA STRIKE(1419) /0.4548328031E+01/
     *    HL(1419) /0.1500600000E+04/
     *    EQLAT(1419) /0.1108673109E+01/
     *    EQLON(1419) /0.2573066660E+01/
     *    SSLIP(1419) /0.1585000000E+01/
     *    DSLIP(1419) /0.0000000000E+00/
     *    DIP(1419) /0.1570796327E+01/
     *    DEPTH(1419) /0.1800000000E+05/
     *    WIDTH(1419) /0.3000000000E+04/
      DATA STRIKE(1420) /0.4550073360E+01/
     *    HL(1420) /0.1500600000E+04/
     *    EQLAT(1420) /0.1108749380E+01/
     *    EQLON(1420) /0.2572028014E+01/
     *    SSLIP(1420) /0.6910000000E+00/
     *    DSLIP(1420) /0.0000000000E+00/
     *    DIP(1420) /0.1570796327E+01/
     *    DEPTH(1420) /0.1800000000E+05/
     *    WIDTH(1420) /0.3000000000E+04/
      DATA STRIKE(1421) /0.4551818689E+01/
     *    HL(1421) /0.1500600000E+04/
     *    EQLAT(1421) /0.1108825476E+01/
     *    EQLON(1421) /0.2570989020E+01/
     *    SSLIP(1421) /0.1070000000E+00/
     *    DSLIP(1421) /0.0000000000E+00/
     *    DIP(1421) /0.1570796327E+01/
     *    DEPTH(1421) /0.1800000000E+05/
     *    WIDTH(1421) /0.3000000000E+04/
      DATA STRIKE(1422) /0.4551818689E+01/
     *    HL(1422) /0.1500600000E+04/
     *    EQLAT(1422) /0.1108900874E+01/
     *    EQLON(1422) /0.2569949851E+01/
     *    SSLIP(1422) /0.0000000000E+00/
     *    DSLIP(1422) /0.0000000000E+00/
     *    DIP(1422) /0.1570796327E+01/
     *    DEPTH(1422) /0.1800000000E+05/
     *    WIDTH(1422) /0.3000000000E+04/
      DATA STRIKE(1423) /0.4862487296E+01/
     *    HL(1423) /0.1468400000E+04/
     *    EQLAT(1423) /0.1108904540E+01/
     *    EQLON(1423) /0.2568920630E+01/
     *    SSLIP(1423) /0.1950000000E+00/
     *    DSLIP(1423) /0.0000000000E+00/
     *    DIP(1423) /0.1570796327E+01/
     *    DEPTH(1423) /0.1800000000E+05/
     *    WIDTH(1423) /0.3000000000E+04/
      DATA STRIKE(1424) /0.4862487296E+01/
     *    HL(1424) /0.1468600000E+04/
     *    EQLAT(1424) /0.1108836297E+01/
     *    EQLON(1424) /0.2567901532E+01/
     *    SSLIP(1424) /0.3660000000E+00/
     *    DSLIP(1424) /0.0000000000E+00/
     *    DIP(1424) /0.1570796327E+01/
     *    DEPTH(1424) /0.1800000000E+05/
     *    WIDTH(1424) /0.3000000000E+04/
      DATA STRIKE(1425) /0.4862487296E+01/
     *    HL(1425) /0.1468800000E+04/
     *    EQLAT(1425) /0.1108768055E+01/
     *    EQLON(1425) /0.2566882434E+01/
     *    SSLIP(1425) /0.3860000000E+00/
     *    DSLIP(1425) /0.0000000000E+00/
     *    DIP(1425) /0.1570796327E+01/
     *    DEPTH(1425) /0.1800000000E+05/
     *    WIDTH(1425) /0.3000000000E+04/
      DATA STRIKE(1426) /0.4860741967E+01/
     *    HL(1426) /0.1469000000E+04/
     *    EQLAT(1426) /0.1108699987E+01/
     *    EQLON(1426) /0.2565863337E+01/
     *    SSLIP(1426) /0.2710000000E+00/
     *    DSLIP(1426) /0.0000000000E+00/
     *    DIP(1426) /0.1570796327E+01/
     *    DEPTH(1426) /0.1800000000E+05/
     *    WIDTH(1426) /0.3000000000E+04/
      DATA STRIKE(1427) /0.4858996638E+01/
     *    HL(1427) /0.1469200000E+04/
     *    EQLAT(1427) /0.1108631745E+01/
     *    EQLON(1427) /0.2564844413E+01/
     *    SSLIP(1427) /0.1100000000E+00/
     *    DSLIP(1427) /-.2600000000E+00/
     *    DIP(1427) /0.1570796327E+01/
     *    DEPTH(1427) /0.1800000000E+05/
     *    WIDTH(1427) /0.3000000000E+04/
      DATA STRIKE(1428) /0.4857251308E+01/
     *    HL(1428) /0.1469400000E+04/
     *    EQLAT(1428) /0.1108563677E+01/
     *    EQLON(1428) /0.2563825316E+01/
     *    SSLIP(1428) /0.4000000000E-02/
     *    DSLIP(1428) /-.8600000000E+00/
     *    DIP(1428) /0.1570796327E+01/
     *    DEPTH(1428) /0.1800000000E+05/
     *    WIDTH(1428) /0.3000000000E+04/
      DATA STRIKE(1429) /0.4855505979E+01/
     *    HL(1429) /0.1469600000E+04/
     *    EQLAT(1429) /0.1108495434E+01/
     *    EQLON(1429) /0.2562806218E+01/
     *    SSLIP(1429) /0.0000000000E+00/
     *    DSLIP(1429) /-.1660000000E+01/
     *    DIP(1429) /0.1570796327E+01/
     *    DEPTH(1429) /0.1800000000E+05/
     *    WIDTH(1429) /0.3000000000E+04/
      DATA STRIKE(1430) /0.4853760650E+01/
     *    HL(1430) /0.1469800000E+04/
     *    EQLAT(1430) /0.1108427192E+01/
     *    EQLON(1430) /0.2561787120E+01/
     *    SSLIP(1430) /0.9000000000E-02/
     *    DSLIP(1430) /-.2410000000E+01/
     *    DIP(1430) /0.1570796327E+01/
     *    DEPTH(1430) /0.1800000000E+05/
     *    WIDTH(1430) /0.3000000000E+04/
      DATA STRIKE(1431) /0.4852015321E+01/
     *    HL(1431) /0.1470000000E+04/
     *    EQLAT(1431) /0.1108359124E+01/
     *    EQLON(1431) /0.2560768197E+01/
     *    SSLIP(1431) /0.4100000000E-01/
     *    DSLIP(1431) /-.2880000000E+01/
     *    DIP(1431) /0.1570796327E+01/
     *    DEPTH(1431) /0.1800000000E+05/
     *    WIDTH(1431) /0.3000000000E+04/
      DATA STRIKE(1432) /0.4850269991E+01/
     *    HL(1432) /0.1470200000E+04/
     *    EQLAT(1432) /0.1108290882E+01/
     *    EQLON(1432) /0.2559749099E+01/
     *    SSLIP(1432) /0.6900000000E-01/
     *    DSLIP(1432) /-.3000000000E+01/
     *    DIP(1432) /0.1570796327E+01/
     *    DEPTH(1432) /0.1800000000E+05/
     *    WIDTH(1432) /0.3000000000E+04/
      DATA STRIKE(1433) /0.4848524662E+01/
     *    HL(1433) /0.1470400000E+04/
     *    EQLAT(1433) /0.1108222639E+01/
     *    EQLON(1433) /0.2558730002E+01/
     *    SSLIP(1433) /0.6600000000E-01/
     *    DSLIP(1433) /-.3000000000E+01/
     *    DIP(1433) /0.1570796327E+01/
     *    DEPTH(1433) /0.1800000000E+05/
     *    WIDTH(1433) /0.3000000000E+04/
      DATA STRIKE(1434) /0.4846779333E+01/
     *    HL(1434) /0.1470600000E+04/
     *    EQLAT(1434) /0.1108154572E+01/
     *    EQLON(1434) /0.2557710904E+01/
     *    SSLIP(1434) /0.3400000000E-01/
     *    DSLIP(1434) /-.3000000000E+01/
     *    DIP(1434) /0.1570796327E+01/
     *    DEPTH(1434) /0.1800000000E+05/
     *    WIDTH(1434) /0.3000000000E+04/
      DATA STRIKE(1435) /0.4845034004E+01/
     *    HL(1435) /0.1470800000E+04/
     *    EQLAT(1435) /0.1108086329E+01/
     *    EQLON(1435) /0.2556691981E+01/
     *    SSLIP(1435) /0.0000000000E+00/
     *    DSLIP(1435) /-.3000000000E+01/
     *    DIP(1435) /0.1570796327E+01/
     *    DEPTH(1435) /0.1800000000E+05/
     *    WIDTH(1435) /0.3000000000E+04/
      DATA STRIKE(1436) /0.4843288674E+01/
     *    HL(1436) /0.1470900000E+04/
     *    EQLAT(1436) /0.1108018261E+01/
     *    EQLON(1436) /0.2555672883E+01/
     *    SSLIP(1436) /0.0000000000E+00/
     *    DSLIP(1436) /-.3000000000E+01/
     *    DIP(1436) /0.1570796327E+01/
     *    DEPTH(1436) /0.1800000000E+05/
     *    WIDTH(1436) /0.3000000000E+04/
      DATA STRIKE(1437) /0.4841543345E+01/
     *    HL(1437) /0.1471100000E+04/
     *    EQLAT(1437) /0.1107950019E+01/
     *    EQLON(1437) /0.2554653785E+01/
     *    SSLIP(1437) /0.0000000000E+00/
     *    DSLIP(1437) /-.3000000000E+01/
     *    DIP(1437) /0.1570796327E+01/
     *    DEPTH(1437) /0.1800000000E+05/
     *    WIDTH(1437) /0.3000000000E+04/
      DATA STRIKE(1438) /0.4839798016E+01/
     *    HL(1438) /0.1471300000E+04/
     *    EQLAT(1438) /0.1107881777E+01/
     *    EQLON(1438) /0.2553634687E+01/
     *    SSLIP(1438) /0.0000000000E+00/
     *    DSLIP(1438) /-.3000000000E+01/
     *    DIP(1438) /0.1570796327E+01/
     *    DEPTH(1438) /0.1800000000E+05/
     *    WIDTH(1438) /0.3000000000E+04/
      DATA STRIKE(1439) /0.4967207051E+01/
     *    HL(1439) /0.1450200000E+04/
     *    EQLAT(1439) /0.1107785434E+01/
     *    EQLON(1439) /0.2552637057E+01/
     *    SSLIP(1439) /0.0000000000E+00/
     *    DSLIP(1439) /-.3000000000E+01/
     *    DIP(1439) /0.1570796327E+01/
     *    DEPTH(1439) /0.1800000000E+05/
     *    WIDTH(1439) /0.3000000000E+04/
      DATA STRIKE(1440) /0.4965461722E+01/
     *    HL(1440) /0.1450500000E+04/
     *    EQLAT(1440) /0.1107660818E+01/
     *    EQLON(1440) /0.2551660720E+01/
     *    SSLIP(1440) /0.0000000000E+00/
     *    DSLIP(1440) /-.2640000000E+01/
     *    DIP(1440) /0.1570796327E+01/
     *    DEPTH(1440) /0.1800000000E+05/
     *    WIDTH(1440) /0.3000000000E+04/
      DATA STRIKE(1441) /0.4963716393E+01/
     *    HL(1441) /0.1450900000E+04/
     *    EQLAT(1441) /0.1107536027E+01/
     *    EQLON(1441) /0.2550684208E+01/
     *    SSLIP(1441) /0.0000000000E+00/
     *    DSLIP(1441) /-.1620000000E+01/
     *    DIP(1441) /0.1570796327E+01/
     *    DEPTH(1441) /0.1800000000E+05/
     *    WIDTH(1441) /0.3000000000E+04/
      DATA STRIKE(1442) /0.4961971063E+01/
     *    HL(1442) /0.1451200000E+04/
     *    EQLAT(1442) /0.1107411410E+01/
     *    EQLON(1442) /0.2549707871E+01/
     *    SSLIP(1442) /0.0000000000E+00/
     *    DSLIP(1442) /-.5100000000E+00/
     *    DIP(1442) /0.1570796327E+01/
     *    DEPTH(1442) /0.1800000000E+05/
     *    WIDTH(1442) /0.3000000000E+04/
      DATA STRIKE(1443) /0.4960225734E+01/
     *    HL(1443) /0.1451500000E+04/
     *    EQLAT(1443) /0.1107286794E+01/
     *    EQLON(1443) /0.2548731534E+01/
     *    SSLIP(1443) /0.0000000000E+00/
     *    DSLIP(1443) /0.0000000000E+00/
     *    DIP(1443) /0.1570796327E+01/
     *    DEPTH(1443) /0.1800000000E+05/
     *    WIDTH(1443) /0.3000000000E+04/
      DATA STRIKE(1444) /0.4956735076E+01/
     *    HL(1444) /0.1451900000E+04/
     *    EQLAT(1444) /0.1107162003E+01/
     *    EQLON(1444) /0.2547755022E+01/
     *    SSLIP(1444) /0.0000000000E+00/
     *    DSLIP(1444) /0.0000000000E+00/
     *    DIP(1444) /0.1570796327E+01/
     *    DEPTH(1444) /0.1800000000E+05/
     *    WIDTH(1444) /0.3000000000E+04/
      DATA STRIKE(1445) /0.4954989746E+01/
     *    HL(1445) /0.1452200000E+04/
     *    EQLAT(1445) /0.1107037386E+01/
     *    EQLON(1445) /0.2546778685E+01/
     *    SSLIP(1445) /0.1339000000E+01/
     *    DSLIP(1445) /0.0000000000E+00/
     *    DIP(1445) /0.1570796327E+01/
     *    DEPTH(1445) /0.1800000000E+05/
     *    WIDTH(1445) /0.3000000000E+04/
      DATA STRIKE(1446) /0.5239478414E+01/
     *    HL(1446) /0.1384800000E+04/
     *    EQLAT(1446) /0.1106865995E+01/
     *    EQLON(1446) /0.2545872335E+01/
     *    SSLIP(1446) /0.3685000000E+01/
     *    DSLIP(1446) /0.0000000000E+00/
     *    DIP(1446) /0.1570796327E+01/
     *    DEPTH(1446) /0.1800000000E+05/
     *    WIDTH(1446) /0.3000000000E+04/
      DATA STRIKE(1447) /0.5237733085E+01/
     *    HL(1447) /0.1385300000E+04/
     *    EQLAT(1447) /0.1106647829E+01/
     *    EQLON(1447) /0.2545035799E+01/
     *    SSLIP(1447) /0.5252000000E+01/
     *    DSLIP(1447) /0.0000000000E+00/
     *    DIP(1447) /0.1570796327E+01/
     *    DEPTH(1447) /0.1800000000E+05/
     *    WIDTH(1447) /0.3000000000E+04/
      DATA STRIKE(1448) /0.5235987756E+01/
     *    HL(1448) /0.1385700000E+04/
     *    EQLAT(1448) /0.1106429663E+01/
     *    EQLON(1448) /0.2544199437E+01/
     *    SSLIP(1448) /0.5389000000E+01/
     *    DSLIP(1448) /0.0000000000E+00/
     *    DIP(1448) /0.1570796327E+01/
     *    DEPTH(1448) /0.1800000000E+05/
     *    WIDTH(1448) /0.3000000000E+04/
      DATA STRIKE(1449) /0.5234242427E+01/
     *    HL(1449) /0.1386200000E+04/
     *    EQLAT(1449) /0.1106211497E+01/
     *    EQLON(1449) /0.2543362901E+01/
     *    SSLIP(1449) /0.4315000000E+01/
     *    DSLIP(1449) /0.0000000000E+00/
     *    DIP(1449) /0.1570796327E+01/
     *    DEPTH(1449) /0.1800000000E+05/
     *    WIDTH(1449) /0.3000000000E+04/
      DATA STRIKE(1450) /0.5232497097E+01/
     *    HL(1450) /0.1386600000E+04/
     *    EQLAT(1450) /0.1105993330E+01/
     *    EQLON(1450) /0.2542526539E+01/
     *    SSLIP(1450) /0.2696000000E+01/
     *    DSLIP(1450) /0.0000000000E+00/
     *    DIP(1450) /0.1570796327E+01/
     *    DEPTH(1450) /0.1800000000E+05/
     *    WIDTH(1450) /0.3000000000E+04/
      DATA STRIKE(1451) /0.5230751768E+01/
     *    HL(1451) /0.1387100000E+04/
     *    EQLAT(1451) /0.1105775164E+01/
     *    EQLON(1451) /0.2541690003E+01/
     *    SSLIP(1451) /0.1327000000E+01/
     *    DSLIP(1451) /0.0000000000E+00/
     *    DIP(1451) /0.1570796327E+01/
     *    DEPTH(1451) /0.1800000000E+05/
     *    WIDTH(1451) /0.3000000000E+04/
      DATA STRIKE(1452) /0.5229006439E+01/
     *    HL(1452) /0.1387500000E+04/
     *    EQLAT(1452) /0.1105556998E+01/
     *    EQLON(1452) /0.2540853641E+01/
     *    SSLIP(1452) /0.8560000000E+00/
     *    DSLIP(1452) /0.0000000000E+00/
     *    DIP(1452) /0.1570796327E+01/
     *    DEPTH(1452) /0.1800000000E+05/
     *    WIDTH(1452) /0.3000000000E+04/
      DATA STRIKE(1453) /0.5227261110E+01/
     *    HL(1453) /0.1388000000E+04/
     *    EQLAT(1453) /0.1105338832E+01/
     *    EQLON(1453) /0.2540017105E+01/
     *    SSLIP(1453) /0.1485000000E+01/
     *    DSLIP(1453) /0.0000000000E+00/
     *    DIP(1453) /0.1570796327E+01/
     *    DEPTH(1453) /0.1800000000E+05/
     *    WIDTH(1453) /0.3000000000E+04/
      DATA STRIKE(1454) /0.5047492197E+01/
     *    HL(1454) /0.1434000000E+04/
     *    EQLAT(1454) /0.1105152954E+01/
     *    EQLON(1454) /0.2539129605E+01/
     *    SSLIP(1454) /0.2744000000E+01/
     *    DSLIP(1454) /0.0000000000E+00/
     *    DIP(1454) /0.1570796327E+01/
     *    DEPTH(1454) /0.1800000000E+05/
     *    WIDTH(1454) /0.3000000000E+04/
      DATA STRIKE(1455) /0.5045746868E+01/
     *    HL(1455) /0.1434400000E+04/
     *    EQLAT(1455) /0.1104999540E+01/
     *    EQLON(1455) /0.2538190967E+01/
     *    SSLIP(1455) /0.3465000000E+01/
     *    DSLIP(1455) /0.0000000000E+00/
     *    DIP(1455) /0.1570796327E+01/
     *    DEPTH(1455) /0.1800000000E+05/
     *    WIDTH(1455) /0.3000000000E+04/
      DATA STRIKE(1456) /0.5044001538E+01/
     *    HL(1456) /0.1434700000E+04/
     *    EQLAT(1456) /0.1104846125E+01/
     *    EQLON(1456) /0.2537252329E+01/
     *    SSLIP(1456) /0.3364000000E+01/
     *    DSLIP(1456) /0.0000000000E+00/
     *    DIP(1456) /0.1570796327E+01/
     *    DEPTH(1456) /0.1800000000E+05/
     *    WIDTH(1456) /0.3000000000E+04/
      DATA STRIKE(1457) /0.5042256209E+01/
     *    HL(1457) /0.1435100000E+04/
     *    EQLAT(1457) /0.1104692711E+01/
     *    EQLON(1457) /0.2536313516E+01/
     *    SSLIP(1457) /0.2800000000E+01/
     *    DSLIP(1457) /0.0000000000E+00/
     *    DIP(1457) /0.1570796327E+01/
     *    DEPTH(1457) /0.1800000000E+05/
     *    WIDTH(1457) /0.3000000000E+04/
      DATA STRIKE(1458) /0.5040510880E+01/
     *    HL(1458) /0.1435500000E+04/
     *    EQLAT(1458) /0.1104539297E+01/
     *    EQLON(1458) /0.2535374878E+01/
     *    SSLIP(1458) /0.2328000000E+01/
     *    DSLIP(1458) /0.0000000000E+00/
     *    DIP(1458) /0.1570796327E+01/
     *    DEPTH(1458) /0.1800000000E+05/
     *    WIDTH(1458) /0.3000000000E+04/
      DATA STRIKE(1459) /0.5038765551E+01/
     *    HL(1459) /0.1435900000E+04/
     *    EQLAT(1459) /0.1104385882E+01/
     *    EQLON(1459) /0.2534436240E+01/
     *    SSLIP(1459) /0.2339000000E+01/
     *    DSLIP(1459) /0.0000000000E+00/
     *    DIP(1459) /0.1570796327E+01/
     *    DEPTH(1459) /0.1800000000E+05/
     *    WIDTH(1459) /0.3000000000E+04/
      DATA STRIKE(1460) /0.5037020221E+01/
     *    HL(1460) /0.1436300000E+04/
     *    EQLAT(1460) /0.1104232468E+01/
     *    EQLON(1460) /0.2533497602E+01/
     *    SSLIP(1460) /0.2880000000E+01/
     *    DSLIP(1460) /0.0000000000E+00/
     *    DIP(1460) /0.1570796327E+01/
     *    DEPTH(1460) /0.1800000000E+05/
     *    WIDTH(1460) /0.3000000000E+04/
      DATA STRIKE(1461) /0.5035274892E+01/
     *    HL(1461) /0.1436700000E+04/
     *    EQLAT(1461) /0.1104079053E+01/
     *    EQLON(1461) /0.2532558964E+01/
     *    SSLIP(1461) /0.3659000000E+01/
     *    DSLIP(1461) /0.0000000000E+00/
     *    DIP(1461) /0.1570796327E+01/
     *    DEPTH(1461) /0.1800000000E+05/
     *    WIDTH(1461) /0.3000000000E+04/
      DATA STRIKE(1462) /0.5033529563E+01/
     *    HL(1462) /0.1437100000E+04/
     *    EQLAT(1462) /0.1103925639E+01/
     *    EQLON(1462) /0.2531620151E+01/
     *    SSLIP(1462) /0.4192000000E+01/
     *    DSLIP(1462) /0.0000000000E+00/
     *    DIP(1462) /0.1570796327E+01/
     *    DEPTH(1462) /0.1800000000E+05/
     *    WIDTH(1462) /0.3000000000E+04/
      DATA STRIKE(1463) /0.5031784233E+01/
     *    HL(1463) /0.1437400000E+04/
     *    EQLAT(1463) /0.1103772224E+01/
     *    EQLON(1463) /0.2530681513E+01/
     *    SSLIP(1463) /0.4023000000E+01/
     *    DSLIP(1463) /0.0000000000E+00/
     *    DIP(1463) /0.1570796327E+01/
     *    DEPTH(1463) /0.1800000000E+05/
     *    WIDTH(1463) /0.3000000000E+04/
      DATA STRIKE(1464) /0.5030038904E+01/
     *    HL(1464) /0.1437800000E+04/
     *    EQLAT(1464) /0.1103618810E+01/
     *    EQLON(1464) /0.2529742875E+01/
     *    SSLIP(1464) /0.2983000000E+01/
     *    DSLIP(1464) /0.0000000000E+00/
     *    DIP(1464) /0.1570796327E+01/
     *    DEPTH(1464) /0.1800000000E+05/
     *    WIDTH(1464) /0.3000000000E+04/
      DATA STRIKE(1465) /0.5153957281E+01/
     *    HL(1465) /0.1412200000E+04/
     *    EQLAT(1465) /0.1103441310E+01/
     *    EQLON(1465) /0.2528837224E+01/
     *    SSLIP(1465) /0.1421000000E+01/
     *    DSLIP(1465) /0.0000000000E+00/
     *    DIP(1465) /0.1570796327E+01/
     *    DEPTH(1465) /0.1800000000E+05/
     *    WIDTH(1465) /0.3000000000E+04/
      DATA STRIKE(1466) /0.5152211952E+01/
     *    HL(1466) /0.1412700000E+04/
     *    EQLAT(1466) /0.1103239899E+01/
     *    EQLON(1466) /0.2527964559E+01/
     *    SSLIP(1466) /0.3620000000E+00/
     *    DSLIP(1466) /0.0000000000E+00/
     *    DIP(1466) /0.1570796327E+01/
     *    DEPTH(1466) /0.1800000000E+05/
     *    WIDTH(1466) /0.3000000000E+04/
      DATA STRIKE(1467) /0.5150466623E+01/
     *    HL(1467) /0.1413100000E+04/
     *    EQLAT(1467) /0.1103038313E+01/
     *    EQLON(1467) /0.2527091895E+01/
     *    SSLIP(1467) /0.1300000000E-01/
     *    DSLIP(1467) /0.0000000000E+00/
     *    DIP(1467) /0.1570796327E+01/
     *    DEPTH(1467) /0.1800000000E+05/
     *    WIDTH(1467) /0.3000000000E+04/
      DATA STRIKE(1468) /0.5183627878E+01/
     *    HL(1468) /0.1413500000E+04/
     *    EQLAT(1468) /0.1102836902E+01/
     *    EQLON(1468) /0.2526219230E+01/
     *    SSLIP(1468) /0.1900000000E-01/
     *    DSLIP(1468) /0.0000000000E+00/
     *    DIP(1468) /0.1570796327E+01/
     *    DEPTH(1468) /0.1800000000E+05/
     *    WIDTH(1468) /0.3000000000E+04/
      DATA STRIKE(1469) /0.5181882549E+01/
     *    HL(1469) /0.1414000000E+04/
     *    EQLAT(1469) /0.1102635491E+01/
     *    EQLON(1469) /0.2525346565E+01/
     *    SSLIP(1469) /0.7800000000E-01/
     *    DSLIP(1469) /0.0000000000E+00/
     *    DIP(1469) /0.1570796327E+01/
     *    DEPTH(1469) /0.1800000000E+05/
     *    WIDTH(1469) /0.3000000000E+04/
      DATA STRIKE(1470) /0.5180137220E+01/
     *    HL(1470) /0.1414400000E+04/
     *    EQLAT(1470) /0.1102433906E+01/
     *    EQLON(1470) /0.2524473901E+01/
     *    SSLIP(1470) /0.1150000000E+00/
     *    DSLIP(1470) /0.0000000000E+00/
     *    DIP(1470) /0.1570796327E+01/
     *    DEPTH(1470) /0.1800000000E+05/
     *    WIDTH(1470) /0.3000000000E+04/
      DATA STRIKE(1471) /0.5178391891E+01/
     *    HL(1471) /0.1414900000E+04/
     *    EQLAT(1471) /0.1102232495E+01/
     *    EQLON(1471) /0.2523601236E+01/
     *    SSLIP(1471) /0.1170000000E+00/
     *    DSLIP(1471) /0.0000000000E+00/
     *    DIP(1471) /0.1570796327E+01/
     *    DEPTH(1471) /0.1800000000E+05/
     *    WIDTH(1471) /0.3000000000E+04/
      DATA STRIKE(1472) /0.5176646561E+01/
     *    HL(1472) /0.1415300000E+04/
     *    EQLAT(1472) /0.1102031084E+01/
     *    EQLON(1472) /0.2522728571E+01/
     *    SSLIP(1472) /0.8800000000E-01/
     *    DSLIP(1472) /0.0000000000E+00/
     *    DIP(1472) /0.1570796327E+01/
     *    DEPTH(1472) /0.1800000000E+05/
     *    WIDTH(1472) /0.3000000000E+04/
      DATA STRIKE(1473) /0.5174901232E+01/
     *    HL(1473) /0.1415800000E+04/
     *    EQLAT(1473) /0.1101829673E+01/
     *    EQLON(1473) /0.2521855907E+01/
     *    SSLIP(1473) /0.4500000000E-01/
     *    DSLIP(1473) /0.0000000000E+00/
     *    DIP(1473) /0.1570796327E+01/
     *    DEPTH(1473) /0.1800000000E+05/
     *    WIDTH(1473) /0.3000000000E+04/
      DATA STRIKE(1474) /0.5173155903E+01/
     *    HL(1474) /0.1416200000E+04/
     *    EQLAT(1474) /0.1101628087E+01/
     *    EQLON(1474) /0.2520983242E+01/
     *    SSLIP(1474) /0.9000000000E-02/
     *    DSLIP(1474) /0.0000000000E+00/
     *    DIP(1474) /0.1570796327E+01/
     *    DEPTH(1474) /0.1800000000E+05/
     *    WIDTH(1474) /0.3000000000E+04/
      DATA STRIKE(1475) /0.5171410574E+01/
     *    HL(1475) /0.1416700000E+04/
     *    EQLAT(1475) /0.1101426676E+01/
     *    EQLON(1475) /0.2520110578E+01/
     *    SSLIP(1475) /0.0000000000E+00/
     *    DSLIP(1475) /0.0000000000E+00/
     *    DIP(1475) /0.1570796327E+01/
     *    DEPTH(1475) /0.1800000000E+05/
     *    WIDTH(1475) /0.3000000000E+04/
      DATA STRIKE(1476) /0.5169665244E+01/
     *    HL(1476) /0.1417100000E+04/
     *    EQLAT(1476) /0.1101225265E+01/
     *    EQLON(1476) /0.2519237913E+01/
     *    SSLIP(1476) /0.0000000000E+00/
     *    DSLIP(1476) /-.1100000000E+00/
     *    DIP(1476) /0.1570796327E+01/
     *    DEPTH(1476) /0.1800000000E+05/
     *    WIDTH(1476) /0.3000000000E+04/
      DATA STRIKE(1477) /0.5167919915E+01/
     *    HL(1477) /0.1417600000E+04/
     *    EQLAT(1477) /0.1101023680E+01/
     *    EQLON(1477) /0.2518365248E+01/
     *    SSLIP(1477) /0.1200000000E-01/
     *    DSLIP(1477) /-.5200000000E+00/
     *    DIP(1477) /0.1570796327E+01/
     *    DEPTH(1477) /0.1800000000E+05/
     *    WIDTH(1477) /0.3000000000E+04/
      DATA STRIKE(1478) /0.5166174586E+01/
     *    HL(1478) /0.1418000000E+04/
     *    EQLAT(1478) /0.1100822269E+01/
     *    EQLON(1478) /0.2517492584E+01/
     *    SSLIP(1478) /0.5400000000E-01/
     *    DSLIP(1478) /-.1160000000E+01/
     *    DIP(1478) /0.1570796327E+01/
     *    DEPTH(1478) /0.1800000000E+05/
     *    WIDTH(1478) /0.3000000000E+04/
      DATA STRIKE(1479) /0.5213298476E+01/
     *    HL(1479) /0.1426200000E+04/
     *    EQLAT(1479) /0.1100610909E+01/
     *    EQLON(1479) /0.2516628820E+01/
     *    SSLIP(1479) /0.1200000000E+00/
     *    DSLIP(1479) /-.1880000000E+01/
     *    DIP(1479) /0.1570796327E+01/
     *    DEPTH(1479) /0.1800000000E+05/
     *    WIDTH(1479) /0.3000000000E+04/
      DATA STRIKE(1480) /0.5211553146E+01/
     *    HL(1480) /0.1426600000E+04/
     *    EQLAT(1480) /0.1100389427E+01/
     *    EQLON(1480) /0.2515773958E+01/
     *    SSLIP(1480) /0.2390000000E+00/
     *    DSLIP(1480) /-.2510000000E+01/
     *    DIP(1480) /0.1570796327E+01/
     *    DEPTH(1480) /0.1800000000E+05/
     *    WIDTH(1480) /0.3000000000E+04/
      DATA STRIKE(1481) /0.5209807817E+01/
     *    HL(1481) /0.1427100000E+04/
     *    EQLAT(1481) /0.1100167945E+01/
     *    EQLON(1481) /0.2514918921E+01/
     *    SSLIP(1481) /0.4860000000E+00/
     *    DSLIP(1481) /-.2900000000E+01/
     *    DIP(1481) /0.1570796327E+01/
     *    DEPTH(1481) /0.1800000000E+05/
     *    WIDTH(1481) /0.3000000000E+04/
      DATA STRIKE(1482) /0.5208062488E+01/
     *    HL(1482) /0.1427600000E+04/
     *    EQLAT(1482) /0.1099946463E+01/
     *    EQLON(1482) /0.2514064059E+01/
     *    SSLIP(1482) /0.8460000000E+00/
     *    DSLIP(1482) /-.3000000000E+01/
     *    DIP(1482) /0.1570796327E+01/
     *    DEPTH(1482) /0.1800000000E+05/
     *    WIDTH(1482) /0.3000000000E+04/
      DATA STRIKE(1483) /0.5206317159E+01/
     *    HL(1483) /0.1428000000E+04/
     *    EQLAT(1483) /0.1099724980E+01/
     *    EQLON(1483) /0.2513209197E+01/
     *    SSLIP(1483) /0.1169000000E+01/
     *    DSLIP(1483) /-.3000000000E+01/
     *    DIP(1483) /0.1570796327E+01/
     *    DEPTH(1483) /0.1800000000E+05/
     *    WIDTH(1483) /0.3000000000E+04/
      DATA STRIKE(1484) /0.5204571829E+01/
     *    HL(1484) /0.1428500000E+04/
     *    EQLAT(1484) /0.1099503498E+01/
     *    EQLON(1484) /0.2512354160E+01/
     *    SSLIP(1484) /0.1297000000E+01/
     *    DSLIP(1484) /-.3000000000E+01/
     *    DIP(1484) /0.1570796327E+01/
     *    DEPTH(1484) /0.1800000000E+05/
     *    WIDTH(1484) /0.3000000000E+04/
      DATA STRIKE(1485) /0.5202826500E+01/
     *    HL(1485) /0.1429000000E+04/
     *    EQLAT(1485) /0.1099282016E+01/
     *    EQLON(1485) /0.2511499298E+01/
     *    SSLIP(1485) /0.1165000000E+01/
     *    DSLIP(1485) /-.3000000000E+01/
     *    DIP(1485) /0.1570796327E+01/
     *    DEPTH(1485) /0.1800000000E+05/
     *    WIDTH(1485) /0.3000000000E+04/
      DATA STRIKE(1486) /0.5201081171E+01/
     *    HL(1486) /0.1429500000E+04/
     *    EQLAT(1486) /0.1099060534E+01/
     *    EQLON(1486) /0.2510644435E+01/
     *    SSLIP(1486) /0.8390000000E+00/
     *    DSLIP(1486) /-.3000000000E+01/
     *    DIP(1486) /0.1570796327E+01/
     *    DEPTH(1486) /0.1800000000E+05/
     *    WIDTH(1486) /0.3000000000E+04/
      DATA STRIKE(1487) /0.5199335842E+01/
     *    HL(1487) /0.1429900000E+04/
     *    EQLAT(1487) /0.1098839051E+01/
     *    EQLON(1487) /0.2509789398E+01/
     *    SSLIP(1487) /0.4740000000E+00/
     *    DSLIP(1487) /-.2990000000E+01/
     *    DIP(1487) /0.1570796327E+01/
     *    DEPTH(1487) /0.1800000000E+05/
     *    WIDTH(1487) /0.3000000000E+04/
      DATA STRIKE(1488) /0.5197590512E+01/
     *    HL(1488) /0.1430400000E+04/
     *    EQLAT(1488) /0.1098617743E+01/
     *    EQLON(1488) /0.2508934536E+01/
     *    SSLIP(1488) /0.2100000000E+00/
     *    DSLIP(1488) /-.2680000000E+01/
     *    DIP(1488) /0.1570796327E+01/
     *    DEPTH(1488) /0.1800000000E+05/
     *    WIDTH(1488) /0.3000000000E+04/
      DATA STRIKE(1489) /0.5195845183E+01/
     *    HL(1489) /0.1430900000E+04/
     *    EQLAT(1489) /0.1098396261E+01/
     *    EQLON(1489) /0.2508079674E+01/
     *    SSLIP(1489) /0.7500000000E-01/
     *    DSLIP(1489) /-.2130000000E+01/
     *    DIP(1489) /0.1570796327E+01/
     *    DEPTH(1489) /0.1800000000E+05/
     *    WIDTH(1489) /0.3000000000E+04/
      DATA STRIKE(1490) /0.5229006439E+01/
     *    HL(1490) /0.1431300000E+04/
     *    EQLAT(1490) /0.1098174779E+01/
     *    EQLON(1490) /0.2507224637E+01/
     *    SSLIP(1490) /0.0000000000E+00/
     *    DSLIP(1490) /-.1500000000E+01/
     *    DIP(1490) /0.1570796327E+01/
     *    DEPTH(1490) /0.1800000000E+05/
     *    WIDTH(1490) /0.3000000000E+04/
      DATA STRIKE(1491) /0.5227261110E+01/
     *    HL(1491) /0.1431800000E+04/
     *    EQLAT(1491) /0.1097953297E+01/
     *    EQLON(1491) /0.2506369775E+01/
     *    SSLIP(1491) /0.0000000000E+00/
     *    DSLIP(1491) /-.9200000000E+00/
     *    DIP(1491) /0.1570796327E+01/
     *    DEPTH(1491) /0.1800000000E+05/
     *    WIDTH(1491) /0.3000000000E+04/
      DATA STRIKE(1492) /0.5225515780E+01/
     *    HL(1492) /0.1432300000E+04/
     *    EQLAT(1492) /0.1097731814E+01/
     *    EQLON(1492) /0.2505514913E+01/
     *    SSLIP(1492) /0.0000000000E+00/
     *    DSLIP(1492) /-.4800000000E+00/
     *    DIP(1492) /0.1570796327E+01/
     *    DEPTH(1492) /0.1800000000E+05/
     *    WIDTH(1492) /0.3000000000E+04/
      DATA STRIKE(1493) /0.5223770451E+01/
     *    HL(1493) /0.1432700000E+04/
     *    EQLAT(1493) /0.1097510332E+01/
     *    EQLON(1493) /0.2504659876E+01/
     *    SSLIP(1493) /0.0000000000E+00/
     *    DSLIP(1493) /-.2000000000E+00/
     *    DIP(1493) /0.1570796327E+01/
     *    DEPTH(1493) /0.1800000000E+05/
     *    WIDTH(1493) /0.3000000000E+04/
      DATA STRIKE(1494) /0.5222025122E+01/
     *    HL(1494) /0.1433200000E+04/
     *    EQLAT(1494) /0.1097288850E+01/
     *    EQLON(1494) /0.2503805014E+01/
     *    SSLIP(1494) /0.0000000000E+00/
     *    DSLIP(1494) /-.7000000000E-01/
     *    DIP(1494) /0.1570796327E+01/
     *    DEPTH(1494) /0.1800000000E+05/
     *    WIDTH(1494) /0.3000000000E+04/
      DATA STRIKE(1495) /0.5220279793E+01/
     *    HL(1495) /0.1433700000E+04/
     *    EQLAT(1495) /0.1097067368E+01/
     *    EQLON(1495) /0.2502950151E+01/
     *    SSLIP(1495) /0.0000000000E+00/
     *    DSLIP(1495) /-.2000000000E-01/
     *    DIP(1495) /0.1570796327E+01/
     *    DEPTH(1495) /0.2100000000E+05/
     *    WIDTH(1495) /0.3000000000E+04/
      DATA STRIKE(1496) /0.5218534463E+01/
     *    HL(1496) /0.1434100000E+04/
     *    EQLAT(1496) /0.1096845885E+01/
     *    EQLON(1496) /0.2502095114E+01/
     *    SSLIP(1496) /0.0000000000E+00/
     *    DSLIP(1496) /-.2000000000E-01/
     *    DIP(1496) /0.1570796327E+01/
     *    DEPTH(1496) /0.2100000000E+05/
     *    WIDTH(1496) /0.3000000000E+04/
      DATA STRIKE(1497) /0.4544837372E+01/
     *    HL(1497) /0.1500600000E+04/
     *    EQLAT(1497) /0.1108284599E+01/
     *    EQLON(1497) /0.2578255000E+01/
     *    SSLIP(1497) /0.3563000000E+01/
     *    DSLIP(1497) /0.0000000000E+00/
     *    DIP(1497) /0.1570796327E+01/
     *    DEPTH(1497) /0.2100000000E+05/
     *    WIDTH(1497) /0.3000000000E+04/
      DATA STRIKE(1498) /0.4544837372E+01/
     *    HL(1498) /0.1500600000E+04/
     *    EQLAT(1498) /0.1108363138E+01/
     *    EQLON(1498) /0.2577217925E+01/
     *    SSLIP(1498) /0.3641000000E+01/
     *    DSLIP(1498) /0.0000000000E+00/
     *    DIP(1498) /0.1570796327E+01/
     *    DEPTH(1498) /0.2100000000E+05/
     *    WIDTH(1498) /0.3000000000E+04/
      DATA STRIKE(1499) /0.4546582701E+01/
     *    HL(1499) /0.1500600000E+04/
     *    EQLAT(1499) /0.1108441329E+01/
     *    EQLON(1499) /0.2576180502E+01/
     *    SSLIP(1499) /0.3578000000E+01/
     *    DSLIP(1499) /0.0000000000E+00/
     *    DIP(1499) /0.1570796327E+01/
     *    DEPTH(1499) /0.2100000000E+05/
     *    WIDTH(1499) /0.3000000000E+04/
      DATA STRIKE(1500) /0.4546582701E+01/
     *    HL(1500) /0.1500600000E+04/
     *    EQLAT(1500) /0.1108518996E+01/
     *    EQLON(1500) /0.2575142903E+01/
     *    SSLIP(1500) /0.3229000000E+01/
     *    DSLIP(1500) /0.0000000000E+00/
     *    DIP(1500) /0.1570796327E+01/
     *    DEPTH(1500) /0.2100000000E+05/
     *    WIDTH(1500) /0.3000000000E+04/
      DATA STRIKE(1501) /0.4548328031E+01/
     *    HL(1501) /0.1500600000E+04/
     *    EQLAT(1501) /0.1108596140E+01/
     *    EQLON(1501) /0.2574104956E+01/
     *    SSLIP(1501) /0.2547000000E+01/
     *    DSLIP(1501) /0.0000000000E+00/
     *    DIP(1501) /0.1570796327E+01/
     *    DEPTH(1501) /0.2100000000E+05/
     *    WIDTH(1501) /0.3000000000E+04/
      DATA STRIKE(1502) /0.4548328031E+01/
     *    HL(1502) /0.1500600000E+04/
     *    EQLAT(1502) /0.1108673109E+01/
     *    EQLON(1502) /0.2573066660E+01/
     *    SSLIP(1502) /0.1644000000E+01/
     *    DSLIP(1502) /0.0000000000E+00/
     *    DIP(1502) /0.1570796327E+01/
     *    DEPTH(1502) /0.2100000000E+05/
     *    WIDTH(1502) /0.3000000000E+04/
      DATA STRIKE(1503) /0.4550073360E+01/
     *    HL(1503) /0.1500600000E+04/
     *    EQLAT(1503) /0.1108749380E+01/
     *    EQLON(1503) /0.2572028014E+01/
     *    SSLIP(1503) /0.7640000000E+00/
     *    DSLIP(1503) /0.0000000000E+00/
     *    DIP(1503) /0.1570796327E+01/
     *    DEPTH(1503) /0.2100000000E+05/
     *    WIDTH(1503) /0.3000000000E+04/
      DATA STRIKE(1504) /0.4551818689E+01/
     *    HL(1504) /0.1500600000E+04/
     *    EQLAT(1504) /0.1108825476E+01/
     *    EQLON(1504) /0.2570989020E+01/
     *    SSLIP(1504) /0.1730000000E+00/
     *    DSLIP(1504) /0.0000000000E+00/
     *    DIP(1504) /0.1570796327E+01/
     *    DEPTH(1504) /0.2100000000E+05/
     *    WIDTH(1504) /0.3000000000E+04/
      DATA STRIKE(1505) /0.4551818689E+01/
     *    HL(1505) /0.1500600000E+04/
     *    EQLAT(1505) /0.1108900874E+01/
     *    EQLON(1505) /0.2569949851E+01/
     *    SSLIP(1505) /0.1900000000E-01/
     *    DSLIP(1505) /0.0000000000E+00/
     *    DIP(1505) /0.1570796327E+01/
     *    DEPTH(1505) /0.2100000000E+05/
     *    WIDTH(1505) /0.3000000000E+04/
      DATA STRIKE(1506) /0.4862487296E+01/
     *    HL(1506) /0.1468400000E+04/
     *    EQLAT(1506) /0.1108904540E+01/
     *    EQLON(1506) /0.2568920630E+01/
     *    SSLIP(1506) /0.1860000000E+00/
     *    DSLIP(1506) /0.0000000000E+00/
     *    DIP(1506) /0.1570796327E+01/
     *    DEPTH(1506) /0.2100000000E+05/
     *    WIDTH(1506) /0.3000000000E+04/
      DATA STRIKE(1507) /0.4862487296E+01/
     *    HL(1507) /0.1468600000E+04/
     *    EQLAT(1507) /0.1108836297E+01/
     *    EQLON(1507) /0.2567901532E+01/
     *    SSLIP(1507) /0.3400000000E+00/
     *    DSLIP(1507) /0.0000000000E+00/
     *    DIP(1507) /0.1570796327E+01/
     *    DEPTH(1507) /0.2100000000E+05/
     *    WIDTH(1507) /0.3000000000E+04/
      DATA STRIKE(1508) /0.4862487296E+01/
     *    HL(1508) /0.1468800000E+04/
     *    EQLAT(1508) /0.1108768055E+01/
     *    EQLON(1508) /0.2566882434E+01/
     *    SSLIP(1508) /0.3610000000E+00/
     *    DSLIP(1508) /0.0000000000E+00/
     *    DIP(1508) /0.1570796327E+01/
     *    DEPTH(1508) /0.2100000000E+05/
     *    WIDTH(1508) /0.3000000000E+04/
      DATA STRIKE(1509) /0.4860741967E+01/
     *    HL(1509) /0.1469000000E+04/
     *    EQLAT(1509) /0.1108699987E+01/
     *    EQLON(1509) /0.2565863337E+01/
     *    SSLIP(1509) /0.2590000000E+00/
     *    DSLIP(1509) /-.1000000000E-01/
     *    DIP(1509) /0.1570796327E+01/
     *    DEPTH(1509) /0.2100000000E+05/
     *    WIDTH(1509) /0.3000000000E+04/
      DATA STRIKE(1510) /0.4858996638E+01/
     *    HL(1510) /0.1469200000E+04/
     *    EQLAT(1510) /0.1108631745E+01/
     *    EQLON(1510) /0.2564844413E+01/
     *    SSLIP(1510) /0.1140000000E+00/
     *    DSLIP(1510) /-.2800000000E+00/
     *    DIP(1510) /0.1570796327E+01/
     *    DEPTH(1510) /0.2100000000E+05/
     *    WIDTH(1510) /0.3000000000E+04/
      DATA STRIKE(1511) /0.4857251308E+01/
     *    HL(1511) /0.1469400000E+04/
     *    EQLAT(1511) /0.1108563677E+01/
     *    EQLON(1511) /0.2563825316E+01/
     *    SSLIP(1511) /0.1600000000E-01/
     *    DSLIP(1511) /-.8700000000E+00/
     *    DIP(1511) /0.1570796327E+01/
     *    DEPTH(1511) /0.2100000000E+05/
     *    WIDTH(1511) /0.3000000000E+04/
      DATA STRIKE(1512) /0.4855505979E+01/
     *    HL(1512) /0.1469600000E+04/
     *    EQLAT(1512) /0.1108495434E+01/
     *    EQLON(1512) /0.2562806218E+01/
     *    SSLIP(1512) /0.0000000000E+00/
     *    DSLIP(1512) /-.1640000000E+01/
     *    DIP(1512) /0.1570796327E+01/
     *    DEPTH(1512) /0.2100000000E+05/
     *    WIDTH(1512) /0.3000000000E+04/
      DATA STRIKE(1513) /0.4853760650E+01/
     *    HL(1513) /0.1469800000E+04/
     *    EQLAT(1513) /0.1108427192E+01/
     *    EQLON(1513) /0.2561787120E+01/
     *    SSLIP(1513) /0.0000000000E+00/
     *    DSLIP(1513) /-.2360000000E+01/
     *    DIP(1513) /0.1570796327E+01/
     *    DEPTH(1513) /0.2100000000E+05/
     *    WIDTH(1513) /0.3000000000E+04/
      DATA STRIKE(1514) /0.4852015321E+01/
     *    HL(1514) /0.1470000000E+04/
     *    EQLAT(1514) /0.1108359124E+01/
     *    EQLON(1514) /0.2560768197E+01/
     *    SSLIP(1514) /0.0000000000E+00/
     *    DSLIP(1514) /-.2840000000E+01/
     *    DIP(1514) /0.1570796327E+01/
     *    DEPTH(1514) /0.2100000000E+05/
     *    WIDTH(1514) /0.3000000000E+04/
      DATA STRIKE(1515) /0.4850269991E+01/
     *    HL(1515) /0.1470200000E+04/
     *    EQLAT(1515) /0.1108290882E+01/
     *    EQLON(1515) /0.2559749099E+01/
     *    SSLIP(1515) /0.2000000000E-02/
     *    DSLIP(1515) /-.3000000000E+01/
     *    DIP(1515) /0.1570796327E+01/
     *    DEPTH(1515) /0.2100000000E+05/
     *    WIDTH(1515) /0.3000000000E+04/
      DATA STRIKE(1516) /0.4848524662E+01/
     *    HL(1516) /0.1470400000E+04/
     *    EQLAT(1516) /0.1108222639E+01/
     *    EQLON(1516) /0.2558730002E+01/
     *    SSLIP(1516) /0.1000000000E-02/
     *    DSLIP(1516) /-.3000000000E+01/
     *    DIP(1516) /0.1570796327E+01/
     *    DEPTH(1516) /0.2100000000E+05/
     *    WIDTH(1516) /0.3000000000E+04/
      DATA STRIKE(1517) /0.4846779333E+01/
     *    HL(1517) /0.1470600000E+04/
     *    EQLAT(1517) /0.1108154572E+01/
     *    EQLON(1517) /0.2557710904E+01/
     *    SSLIP(1517) /0.0000000000E+00/
     *    DSLIP(1517) /-.3000000000E+01/
     *    DIP(1517) /0.1570796327E+01/
     *    DEPTH(1517) /0.2100000000E+05/
     *    WIDTH(1517) /0.3000000000E+04/
      DATA STRIKE(1518) /0.4845034004E+01/
     *    HL(1518) /0.1470800000E+04/
     *    EQLAT(1518) /0.1108086329E+01/
     *    EQLON(1518) /0.2556691981E+01/
     *    SSLIP(1518) /0.0000000000E+00/
     *    DSLIP(1518) /-.3000000000E+01/
     *    DIP(1518) /0.1570796327E+01/
     *    DEPTH(1518) /0.2100000000E+05/
     *    WIDTH(1518) /0.3000000000E+04/
      DATA STRIKE(1519) /0.4843288674E+01/
     *    HL(1519) /0.1470900000E+04/
     *    EQLAT(1519) /0.1108018261E+01/
     *    EQLON(1519) /0.2555672883E+01/
     *    SSLIP(1519) /0.0000000000E+00/
     *    DSLIP(1519) /-.3000000000E+01/
     *    DIP(1519) /0.1570796327E+01/
     *    DEPTH(1519) /0.2100000000E+05/
     *    WIDTH(1519) /0.3000000000E+04/
      DATA STRIKE(1520) /0.4841543345E+01/
     *    HL(1520) /0.1471100000E+04/
     *    EQLAT(1520) /0.1107950019E+01/
     *    EQLON(1520) /0.2554653785E+01/
     *    SSLIP(1520) /0.0000000000E+00/
     *    DSLIP(1520) /-.3000000000E+01/
     *    DIP(1520) /0.1570796327E+01/
     *    DEPTH(1520) /0.2100000000E+05/
     *    WIDTH(1520) /0.3000000000E+04/
      DATA STRIKE(1521) /0.4839798016E+01/
     *    HL(1521) /0.1471300000E+04/
     *    EQLAT(1521) /0.1107881777E+01/
     *    EQLON(1521) /0.2553634687E+01/
     *    SSLIP(1521) /0.0000000000E+00/
     *    DSLIP(1521) /-.3000000000E+01/
     *    DIP(1521) /0.1570796327E+01/
     *    DEPTH(1521) /0.2100000000E+05/
     *    WIDTH(1521) /0.3000000000E+04/
      DATA STRIKE(1522) /0.4967207051E+01/
     *    HL(1522) /0.1450200000E+04/
     *    EQLAT(1522) /0.1107785434E+01/
     *    EQLON(1522) /0.2552637057E+01/
     *    SSLIP(1522) /0.0000000000E+00/
     *    DSLIP(1522) /-.3000000000E+01/
     *    DIP(1522) /0.1570796327E+01/
     *    DEPTH(1522) /0.2100000000E+05/
     *    WIDTH(1522) /0.3000000000E+04/
      DATA STRIKE(1523) /0.4965461722E+01/
     *    HL(1523) /0.1450500000E+04/
     *    EQLAT(1523) /0.1107660818E+01/
     *    EQLON(1523) /0.2551660720E+01/
     *    SSLIP(1523) /0.0000000000E+00/
     *    DSLIP(1523) /-.2610000000E+01/
     *    DIP(1523) /0.1570796327E+01/
     *    DEPTH(1523) /0.2100000000E+05/
     *    WIDTH(1523) /0.3000000000E+04/
      DATA STRIKE(1524) /0.4963716393E+01/
     *    HL(1524) /0.1450900000E+04/
     *    EQLAT(1524) /0.1107536027E+01/
     *    EQLON(1524) /0.2550684208E+01/
     *    SSLIP(1524) /0.0000000000E+00/
     *    DSLIP(1524) /-.1640000000E+01/
     *    DIP(1524) /0.1570796327E+01/
     *    DEPTH(1524) /0.2100000000E+05/
     *    WIDTH(1524) /0.3000000000E+04/
      DATA STRIKE(1525) /0.4961971063E+01/
     *    HL(1525) /0.1451200000E+04/
     *    EQLAT(1525) /0.1107411410E+01/
     *    EQLON(1525) /0.2549707871E+01/
     *    SSLIP(1525) /0.0000000000E+00/
     *    DSLIP(1525) /-.5700000000E+00/
     *    DIP(1525) /0.1570796327E+01/
     *    DEPTH(1525) /0.2100000000E+05/
     *    WIDTH(1525) /0.3000000000E+04/
      DATA STRIKE(1526) /0.4960225734E+01/
     *    HL(1526) /0.1451500000E+04/
     *    EQLAT(1526) /0.1107286794E+01/
     *    EQLON(1526) /0.2548731534E+01/
     *    SSLIP(1526) /0.0000000000E+00/
     *    DSLIP(1526) /0.0000000000E+00/
     *    DIP(1526) /0.1570796327E+01/
     *    DEPTH(1526) /0.2100000000E+05/
     *    WIDTH(1526) /0.3000000000E+04/
      DATA STRIKE(1527) /0.4956735076E+01/
     *    HL(1527) /0.1451900000E+04/
     *    EQLAT(1527) /0.1107162003E+01/
     *    EQLON(1527) /0.2547755022E+01/
     *    SSLIP(1527) /0.5000000000E-01/
     *    DSLIP(1527) /0.0000000000E+00/
     *    DIP(1527) /0.1570796327E+01/
     *    DEPTH(1527) /0.2100000000E+05/
     *    WIDTH(1527) /0.3000000000E+04/
      DATA STRIKE(1528) /0.4954989746E+01/
     *    HL(1528) /0.1452200000E+04/
     *    EQLAT(1528) /0.1107037386E+01/
     *    EQLON(1528) /0.2546778685E+01/
     *    SSLIP(1528) /0.1265000000E+01/
     *    DSLIP(1528) /0.0000000000E+00/
     *    DIP(1528) /0.1570796327E+01/
     *    DEPTH(1528) /0.2100000000E+05/
     *    WIDTH(1528) /0.3000000000E+04/
      DATA STRIKE(1529) /0.5239478414E+01/
     *    HL(1529) /0.1384800000E+04/
     *    EQLAT(1529) /0.1106865995E+01/
     *    EQLON(1529) /0.2545872335E+01/
     *    SSLIP(1529) /0.3338000000E+01/
     *    DSLIP(1529) /0.0000000000E+00/
     *    DIP(1529) /0.1570796327E+01/
     *    DEPTH(1529) /0.2100000000E+05/
     *    WIDTH(1529) /0.3000000000E+04/
      DATA STRIKE(1530) /0.5237733085E+01/
     *    HL(1530) /0.1385300000E+04/
     *    EQLAT(1530) /0.1106647829E+01/
     *    EQLON(1530) /0.2545035799E+01/
     *    SSLIP(1530) /0.4783000000E+01/
     *    DSLIP(1530) /0.0000000000E+00/
     *    DIP(1530) /0.1570796327E+01/
     *    DEPTH(1530) /0.2100000000E+05/
     *    WIDTH(1530) /0.3000000000E+04/
      DATA STRIKE(1531) /0.5235987756E+01/
     *    HL(1531) /0.1385700000E+04/
     *    EQLAT(1531) /0.1106429663E+01/
     *    EQLON(1531) /0.2544199437E+01/
     *    SSLIP(1531) /0.4969000000E+01/
     *    DSLIP(1531) /0.0000000000E+00/
     *    DIP(1531) /0.1570796327E+01/
     *    DEPTH(1531) /0.2100000000E+05/
     *    WIDTH(1531) /0.3000000000E+04/
      DATA STRIKE(1532) /0.5234242427E+01/
     *    HL(1532) /0.1386200000E+04/
     *    EQLAT(1532) /0.1106211497E+01/
     *    EQLON(1532) /0.2543362901E+01/
     *    SSLIP(1532) /0.4036000000E+01/
     *    DSLIP(1532) /0.0000000000E+00/
     *    DIP(1532) /0.1570796327E+01/
     *    DEPTH(1532) /0.2100000000E+05/
     *    WIDTH(1532) /0.3000000000E+04/
      DATA STRIKE(1533) /0.5232497097E+01/
     *    HL(1533) /0.1386600000E+04/
     *    EQLAT(1533) /0.1105993330E+01/
     *    EQLON(1533) /0.2542526539E+01/
     *    SSLIP(1533) /0.2578000000E+01/
     *    DSLIP(1533) /0.0000000000E+00/
     *    DIP(1533) /0.1570796327E+01/
     *    DEPTH(1533) /0.2100000000E+05/
     *    WIDTH(1533) /0.3000000000E+04/
      DATA STRIKE(1534) /0.5230751768E+01/
     *    HL(1534) /0.1387100000E+04/
     *    EQLAT(1534) /0.1105775164E+01/
     *    EQLON(1534) /0.2541690003E+01/
     *    SSLIP(1534) /0.1324000000E+01/
     *    DSLIP(1534) /0.0000000000E+00/
     *    DIP(1534) /0.1570796327E+01/
     *    DEPTH(1534) /0.2100000000E+05/
     *    WIDTH(1534) /0.3000000000E+04/
      DATA STRIKE(1535) /0.5229006439E+01/
     *    HL(1535) /0.1387500000E+04/
     *    EQLAT(1535) /0.1105556998E+01/
     *    EQLON(1535) /0.2540853641E+01/
     *    SSLIP(1535) /0.8560000000E+00/
     *    DSLIP(1535) /0.0000000000E+00/
     *    DIP(1535) /0.1570796327E+01/
     *    DEPTH(1535) /0.2100000000E+05/
     *    WIDTH(1535) /0.3000000000E+04/
      DATA STRIKE(1536) /0.5227261110E+01/
     *    HL(1536) /0.1388000000E+04/
     *    EQLAT(1536) /0.1105338832E+01/
     *    EQLON(1536) /0.2540017105E+01/
     *    SSLIP(1536) /0.1343000000E+01/
     *    DSLIP(1536) /0.0000000000E+00/
     *    DIP(1536) /0.1570796327E+01/
     *    DEPTH(1536) /0.2100000000E+05/
     *    WIDTH(1536) /0.3000000000E+04/
      DATA STRIKE(1537) /0.5047492197E+01/
     *    HL(1537) /0.1434000000E+04/
     *    EQLAT(1537) /0.1105152954E+01/
     *    EQLON(1537) /0.2539129605E+01/
     *    SSLIP(1537) /0.2378000000E+01/
     *    DSLIP(1537) /0.0000000000E+00/
     *    DIP(1537) /0.1570796327E+01/
     *    DEPTH(1537) /0.2100000000E+05/
     *    WIDTH(1537) /0.3000000000E+04/
      DATA STRIKE(1538) /0.5045746868E+01/
     *    HL(1538) /0.1434400000E+04/
     *    EQLAT(1538) /0.1104999540E+01/
     *    EQLON(1538) /0.2538190967E+01/
     *    SSLIP(1538) /0.3019000000E+01/
     *    DSLIP(1538) /0.0000000000E+00/
     *    DIP(1538) /0.1570796327E+01/
     *    DEPTH(1538) /0.2100000000E+05/
     *    WIDTH(1538) /0.3000000000E+04/
      DATA STRIKE(1539) /0.5044001538E+01/
     *    HL(1539) /0.1434700000E+04/
     *    EQLAT(1539) /0.1104846125E+01/
     *    EQLON(1539) /0.2537252329E+01/
     *    SSLIP(1539) /0.2985000000E+01/
     *    DSLIP(1539) /0.0000000000E+00/
     *    DIP(1539) /0.1570796327E+01/
     *    DEPTH(1539) /0.2100000000E+05/
     *    WIDTH(1539) /0.3000000000E+04/
      DATA STRIKE(1540) /0.5042256209E+01/
     *    HL(1540) /0.1435100000E+04/
     *    EQLAT(1540) /0.1104692711E+01/
     *    EQLON(1540) /0.2536313516E+01/
     *    SSLIP(1540) /0.2550000000E+01/
     *    DSLIP(1540) /0.0000000000E+00/
     *    DIP(1540) /0.1570796327E+01/
     *    DEPTH(1540) /0.2100000000E+05/
     *    WIDTH(1540) /0.3000000000E+04/
      DATA STRIKE(1541) /0.5040510880E+01/
     *    HL(1541) /0.1435500000E+04/
     *    EQLAT(1541) /0.1104539297E+01/
     *    EQLON(1541) /0.2535374878E+01/
     *    SSLIP(1541) /0.2181000000E+01/
     *    DSLIP(1541) /0.0000000000E+00/
     *    DIP(1541) /0.1570796327E+01/
     *    DEPTH(1541) /0.2100000000E+05/
     *    WIDTH(1541) /0.3000000000E+04/
      DATA STRIKE(1542) /0.5038765551E+01/
     *    HL(1542) /0.1435900000E+04/
     *    EQLAT(1542) /0.1104385882E+01/
     *    EQLON(1542) /0.2534436240E+01/
     *    SSLIP(1542) /0.2223000000E+01/
     *    DSLIP(1542) /0.0000000000E+00/
     *    DIP(1542) /0.1570796327E+01/
     *    DEPTH(1542) /0.2100000000E+05/
     *    WIDTH(1542) /0.3000000000E+04/
      DATA STRIKE(1543) /0.5037020221E+01/
     *    HL(1543) /0.1436300000E+04/
     *    EQLAT(1543) /0.1104232468E+01/
     *    EQLON(1543) /0.2533497602E+01/
     *    SSLIP(1543) /0.2719000000E+01/
     *    DSLIP(1543) /0.0000000000E+00/
     *    DIP(1543) /0.1570796327E+01/
     *    DEPTH(1543) /0.2100000000E+05/
     *    WIDTH(1543) /0.3000000000E+04/
      DATA STRIKE(1544) /0.5035274892E+01/
     *    HL(1544) /0.1436700000E+04/
     *    EQLAT(1544) /0.1104079053E+01/
     *    EQLON(1544) /0.2532558964E+01/
     *    SSLIP(1544) /0.3409000000E+01/
     *    DSLIP(1544) /0.0000000000E+00/
     *    DIP(1544) /0.1570796327E+01/
     *    DEPTH(1544) /0.2100000000E+05/
     *    WIDTH(1544) /0.3000000000E+04/
      DATA STRIKE(1545) /0.5033529563E+01/
     *    HL(1545) /0.1437100000E+04/
     *    EQLAT(1545) /0.1103925639E+01/
     *    EQLON(1545) /0.2531620151E+01/
     *    SSLIP(1545) /0.3853000000E+01/
     *    DSLIP(1545) /0.0000000000E+00/
     *    DIP(1545) /0.1570796327E+01/
     *    DEPTH(1545) /0.2100000000E+05/
     *    WIDTH(1545) /0.3000000000E+04/
      DATA STRIKE(1546) /0.5031784233E+01/
     *    HL(1546) /0.1437400000E+04/
     *    EQLAT(1546) /0.1103772224E+01/
     *    EQLON(1546) /0.2530681513E+01/
     *    SSLIP(1546) /0.3651000000E+01/
     *    DSLIP(1546) /0.0000000000E+00/
     *    DIP(1546) /0.1570796327E+01/
     *    DEPTH(1546) /0.2100000000E+05/
     *    WIDTH(1546) /0.3000000000E+04/
      DATA STRIKE(1547) /0.5030038904E+01/
     *    HL(1547) /0.1437800000E+04/
     *    EQLAT(1547) /0.1103618810E+01/
     *    EQLON(1547) /0.2529742875E+01/
     *    SSLIP(1547) /0.2666000000E+01/
     *    DSLIP(1547) /0.0000000000E+00/
     *    DIP(1547) /0.1570796327E+01/
     *    DEPTH(1547) /0.2100000000E+05/
     *    WIDTH(1547) /0.3000000000E+04/
      DATA STRIKE(1548) /0.5153957281E+01/
     *    HL(1548) /0.1412200000E+04/
     *    EQLAT(1548) /0.1103441310E+01/
     *    EQLON(1548) /0.2528837224E+01/
     *    SSLIP(1548) /0.1235000000E+01/
     *    DSLIP(1548) /0.0000000000E+00/
     *    DIP(1548) /0.1570796327E+01/
     *    DEPTH(1548) /0.2100000000E+05/
     *    WIDTH(1548) /0.3000000000E+04/
      DATA STRIKE(1549) /0.5152211952E+01/
     *    HL(1549) /0.1412700000E+04/
     *    EQLAT(1549) /0.1103239899E+01/
     *    EQLON(1549) /0.2527964559E+01/
     *    SSLIP(1549) /0.2730000000E+00/
     *    DSLIP(1549) /0.0000000000E+00/
     *    DIP(1549) /0.1570796327E+01/
     *    DEPTH(1549) /0.2100000000E+05/
     *    WIDTH(1549) /0.3000000000E+04/
      DATA STRIKE(1550) /0.5150466623E+01/
     *    HL(1550) /0.1413100000E+04/
     *    EQLAT(1550) /0.1103038313E+01/
     *    EQLON(1550) /0.2527091895E+01/
     *    SSLIP(1550) /0.0000000000E+00/
     *    DSLIP(1550) /0.0000000000E+00/
     *    DIP(1550) /0.1570796327E+01/
     *    DEPTH(1550) /0.2100000000E+05/
     *    WIDTH(1550) /0.3000000000E+04/
      DATA STRIKE(1551) /0.5183627878E+01/
     *    HL(1551) /0.1413500000E+04/
     *    EQLAT(1551) /0.1102836902E+01/
     *    EQLON(1551) /0.2526219230E+01/
     *    SSLIP(1551) /0.0000000000E+00/
     *    DSLIP(1551) /0.0000000000E+00/
     *    DIP(1551) /0.1570796327E+01/
     *    DEPTH(1551) /0.2100000000E+05/
     *    WIDTH(1551) /0.3000000000E+04/
      DATA STRIKE(1552) /0.5181882549E+01/
     *    HL(1552) /0.1414000000E+04/
     *    EQLAT(1552) /0.1102635491E+01/
     *    EQLON(1552) /0.2525346565E+01/
     *    SSLIP(1552) /0.0000000000E+00/
     *    DSLIP(1552) /0.0000000000E+00/
     *    DIP(1552) /0.1570796327E+01/
     *    DEPTH(1552) /0.2100000000E+05/
     *    WIDTH(1552) /0.3000000000E+04/
      DATA STRIKE(1553) /0.5180137220E+01/
     *    HL(1553) /0.1414400000E+04/
     *    EQLAT(1553) /0.1102433906E+01/
     *    EQLON(1553) /0.2524473901E+01/
     *    SSLIP(1553) /0.0000000000E+00/
     *    DSLIP(1553) /0.0000000000E+00/
     *    DIP(1553) /0.1570796327E+01/
     *    DEPTH(1553) /0.2100000000E+05/
     *    WIDTH(1553) /0.3000000000E+04/
      DATA STRIKE(1554) /0.5178391891E+01/
     *    HL(1554) /0.1414900000E+04/
     *    EQLAT(1554) /0.1102232495E+01/
     *    EQLON(1554) /0.2523601236E+01/
     *    SSLIP(1554) /0.0000000000E+00/
     *    DSLIP(1554) /0.0000000000E+00/
     *    DIP(1554) /0.1570796327E+01/
     *    DEPTH(1554) /0.2100000000E+05/
     *    WIDTH(1554) /0.3000000000E+04/
      DATA STRIKE(1555) /0.5176646561E+01/
     *    HL(1555) /0.1415300000E+04/
     *    EQLAT(1555) /0.1102031084E+01/
     *    EQLON(1555) /0.2522728571E+01/
     *    SSLIP(1555) /0.0000000000E+00/
     *    DSLIP(1555) /0.0000000000E+00/
     *    DIP(1555) /0.1570796327E+01/
     *    DEPTH(1555) /0.2100000000E+05/
     *    WIDTH(1555) /0.3000000000E+04/
      DATA STRIKE(1556) /0.5174901232E+01/
     *    HL(1556) /0.1415800000E+04/
     *    EQLAT(1556) /0.1101829673E+01/
     *    EQLON(1556) /0.2521855907E+01/
     *    SSLIP(1556) /0.0000000000E+00/
     *    DSLIP(1556) /0.0000000000E+00/
     *    DIP(1556) /0.1570796327E+01/
     *    DEPTH(1556) /0.2100000000E+05/
     *    WIDTH(1556) /0.3000000000E+04/
      DATA STRIKE(1557) /0.5173155903E+01/
     *    HL(1557) /0.1416200000E+04/
     *    EQLAT(1557) /0.1101628087E+01/
     *    EQLON(1557) /0.2520983242E+01/
     *    SSLIP(1557) /0.0000000000E+00/
     *    DSLIP(1557) /0.0000000000E+00/
     *    DIP(1557) /0.1570796327E+01/
     *    DEPTH(1557) /0.2100000000E+05/
     *    WIDTH(1557) /0.3000000000E+04/
      DATA STRIKE(1558) /0.5171410574E+01/
     *    HL(1558) /0.1416700000E+04/
     *    EQLAT(1558) /0.1101426676E+01/
     *    EQLON(1558) /0.2520110578E+01/
     *    SSLIP(1558) /0.0000000000E+00/
     *    DSLIP(1558) /0.0000000000E+00/
     *    DIP(1558) /0.1570796327E+01/
     *    DEPTH(1558) /0.2100000000E+05/
     *    WIDTH(1558) /0.3000000000E+04/
      DATA STRIKE(1559) /0.5169665244E+01/
     *    HL(1559) /0.1417100000E+04/
     *    EQLAT(1559) /0.1101225265E+01/
     *    EQLON(1559) /0.2519237913E+01/
     *    SSLIP(1559) /0.0000000000E+00/
     *    DSLIP(1559) /-.1300000000E+00/
     *    DIP(1559) /0.1570796327E+01/
     *    DEPTH(1559) /0.2100000000E+05/
     *    WIDTH(1559) /0.3000000000E+04/
      DATA STRIKE(1560) /0.5167919915E+01/
     *    HL(1560) /0.1417600000E+04/
     *    EQLAT(1560) /0.1101023680E+01/
     *    EQLON(1560) /0.2518365248E+01/
     *    SSLIP(1560) /0.0000000000E+00/
     *    DSLIP(1560) /-.5200000000E+00/
     *    DIP(1560) /0.1570796327E+01/
     *    DEPTH(1560) /0.2100000000E+05/
     *    WIDTH(1560) /0.3000000000E+04/
      DATA STRIKE(1561) /0.5166174586E+01/
     *    HL(1561) /0.1418000000E+04/
     *    EQLAT(1561) /0.1100822269E+01/
     *    EQLON(1561) /0.2517492584E+01/
     *    SSLIP(1561) /0.0000000000E+00/
     *    DSLIP(1561) /-.1140000000E+01/
     *    DIP(1561) /0.1570796327E+01/
     *    DEPTH(1561) /0.2100000000E+05/
     *    WIDTH(1561) /0.3000000000E+04/
      DATA STRIKE(1562) /0.5213298476E+01/
     *    HL(1562) /0.1426200000E+04/
     *    EQLAT(1562) /0.1100610909E+01/
     *    EQLON(1562) /0.2516628820E+01/
     *    SSLIP(1562) /0.0000000000E+00/
     *    DSLIP(1562) /-.1840000000E+01/
     *    DIP(1562) /0.1570796327E+01/
     *    DEPTH(1562) /0.2100000000E+05/
     *    WIDTH(1562) /0.3000000000E+04/
      DATA STRIKE(1563) /0.5211553146E+01/
     *    HL(1563) /0.1426600000E+04/
     *    EQLAT(1563) /0.1100389427E+01/
     *    EQLON(1563) /0.2515773958E+01/
     *    SSLIP(1563) /0.0000000000E+00/
     *    DSLIP(1563) /-.2460000000E+01/
     *    DIP(1563) /0.1570796327E+01/
     *    DEPTH(1563) /0.2100000000E+05/
     *    WIDTH(1563) /0.3000000000E+04/
      DATA STRIKE(1564) /0.5209807817E+01/
     *    HL(1564) /0.1427100000E+04/
     *    EQLAT(1564) /0.1100167945E+01/
     *    EQLON(1564) /0.2514918921E+01/
     *    SSLIP(1564) /0.1230000000E+00/
     *    DSLIP(1564) /-.2860000000E+01/
     *    DIP(1564) /0.1570796327E+01/
     *    DEPTH(1564) /0.2100000000E+05/
     *    WIDTH(1564) /0.3000000000E+04/
      DATA STRIKE(1565) /0.5208062488E+01/
     *    HL(1565) /0.1427600000E+04/
     *    EQLAT(1565) /0.1099946463E+01/
     *    EQLON(1565) /0.2514064059E+01/
     *    SSLIP(1565) /0.3900000000E+00/
     *    DSLIP(1565) /-.3000000000E+01/
     *    DIP(1565) /0.1570796327E+01/
     *    DEPTH(1565) /0.2100000000E+05/
     *    WIDTH(1565) /0.3000000000E+04/
      DATA STRIKE(1566) /0.5206317159E+01/
     *    HL(1566) /0.1428000000E+04/
     *    EQLAT(1566) /0.1099724980E+01/
     *    EQLON(1566) /0.2513209197E+01/
     *    SSLIP(1566) /0.6540000000E+00/
     *    DSLIP(1566) /-.3000000000E+01/
     *    DIP(1566) /0.1570796327E+01/
     *    DEPTH(1566) /0.2100000000E+05/
     *    WIDTH(1566) /0.3000000000E+04/
      DATA STRIKE(1567) /0.5204571829E+01/
     *    HL(1567) /0.1428500000E+04/
     *    EQLAT(1567) /0.1099503498E+01/
     *    EQLON(1567) /0.2512354160E+01/
     *    SSLIP(1567) /0.7670000000E+00/
     *    DSLIP(1567) /-.3000000000E+01/
     *    DIP(1567) /0.1570796327E+01/
     *    DEPTH(1567) /0.2100000000E+05/
     *    WIDTH(1567) /0.3000000000E+04/
      DATA STRIKE(1568) /0.5202826500E+01/
     *    HL(1568) /0.1429000000E+04/
     *    EQLAT(1568) /0.1099282016E+01/
     *    EQLON(1568) /0.2511499298E+01/
     *    SSLIP(1568) /0.6650000000E+00/
     *    DSLIP(1568) /-.3000000000E+01/
     *    DIP(1568) /0.1570796327E+01/
     *    DEPTH(1568) /0.2100000000E+05/
     *    WIDTH(1568) /0.3000000000E+04/
      DATA STRIKE(1569) /0.5201081171E+01/
     *    HL(1569) /0.1429500000E+04/
     *    EQLAT(1569) /0.1099060534E+01/
     *    EQLON(1569) /0.2510644435E+01/
     *    SSLIP(1569) /0.4080000000E+00/
     *    DSLIP(1569) /-.3000000000E+01/
     *    DIP(1569) /0.1570796327E+01/
     *    DEPTH(1569) /0.2100000000E+05/
     *    WIDTH(1569) /0.3000000000E+04/
      DATA STRIKE(1570) /0.5199335842E+01/
     *    HL(1570) /0.1429900000E+04/
     *    EQLAT(1570) /0.1098839051E+01/
     *    EQLON(1570) /0.2509789398E+01/
     *    SSLIP(1570) /0.1380000000E+00/
     *    DSLIP(1570) /-.3000000000E+01/
     *    DIP(1570) /0.1570796327E+01/
     *    DEPTH(1570) /0.2100000000E+05/
     *    WIDTH(1570) /0.3000000000E+04/
      DATA STRIKE(1571) /0.5197590512E+01/
     *    HL(1571) /0.1430400000E+04/
     *    EQLAT(1571) /0.1098617743E+01/
     *    EQLON(1571) /0.2508934536E+01/
     *    SSLIP(1571) /0.0000000000E+00/
     *    DSLIP(1571) /-.2780000000E+01/
     *    DIP(1571) /0.1570796327E+01/
     *    DEPTH(1571) /0.2100000000E+05/
     *    WIDTH(1571) /0.3000000000E+04/
      DATA STRIKE(1572) /0.5195845183E+01/
     *    HL(1572) /0.1430900000E+04/
     *    EQLAT(1572) /0.1098396261E+01/
     *    EQLON(1572) /0.2508079674E+01/
     *    SSLIP(1572) /0.0000000000E+00/
     *    DSLIP(1572) /-.2290000000E+01/
     *    DIP(1572) /0.1570796327E+01/
     *    DEPTH(1572) /0.2100000000E+05/
     *    WIDTH(1572) /0.3000000000E+04/
      DATA STRIKE(1573) /0.5229006439E+01/
     *    HL(1573) /0.1431300000E+04/
     *    EQLAT(1573) /0.1098174779E+01/
     *    EQLON(1573) /0.2507224637E+01/
     *    SSLIP(1573) /0.0000000000E+00/
     *    DSLIP(1573) /-.1680000000E+01/
     *    DIP(1573) /0.1570796327E+01/
     *    DEPTH(1573) /0.2100000000E+05/
     *    WIDTH(1573) /0.3000000000E+04/
      DATA STRIKE(1574) /0.5227261110E+01/
     *    HL(1574) /0.1431800000E+04/
     *    EQLAT(1574) /0.1097953297E+01/
     *    EQLON(1574) /0.2506369775E+01/
     *    SSLIP(1574) /0.0000000000E+00/
     *    DSLIP(1574) /-.1090000000E+01/
     *    DIP(1574) /0.1570796327E+01/
     *    DEPTH(1574) /0.2100000000E+05/
     *    WIDTH(1574) /0.3000000000E+04/
      DATA STRIKE(1575) /0.5225515780E+01/
     *    HL(1575) /0.1432300000E+04/
     *    EQLAT(1575) /0.1097731814E+01/
     *    EQLON(1575) /0.2505514913E+01/
     *    SSLIP(1575) /0.0000000000E+00/
     *    DSLIP(1575) /-.6200000000E+00/
     *    DIP(1575) /0.1570796327E+01/
     *    DEPTH(1575) /0.2100000000E+05/
     *    WIDTH(1575) /0.3000000000E+04/
      DATA STRIKE(1576) /0.5223770451E+01/
     *    HL(1576) /0.1432700000E+04/
     *    EQLAT(1576) /0.1097510332E+01/
     *    EQLON(1576) /0.2504659876E+01/
     *    SSLIP(1576) /0.0000000000E+00/
     *    DSLIP(1576) /-.3000000000E+00/
     *    DIP(1576) /0.1570796327E+01/
     *    DEPTH(1576) /0.2100000000E+05/
     *    WIDTH(1576) /0.3000000000E+04/
      DATA STRIKE(1577) /0.5222025122E+01/
     *    HL(1577) /0.1433200000E+04/
     *    EQLAT(1577) /0.1097288850E+01/
     *    EQLON(1577) /0.2503805014E+01/
     *    SSLIP(1577) /0.0000000000E+00/
     *    DSLIP(1577) /-.1300000000E+00/
     *    DIP(1577) /0.1570796327E+01/
     *    DEPTH(1577) /0.2100000000E+05/
     *    WIDTH(1577) /0.3000000000E+04/
      DATA STRIKE(1578) /0.5220279793E+01/
     *    HL(1578) /0.1433700000E+04/
     *    EQLAT(1578) /0.1097067368E+01/
     *    EQLON(1578) /0.2502950151E+01/
     *    SSLIP(1578) /0.0000000000E+00/
     *    DSLIP(1578) /-.6000000000E-01/
     *    DIP(1578) /0.1570796327E+01/
     *    DEPTH(1578) /0.2400000000E+05/
     *    WIDTH(1578) /0.3000000000E+04/
      DATA STRIKE(1579) /0.5218534463E+01/
     *    HL(1579) /0.1434100000E+04/
     *    EQLAT(1579) /0.1096845885E+01/
     *    EQLON(1579) /0.2502095114E+01/
     *    SSLIP(1579) /0.0000000000E+00/
     *    DSLIP(1579) /-.4000000000E-01/
     *    DIP(1579) /0.1570796327E+01/
     *    DEPTH(1579) /0.2400000000E+05/
     *    WIDTH(1579) /0.3000000000E+04/
      DATA STRIKE(1580) /0.5829399702E+01/
     *    HL(1580) /0.1483700000E+04/
     *    EQLAT(1580) /0.1096525443E+01/
     *    EQLON(1580) /0.2501449517E+01/
     *    SSLIP(1580) /0.6145000000E+01/
     *    DSLIP(1580) /-.1920000000E+01/
     *    DIP(1580) /0.1570796327E+01/
     *    DEPTH(1580) /0.2400000000E+05/
     *    WIDTH(1580) /0.3000000000E+04/
      DATA STRIKE(1581) /0.5827654372E+01/
     *    HL(1581) /0.1483900000E+04/
     *    EQLAT(1581) /0.1096105866E+01/
     *    EQLON(1581) /0.2501013185E+01/
     *    SSLIP(1581) /0.5328000000E+01/
     *    DSLIP(1581) /-.2030000000E+01/
     *    DIP(1581) /0.1570796327E+01/
     *    DEPTH(1581) /0.2400000000E+05/
     *    WIDTH(1581) /0.3000000000E+04/
      DATA STRIKE(1582) /0.5827654372E+01/
     *    HL(1582) /0.1484100000E+04/
     *    EQLAT(1582) /0.1095686114E+01/
     *    EQLON(1582) /0.2500576853E+01/
     *    SSLIP(1582) /0.3713000000E+01/
     *    DSLIP(1582) /-.2630000000E+01/
     *    DIP(1582) /0.1570796327E+01/
     *    DEPTH(1582) /0.2400000000E+05/
     *    WIDTH(1582) /0.3000000000E+04/
      DATA STRIKE(1583) /0.5825909043E+01/
     *    HL(1583) /0.1484300000E+04/
     *    EQLAT(1583) /0.1095266537E+01/
     *    EQLON(1583) /0.2500140520E+01/
     *    SSLIP(1583) /0.1714000000E+01/
     *    DSLIP(1583) /-.2680000000E+01/
     *    DIP(1583) /0.1570796327E+01/
     *    DEPTH(1583) /0.2400000000E+05/
     *    WIDTH(1583) /0.3000000000E+04/
      DATA STRIKE(1584) /0.5825909043E+01/
     *    HL(1584) /0.1484600000E+04/
     *    EQLAT(1584) /0.1094846960E+01/
     *    EQLON(1584) /0.2499704188E+01/
     *    SSLIP(1584) /0.1331000000E+01/
     *    DSLIP(1584) /-.4000000000E+00/
     *    DIP(1584) /0.1570796327E+01/
     *    DEPTH(1584) /0.2400000000E+05/
     *    WIDTH(1584) /0.3000000000E+04/
      DATA STRIKE(1585) /0.5824163714E+01/
     *    HL(1585) /0.1484800000E+04/
     *    EQLAT(1585) /0.1094427208E+01/
     *    EQLON(1585) /0.2499267856E+01/
     *    SSLIP(1585) /0.1459000000E+01/
     *    DSLIP(1585) /0.0000000000E+00/
     *    DIP(1585) /0.1570796327E+01/
     *    DEPTH(1585) /0.2400000000E+05/
     *    WIDTH(1585) /0.3000000000E+04/
      DATA STRIKE(1586) /0.5822418385E+01/
     *    HL(1586) /0.1485000000E+04/
     *    EQLAT(1586) /0.1094007631E+01/
     *    EQLON(1586) /0.2498831523E+01/
     *    SSLIP(1586) /0.1711000000E+01/
     *    DSLIP(1586) /0.0000000000E+00/
     *    DIP(1586) /0.1570796327E+01/
     *    DEPTH(1586) /0.2400000000E+05/
     *    WIDTH(1586) /0.3000000000E+04/
      DATA STRIKE(1587) /0.5553637680E+01/
     *    HL(1587) /0.1457400000E+04/
     *    EQLAT(1587) /0.1093625229E+01/
     *    EQLON(1587) /0.2498288551E+01/
     *    SSLIP(1587) /0.2685000000E+01/
     *    DSLIP(1587) /-.4300000000E+00/
     *    DIP(1587) /0.1570796327E+01/
     *    DEPTH(1587) /0.2400000000E+05/
     *    WIDTH(1587) /0.3000000000E+04/
      DATA STRIKE(1588) /0.5553637680E+01/
     *    HL(1588) /0.1457800000E+04/
     *    EQLAT(1588) /0.1093280178E+01/
     *    EQLON(1588) /0.2497638940E+01/
     *    SSLIP(1588) /0.3119000000E+01/
     *    DSLIP(1588) /-.2400000000E+00/
     *    DIP(1588) /0.1570796327E+01/
     *    DEPTH(1588) /0.2400000000E+05/
     *    WIDTH(1588) /0.3000000000E+04/
      DATA STRIKE(1589) /0.5551892351E+01/
     *    HL(1589) /0.1458200000E+04/
     *    EQLAT(1589) /0.1092935126E+01/
     *    EQLON(1589) /0.2496989503E+01/
     *    SSLIP(1589) /0.3043000000E+01/
     *    DSLIP(1589) /-.5000000000E-01/
     *    DIP(1589) /0.1570796327E+01/
     *    DEPTH(1589) /0.2400000000E+05/
     *    WIDTH(1589) /0.3000000000E+04/
      DATA STRIKE(1590) /0.5550147021E+01/
     *    HL(1590) /0.1458600000E+04/
     *    EQLAT(1590) /0.1092590074E+01/
     *    EQLON(1590) /0.2496339891E+01/
     *    SSLIP(1590) /0.2627000000E+01/
     *    DSLIP(1590) /0.0000000000E+00/
     *    DIP(1590) /0.1570796327E+01/
     *    DEPTH(1590) /0.2400000000E+05/
     *    WIDTH(1590) /0.3000000000E+04/
      DATA STRIKE(1591) /0.5548401692E+01/
     *    HL(1591) /0.1459000000E+04/
     *    EQLAT(1591) /0.1092245023E+01/
     *    EQLON(1591) /0.2495690280E+01/
     *    SSLIP(1591) /0.2179000000E+01/
     *    DSLIP(1591) /0.0000000000E+00/
     *    DIP(1591) /0.1570796327E+01/
     *    DEPTH(1591) /0.2400000000E+05/
     *    WIDTH(1591) /0.3000000000E+04/
      DATA STRIKE(1592) /0.5546656363E+01/
     *    HL(1592) /0.1459400000E+04/
     *    EQLAT(1592) /0.1091899971E+01/
     *    EQLON(1592) /0.2495040668E+01/
     *    SSLIP(1592) /0.2717000000E+01/
     *    DSLIP(1592) /0.0000000000E+00/
     *    DIP(1592) /0.1570796327E+01/
     *    DEPTH(1592) /0.2400000000E+05/
     *    WIDTH(1592) /0.3000000000E+04/
      DATA STRIKE(1593) /0.5544911034E+01/
     *    HL(1593) /0.1459800000E+04/
     *    EQLAT(1593) /0.1091554920E+01/
     *    EQLON(1593) /0.2494391231E+01/
     *    SSLIP(1593) /0.3009000000E+01/
     *    DSLIP(1593) /0.0000000000E+00/
     *    DIP(1593) /0.1570796327E+01/
     *    DEPTH(1593) /0.2400000000E+05/
     *    WIDTH(1593) /0.3000000000E+04/
      DATA STRIKE(1594) /0.5543165704E+01/
     *    HL(1594) /0.1460300000E+04/
     *    EQLAT(1594) /0.1091209868E+01/
     *    EQLON(1594) /0.2493741620E+01/
     *    SSLIP(1594) /0.2925000000E+01/
     *    DSLIP(1594) /0.0000000000E+00/
     *    DIP(1594) /0.1570796327E+01/
     *    DEPTH(1594) /0.2400000000E+05/
     *    WIDTH(1594) /0.3000000000E+04/
      DATA STRIKE(1595) /0.5543165704E+01/
     *    HL(1595) /0.1460700000E+04/
     *    EQLAT(1595) /0.1090864816E+01/
     *    EQLON(1595) /0.2493092008E+01/
     *    SSLIP(1595) /0.2761000000E+01/
     *    DSLIP(1595) /0.0000000000E+00/
     *    DIP(1595) /0.1570796327E+01/
     *    DEPTH(1595) /0.2400000000E+05/
     *    WIDTH(1595) /0.3000000000E+04/
      DATA STRIKE(1596) /0.5541420375E+01/
     *    HL(1596) /0.1461100000E+04/
     *    EQLAT(1596) /0.1090519765E+01/
     *    EQLON(1596) /0.2492442397E+01/
     *    SSLIP(1596) /0.1749000000E+01/
     *    DSLIP(1596) /0.0000000000E+00/
     *    DIP(1596) /0.1570796327E+01/
     *    DEPTH(1596) /0.2400000000E+05/
     *    WIDTH(1596) /0.3000000000E+04/
      DATA STRIKE(1597) /0.5539675046E+01/
     *    HL(1597) /0.1461500000E+04/
     *    EQLAT(1597) /0.1090174713E+01/
     *    EQLON(1597) /0.2491792785E+01/
     *    SSLIP(1597) /0.7030000000E+00/
     *    DSLIP(1597) /0.0000000000E+00/
     *    DIP(1597) /0.1570796327E+01/
     *    DEPTH(1597) /0.2400000000E+05/
     *    WIDTH(1597) /0.3000000000E+04/
      DATA STRIKE(1598) /0.5537929717E+01/
     *    HL(1598) /0.1461900000E+04/
     *    EQLAT(1598) /0.1089829662E+01/
     *    EQLON(1598) /0.2491143348E+01/
     *    SSLIP(1598) /0.1030000000E+00/
     *    DSLIP(1598) /0.0000000000E+00/
     *    DIP(1598) /0.1570796327E+01/
     *    DEPTH(1598) /0.2400000000E+05/
     *    WIDTH(1598) /0.3000000000E+04/
      DATA STRIKE(1599) /0.5536184387E+01/
     *    HL(1599) /0.1462300000E+04/
     *    EQLAT(1599) /0.1089484610E+01/
     *    EQLON(1599) /0.2490493736E+01/
     *    SSLIP(1599) /0.0000000000E+00/
     *    DSLIP(1599) /0.0000000000E+00/
     *    DIP(1599) /0.1570796327E+01/
     *    DEPTH(1599) /0.2400000000E+05/
     *    WIDTH(1599) /0.3000000000E+04/
      DATA STRIKE(1600) /0.5536184387E+01/
     *    HL(1600) /0.1462700000E+04/
     *    EQLAT(1600) /0.1089139558E+01/
     *    EQLON(1600) /0.2489844125E+01/
     *    SSLIP(1600) /0.0000000000E+00/
     *    DSLIP(1600) /0.0000000000E+00/
     *    DIP(1600) /0.1570796327E+01/
     *    DEPTH(1600) /0.2400000000E+05/
     *    WIDTH(1600) /0.3000000000E+04/
      DATA STRIKE(1601) /0.5534439058E+01/
     *    HL(1601) /0.1463200000E+04/
     *    EQLAT(1601) /0.1088794507E+01/
     *    EQLON(1601) /0.2489194513E+01/
     *    SSLIP(1601) /0.1570000000E+00/
     *    DSLIP(1601) /0.0000000000E+00/
     *    DIP(1601) /0.1570796327E+01/
     *    DEPTH(1601) /0.2400000000E+05/
     *    WIDTH(1601) /0.3000000000E+04/
      DATA STRIKE(1602) /0.5532693729E+01/
     *    HL(1602) /0.1463600000E+04/
     *    EQLAT(1602) /0.1088449455E+01/
     *    EQLON(1602) /0.2488545076E+01/
     *    SSLIP(1602) /0.6260000000E+00/
     *    DSLIP(1602) /0.0000000000E+00/
     *    DIP(1602) /0.1570796327E+01/
     *    DEPTH(1602) /0.2400000000E+05/
     *    WIDTH(1602) /0.3000000000E+04/
      DATA STRIKE(1603) /0.5530948400E+01/
     *    HL(1603) /0.1464000000E+04/
     *    EQLAT(1603) /0.1088104404E+01/
     *    EQLON(1603) /0.2487895465E+01/
     *    SSLIP(1603) /0.8300000000E+00/
     *    DSLIP(1603) /-.5000000000E-01/
     *    DIP(1603) /0.1570796327E+01/
     *    DEPTH(1603) /0.2400000000E+05/
     *    WIDTH(1603) /0.3000000000E+04/
      DATA STRIKE(1604) /0.5829399702E+01/
     *    HL(1604) /0.1483700000E+04/
     *    EQLAT(1604) /0.1096525443E+01/
     *    EQLON(1604) /0.2501449517E+01/
     *    SSLIP(1604) /0.6583000000E+01/
     *    DSLIP(1604) /-.1870000000E+01/
     *    DIP(1604) /0.1570796327E+01/
     *    DEPTH(1604) /0.2400000000E+05/
     *    WIDTH(1604) /0.3000000000E+04/
      DATA STRIKE(1605) /0.5827654372E+01/
     *    HL(1605) /0.1483900000E+04/
     *    EQLAT(1605) /0.1096105866E+01/
     *    EQLON(1605) /0.2501013185E+01/
     *    SSLIP(1605) /0.5941000000E+01/
     *    DSLIP(1605) /-.2010000000E+01/
     *    DIP(1605) /0.1570796327E+01/
     *    DEPTH(1605) /0.2400000000E+05/
     *    WIDTH(1605) /0.3000000000E+04/
      DATA STRIKE(1606) /0.5827654372E+01/
     *    HL(1606) /0.1484100000E+04/
     *    EQLAT(1606) /0.1095686114E+01/
     *    EQLON(1606) /0.2500576853E+01/
     *    SSLIP(1606) /0.4167000000E+01/
     *    DSLIP(1606) /-.2410000000E+01/
     *    DIP(1606) /0.1570796327E+01/
     *    DEPTH(1606) /0.2400000000E+05/
     *    WIDTH(1606) /0.3000000000E+04/
      DATA STRIKE(1607) /0.5825909043E+01/
     *    HL(1607) /0.1484300000E+04/
     *    EQLAT(1607) /0.1095266537E+01/
     *    EQLON(1607) /0.2500140520E+01/
     *    SSLIP(1607) /0.2237000000E+01/
     *    DSLIP(1607) /-.2190000000E+01/
     *    DIP(1607) /0.1570796327E+01/
     *    DEPTH(1607) /0.2400000000E+05/
     *    WIDTH(1607) /0.3000000000E+04/
      DATA STRIKE(1608) /0.5825909043E+01/
     *    HL(1608) /0.1484600000E+04/
     *    EQLAT(1608) /0.1094846960E+01/
     *    EQLON(1608) /0.2499704188E+01/
     *    SSLIP(1608) /0.1571000000E+01/
     *    DSLIP(1608) /-.5400000000E+00/
     *    DIP(1608) /0.1570796327E+01/
     *    DEPTH(1608) /0.2400000000E+05/
     *    WIDTH(1608) /0.3000000000E+04/
      DATA STRIKE(1609) /0.5824163714E+01/
     *    HL(1609) /0.1484800000E+04/
     *    EQLAT(1609) /0.1094427208E+01/
     *    EQLON(1609) /0.2499267856E+01/
     *    SSLIP(1609) /0.1601000000E+01/
     *    DSLIP(1609) /0.0000000000E+00/
     *    DIP(1609) /0.1570796327E+01/
     *    DEPTH(1609) /0.2400000000E+05/
     *    WIDTH(1609) /0.3000000000E+04/
      DATA STRIKE(1610) /0.5822418385E+01/
     *    HL(1610) /0.1485000000E+04/
     *    EQLAT(1610) /0.1094007631E+01/
     *    EQLON(1610) /0.2498831523E+01/
     *    SSLIP(1610) /0.1932000000E+01/
     *    DSLIP(1610) /0.0000000000E+00/
     *    DIP(1610) /0.1570796327E+01/
     *    DEPTH(1610) /0.2400000000E+05/
     *    WIDTH(1610) /0.3000000000E+04/
      DATA STRIKE(1611) /0.5553637680E+01/
     *    HL(1611) /0.1457400000E+04/
     *    EQLAT(1611) /0.1093625229E+01/
     *    EQLON(1611) /0.2498288551E+01/
     *    SSLIP(1611) /0.2677000000E+01/
     *    DSLIP(1611) /-.2400000000E+00/
     *    DIP(1611) /0.1570796327E+01/
     *    DEPTH(1611) /0.2400000000E+05/
     *    WIDTH(1611) /0.3000000000E+04/
      DATA STRIKE(1612) /0.5553637680E+01/
     *    HL(1612) /0.1457800000E+04/
     *    EQLAT(1612) /0.1093280178E+01/
     *    EQLON(1612) /0.2497638940E+01/
     *    SSLIP(1612) /0.3060000000E+01/
     *    DSLIP(1612) /-.1200000000E+00/
     *    DIP(1612) /0.1570796327E+01/
     *    DEPTH(1612) /0.2400000000E+05/
     *    WIDTH(1612) /0.3000000000E+04/
      DATA STRIKE(1613) /0.5551892351E+01/
     *    HL(1613) /0.1458200000E+04/
     *    EQLAT(1613) /0.1092935126E+01/
     *    EQLON(1613) /0.2496989503E+01/
     *    SSLIP(1613) /0.3008000000E+01/
     *    DSLIP(1613) /0.0000000000E+00/
     *    DIP(1613) /0.1570796327E+01/
     *    DEPTH(1613) /0.2400000000E+05/
     *    WIDTH(1613) /0.3000000000E+04/
      DATA STRIKE(1614) /0.5550147021E+01/
     *    HL(1614) /0.1458600000E+04/
     *    EQLAT(1614) /0.1092590074E+01/
     *    EQLON(1614) /0.2496339891E+01/
     *    SSLIP(1614) /0.2709000000E+01/
     *    DSLIP(1614) /0.0000000000E+00/
     *    DIP(1614) /0.1570796327E+01/
     *    DEPTH(1614) /0.2400000000E+05/
     *    WIDTH(1614) /0.3000000000E+04/
      DATA STRIKE(1615) /0.5548401692E+01/
     *    HL(1615) /0.1459000000E+04/
     *    EQLAT(1615) /0.1092245023E+01/
     *    EQLON(1615) /0.2495690280E+01/
     *    SSLIP(1615) /0.2491000000E+01/
     *    DSLIP(1615) /0.0000000000E+00/
     *    DIP(1615) /0.1570796327E+01/
     *    DEPTH(1615) /0.2400000000E+05/
     *    WIDTH(1615) /0.3000000000E+04/
      DATA STRIKE(1616) /0.5546656363E+01/
     *    HL(1616) /0.1459400000E+04/
     *    EQLAT(1616) /0.1091899971E+01/
     *    EQLON(1616) /0.2495040668E+01/
     *    SSLIP(1616) /0.2893000000E+01/
     *    DSLIP(1616) /0.0000000000E+00/
     *    DIP(1616) /0.1570796327E+01/
     *    DEPTH(1616) /0.2400000000E+05/
     *    WIDTH(1616) /0.3000000000E+04/
      DATA STRIKE(1617) /0.5544911034E+01/
     *    HL(1617) /0.1459800000E+04/
     *    EQLAT(1617) /0.1091554920E+01/
     *    EQLON(1617) /0.2494391231E+01/
     *    SSLIP(1617) /0.3131000000E+01/
     *    DSLIP(1617) /0.0000000000E+00/
     *    DIP(1617) /0.1570796327E+01/
     *    DEPTH(1617) /0.2400000000E+05/
     *    WIDTH(1617) /0.3000000000E+04/
      DATA STRIKE(1618) /0.5543165704E+01/
     *    HL(1618) /0.1460300000E+04/
     *    EQLAT(1618) /0.1091209868E+01/
     *    EQLON(1618) /0.2493741620E+01/
     *    SSLIP(1618) /0.2997000000E+01/
     *    DSLIP(1618) /0.0000000000E+00/
     *    DIP(1618) /0.1570796327E+01/
     *    DEPTH(1618) /0.2400000000E+05/
     *    WIDTH(1618) /0.3000000000E+04/
      DATA STRIKE(1619) /0.5543165704E+01/
     *    HL(1619) /0.1460700000E+04/
     *    EQLAT(1619) /0.1090864816E+01/
     *    EQLON(1619) /0.2493092008E+01/
     *    SSLIP(1619) /0.2607000000E+01/
     *    DSLIP(1619) /0.0000000000E+00/
     *    DIP(1619) /0.1570796327E+01/
     *    DEPTH(1619) /0.2400000000E+05/
     *    WIDTH(1619) /0.3000000000E+04/
      DATA STRIKE(1620) /0.5541420375E+01/
     *    HL(1620) /0.1461100000E+04/
     *    EQLAT(1620) /0.1090519765E+01/
     *    EQLON(1620) /0.2492442397E+01/
     *    SSLIP(1620) /0.1612000000E+01/
     *    DSLIP(1620) /0.0000000000E+00/
     *    DIP(1620) /0.1570796327E+01/
     *    DEPTH(1620) /0.2400000000E+05/
     *    WIDTH(1620) /0.3000000000E+04/
      DATA STRIKE(1621) /0.5539675046E+01/
     *    HL(1621) /0.1461500000E+04/
     *    EQLAT(1621) /0.1090174713E+01/
     *    EQLON(1621) /0.2491792785E+01/
     *    SSLIP(1621) /0.6010000000E+00/
     *    DSLIP(1621) /0.0000000000E+00/
     *    DIP(1621) /0.1570796327E+01/
     *    DEPTH(1621) /0.2400000000E+05/
     *    WIDTH(1621) /0.3000000000E+04/
      DATA STRIKE(1622) /0.5537929717E+01/
     *    HL(1622) /0.1461900000E+04/
     *    EQLAT(1622) /0.1089829662E+01/
     *    EQLON(1622) /0.2491143348E+01/
     *    SSLIP(1622) /0.4500000000E-01/
     *    DSLIP(1622) /0.0000000000E+00/
     *    DIP(1622) /0.1570796327E+01/
     *    DEPTH(1622) /0.2400000000E+05/
     *    WIDTH(1622) /0.3000000000E+04/
      DATA STRIKE(1623) /0.5536184387E+01/
     *    HL(1623) /0.1462300000E+04/
     *    EQLAT(1623) /0.1089484610E+01/
     *    EQLON(1623) /0.2490493736E+01/
     *    SSLIP(1623) /0.0000000000E+00/
     *    DSLIP(1623) /0.0000000000E+00/
     *    DIP(1623) /0.1570796327E+01/
     *    DEPTH(1623) /0.2400000000E+05/
     *    WIDTH(1623) /0.3000000000E+04/
      DATA STRIKE(1624) /0.5536184387E+01/
     *    HL(1624) /0.1462700000E+04/
     *    EQLAT(1624) /0.1089139558E+01/
     *    EQLON(1624) /0.2489844125E+01/
     *    SSLIP(1624) /0.0000000000E+00/
     *    DSLIP(1624) /-.3000000000E-01/
     *    DIP(1624) /0.1570796327E+01/
     *    DEPTH(1624) /0.2400000000E+05/
     *    WIDTH(1624) /0.3000000000E+04/
      DATA STRIKE(1625) /0.5534439058E+01/
     *    HL(1625) /0.1463200000E+04/
     *    EQLAT(1625) /0.1088794507E+01/
     *    EQLON(1625) /0.2489194513E+01/
     *    SSLIP(1625) /0.6300000000E-01/
     *    DSLIP(1625) /-.7000000000E-01/
     *    DIP(1625) /0.1570796327E+01/
     *    DEPTH(1625) /0.2400000000E+05/
     *    WIDTH(1625) /0.3000000000E+04/
      DATA STRIKE(1626) /0.5532693729E+01/
     *    HL(1626) /0.1463600000E+04/
     *    EQLAT(1626) /0.1088449455E+01/
     *    EQLON(1626) /0.2488545076E+01/
     *    SSLIP(1626) /0.3500000000E+00/
     *    DSLIP(1626) /-.1000000000E+00/
     *    DIP(1626) /0.1570796327E+01/
     *    DEPTH(1626) /0.2400000000E+05/
     *    WIDTH(1626) /0.3000000000E+04/
      DATA STRIKE(1627) /0.5530948400E+01/
     *    HL(1627) /0.1464000000E+04/
     *    EQLAT(1627) /0.1088104404E+01/
     *    EQLON(1627) /0.2487895465E+01/
     *    SSLIP(1627) /0.4800000000E+00/
     *    DSLIP(1627) /-.1600000000E+00/
     *    DIP(1627) /0.1570796327E+01/
     *    DEPTH(1627) /0.2400000000E+05/
     *    WIDTH(1627) /0.3000000000E+04/
      DATA STRIKE(1628) /0.5829399702E+01/
     *    HL(1628) /0.1483700000E+04/
     *    EQLAT(1628) /0.1096525443E+01/
     *    EQLON(1628) /0.2501449517E+01/
     *    SSLIP(1628) /0.6728000000E+01/
     *    DSLIP(1628) /-.1600000000E+01/
     *    DIP(1628) /0.1570796327E+01/
     *    DEPTH(1628) /0.2400000000E+05/
     *    WIDTH(1628) /0.3000000000E+04/
      DATA STRIKE(1629) /0.5827654372E+01/
     *    HL(1629) /0.1483900000E+04/
     *    EQLAT(1629) /0.1096105866E+01/
     *    EQLON(1629) /0.2501013185E+01/
     *    SSLIP(1629) /0.6295000000E+01/
     *    DSLIP(1629) /-.1670000000E+01/
     *    DIP(1629) /0.1570796327E+01/
     *    DEPTH(1629) /0.2400000000E+05/
     *    WIDTH(1629) /0.3000000000E+04/
      DATA STRIKE(1630) /0.5827654372E+01/
     *    HL(1630) /0.1484100000E+04/
     *    EQLAT(1630) /0.1095686114E+01/
     *    EQLON(1630) /0.2500576853E+01/
     *    SSLIP(1630) /0.4664000000E+01/
     *    DSLIP(1630) /-.1740000000E+01/
     *    DIP(1630) /0.1570796327E+01/
     *    DEPTH(1630) /0.2400000000E+05/
     *    WIDTH(1630) /0.3000000000E+04/
      DATA STRIKE(1631) /0.5825909043E+01/
     *    HL(1631) /0.1484300000E+04/
     *    EQLAT(1631) /0.1095266537E+01/
     *    EQLON(1631) /0.2500140520E+01/
     *    SSLIP(1631) /0.2924000000E+01/
     *    DSLIP(1631) /-.1370000000E+01/
     *    DIP(1631) /0.1570796327E+01/
     *    DEPTH(1631) /0.2400000000E+05/
     *    WIDTH(1631) /0.3000000000E+04/
      DATA STRIKE(1632) /0.5825909043E+01/
     *    HL(1632) /0.1484600000E+04/
     *    EQLAT(1632) /0.1094846960E+01/
     *    EQLON(1632) /0.2499704188E+01/
     *    SSLIP(1632) /0.1991000000E+01/
     *    DSLIP(1632) /-.4400000000E+00/
     *    DIP(1632) /0.1570796327E+01/
     *    DEPTH(1632) /0.2400000000E+05/
     *    WIDTH(1632) /0.3000000000E+04/
      DATA STRIKE(1633) /0.5824163714E+01/
     *    HL(1633) /0.1484800000E+04/
     *    EQLAT(1633) /0.1094427208E+01/
     *    EQLON(1633) /0.2499267856E+01/
     *    SSLIP(1633) /0.1766000000E+01/
     *    DSLIP(1633) /-.1000000000E-01/
     *    DIP(1633) /0.1570796327E+01/
     *    DEPTH(1633) /0.2400000000E+05/
     *    WIDTH(1633) /0.3000000000E+04/
      DATA STRIKE(1634) /0.5822418385E+01/
     *    HL(1634) /0.1485000000E+04/
     *    EQLAT(1634) /0.1094007631E+01/
     *    EQLON(1634) /0.2498831523E+01/
     *    SSLIP(1634) /0.1944000000E+01/
     *    DSLIP(1634) /0.0000000000E+00/
     *    DIP(1634) /0.1570796327E+01/
     *    DEPTH(1634) /0.2400000000E+05/
     *    WIDTH(1634) /0.3000000000E+04/
      DATA STRIKE(1635) /0.5553637680E+01/
     *    HL(1635) /0.1457400000E+04/
     *    EQLAT(1635) /0.1093625229E+01/
     *    EQLON(1635) /0.2498288551E+01/
     *    SSLIP(1635) /0.2324000000E+01/
     *    DSLIP(1635) /-.3000000000E-01/
     *    DIP(1635) /0.1570796327E+01/
     *    DEPTH(1635) /0.2400000000E+05/
     *    WIDTH(1635) /0.3000000000E+04/
      DATA STRIKE(1636) /0.5553637680E+01/
     *    HL(1636) /0.1457800000E+04/
     *    EQLAT(1636) /0.1093280178E+01/
     *    EQLON(1636) /0.2497638940E+01/
     *    SSLIP(1636) /0.2562000000E+01/
     *    DSLIP(1636) /0.0000000000E+00/
     *    DIP(1636) /0.1570796327E+01/
     *    DEPTH(1636) /0.2400000000E+05/
     *    WIDTH(1636) /0.3000000000E+04/
      DATA STRIKE(1637) /0.5551892351E+01/
     *    HL(1637) /0.1458200000E+04/
     *    EQLAT(1637) /0.1092935126E+01/
     *    EQLON(1637) /0.2496989503E+01/
     *    SSLIP(1637) /0.2594000000E+01/
     *    DSLIP(1637) /0.0000000000E+00/
     *    DIP(1637) /0.1570796327E+01/
     *    DEPTH(1637) /0.2400000000E+05/
     *    WIDTH(1637) /0.3000000000E+04/
      DATA STRIKE(1638) /0.5550147021E+01/
     *    HL(1638) /0.1458600000E+04/
     *    EQLAT(1638) /0.1092590074E+01/
     *    EQLON(1638) /0.2496339891E+01/
     *    SSLIP(1638) /0.2544000000E+01/
     *    DSLIP(1638) /0.0000000000E+00/
     *    DIP(1638) /0.1570796327E+01/
     *    DEPTH(1638) /0.2400000000E+05/
     *    WIDTH(1638) /0.3000000000E+04/
      DATA STRIKE(1639) /0.5548401692E+01/
     *    HL(1639) /0.1459000000E+04/
     *    EQLAT(1639) /0.1092245023E+01/
     *    EQLON(1639) /0.2495690280E+01/
     *    SSLIP(1639) /0.2588000000E+01/
     *    DSLIP(1639) /0.0000000000E+00/
     *    DIP(1639) /0.1570796327E+01/
     *    DEPTH(1639) /0.2400000000E+05/
     *    WIDTH(1639) /0.3000000000E+04/
      DATA STRIKE(1640) /0.5546656363E+01/
     *    HL(1640) /0.1459400000E+04/
     *    EQLAT(1640) /0.1091899971E+01/
     *    EQLON(1640) /0.2495040668E+01/
     *    SSLIP(1640) /0.2847000000E+01/
     *    DSLIP(1640) /0.0000000000E+00/
     *    DIP(1640) /0.1570796327E+01/
     *    DEPTH(1640) /0.2400000000E+05/
     *    WIDTH(1640) /0.3000000000E+04/
      DATA STRIKE(1641) /0.5544911034E+01/
     *    HL(1641) /0.1459800000E+04/
     *    EQLAT(1641) /0.1091554920E+01/
     *    EQLON(1641) /0.2494391231E+01/
     *    SSLIP(1641) /0.2937000000E+01/
     *    DSLIP(1641) /0.0000000000E+00/
     *    DIP(1641) /0.1570796327E+01/
     *    DEPTH(1641) /0.2400000000E+05/
     *    WIDTH(1641) /0.3000000000E+04/
      DATA STRIKE(1642) /0.5543165704E+01/
     *    HL(1642) /0.1460300000E+04/
     *    EQLAT(1642) /0.1091209868E+01/
     *    EQLON(1642) /0.2493741620E+01/
     *    SSLIP(1642) /0.2679000000E+01/
     *    DSLIP(1642) /0.0000000000E+00/
     *    DIP(1642) /0.1570796327E+01/
     *    DEPTH(1642) /0.2400000000E+05/
     *    WIDTH(1642) /0.3000000000E+04/
      DATA STRIKE(1643) /0.5543165704E+01/
     *    HL(1643) /0.1460700000E+04/
     *    EQLAT(1643) /0.1090864816E+01/
     *    EQLON(1643) /0.2493092008E+01/
     *    SSLIP(1643) /0.2110000000E+01/
     *    DSLIP(1643) /0.0000000000E+00/
     *    DIP(1643) /0.1570796327E+01/
     *    DEPTH(1643) /0.2400000000E+05/
     *    WIDTH(1643) /0.3000000000E+04/
      DATA STRIKE(1644) /0.5541420375E+01/
     *    HL(1644) /0.1461100000E+04/
     *    EQLAT(1644) /0.1090519765E+01/
     *    EQLON(1644) /0.2492442397E+01/
     *    SSLIP(1644) /0.1234000000E+01/
     *    DSLIP(1644) /0.0000000000E+00/
     *    DIP(1644) /0.1570796327E+01/
     *    DEPTH(1644) /0.2400000000E+05/
     *    WIDTH(1644) /0.3000000000E+04/
      DATA STRIKE(1645) /0.5539675046E+01/
     *    HL(1645) /0.1461500000E+04/
     *    EQLAT(1645) /0.1090174713E+01/
     *    EQLON(1645) /0.2491792785E+01/
     *    SSLIP(1645) /0.4260000000E+00/
     *    DSLIP(1645) /0.0000000000E+00/
     *    DIP(1645) /0.1570796327E+01/
     *    DEPTH(1645) /0.2400000000E+05/
     *    WIDTH(1645) /0.3000000000E+04/
      DATA STRIKE(1646) /0.5537929717E+01/
     *    HL(1646) /0.1461900000E+04/
     *    EQLAT(1646) /0.1089829662E+01/
     *    EQLON(1646) /0.2491143348E+01/
     *    SSLIP(1646) /0.1400000000E-01/
     *    DSLIP(1646) /0.0000000000E+00/
     *    DIP(1646) /0.1570796327E+01/
     *    DEPTH(1646) /0.2400000000E+05/
     *    WIDTH(1646) /0.3000000000E+04/
      DATA STRIKE(1647) /0.5536184387E+01/
     *    HL(1647) /0.1462300000E+04/
     *    EQLAT(1647) /0.1089484610E+01/
     *    EQLON(1647) /0.2490493736E+01/
     *    SSLIP(1647) /0.0000000000E+00/
     *    DSLIP(1647) /-.6000000000E-01/
     *    DIP(1647) /0.1570796327E+01/
     *    DEPTH(1647) /0.2400000000E+05/
     *    WIDTH(1647) /0.3000000000E+04/
      DATA STRIKE(1648) /0.5536184387E+01/
     *    HL(1648) /0.1462700000E+04/
     *    EQLAT(1648) /0.1089139558E+01/
     *    EQLON(1648) /0.2489844125E+01/
     *    SSLIP(1648) /0.0000000000E+00/
     *    DSLIP(1648) /-.1800000000E+00/
     *    DIP(1648) /0.1570796327E+01/
     *    DEPTH(1648) /0.2400000000E+05/
     *    WIDTH(1648) /0.3000000000E+04/
      DATA STRIKE(1649) /0.5534439058E+01/
     *    HL(1649) /0.1463200000E+04/
     *    EQLAT(1649) /0.1088794507E+01/
     *    EQLON(1649) /0.2489194513E+01/
     *    SSLIP(1649) /0.0000000000E+00/
     *    DSLIP(1649) /-.3200000000E+00/
     *    DIP(1649) /0.1570796327E+01/
     *    DEPTH(1649) /0.2400000000E+05/
     *    WIDTH(1649) /0.3000000000E+04/
      DATA STRIKE(1650) /0.5532693729E+01/
     *    HL(1650) /0.1463600000E+04/
     *    EQLAT(1650) /0.1088449455E+01/
     *    EQLON(1650) /0.2488545076E+01/
     *    SSLIP(1650) /0.2900000000E-01/
     *    DSLIP(1650) /-.4300000000E+00/
     *    DIP(1650) /0.1570796327E+01/
     *    DEPTH(1650) /0.2400000000E+05/
     *    WIDTH(1650) /0.3000000000E+04/
      DATA STRIKE(1651) /0.5530948400E+01/
     *    HL(1651) /0.1464000000E+04/
     *    EQLAT(1651) /0.1088104404E+01/
     *    EQLON(1651) /0.2487895465E+01/
     *    SSLIP(1651) /0.7400000000E-01/
     *    DSLIP(1651) /-.4800000000E+00/
     *    DIP(1651) /0.1570796327E+01/
     *    DEPTH(1651) /0.2400000000E+05/
     *    WIDTH(1651) /0.3000000000E+04/
      DATA STRIKE(1652) /0.5829399702E+01/
     *    HL(1652) /0.1483700000E+04/
     *    EQLAT(1652) /0.1096525443E+01/
     *    EQLON(1652) /0.2501449517E+01/
     *    SSLIP(1652) /0.6146000000E+01/
     *    DSLIP(1652) /-.1220000000E+01/
     *    DIP(1652) /0.1570796327E+01/
     *    DEPTH(1652) /0.2400000000E+05/
     *    WIDTH(1652) /0.3000000000E+04/
      DATA STRIKE(1653) /0.5827654372E+01/
     *    HL(1653) /0.1483900000E+04/
     *    EQLAT(1653) /0.1096105866E+01/
     *    EQLON(1653) /0.2501013185E+01/
     *    SSLIP(1653) /0.5819000000E+01/
     *    DSLIP(1653) /-.1210000000E+01/
     *    DIP(1653) /0.1570796327E+01/
     *    DEPTH(1653) /0.2400000000E+05/
     *    WIDTH(1653) /0.3000000000E+04/
      DATA STRIKE(1654) /0.5827654372E+01/
     *    HL(1654) /0.1484100000E+04/
     *    EQLAT(1654) /0.1095686114E+01/
     *    EQLON(1654) /0.2500576853E+01/
     *    SSLIP(1654) /0.4432000000E+01/
     *    DSLIP(1654) /-.1080000000E+01/
     *    DIP(1654) /0.1570796327E+01/
     *    DEPTH(1654) /0.2400000000E+05/
     *    WIDTH(1654) /0.3000000000E+04/
      DATA STRIKE(1655) /0.5825909043E+01/
     *    HL(1655) /0.1484300000E+04/
     *    EQLAT(1655) /0.1095266537E+01/
     *    EQLON(1655) /0.2500140520E+01/
     *    SSLIP(1655) /0.2911000000E+01/
     *    DSLIP(1655) /-.7200000000E+00/
     *    DIP(1655) /0.1570796327E+01/
     *    DEPTH(1655) /0.2400000000E+05/
     *    WIDTH(1655) /0.3000000000E+04/
      DATA STRIKE(1656) /0.5825909043E+01/
     *    HL(1656) /0.1484600000E+04/
     *    EQLAT(1656) /0.1094846960E+01/
     *    EQLON(1656) /0.2499704188E+01/
     *    SSLIP(1656) /0.1919000000E+01/
     *    DSLIP(1656) /-.2100000000E+00/
     *    DIP(1656) /0.1570796327E+01/
     *    DEPTH(1656) /0.2400000000E+05/
     *    WIDTH(1656) /0.3000000000E+04/
      DATA STRIKE(1657) /0.5824163714E+01/
     *    HL(1657) /0.1484800000E+04/
     *    EQLAT(1657) /0.1094427208E+01/
     *    EQLON(1657) /0.2499267856E+01/
     *    SSLIP(1657) /0.1532000000E+01/
     *    DSLIP(1657) /0.0000000000E+00/
     *    DIP(1657) /0.1570796327E+01/
     *    DEPTH(1657) /0.2400000000E+05/
     *    WIDTH(1657) /0.3000000000E+04/
      DATA STRIKE(1658) /0.5822418385E+01/
     *    HL(1658) /0.1485000000E+04/
     *    EQLAT(1658) /0.1094007631E+01/
     *    EQLON(1658) /0.2498831523E+01/
     *    SSLIP(1658) /0.1524000000E+01/
     *    DSLIP(1658) /0.0000000000E+00/
     *    DIP(1658) /0.1570796327E+01/
     *    DEPTH(1658) /0.2400000000E+05/
     *    WIDTH(1658) /0.3000000000E+04/
      DATA STRIKE(1659) /0.5553637680E+01/
     *    HL(1659) /0.1457400000E+04/
     *    EQLAT(1659) /0.1093625229E+01/
     *    EQLON(1659) /0.2498288551E+01/
     *    SSLIP(1659) /0.1650000000E+01/
     *    DSLIP(1659) /0.0000000000E+00/
     *    DIP(1659) /0.1570796327E+01/
     *    DEPTH(1659) /0.2400000000E+05/
     *    WIDTH(1659) /0.3000000000E+04/
      DATA STRIKE(1660) /0.5553637680E+01/
     *    HL(1660) /0.1457800000E+04/
     *    EQLAT(1660) /0.1093280178E+01/
     *    EQLON(1660) /0.2497638940E+01/
     *    SSLIP(1660) /0.1771000000E+01/
     *    DSLIP(1660) /0.0000000000E+00/
     *    DIP(1660) /0.1570796327E+01/
     *    DEPTH(1660) /0.2400000000E+05/
     *    WIDTH(1660) /0.3000000000E+04/
      DATA STRIKE(1661) /0.5551892351E+01/
     *    HL(1661) /0.1458200000E+04/
     *    EQLAT(1661) /0.1092935126E+01/
     *    EQLON(1661) /0.2496989503E+01/
     *    SSLIP(1661) /0.1853000000E+01/
     *    DSLIP(1661) /0.0000000000E+00/
     *    DIP(1661) /0.1570796327E+01/
     *    DEPTH(1661) /0.3000000000E+04/
     *    WIDTH(1661) /0.3000000000E+04/
      DATA STRIKE(1662) /0.5550147021E+01/
     *    HL(1662) /0.1458600000E+04/
     *    EQLAT(1662) /0.1092590074E+01/
     *    EQLON(1662) /0.2496339891E+01/
     *    SSLIP(1662) /0.1953000000E+01/
     *    DSLIP(1662) /0.0000000000E+00/
     *    DIP(1662) /0.1570796327E+01/
     *    DEPTH(1662) /0.3000000000E+04/
     *    WIDTH(1662) /0.3000000000E+04/
      DATA STRIKE(1663) /0.5548401692E+01/
     *    HL(1663) /0.1459000000E+04/
     *    EQLAT(1663) /0.1092245023E+01/
     *    EQLON(1663) /0.2495690280E+01/
     *    SSLIP(1663) /0.2116000000E+01/
     *    DSLIP(1663) /0.0000000000E+00/
     *    DIP(1663) /0.1570796327E+01/
     *    DEPTH(1663) /0.3000000000E+04/
     *    WIDTH(1663) /0.3000000000E+04/
      DATA STRIKE(1664) /0.5546656363E+01/
     *    HL(1664) /0.1459400000E+04/
     *    EQLAT(1664) /0.1091899971E+01/
     *    EQLON(1664) /0.2495040668E+01/
     *    SSLIP(1664) /0.2301000000E+01/
     *    DSLIP(1664) /0.0000000000E+00/
     *    DIP(1664) /0.1570796327E+01/
     *    DEPTH(1664) /0.3000000000E+04/
     *    WIDTH(1664) /0.3000000000E+04/
      DATA STRIKE(1665) /0.5544911034E+01/
     *    HL(1665) /0.1459800000E+04/
     *    EQLAT(1665) /0.1091554920E+01/
     *    EQLON(1665) /0.2494391231E+01/
     *    SSLIP(1665) /0.2298000000E+01/
     *    DSLIP(1665) /0.0000000000E+00/
     *    DIP(1665) /0.1570796327E+01/
     *    DEPTH(1665) /0.3000000000E+04/
     *    WIDTH(1665) /0.3000000000E+04/
      DATA STRIKE(1666) /0.5543165704E+01/
     *    HL(1666) /0.1460300000E+04/
     *    EQLAT(1666) /0.1091209868E+01/
     *    EQLON(1666) /0.2493741620E+01/
     *    SSLIP(1666) /0.2000000000E+01/
     *    DSLIP(1666) /0.0000000000E+00/
     *    DIP(1666) /0.1570796327E+01/
     *    DEPTH(1666) /0.3000000000E+04/
     *    WIDTH(1666) /0.3000000000E+04/
      DATA STRIKE(1667) /0.5543165704E+01/
     *    HL(1667) /0.1460700000E+04/
     *    EQLAT(1667) /0.1090864816E+01/
     *    EQLON(1667) /0.2493092008E+01/
     *    SSLIP(1667) /0.1450000000E+01/
     *    DSLIP(1667) /0.0000000000E+00/
     *    DIP(1667) /0.1570796327E+01/
     *    DEPTH(1667) /0.3000000000E+04/
     *    WIDTH(1667) /0.3000000000E+04/
      DATA STRIKE(1668) /0.5541420375E+01/
     *    HL(1668) /0.1461100000E+04/
     *    EQLAT(1668) /0.1090519765E+01/
     *    EQLON(1668) /0.2492442397E+01/
     *    SSLIP(1668) /0.7720000000E+00/
     *    DSLIP(1668) /0.0000000000E+00/
     *    DIP(1668) /0.1570796327E+01/
     *    DEPTH(1668) /0.3000000000E+04/
     *    WIDTH(1668) /0.3000000000E+04/
      DATA STRIKE(1669) /0.5539675046E+01/
     *    HL(1669) /0.1461500000E+04/
     *    EQLAT(1669) /0.1090174713E+01/
     *    EQLON(1669) /0.2491792785E+01/
     *    SSLIP(1669) /0.2260000000E+00/
     *    DSLIP(1669) /0.0000000000E+00/
     *    DIP(1669) /0.1570796327E+01/
     *    DEPTH(1669) /0.3000000000E+04/
     *    WIDTH(1669) /0.3000000000E+04/
      DATA STRIKE(1670) /0.5537929717E+01/
     *    HL(1670) /0.1461900000E+04/
     *    EQLAT(1670) /0.1089829662E+01/
     *    EQLON(1670) /0.2491143348E+01/
     *    SSLIP(1670) /0.0000000000E+00/
     *    DSLIP(1670) /-.2000000000E-01/
     *    DIP(1670) /0.1570796327E+01/
     *    DEPTH(1670) /0.3000000000E+04/
     *    WIDTH(1670) /0.3000000000E+04/
      DATA STRIKE(1671) /0.5536184387E+01/
     *    HL(1671) /0.1462300000E+04/
     *    EQLAT(1671) /0.1089484610E+01/
     *    EQLON(1671) /0.2490493736E+01/
     *    SSLIP(1671) /0.0000000000E+00/
     *    DSLIP(1671) /-.1700000000E+00/
     *    DIP(1671) /0.1570796327E+01/
     *    DEPTH(1671) /0.3000000000E+04/
     *    WIDTH(1671) /0.3000000000E+04/
      DATA STRIKE(1672) /0.5536184387E+01/
     *    HL(1672) /0.1462700000E+04/
     *    EQLAT(1672) /0.1089139558E+01/
     *    EQLON(1672) /0.2489844125E+01/
     *    SSLIP(1672) /0.0000000000E+00/
     *    DSLIP(1672) /-.4100000000E+00/
     *    DIP(1672) /0.1570796327E+01/
     *    DEPTH(1672) /0.3000000000E+04/
     *    WIDTH(1672) /0.3000000000E+04/
      DATA STRIKE(1673) /0.5534439058E+01/
     *    HL(1673) /0.1463200000E+04/
     *    EQLAT(1673) /0.1088794507E+01/
     *    EQLON(1673) /0.2489194513E+01/
     *    SSLIP(1673) /0.0000000000E+00/
     *    DSLIP(1673) /-.6600000000E+00/
     *    DIP(1673) /0.1570796327E+01/
     *    DEPTH(1673) /0.3000000000E+04/
     *    WIDTH(1673) /0.3000000000E+04/
      DATA STRIKE(1674) /0.5532693729E+01/
     *    HL(1674) /0.1463600000E+04/
     *    EQLAT(1674) /0.1088449455E+01/
     *    EQLON(1674) /0.2488545076E+01/
     *    SSLIP(1674) /0.0000000000E+00/
     *    DSLIP(1674) /-.8600000000E+00/
     *    DIP(1674) /0.1570796327E+01/
     *    DEPTH(1674) /0.3000000000E+04/
     *    WIDTH(1674) /0.3000000000E+04/
      DATA STRIKE(1675) /0.5530948400E+01/
     *    HL(1675) /0.1464000000E+04/
     *    EQLAT(1675) /0.1088104404E+01/
     *    EQLON(1675) /0.2487895465E+01/
     *    SSLIP(1675) /0.0000000000E+00/
     *    DSLIP(1675) /-.9100000000E+00/
     *    DIP(1675) /0.1570796327E+01/
     *    DEPTH(1675) /0.3000000000E+04/
     *    WIDTH(1675) /0.3000000000E+04/
      DATA STRIKE(1676) /0.5829399702E+01/
     *    HL(1676) /0.1483700000E+04/
     *    EQLAT(1676) /0.1096525443E+01/
     *    EQLON(1676) /0.2501449517E+01/
     *    SSLIP(1676) /0.4902000000E+01/
     *    DSLIP(1676) /-.8800000000E+00/
     *    DIP(1676) /0.1570796327E+01/
     *    DEPTH(1676) /0.3000000000E+04/
     *    WIDTH(1676) /0.3000000000E+04/
      DATA STRIKE(1677) /0.5827654372E+01/
     *    HL(1677) /0.1483900000E+04/
     *    EQLAT(1677) /0.1096105866E+01/
     *    EQLON(1677) /0.2501013185E+01/
     *    SSLIP(1677) /0.4604000000E+01/
     *    DSLIP(1677) /-.8200000000E+00/
     *    DIP(1677) /0.1570796327E+01/
     *    DEPTH(1677) /0.3000000000E+04/
     *    WIDTH(1677) /0.3000000000E+04/
      DATA STRIKE(1678) /0.5827654372E+01/
     *    HL(1678) /0.1484100000E+04/
     *    EQLAT(1678) /0.1095686114E+01/
     *    EQLON(1678) /0.2500576853E+01/
     *    SSLIP(1678) /0.3474000000E+01/
     *    DSLIP(1678) /-.6100000000E+00/
     *    DIP(1678) /0.1570796327E+01/
     *    DEPTH(1678) /0.3000000000E+04/
     *    WIDTH(1678) /0.3000000000E+04/
      DATA STRIKE(1679) /0.5825909043E+01/
     *    HL(1679) /0.1484300000E+04/
     *    EQLAT(1679) /0.1095266537E+01/
     *    EQLON(1679) /0.2500140520E+01/
     *    SSLIP(1679) /0.2221000000E+01/
     *    DSLIP(1679) /-.3100000000E+00/
     *    DIP(1679) /0.1570796327E+01/
     *    DEPTH(1679) /0.3000000000E+04/
     *    WIDTH(1679) /0.3000000000E+04/
      DATA STRIKE(1680) /0.5825909043E+01/
     *    HL(1680) /0.1484600000E+04/
     *    EQLAT(1680) /0.1094846960E+01/
     *    EQLON(1680) /0.2499704188E+01/
     *    SSLIP(1680) /0.1348000000E+01/
     *    DSLIP(1680) /-.5000000000E-01/
     *    DIP(1680) /0.1570796327E+01/
     *    DEPTH(1680) /0.3000000000E+04/
     *    WIDTH(1680) /0.3000000000E+04/
      DATA STRIKE(1681) /0.5824163714E+01/
     *    HL(1681) /0.1484800000E+04/
     *    EQLAT(1681) /0.1094427208E+01/
     *    EQLON(1681) /0.2499267856E+01/
     *    SSLIP(1681) /0.9550000000E+00/
     *    DSLIP(1681) /0.0000000000E+00/
     *    DIP(1681) /0.1570796327E+01/
     *    DEPTH(1681) /0.3000000000E+04/
     *    WIDTH(1681) /0.3000000000E+04/
      DATA STRIKE(1682) /0.5822418385E+01/
     *    HL(1682) /0.1485000000E+04/
     *    EQLAT(1682) /0.1094007631E+01/
     *    EQLON(1682) /0.2498831523E+01/
     *    SSLIP(1682) /0.8620000000E+00/
     *    DSLIP(1682) /0.0000000000E+00/
     *    DIP(1682) /0.1570796327E+01/
     *    DEPTH(1682) /0.3000000000E+04/
     *    WIDTH(1682) /0.3000000000E+04/
      DATA STRIKE(1683) /0.5553637680E+01/
     *    HL(1683) /0.1457400000E+04/
     *    EQLAT(1683) /0.1093625229E+01/
     *    EQLON(1683) /0.2498288551E+01/
     *    SSLIP(1683) /0.8610000000E+00/
     *    DSLIP(1683) /0.0000000000E+00/
     *    DIP(1683) /0.1570796327E+01/
     *    DEPTH(1683) /0.3000000000E+04/
     *    WIDTH(1683) /0.3000000000E+04/
      DATA STRIKE(1684) /0.5553637680E+01/
     *    HL(1684) /0.1457800000E+04/
     *    EQLAT(1684) /0.1093280178E+01/
     *    EQLON(1684) /0.2497638940E+01/
     *    SSLIP(1684) /0.9110000000E+00/
     *    DSLIP(1684) /0.0000000000E+00/
     *    DIP(1684) /0.1570796327E+01/
     *    DEPTH(1684) /0.3000000000E+04/
     *    WIDTH(1684) /0.3000000000E+04/
      DATA STRIKE(1685) /0.5551892351E+01/
     *    HL(1685) /0.1458200000E+04/
     *    EQLAT(1685) /0.1092935126E+01/
     *    EQLON(1685) /0.2496989503E+01/
     *    SSLIP(1685) /0.9940000000E+00/
     *    DSLIP(1685) /0.0000000000E+00/
     *    DIP(1685) /0.1570796327E+01/
     *    DEPTH(1685) /0.6000000000E+04/
     *    WIDTH(1685) /0.3000000000E+04/
      DATA STRIKE(1686) /0.5550147021E+01/
     *    HL(1686) /0.1458600000E+04/
     *    EQLAT(1686) /0.1092590074E+01/
     *    EQLON(1686) /0.2496339891E+01/
     *    SSLIP(1686) /0.1127000000E+01/
     *    DSLIP(1686) /0.0000000000E+00/
     *    DIP(1686) /0.1570796327E+01/
     *    DEPTH(1686) /0.6000000000E+04/
     *    WIDTH(1686) /0.3000000000E+04/
      DATA STRIKE(1687) /0.5548401692E+01/
     *    HL(1687) /0.1459000000E+04/
     *    EQLAT(1687) /0.1092245023E+01/
     *    EQLON(1687) /0.2495690280E+01/
     *    SSLIP(1687) /0.1298000000E+01/
     *    DSLIP(1687) /0.0000000000E+00/
     *    DIP(1687) /0.1570796327E+01/
     *    DEPTH(1687) /0.6000000000E+04/
     *    WIDTH(1687) /0.3000000000E+04/
      DATA STRIKE(1688) /0.5546656363E+01/
     *    HL(1688) /0.1459400000E+04/
     *    EQLAT(1688) /0.1091899971E+01/
     *    EQLON(1688) /0.2495040668E+01/
     *    SSLIP(1688) /0.1432000000E+01/
     *    DSLIP(1688) /0.0000000000E+00/
     *    DIP(1688) /0.1570796327E+01/
     *    DEPTH(1688) /0.6000000000E+04/
     *    WIDTH(1688) /0.3000000000E+04/
      DATA STRIKE(1689) /0.5544911034E+01/
     *    HL(1689) /0.1459800000E+04/
     *    EQLAT(1689) /0.1091554920E+01/
     *    EQLON(1689) /0.2494391231E+01/
     *    SSLIP(1689) /0.1406000000E+01/
     *    DSLIP(1689) /0.0000000000E+00/
     *    DIP(1689) /0.1570796327E+01/
     *    DEPTH(1689) /0.6000000000E+04/
     *    WIDTH(1689) /0.3000000000E+04/
      DATA STRIKE(1690) /0.5543165704E+01/
     *    HL(1690) /0.1460300000E+04/
     *    EQLAT(1690) /0.1091209868E+01/
     *    EQLON(1690) /0.2493741620E+01/
     *    SSLIP(1690) /0.1167000000E+01/
     *    DSLIP(1690) /0.0000000000E+00/
     *    DIP(1690) /0.1570796327E+01/
     *    DEPTH(1690) /0.6000000000E+04/
     *    WIDTH(1690) /0.3000000000E+04/
      DATA STRIKE(1691) /0.5543165704E+01/
     *    HL(1691) /0.1460700000E+04/
     *    EQLAT(1691) /0.1090864816E+01/
     *    EQLON(1691) /0.2493092008E+01/
     *    SSLIP(1691) /0.7700000000E+00/
     *    DSLIP(1691) /0.0000000000E+00/
     *    DIP(1691) /0.1570796327E+01/
     *    DEPTH(1691) /0.6000000000E+04/
     *    WIDTH(1691) /0.3000000000E+04/
      DATA STRIKE(1692) /0.5541420375E+01/
     *    HL(1692) /0.1461100000E+04/
     *    EQLAT(1692) /0.1090519765E+01/
     *    EQLON(1692) /0.2492442397E+01/
     *    SSLIP(1692) /0.3470000000E+00/
     *    DSLIP(1692) /0.0000000000E+00/
     *    DIP(1692) /0.1570796327E+01/
     *    DEPTH(1692) /0.6000000000E+04/
     *    WIDTH(1692) /0.3000000000E+04/
      DATA STRIKE(1693) /0.5539675046E+01/
     *    HL(1693) /0.1461500000E+04/
     *    EQLAT(1693) /0.1090174713E+01/
     *    EQLON(1693) /0.2491792785E+01/
     *    SSLIP(1693) /0.6500000000E-01/
     *    DSLIP(1693) /0.0000000000E+00/
     *    DIP(1693) /0.1570796327E+01/
     *    DEPTH(1693) /0.6000000000E+04/
     *    WIDTH(1693) /0.3000000000E+04/
      DATA STRIKE(1694) /0.5537929717E+01/
     *    HL(1694) /0.1461900000E+04/
     *    EQLAT(1694) /0.1089829662E+01/
     *    EQLON(1694) /0.2491143348E+01/
     *    SSLIP(1694) /0.0000000000E+00/
     *    DSLIP(1694) /-.7000000000E-01/
     *    DIP(1694) /0.1570796327E+01/
     *    DEPTH(1694) /0.6000000000E+04/
     *    WIDTH(1694) /0.3000000000E+04/
      DATA STRIKE(1695) /0.5536184387E+01/
     *    HL(1695) /0.1462300000E+04/
     *    EQLAT(1695) /0.1089484610E+01/
     *    EQLON(1695) /0.2490493736E+01/
     *    SSLIP(1695) /0.0000000000E+00/
     *    DSLIP(1695) /-.3100000000E+00/
     *    DIP(1695) /0.1570796327E+01/
     *    DEPTH(1695) /0.6000000000E+04/
     *    WIDTH(1695) /0.3000000000E+04/
      DATA STRIKE(1696) /0.5536184387E+01/
     *    HL(1696) /0.1462700000E+04/
     *    EQLAT(1696) /0.1089139558E+01/
     *    EQLON(1696) /0.2489844125E+01/
     *    SSLIP(1696) /0.0000000000E+00/
     *    DSLIP(1696) /-.6700000000E+00/
     *    DIP(1696) /0.1570796327E+01/
     *    DEPTH(1696) /0.6000000000E+04/
     *    WIDTH(1696) /0.3000000000E+04/
      DATA STRIKE(1697) /0.5534439058E+01/
     *    HL(1697) /0.1463200000E+04/
     *    EQLAT(1697) /0.1088794507E+01/
     *    EQLON(1697) /0.2489194513E+01/
     *    SSLIP(1697) /0.0000000000E+00/
     *    DSLIP(1697) /-.1050000000E+01/
     *    DIP(1697) /0.1570796327E+01/
     *    DEPTH(1697) /0.6000000000E+04/
     *    WIDTH(1697) /0.3000000000E+04/
      DATA STRIKE(1698) /0.5532693729E+01/
     *    HL(1698) /0.1463600000E+04/
     *    EQLAT(1698) /0.1088449455E+01/
     *    EQLON(1698) /0.2488545076E+01/
     *    SSLIP(1698) /0.0000000000E+00/
     *    DSLIP(1698) /-.1310000000E+01/
     *    DIP(1698) /0.1570796327E+01/
     *    DEPTH(1698) /0.6000000000E+04/
     *    WIDTH(1698) /0.3000000000E+04/
      DATA STRIKE(1699) /0.5530948400E+01/
     *    HL(1699) /0.1464000000E+04/
     *    EQLAT(1699) /0.1088104404E+01/
     *    EQLON(1699) /0.2487895465E+01/
     *    SSLIP(1699) /0.0000000000E+00/
     *    DSLIP(1699) /-.1370000000E+01/
     *    DIP(1699) /0.1570796327E+01/
     *    DEPTH(1699) /0.6000000000E+04/
     *    WIDTH(1699) /0.3000000000E+04/
      DATA STRIKE(1700) /0.5829399702E+01/
     *    HL(1700) /0.1483700000E+04/
     *    EQLAT(1700) /0.1096525443E+01/
     *    EQLON(1700) /0.2501449517E+01/
     *    SSLIP(1700) /0.3420000000E+01/
     *    DSLIP(1700) /-.6700000000E+00/
     *    DIP(1700) /0.1570796327E+01/
     *    DEPTH(1700) /0.6000000000E+04/
     *    WIDTH(1700) /0.3000000000E+04/
      DATA STRIKE(1701) /0.5827654372E+01/
     *    HL(1701) /0.1483900000E+04/
     *    EQLAT(1701) /0.1096105866E+01/
     *    EQLON(1701) /0.2501013185E+01/
     *    SSLIP(1701) /0.3111000000E+01/
     *    DSLIP(1701) /-.5900000000E+00/
     *    DIP(1701) /0.1570796327E+01/
     *    DEPTH(1701) /0.6000000000E+04/
     *    WIDTH(1701) /0.3000000000E+04/
      DATA STRIKE(1702) /0.5827654372E+01/
     *    HL(1702) /0.1484100000E+04/
     *    EQLAT(1702) /0.1095686114E+01/
     *    EQLON(1702) /0.2500576853E+01/
     *    SSLIP(1702) /0.2216000000E+01/
     *    DSLIP(1702) /-.3500000000E+00/
     *    DIP(1702) /0.1570796327E+01/
     *    DEPTH(1702) /0.6000000000E+04/
     *    WIDTH(1702) /0.3000000000E+04/
      DATA STRIKE(1703) /0.5825909043E+01/
     *    HL(1703) /0.1484300000E+04/
     *    EQLAT(1703) /0.1095266537E+01/
     *    EQLON(1703) /0.2500140520E+01/
     *    SSLIP(1703) /0.1252000000E+01/
     *    DSLIP(1703) /-.1100000000E+00/
     *    DIP(1703) /0.1570796327E+01/
     *    DEPTH(1703) /0.6000000000E+04/
     *    WIDTH(1703) /0.3000000000E+04/
      DATA STRIKE(1704) /0.5825909043E+01/
     *    HL(1704) /0.1484600000E+04/
     *    EQLAT(1704) /0.1094846960E+01/
     *    EQLON(1704) /0.2499704188E+01/
     *    SSLIP(1704) /0.6030000000E+00/
     *    DSLIP(1704) /0.0000000000E+00/
     *    DIP(1704) /0.1570796327E+01/
     *    DEPTH(1704) /0.6000000000E+04/
     *    WIDTH(1704) /0.3000000000E+04/
      DATA STRIKE(1705) /0.5824163714E+01/
     *    HL(1705) /0.1484800000E+04/
     *    EQLAT(1705) /0.1094427208E+01/
     *    EQLON(1705) /0.2499267856E+01/
     *    SSLIP(1705) /0.3420000000E+00/
     *    DSLIP(1705) /0.0000000000E+00/
     *    DIP(1705) /0.1570796327E+01/
     *    DEPTH(1705) /0.6000000000E+04/
     *    WIDTH(1705) /0.3000000000E+04/
      DATA STRIKE(1706) /0.5822418385E+01/
     *    HL(1706) /0.1485000000E+04/
     *    EQLAT(1706) /0.1094007631E+01/
     *    EQLON(1706) /0.2498831523E+01/
     *    SSLIP(1706) /0.2740000000E+00/
     *    DSLIP(1706) /0.0000000000E+00/
     *    DIP(1706) /0.1570796327E+01/
     *    DEPTH(1706) /0.6000000000E+04/
     *    WIDTH(1706) /0.3000000000E+04/
      DATA STRIKE(1707) /0.5553637680E+01/
     *    HL(1707) /0.1457400000E+04/
     *    EQLAT(1707) /0.1093625229E+01/
     *    EQLON(1707) /0.2498288551E+01/
     *    SSLIP(1707) /0.2470000000E+00/
     *    DSLIP(1707) /0.0000000000E+00/
     *    DIP(1707) /0.1570796327E+01/
     *    DEPTH(1707) /0.6000000000E+04/
     *    WIDTH(1707) /0.3000000000E+04/
      DATA STRIKE(1708) /0.5553637680E+01/
     *    HL(1708) /0.1457800000E+04/
     *    EQLAT(1708) /0.1093280178E+01/
     *    EQLON(1708) /0.2497638940E+01/
     *    SSLIP(1708) /0.2610000000E+00/
     *    DSLIP(1708) /0.0000000000E+00/
     *    DIP(1708) /0.1570796327E+01/
     *    DEPTH(1708) /0.6000000000E+04/
     *    WIDTH(1708) /0.3000000000E+04/
      DATA STRIKE(1709) /0.5551892351E+01/
     *    HL(1709) /0.1458200000E+04/
     *    EQLAT(1709) /0.1092935126E+01/
     *    EQLON(1709) /0.2496989503E+01/
     *    SSLIP(1709) /0.3080000000E+00/
     *    DSLIP(1709) /0.0000000000E+00/
     *    DIP(1709) /0.1570796327E+01/
     *    DEPTH(1709) /0.9000000000E+04/
     *    WIDTH(1709) /0.3000000000E+04/
      DATA STRIKE(1710) /0.5550147021E+01/
     *    HL(1710) /0.1458600000E+04/
     *    EQLAT(1710) /0.1092590074E+01/
     *    EQLON(1710) /0.2496339891E+01/
     *    SSLIP(1710) /0.3950000000E+00/
     *    DSLIP(1710) /0.0000000000E+00/
     *    DIP(1710) /0.1570796327E+01/
     *    DEPTH(1710) /0.9000000000E+04/
     *    WIDTH(1710) /0.3000000000E+04/
      DATA STRIKE(1711) /0.5548401692E+01/
     *    HL(1711) /0.1459000000E+04/
     *    EQLAT(1711) /0.1092245023E+01/
     *    EQLON(1711) /0.2495690280E+01/
     *    SSLIP(1711) /0.5070000000E+00/
     *    DSLIP(1711) /0.0000000000E+00/
     *    DIP(1711) /0.1570796327E+01/
     *    DEPTH(1711) /0.9000000000E+04/
     *    WIDTH(1711) /0.3000000000E+04/
      DATA STRIKE(1712) /0.5546656363E+01/
     *    HL(1712) /0.1459400000E+04/
     *    EQLAT(1712) /0.1091899971E+01/
     *    EQLON(1712) /0.2495040668E+01/
     *    SSLIP(1712) /0.5880000000E+00/
     *    DSLIP(1712) /0.0000000000E+00/
     *    DIP(1712) /0.1570796327E+01/
     *    DEPTH(1712) /0.9000000000E+04/
     *    WIDTH(1712) /0.3000000000E+04/
      DATA STRIKE(1713) /0.5544911034E+01/
     *    HL(1713) /0.1459800000E+04/
     *    EQLAT(1713) /0.1091554920E+01/
     *    EQLON(1713) /0.2494391231E+01/
     *    SSLIP(1713) /0.5740000000E+00/
     *    DSLIP(1713) /0.0000000000E+00/
     *    DIP(1713) /0.1570796327E+01/
     *    DEPTH(1713) /0.9000000000E+04/
     *    WIDTH(1713) /0.3000000000E+04/
      DATA STRIKE(1714) /0.5543165704E+01/
     *    HL(1714) /0.1460300000E+04/
     *    EQLAT(1714) /0.1091209868E+01/
     *    EQLON(1714) /0.2493741620E+01/
     *    SSLIP(1714) /0.4440000000E+00/
     *    DSLIP(1714) /0.0000000000E+00/
     *    DIP(1714) /0.1570796327E+01/
     *    DEPTH(1714) /0.9000000000E+04/
     *    WIDTH(1714) /0.3000000000E+04/
      DATA STRIKE(1715) /0.5543165704E+01/
     *    HL(1715) /0.1460700000E+04/
     *    EQLAT(1715) /0.1090864816E+01/
     *    EQLON(1715) /0.2493092008E+01/
     *    SSLIP(1715) /0.2460000000E+00/
     *    DSLIP(1715) /0.0000000000E+00/
     *    DIP(1715) /0.1570796327E+01/
     *    DEPTH(1715) /0.9000000000E+04/
     *    WIDTH(1715) /0.3000000000E+04/
      DATA STRIKE(1716) /0.5541420375E+01/
     *    HL(1716) /0.1461100000E+04/
     *    EQLAT(1716) /0.1090519765E+01/
     *    EQLON(1716) /0.2492442397E+01/
     *    SSLIP(1716) /0.7500000000E-01/
     *    DSLIP(1716) /0.0000000000E+00/
     *    DIP(1716) /0.1570796327E+01/
     *    DEPTH(1716) /0.9000000000E+04/
     *    WIDTH(1716) /0.3000000000E+04/
      DATA STRIKE(1717) /0.5539675046E+01/
     *    HL(1717) /0.1461500000E+04/
     *    EQLAT(1717) /0.1090174713E+01/
     *    EQLON(1717) /0.2491792785E+01/
     *    SSLIP(1717) /0.0000000000E+00/
     *    DSLIP(1717) /0.0000000000E+00/
     *    DIP(1717) /0.1570796327E+01/
     *    DEPTH(1717) /0.9000000000E+04/
     *    WIDTH(1717) /0.3000000000E+04/
      DATA STRIKE(1718) /0.5537929717E+01/
     *    HL(1718) /0.1461900000E+04/
     *    EQLAT(1718) /0.1089829662E+01/
     *    EQLON(1718) /0.2491143348E+01/
     *    SSLIP(1718) /0.0000000000E+00/
     *    DSLIP(1718) /-.1300000000E+00/
     *    DIP(1718) /0.1570796327E+01/
     *    DEPTH(1718) /0.9000000000E+04/
     *    WIDTH(1718) /0.3000000000E+04/
      DATA STRIKE(1719) /0.5536184387E+01/
     *    HL(1719) /0.1462300000E+04/
     *    EQLAT(1719) /0.1089484610E+01/
     *    EQLON(1719) /0.2490493736E+01/
     *    SSLIP(1719) /0.0000000000E+00/
     *    DSLIP(1719) /-.4700000000E+00/
     *    DIP(1719) /0.1570796327E+01/
     *    DEPTH(1719) /0.9000000000E+04/
     *    WIDTH(1719) /0.3000000000E+04/
      DATA STRIKE(1720) /0.5536184387E+01/
     *    HL(1720) /0.1462700000E+04/
     *    EQLAT(1720) /0.1089139558E+01/
     *    EQLON(1720) /0.2489844125E+01/
     *    SSLIP(1720) /0.0000000000E+00/
     *    DSLIP(1720) /-.9300000000E+00/
     *    DIP(1720) /0.1570796327E+01/
     *    DEPTH(1720) /0.9000000000E+04/
     *    WIDTH(1720) /0.3000000000E+04/
      DATA STRIKE(1721) /0.5534439058E+01/
     *    HL(1721) /0.1463200000E+04/
     *    EQLAT(1721) /0.1088794507E+01/
     *    EQLON(1721) /0.2489194513E+01/
     *    SSLIP(1721) /0.0000000000E+00/
     *    DSLIP(1721) /-.1390000000E+01/
     *    DIP(1721) /0.1570796327E+01/
     *    DEPTH(1721) /0.9000000000E+04/
     *    WIDTH(1721) /0.3000000000E+04/
      DATA STRIKE(1722) /0.5532693729E+01/
     *    HL(1722) /0.1463600000E+04/
     *    EQLAT(1722) /0.1088449455E+01/
     *    EQLON(1722) /0.2488545076E+01/
     *    SSLIP(1722) /0.0000000000E+00/
     *    DSLIP(1722) /-.1720000000E+01/
     *    DIP(1722) /0.1570796327E+01/
     *    DEPTH(1722) /0.9000000000E+04/
     *    WIDTH(1722) /0.3000000000E+04/
      DATA STRIKE(1723) /0.5530948400E+01/
     *    HL(1723) /0.1464000000E+04/
     *    EQLAT(1723) /0.1088104404E+01/
     *    EQLON(1723) /0.2487895465E+01/
     *    SSLIP(1723) /0.0000000000E+00/
     *    DSLIP(1723) /-.1770000000E+01/
     *    DIP(1723) /0.1570796327E+01/
     *    DEPTH(1723) /0.9000000000E+04/
     *    WIDTH(1723) /0.3000000000E+04/
      DATA STRIKE(1724) /0.5829399702E+01/
     *    HL(1724) /0.1483700000E+04/
     *    EQLAT(1724) /0.1096525443E+01/
     *    EQLON(1724) /0.2501449517E+01/
     *    SSLIP(1724) /0.2248000000E+01/
     *    DSLIP(1724) /-.5800000000E+00/
     *    DIP(1724) /0.1570796327E+01/
     *    DEPTH(1724) /0.9000000000E+04/
     *    WIDTH(1724) /0.3000000000E+04/
      DATA STRIKE(1725) /0.5827654372E+01/
     *    HL(1725) /0.1483900000E+04/
     *    EQLAT(1725) /0.1096105866E+01/
     *    EQLON(1725) /0.2501013185E+01/
     *    SSLIP(1725) /0.1923000000E+01/
     *    DSLIP(1725) /-.5000000000E+00/
     *    DIP(1725) /0.1570796327E+01/
     *    DEPTH(1725) /0.9000000000E+04/
     *    WIDTH(1725) /0.3000000000E+04/
      DATA STRIKE(1726) /0.5827654372E+01/
     *    HL(1726) /0.1484100000E+04/
     *    EQLAT(1726) /0.1095686114E+01/
     *    EQLON(1726) /0.2500576853E+01/
     *    SSLIP(1726) /0.1209000000E+01/
     *    DSLIP(1726) /-.2500000000E+00/
     *    DIP(1726) /0.1570796327E+01/
     *    DEPTH(1726) /0.9000000000E+04/
     *    WIDTH(1726) /0.3000000000E+04/
      DATA STRIKE(1727) /0.5825909043E+01/
     *    HL(1727) /0.1484300000E+04/
     *    EQLAT(1727) /0.1095266537E+01/
     *    EQLON(1727) /0.2500140520E+01/
     *    SSLIP(1727) /0.4880000000E+00/
     *    DSLIP(1727) /-.4000000000E-01/
     *    DIP(1727) /0.1570796327E+01/
     *    DEPTH(1727) /0.9000000000E+04/
     *    WIDTH(1727) /0.3000000000E+04/
      DATA STRIKE(1728) /0.5825909043E+01/
     *    HL(1728) /0.1484600000E+04/
     *    EQLAT(1728) /0.1094846960E+01/
     *    EQLON(1728) /0.2499704188E+01/
     *    SSLIP(1728) /0.7000000000E-01/
     *    DSLIP(1728) /0.0000000000E+00/
     *    DIP(1728) /0.1570796327E+01/
     *    DEPTH(1728) /0.9000000000E+04/
     *    WIDTH(1728) /0.3000000000E+04/
      DATA STRIKE(1729) /0.5824163714E+01/
     *    HL(1729) /0.1484800000E+04/
     *    EQLAT(1729) /0.1094427208E+01/
     *    EQLON(1729) /0.2499267856E+01/
     *    SSLIP(1729) /0.0000000000E+00/
     *    DSLIP(1729) /0.0000000000E+00/
     *    DIP(1729) /0.1570796327E+01/
     *    DEPTH(1729) /0.9000000000E+04/
     *    WIDTH(1729) /0.3000000000E+04/
      DATA STRIKE(1730) /0.5822418385E+01/
     *    HL(1730) /0.1485000000E+04/
     *    EQLAT(1730) /0.1094007631E+01/
     *    EQLON(1730) /0.2498831523E+01/
     *    SSLIP(1730) /0.0000000000E+00/
     *    DSLIP(1730) /0.0000000000E+00/
     *    DIP(1730) /0.1570796327E+01/
     *    DEPTH(1730) /0.9000000000E+04/
     *    WIDTH(1730) /0.3000000000E+04/
      DATA STRIKE(1731) /0.5553637680E+01/
     *    HL(1731) /0.1457400000E+04/
     *    EQLAT(1731) /0.1093625229E+01/
     *    EQLON(1731) /0.2498288551E+01/
     *    SSLIP(1731) /0.0000000000E+00/
     *    DSLIP(1731) /0.0000000000E+00/
     *    DIP(1731) /0.1570796327E+01/
     *    DEPTH(1731) /0.9000000000E+04/
     *    WIDTH(1731) /0.3000000000E+04/
      DATA STRIKE(1732) /0.5553637680E+01/
     *    HL(1732) /0.1457800000E+04/
     *    EQLAT(1732) /0.1093280178E+01/
     *    EQLON(1732) /0.2497638940E+01/
     *    SSLIP(1732) /0.0000000000E+00/
     *    DSLIP(1732) /0.0000000000E+00/
     *    DIP(1732) /0.1570796327E+01/
     *    DEPTH(1732) /0.9000000000E+04/
     *    WIDTH(1732) /0.3000000000E+04/
      DATA STRIKE(1733) /0.5551892351E+01/
     *    HL(1733) /0.1458200000E+04/
     *    EQLAT(1733) /0.1092935126E+01/
     *    EQLON(1733) /0.2496989503E+01/
     *    SSLIP(1733) /0.0000000000E+00/
     *    DSLIP(1733) /0.0000000000E+00/
     *    DIP(1733) /0.1570796327E+01/
     *    DEPTH(1733) /0.1200000000E+05/
     *    WIDTH(1733) /0.3000000000E+04/
      DATA STRIKE(1734) /0.5550147021E+01/
     *    HL(1734) /0.1458600000E+04/
     *    EQLAT(1734) /0.1092590074E+01/
     *    EQLON(1734) /0.2496339891E+01/
     *    SSLIP(1734) /0.1200000000E-01/
     *    DSLIP(1734) /0.0000000000E+00/
     *    DIP(1734) /0.1570796327E+01/
     *    DEPTH(1734) /0.1200000000E+05/
     *    WIDTH(1734) /0.3000000000E+04/
      DATA STRIKE(1735) /0.5548401692E+01/
     *    HL(1735) /0.1459000000E+04/
     *    EQLAT(1735) /0.1092245023E+01/
     *    EQLON(1735) /0.2495690280E+01/
     *    SSLIP(1735) /0.4500000000E-01/
     *    DSLIP(1735) /0.0000000000E+00/
     *    DIP(1735) /0.1570796327E+01/
     *    DEPTH(1735) /0.1200000000E+05/
     *    WIDTH(1735) /0.3000000000E+04/
      DATA STRIKE(1736) /0.5546656363E+01/
     *    HL(1736) /0.1459400000E+04/
     *    EQLAT(1736) /0.1091899971E+01/
     *    EQLON(1736) /0.2495040668E+01/
     *    SSLIP(1736) /0.7300000000E-01/
     *    DSLIP(1736) /0.0000000000E+00/
     *    DIP(1736) /0.1570796327E+01/
     *    DEPTH(1736) /0.1200000000E+05/
     *    WIDTH(1736) /0.3000000000E+04/
      DATA STRIKE(1737) /0.5544911034E+01/
     *    HL(1737) /0.1459800000E+04/
     *    EQLAT(1737) /0.1091554920E+01/
     *    EQLON(1737) /0.2494391231E+01/
     *    SSLIP(1737) /0.7300000000E-01/
     *    DSLIP(1737) /0.0000000000E+00/
     *    DIP(1737) /0.1570796327E+01/
     *    DEPTH(1737) /0.1200000000E+05/
     *    WIDTH(1737) /0.3000000000E+04/
      DATA STRIKE(1738) /0.5543165704E+01/
     *    HL(1738) /0.1460300000E+04/
     *    EQLAT(1738) /0.1091209868E+01/
     *    EQLON(1738) /0.2493741620E+01/
     *    SSLIP(1738) /0.4000000000E-01/
     *    DSLIP(1738) /0.0000000000E+00/
     *    DIP(1738) /0.1570796327E+01/
     *    DEPTH(1738) /0.1200000000E+05/
     *    WIDTH(1738) /0.3000000000E+04/
      DATA STRIKE(1739) /0.5543165704E+01/
     *    HL(1739) /0.1460700000E+04/
     *    EQLAT(1739) /0.1090864816E+01/
     *    EQLON(1739) /0.2493092008E+01/
     *    SSLIP(1739) /0.1000000000E-02/
     *    DSLIP(1739) /0.0000000000E+00/
     *    DIP(1739) /0.1570796327E+01/
     *    DEPTH(1739) /0.1200000000E+05/
     *    WIDTH(1739) /0.3000000000E+04/
      DATA STRIKE(1740) /0.5541420375E+01/
     *    HL(1740) /0.1461100000E+04/
     *    EQLAT(1740) /0.1090519765E+01/
     *    EQLON(1740) /0.2492442397E+01/
     *    SSLIP(1740) /0.0000000000E+00/
     *    DSLIP(1740) /0.0000000000E+00/
     *    DIP(1740) /0.1570796327E+01/
     *    DEPTH(1740) /0.1200000000E+05/
     *    WIDTH(1740) /0.3000000000E+04/
      DATA STRIKE(1741) /0.5539675046E+01/
     *    HL(1741) /0.1461500000E+04/
     *    EQLAT(1741) /0.1090174713E+01/
     *    EQLON(1741) /0.2491792785E+01/
     *    SSLIP(1741) /0.0000000000E+00/
     *    DSLIP(1741) /0.0000000000E+00/
     *    DIP(1741) /0.1570796327E+01/
     *    DEPTH(1741) /0.1200000000E+05/
     *    WIDTH(1741) /0.3000000000E+04/
      DATA STRIKE(1742) /0.5537929717E+01/
     *    HL(1742) /0.1461900000E+04/
     *    EQLAT(1742) /0.1089829662E+01/
     *    EQLON(1742) /0.2491143348E+01/
     *    SSLIP(1742) /0.0000000000E+00/
     *    DSLIP(1742) /-.1900000000E+00/
     *    DIP(1742) /0.1570796327E+01/
     *    DEPTH(1742) /0.1200000000E+05/
     *    WIDTH(1742) /0.3000000000E+04/
      DATA STRIKE(1743) /0.5536184387E+01/
     *    HL(1743) /0.1462300000E+04/
     *    EQLAT(1743) /0.1089484610E+01/
     *    EQLON(1743) /0.2490493736E+01/
     *    SSLIP(1743) /0.0000000000E+00/
     *    DSLIP(1743) /-.5800000000E+00/
     *    DIP(1743) /0.1570796327E+01/
     *    DEPTH(1743) /0.1200000000E+05/
     *    WIDTH(1743) /0.3000000000E+04/
      DATA STRIKE(1744) /0.5536184387E+01/
     *    HL(1744) /0.1462700000E+04/
     *    EQLAT(1744) /0.1089139558E+01/
     *    EQLON(1744) /0.2489844125E+01/
     *    SSLIP(1744) /0.0000000000E+00/
     *    DSLIP(1744) /-.1100000000E+01/
     *    DIP(1744) /0.1570796327E+01/
     *    DEPTH(1744) /0.1200000000E+05/
     *    WIDTH(1744) /0.3000000000E+04/
      DATA STRIKE(1745) /0.5534439058E+01/
     *    HL(1745) /0.1463200000E+04/
     *    EQLAT(1745) /0.1088794507E+01/
     *    EQLON(1745) /0.2489194513E+01/
     *    SSLIP(1745) /0.0000000000E+00/
     *    DSLIP(1745) /-.1620000000E+01/
     *    DIP(1745) /0.1570796327E+01/
     *    DEPTH(1745) /0.1200000000E+05/
     *    WIDTH(1745) /0.3000000000E+04/
      DATA STRIKE(1746) /0.5532693729E+01/
     *    HL(1746) /0.1463600000E+04/
     *    EQLAT(1746) /0.1088449455E+01/
     *    EQLON(1746) /0.2488545076E+01/
     *    SSLIP(1746) /0.0000000000E+00/
     *    DSLIP(1746) /-.1980000000E+01/
     *    DIP(1746) /0.1570796327E+01/
     *    DEPTH(1746) /0.1200000000E+05/
     *    WIDTH(1746) /0.3000000000E+04/
      DATA STRIKE(1747) /0.5530948400E+01/
     *    HL(1747) /0.1464000000E+04/
     *    EQLAT(1747) /0.1088104404E+01/
     *    EQLON(1747) /0.2487895465E+01/
     *    SSLIP(1747) /0.0000000000E+00/
     *    DSLIP(1747) /-.2030000000E+01/
     *    DIP(1747) /0.1570796327E+01/
     *    DEPTH(1747) /0.1200000000E+05/
     *    WIDTH(1747) /0.3000000000E+04/
      DATA STRIKE(1748) /0.5829399702E+01/
     *    HL(1748) /0.1483700000E+04/
     *    EQLAT(1748) /0.1096525443E+01/
     *    EQLON(1748) /0.2501449517E+01/
     *    SSLIP(1748) /0.1854000000E+01/
     *    DSLIP(1748) /-.5500000000E+00/
     *    DIP(1748) /0.1570796327E+01/
     *    DEPTH(1748) /0.1200000000E+05/
     *    WIDTH(1748) /0.3000000000E+04/
      DATA STRIKE(1749) /0.5827654372E+01/
     *    HL(1749) /0.1483900000E+04/
     *    EQLAT(1749) /0.1096105866E+01/
     *    EQLON(1749) /0.2501013185E+01/
     *    SSLIP(1749) /0.1555000000E+01/
     *    DSLIP(1749) /-.4700000000E+00/
     *    DIP(1749) /0.1570796327E+01/
     *    DEPTH(1749) /0.1200000000E+05/
     *    WIDTH(1749) /0.3000000000E+04/
      DATA STRIKE(1750) /0.5827654372E+01/
     *    HL(1750) /0.1484100000E+04/
     *    EQLAT(1750) /0.1095686114E+01/
     *    EQLON(1750) /0.2500576853E+01/
     *    SSLIP(1750) /0.9410000000E+00/
     *    DSLIP(1750) /-.2400000000E+00/
     *    DIP(1750) /0.1570796327E+01/
     *    DEPTH(1750) /0.1200000000E+05/
     *    WIDTH(1750) /0.3000000000E+04/
      DATA STRIKE(1751) /0.5825909043E+01/
     *    HL(1751) /0.1484300000E+04/
     *    EQLAT(1751) /0.1095266537E+01/
     *    EQLON(1751) /0.2500140520E+01/
     *    SSLIP(1751) /0.3310000000E+00/
     *    DSLIP(1751) /-.5000000000E-01/
     *    DIP(1751) /0.1570796327E+01/
     *    DEPTH(1751) /0.1200000000E+05/
     *    WIDTH(1751) /0.3000000000E+04/
      DATA STRIKE(1752) /0.5825909043E+01/
     *    HL(1752) /0.1484600000E+04/
     *    EQLAT(1752) /0.1094846960E+01/
     *    EQLON(1752) /0.2499704188E+01/
     *    SSLIP(1752) /0.1000000000E-02/
     *    DSLIP(1752) /0.0000000000E+00/
     *    DIP(1752) /0.1570796327E+01/
     *    DEPTH(1752) /0.1200000000E+05/
     *    WIDTH(1752) /0.3000000000E+04/
      DATA STRIKE(1753) /0.5824163714E+01/
     *    HL(1753) /0.1484800000E+04/
     *    EQLAT(1753) /0.1094427208E+01/
     *    EQLON(1753) /0.2499267856E+01/
     *    SSLIP(1753) /0.0000000000E+00/
     *    DSLIP(1753) /0.0000000000E+00/
     *    DIP(1753) /0.1570796327E+01/
     *    DEPTH(1753) /0.1200000000E+05/
     *    WIDTH(1753) /0.3000000000E+04/
      DATA STRIKE(1754) /0.5822418385E+01/
     *    HL(1754) /0.1485000000E+04/
     *    EQLAT(1754) /0.1094007631E+01/
     *    EQLON(1754) /0.2498831523E+01/
     *    SSLIP(1754) /0.0000000000E+00/
     *    DSLIP(1754) /0.0000000000E+00/
     *    DIP(1754) /0.1570796327E+01/
     *    DEPTH(1754) /0.1200000000E+05/
     *    WIDTH(1754) /0.3000000000E+04/
      DATA STRIKE(1755) /0.5553637680E+01/
     *    HL(1755) /0.1457400000E+04/
     *    EQLAT(1755) /0.1093625229E+01/
     *    EQLON(1755) /0.2498288551E+01/
     *    SSLIP(1755) /0.0000000000E+00/
     *    DSLIP(1755) /0.0000000000E+00/
     *    DIP(1755) /0.1570796327E+01/
     *    DEPTH(1755) /0.1200000000E+05/
     *    WIDTH(1755) /0.3000000000E+04/
      DATA STRIKE(1756) /0.5553637680E+01/
     *    HL(1756) /0.1457800000E+04/
     *    EQLAT(1756) /0.1093280178E+01/
     *    EQLON(1756) /0.2497638940E+01/
     *    SSLIP(1756) /0.0000000000E+00/
     *    DSLIP(1756) /0.0000000000E+00/
     *    DIP(1756) /0.1570796327E+01/
     *    DEPTH(1756) /0.1200000000E+05/
     *    WIDTH(1756) /0.3000000000E+04/
      DATA STRIKE(1757) /0.5551892351E+01/
     *    HL(1757) /0.1458200000E+04/
     *    EQLAT(1757) /0.1092935126E+01/
     *    EQLON(1757) /0.2496989503E+01/
     *    SSLIP(1757) /0.0000000000E+00/
     *    DSLIP(1757) /0.0000000000E+00/
     *    DIP(1757) /0.1570796327E+01/
     *    DEPTH(1757) /0.1500000000E+05/
     *    WIDTH(1757) /0.3000000000E+04/
      DATA STRIKE(1758) /0.5550147021E+01/
     *    HL(1758) /0.1458600000E+04/
     *    EQLAT(1758) /0.1092590074E+01/
     *    EQLON(1758) /0.2496339891E+01/
     *    SSLIP(1758) /0.0000000000E+00/
     *    DSLIP(1758) /0.0000000000E+00/
     *    DIP(1758) /0.1570796327E+01/
     *    DEPTH(1758) /0.1500000000E+05/
     *    WIDTH(1758) /0.3000000000E+04/
      DATA STRIKE(1759) /0.5548401692E+01/
     *    HL(1759) /0.1459000000E+04/
     *    EQLAT(1759) /0.1092245023E+01/
     *    EQLON(1759) /0.2495690280E+01/
     *    SSLIP(1759) /0.0000000000E+00/
     *    DSLIP(1759) /0.0000000000E+00/
     *    DIP(1759) /0.1570796327E+01/
     *    DEPTH(1759) /0.1500000000E+05/
     *    WIDTH(1759) /0.3000000000E+04/
      DATA STRIKE(1760) /0.5546656363E+01/
     *    HL(1760) /0.1459400000E+04/
     *    EQLAT(1760) /0.1091899971E+01/
     *    EQLON(1760) /0.2495040668E+01/
     *    SSLIP(1760) /0.0000000000E+00/
     *    DSLIP(1760) /0.0000000000E+00/
     *    DIP(1760) /0.1570796327E+01/
     *    DEPTH(1760) /0.1500000000E+05/
     *    WIDTH(1760) /0.3000000000E+04/
      DATA STRIKE(1761) /0.5544911034E+01/
     *    HL(1761) /0.1459800000E+04/
     *    EQLAT(1761) /0.1091554920E+01/
     *    EQLON(1761) /0.2494391231E+01/
     *    SSLIP(1761) /0.0000000000E+00/
     *    DSLIP(1761) /0.0000000000E+00/
     *    DIP(1761) /0.1570796327E+01/
     *    DEPTH(1761) /0.1500000000E+05/
     *    WIDTH(1761) /0.3000000000E+04/
      DATA STRIKE(1762) /0.5543165704E+01/
     *    HL(1762) /0.1460300000E+04/
     *    EQLAT(1762) /0.1091209868E+01/
     *    EQLON(1762) /0.2493741620E+01/
     *    SSLIP(1762) /0.0000000000E+00/
     *    DSLIP(1762) /0.0000000000E+00/
     *    DIP(1762) /0.1570796327E+01/
     *    DEPTH(1762) /0.1500000000E+05/
     *    WIDTH(1762) /0.3000000000E+04/
      DATA STRIKE(1763) /0.5543165704E+01/
     *    HL(1763) /0.1460700000E+04/
     *    EQLAT(1763) /0.1090864816E+01/
     *    EQLON(1763) /0.2493092008E+01/
     *    SSLIP(1763) /0.0000000000E+00/
     *    DSLIP(1763) /0.0000000000E+00/
     *    DIP(1763) /0.1570796327E+01/
     *    DEPTH(1763) /0.1500000000E+05/
     *    WIDTH(1763) /0.3000000000E+04/
      DATA STRIKE(1764) /0.5541420375E+01/
     *    HL(1764) /0.1461100000E+04/
     *    EQLAT(1764) /0.1090519765E+01/
     *    EQLON(1764) /0.2492442397E+01/
     *    SSLIP(1764) /0.0000000000E+00/
     *    DSLIP(1764) /0.0000000000E+00/
     *    DIP(1764) /0.1570796327E+01/
     *    DEPTH(1764) /0.1500000000E+05/
     *    WIDTH(1764) /0.3000000000E+04/
      DATA STRIKE(1765) /0.5539675046E+01/
     *    HL(1765) /0.1461500000E+04/
     *    EQLAT(1765) /0.1090174713E+01/
     *    EQLON(1765) /0.2491792785E+01/
     *    SSLIP(1765) /0.0000000000E+00/
     *    DSLIP(1765) /-.3000000000E-01/
     *    DIP(1765) /0.1570796327E+01/
     *    DEPTH(1765) /0.1500000000E+05/
     *    WIDTH(1765) /0.3000000000E+04/
      DATA STRIKE(1766) /0.5537929717E+01/
     *    HL(1766) /0.1461900000E+04/
     *    EQLAT(1766) /0.1089829662E+01/
     *    EQLON(1766) /0.2491143348E+01/
     *    SSLIP(1766) /0.0000000000E+00/
     *    DSLIP(1766) /-.2300000000E+00/
     *    DIP(1766) /0.1570796327E+01/
     *    DEPTH(1766) /0.1500000000E+05/
     *    WIDTH(1766) /0.3000000000E+04/
      DATA STRIKE(1767) /0.5536184387E+01/
     *    HL(1767) /0.1462300000E+04/
     *    EQLAT(1767) /0.1089484610E+01/
     *    EQLON(1767) /0.2490493736E+01/
     *    SSLIP(1767) /0.0000000000E+00/
     *    DSLIP(1767) /-.6300000000E+00/
     *    DIP(1767) /0.1570796327E+01/
     *    DEPTH(1767) /0.1500000000E+05/
     *    WIDTH(1767) /0.3000000000E+04/
      DATA STRIKE(1768) /0.5536184387E+01/
     *    HL(1768) /0.1462700000E+04/
     *    EQLAT(1768) /0.1089139558E+01/
     *    EQLON(1768) /0.2489844125E+01/
     *    SSLIP(1768) /0.0000000000E+00/
     *    DSLIP(1768) /-.1150000000E+01/
     *    DIP(1768) /0.1570796327E+01/
     *    DEPTH(1768) /0.1500000000E+05/
     *    WIDTH(1768) /0.3000000000E+04/
      DATA STRIKE(1769) /0.5534439058E+01/
     *    HL(1769) /0.1463200000E+04/
     *    EQLAT(1769) /0.1088794507E+01/
     *    EQLON(1769) /0.2489194513E+01/
     *    SSLIP(1769) /0.0000000000E+00/
     *    DSLIP(1769) /-.1650000000E+01/
     *    DIP(1769) /0.1570796327E+01/
     *    DEPTH(1769) /0.1500000000E+05/
     *    WIDTH(1769) /0.3000000000E+04/
      DATA STRIKE(1770) /0.5532693729E+01/
     *    HL(1770) /0.1463600000E+04/
     *    EQLAT(1770) /0.1088449455E+01/
     *    EQLON(1770) /0.2488545076E+01/
     *    SSLIP(1770) /0.0000000000E+00/
     *    DSLIP(1770) /-.2000000000E+01/
     *    DIP(1770) /0.1570796327E+01/
     *    DEPTH(1770) /0.1500000000E+05/
     *    WIDTH(1770) /0.3000000000E+04/
      DATA STRIKE(1771) /0.5530948400E+01/
     *    HL(1771) /0.1464000000E+04/
     *    EQLAT(1771) /0.1088104404E+01/
     *    EQLON(1771) /0.2487895465E+01/
     *    SSLIP(1771) /0.0000000000E+00/
     *    DSLIP(1771) /-.2070000000E+01/
     *    DIP(1771) /0.1570796327E+01/
     *    DEPTH(1771) /0.1500000000E+05/
     *    WIDTH(1771) /0.3000000000E+04/
      DATA STRIKE(1772) /0.1431169987E+01/
     *    HL(1772) /0.1495900000E+04/
     *    EQLAT(1772) /0.1106499476E+01/
     *    EQLON(1772) /0.2577209548E+01/
     *    SSLIP(1772) /-.5340000000E+00/
     *    DSLIP(1772) /-.4840000000E+01/
     *    DIP(1772) /0.3316125579E+00/
     *    DEPTH(1772) /0.0000000000E+00/
     *    WIDTH(1772) /0.3160700000E+04/
      DATA STRIKE(1773) /0.1432915316E+01/
     *    HL(1773) /0.1495900000E+04/
     *    EQLAT(1773) /0.1106564228E+01/
     *    EQLON(1773) /0.2576174742E+01/
     *    SSLIP(1773) /-.3900000000E+00/
     *    DSLIP(1773) /-.4710000000E+01/
     *    DIP(1773) /0.3316125579E+00/
     *    DEPTH(1773) /0.0000000000E+00/
     *    WIDTH(1773) /0.3160700000E+04/
      DATA STRIKE(1774) /0.1434660645E+01/
     *    HL(1774) /0.1495900000E+04/
     *    EQLAT(1774) /0.1106628805E+01/
     *    EQLON(1774) /0.2575139762E+01/
     *    SSLIP(1774) /-.3360000000E+00/
     *    DSLIP(1774) /-.4550000000E+01/
     *    DIP(1774) /0.3316125579E+00/
     *    DEPTH(1774) /0.0000000000E+00/
     *    WIDTH(1774) /0.3160700000E+04/
      DATA STRIKE(1775) /0.1434660645E+01/
     *    HL(1775) /0.1495900000E+04/
     *    EQLAT(1775) /0.1106692684E+01/
     *    EQLON(1775) /0.2574104432E+01/
     *    SSLIP(1775) /-.2330000000E+00/
     *    DSLIP(1775) /-.4370000000E+01/
     *    DIP(1775) /0.3316125579E+00/
     *    DEPTH(1775) /0.0000000000E+00/
     *    WIDTH(1775) /0.3160700000E+04/
      DATA STRIKE(1776) /0.1436405974E+01/
     *    HL(1776) /0.1495900000E+04/
     *    EQLAT(1776) /0.1106756214E+01/
     *    EQLON(1776) /0.2573068929E+01/
     *    SSLIP(1776) /-.9900000000E-01/
     *    DSLIP(1776) /-.4210000000E+01/
     *    DIP(1776) /0.3316125579E+00/
     *    DEPTH(1776) /0.0000000000E+00/
     *    WIDTH(1776) /0.3160700000E+04/
      DATA STRIKE(1777) /0.1436405974E+01/
     *    HL(1777) /0.1495900000E+04/
     *    EQLAT(1777) /0.1106819395E+01/
     *    EQLON(1777) /0.2572033250E+01/
     *    SSLIP(1777) /0.0000000000E+00/
     *    DSLIP(1777) /-.4060000000E+01/
     *    DIP(1777) /0.3316125579E+00/
     *    DEPTH(1777) /0.0000000000E+00/
     *    WIDTH(1777) /0.3160700000E+04/
      DATA STRIKE(1778) /0.1438151304E+01/
     *    HL(1778) /0.1495900000E+04/
     *    EQLAT(1778) /0.1106882052E+01/
     *    EQLON(1778) /0.2570997223E+01/
     *    SSLIP(1778) /0.0000000000E+00/
     *    DSLIP(1778) /-.3910000000E+01/
     *    DIP(1778) /0.3316125579E+00/
     *    DEPTH(1778) /0.0000000000E+00/
     *    WIDTH(1778) /0.3160700000E+04/
      DATA STRIKE(1779) /0.1438151304E+01/
     *    HL(1779) /0.1495900000E+04/
     *    EQLAT(1779) /0.1106944360E+01/
     *    EQLON(1779) /0.2569960846E+01/
     *    SSLIP(1779) /0.0000000000E+00/
     *    DSLIP(1779) /-.3750000000E+01/
     *    DIP(1779) /0.3316125579E+00/
     *    DEPTH(1779) /0.0000000000E+00/
     *    WIDTH(1779) /0.3160700000E+04/
      DATA STRIKE(1780) /0.1439896633E+01/
     *    HL(1780) /0.1495900000E+04/
     *    EQLAT(1780) /0.1107006319E+01/
     *    EQLON(1780) /0.2568924295E+01/
     *    SSLIP(1780) /0.0000000000E+00/
     *    DSLIP(1780) /-.3590000000E+01/
     *    DIP(1780) /0.3316125579E+00/
     *    DEPTH(1780) /0.0000000000E+00/
     *    WIDTH(1780) /0.3160700000E+04/
      DATA STRIKE(1781) /0.1439896633E+01/
     *    HL(1781) /0.1495900000E+04/
     *    EQLAT(1781) /0.1107067581E+01/
     *    EQLON(1781) /0.2567887570E+01/
     *    SSLIP(1781) /0.0000000000E+00/
     *    DSLIP(1781) /-.3470000000E+01/
     *    DIP(1781) /0.3316125579E+00/
     *    DEPTH(1781) /0.0000000000E+00/
     *    WIDTH(1781) /0.3160700000E+04/
      DATA STRIKE(1782) /0.1441641962E+01/
     *    HL(1782) /0.1495900000E+04/
     *    EQLAT(1782) /0.1107128667E+01/
     *    EQLON(1782) /0.2566850495E+01/
     *    SSLIP(1782) /0.0000000000E+00/
     *    DSLIP(1782) /-.3370000000E+01/
     *    DIP(1782) /0.3316125579E+00/
     *    DEPTH(1782) /0.0000000000E+00/
     *    WIDTH(1782) /0.3160700000E+04/
      DATA STRIKE(1783) /0.1431169987E+01/
     *    HL(1783) /0.1495900000E+04/
     *    EQLAT(1783) /0.1106938775E+01/
     *    EQLON(1783) /0.2577357726E+01/
     *    SSLIP(1783) /-.1181000000E+01/
     *    DSLIP(1783) /-.5220000000E+01/
     *    DIP(1783) /0.3316125579E+00/
     *    DEPTH(1783) /0.9767000000E+03/
     *    WIDTH(1783) /0.3160700000E+04/
      DATA STRIKE(1784) /0.1432915316E+01/
     *    HL(1784) /0.1495900000E+04/
     *    EQLAT(1784) /0.1107003527E+01/
     *    EQLON(1784) /0.2576322048E+01/
     *    SSLIP(1784) /-.1045000000E+01/
     *    DSLIP(1784) /-.5070000000E+01/
     *    DIP(1784) /0.3316125579E+00/
     *    DEPTH(1784) /0.9767000000E+03/
     *    WIDTH(1784) /0.3160700000E+04/
      DATA STRIKE(1785) /0.1432915316E+01/
     *    HL(1785) /0.1495900000E+04/
     *    EQLAT(1785) /0.1107068104E+01/
     *    EQLON(1785) /0.2575286195E+01/
     *    SSLIP(1785) /-.9270000000E+00/
     *    DSLIP(1785) /-.4810000000E+01/
     *    DIP(1785) /0.3316125579E+00/
     *    DEPTH(1785) /0.9767000000E+03/
     *    WIDTH(1785) /0.3160700000E+04/
      DATA STRIKE(1786) /0.1434660645E+01/
     *    HL(1786) /0.1495900000E+04/
     *    EQLAT(1786) /0.1107131983E+01/
     *    EQLON(1786) /0.2574249993E+01/
     *    SSLIP(1786) /-.7030000000E+00/
     *    DSLIP(1786) /-.4520000000E+01/
     *    DIP(1786) /0.3316125579E+00/
     *    DEPTH(1786) /0.9767000000E+03/
     *    WIDTH(1786) /0.3160700000E+04/
      DATA STRIKE(1787) /0.1436405974E+01/
     *    HL(1787) /0.1495900000E+04/
     *    EQLAT(1787) /0.1107195513E+01/
     *    EQLON(1787) /0.2573213616E+01/
     *    SSLIP(1787) /-.4060000000E+00/
     *    DSLIP(1787) /-.4260000000E+01/
     *    DIP(1787) /0.3316125579E+00/
     *    DEPTH(1787) /0.9767000000E+03/
     *    WIDTH(1787) /0.3160700000E+04/
      DATA STRIKE(1788) /0.1436405974E+01/
     *    HL(1788) /0.1495900000E+04/
     *    EQLAT(1788) /0.1107258694E+01/
     *    EQLON(1788) /0.2572176891E+01/
     *    SSLIP(1788) /-.1400000000E+00/
     *    DSLIP(1788) /-.4040000000E+01/
     *    DIP(1788) /0.3316125579E+00/
     *    DEPTH(1788) /0.9767000000E+03/
     *    WIDTH(1788) /0.3160700000E+04/
      DATA STRIKE(1789) /0.1438151304E+01/
     *    HL(1789) /0.1495900000E+04/
     *    EQLAT(1789) /0.1107321351E+01/
     *    EQLON(1789) /0.2571139816E+01/
     *    SSLIP(1789) /-.7000000000E-02/
     *    DSLIP(1789) /-.3810000000E+01/
     *    DIP(1789) /0.3316125579E+00/
     *    DEPTH(1789) /0.9767000000E+03/
     *    WIDTH(1789) /0.3160700000E+04/
      DATA STRIKE(1790) /0.1438151304E+01/
     *    HL(1790) /0.1495900000E+04/
     *    EQLAT(1790) /0.1107383660E+01/
     *    EQLON(1790) /0.2570102741E+01/
     *    SSLIP(1790) /0.0000000000E+00/
     *    DSLIP(1790) /-.3590000000E+01/
     *    DIP(1790) /0.3316125579E+00/
     *    DEPTH(1790) /0.9767000000E+03/
     *    WIDTH(1790) /0.3160700000E+04/
      DATA STRIKE(1791) /0.1439896633E+01/
     *    HL(1791) /0.1495900000E+04/
     *    EQLAT(1791) /0.1107445444E+01/
     *    EQLON(1791) /0.2569065143E+01/
     *    SSLIP(1791) /0.0000000000E+00/
     *    DSLIP(1791) /-.3370000000E+01/
     *    DIP(1791) /0.3316125579E+00/
     *    DEPTH(1791) /0.9767000000E+03/
     *    WIDTH(1791) /0.3160700000E+04/
      DATA STRIKE(1792) /0.1439896633E+01/
     *    HL(1792) /0.1495900000E+04/
     *    EQLAT(1792) /0.1107506880E+01/
     *    EQLON(1792) /0.2568027545E+01/
     *    SSLIP(1792) /0.0000000000E+00/
     *    DSLIP(1792) /-.3200000000E+01/
     *    DIP(1792) /0.3316125579E+00/
     *    DEPTH(1792) /0.9767000000E+03/
     *    WIDTH(1792) /0.3160700000E+04/
      DATA STRIKE(1793) /0.1441641962E+01/
     *    HL(1793) /0.1495900000E+04/
     *    EQLAT(1793) /0.1107567966E+01/
     *    EQLON(1793) /0.2566989598E+01/
     *    SSLIP(1793) /0.0000000000E+00/
     *    DSLIP(1793) /-.3110000000E+01/
     *    DIP(1793) /0.3316125579E+00/
     *    DEPTH(1793) /0.9767000000E+03/
     *    WIDTH(1793) /0.3160700000E+04/
      DATA STRIKE(1794) /0.1431169987E+01/
     *    HL(1794) /0.1495900000E+04/
     *    EQLAT(1794) /0.1107378075E+01/
     *    EQLON(1794) /0.2577506079E+01/
     *    SSLIP(1794) /-.2733000000E+01/
     *    DSLIP(1794) /-.5960000000E+01/
     *    DIP(1794) /0.8377580410E+00/
     *    DEPTH(1794) /0.1953400000E+04/
     *    WIDTH(1794) /0.3127200000E+04/
      DATA STRIKE(1795) /0.1432915316E+01/
     *    HL(1795) /0.1495900000E+04/
     *    EQLAT(1795) /0.1107442826E+01/
     *    EQLON(1795) /0.2576469528E+01/
     *    SSLIP(1795) /-.2726000000E+01/
     *    DSLIP(1795) /-.5820000000E+01/
     *    DIP(1795) /0.8377580410E+00/
     *    DEPTH(1795) /0.1953400000E+04/
     *    WIDTH(1795) /0.3127200000E+04/
      DATA STRIKE(1796) /0.1432915316E+01/
     *    HL(1796) /0.1495900000E+04/
     *    EQLAT(1796) /0.1107507229E+01/
     *    EQLON(1796) /0.2575432802E+01/
     *    SSLIP(1796) /-.2484000000E+01/
     *    DSLIP(1796) /-.5350000000E+01/
     *    DIP(1796) /0.8377580410E+00/
     *    DEPTH(1796) /0.1953400000E+04/
     *    WIDTH(1796) /0.3127200000E+04/
      DATA STRIKE(1797) /0.1434660645E+01/
     *    HL(1797) /0.1495900000E+04/
     *    EQLAT(1797) /0.1107571283E+01/
     *    EQLON(1797) /0.2574395728E+01/
     *    SSLIP(1797) /-.1996000000E+01/
     *    DSLIP(1797) /-.4810000000E+01/
     *    DIP(1797) /0.8377580410E+00/
     *    DEPTH(1797) /0.1953400000E+04/
     *    WIDTH(1797) /0.3127200000E+04/
      DATA STRIKE(1798) /0.1436405974E+01/
     *    HL(1798) /0.1495900000E+04/
     *    EQLAT(1798) /0.1107634813E+01/
     *    EQLON(1798) /0.2573358304E+01/
     *    SSLIP(1798) /-.1347000000E+01/
     *    DSLIP(1798) /-.4320000000E+01/
     *    DIP(1798) /0.8377580410E+00/
     *    DEPTH(1798) /0.1953400000E+04/
     *    WIDTH(1798) /0.3127200000E+04/
      DATA STRIKE(1799) /0.1436405974E+01/
     *    HL(1799) /0.1495900000E+04/
     *    EQLAT(1799) /0.1107697993E+01/
     *    EQLON(1799) /0.2572320706E+01/
     *    SSLIP(1799) /-.6980000000E+00/
     *    DSLIP(1799) /-.3890000000E+01/
     *    DIP(1799) /0.8377580410E+00/
     *    DEPTH(1799) /0.1953400000E+04/
     *    WIDTH(1799) /0.3127200000E+04/
      DATA STRIKE(1800) /0.1438151304E+01/
     *    HL(1800) /0.1495900000E+04/
     *    EQLAT(1800) /0.1107760651E+01/
     *    EQLON(1800) /0.2571282933E+01/
     *    SSLIP(1800) /-.2170000000E+00/
     *    DSLIP(1800) /-.3490000000E+01/
     *    DIP(1800) /0.8377580410E+00/
     *    DEPTH(1800) /0.1953400000E+04/
     *    WIDTH(1800) /0.3127200000E+04/
      DATA STRIKE(1801) /0.1438151304E+01/
     *    HL(1801) /0.1495900000E+04/
     *    EQLAT(1801) /0.1107822959E+01/
     *    EQLON(1801) /0.2570244811E+01/
     *    SSLIP(1801) /0.0000000000E+00/
     *    DSLIP(1801) /-.3120000000E+01/
     *    DIP(1801) /0.8377580410E+00/
     *    DEPTH(1801) /0.1953400000E+04/
     *    WIDTH(1801) /0.3127200000E+04/
      DATA STRIKE(1802) /0.1439896633E+01/
     *    HL(1802) /0.1495900000E+04/
     *    EQLAT(1802) /0.1107884744E+01/
     *    EQLON(1802) /0.2569206340E+01/
     *    SSLIP(1802) /0.0000000000E+00/
     *    DSLIP(1802) /-.2780000000E+01/
     *    DIP(1802) /0.8377580410E+00/
     *    DEPTH(1802) /0.1953400000E+04/
     *    WIDTH(1802) /0.3127200000E+04/
      DATA STRIKE(1803) /0.1439896633E+01/
     *    HL(1803) /0.1495900000E+04/
     *    EQLAT(1803) /0.1107946179E+01/
     *    EQLON(1803) /0.2568167695E+01/
     *    SSLIP(1803) /0.0000000000E+00/
     *    DSLIP(1803) /-.2530000000E+01/
     *    DIP(1803) /0.8377580410E+00/
     *    DEPTH(1803) /0.1953400000E+04/
     *    WIDTH(1803) /0.3127200000E+04/
      DATA STRIKE(1804) /0.1441641962E+01/
     *    HL(1804) /0.1495900000E+04/
     *    EQLAT(1804) /0.1108007091E+01/
     *    EQLON(1804) /0.2567128875E+01/
     *    SSLIP(1804) /0.0000000000E+00/
     *    DSLIP(1804) /-.2480000000E+01/
     *    DIP(1804) /0.8377580410E+00/
     *    DEPTH(1804) /0.1953400000E+04/
     *    WIDTH(1804) /0.3127200000E+04/
      DATA STRIKE(1805) /0.1431169987E+01/
     *    HL(1805) /0.1495900000E+04/
     *    EQLAT(1805) /0.1107688918E+01/
     *    EQLON(1805) /0.2577611322E+01/
     *    SSLIP(1805) /-.4064000000E+01/
     *    DSLIP(1805) /-.6600000000E+01/
     *    DIP(1805) /0.8377580410E+00/
     *    DEPTH(1805) /0.4182800000E+04/
     *    WIDTH(1805) /0.3127200000E+04/
      DATA STRIKE(1806) /0.1432915316E+01/
     *    HL(1806) /0.1495900000E+04/
     *    EQLAT(1806) /0.1107753669E+01/
     *    EQLON(1806) /0.2576574073E+01/
     *    SSLIP(1806) /-.4154000000E+01/
     *    DSLIP(1806) /-.6460000000E+01/
     *    DIP(1806) /0.8377580410E+00/
     *    DEPTH(1806) /0.4182800000E+04/
     *    WIDTH(1806) /0.3127200000E+04/
      DATA STRIKE(1807) /0.1434660645E+01/
     *    HL(1807) /0.1495900000E+04/
     *    EQLAT(1807) /0.1107818072E+01/
     *    EQLON(1807) /0.2575536650E+01/
     *    SSLIP(1807) /-.3826000000E+01/
     *    DSLIP(1807) /-.5830000000E+01/
     *    DIP(1807) /0.8377580410E+00/
     *    DEPTH(1807) /0.4182800000E+04/
     *    WIDTH(1807) /0.3127200000E+04/
      DATA STRIKE(1808) /0.1434660645E+01/
     *    HL(1808) /0.1495900000E+04/
     *    EQLAT(1808) /0.1107882126E+01/
     *    EQLON(1808) /0.2574498877E+01/
     *    SSLIP(1808) /-.3147000000E+01/
     *    DSLIP(1808) /-.5080000000E+01/
     *    DIP(1808) /0.8377580410E+00/
     *    DEPTH(1808) /0.4182800000E+04/
     *    WIDTH(1808) /0.3127200000E+04/
      DATA STRIKE(1809) /0.1436405974E+01/
     *    HL(1809) /0.1495900000E+04/
     *    EQLAT(1809) /0.1107945656E+01/
     *    EQLON(1809) /0.2573460929E+01/
     *    SSLIP(1809) /-.2240000000E+01/
     *    DSLIP(1809) /-.4380000000E+01/
     *    DIP(1809) /0.8377580410E+00/
     *    DEPTH(1809) /0.4182800000E+04/
     *    WIDTH(1809) /0.3127200000E+04/
      DATA STRIKE(1810) /0.1436405974E+01/
     *    HL(1810) /0.1495900000E+04/
     *    EQLAT(1810) /0.1108008837E+01/
     *    EQLON(1810) /0.2572422808E+01/
     *    SSLIP(1810) /-.1300000000E+01/
     *    DSLIP(1810) /-.3770000000E+01/
     *    DIP(1810) /0.8377580410E+00/
     *    DEPTH(1810) /0.4182800000E+04/
     *    WIDTH(1810) /0.3127200000E+04/
      DATA STRIKE(1811) /0.1438151304E+01/
     *    HL(1811) /0.1495900000E+04/
     *    EQLAT(1811) /0.1108071494E+01/
     *    EQLON(1811) /0.2571384162E+01/
     *    SSLIP(1811) /-.5390000000E+00/
     *    DSLIP(1811) /-.3220000000E+01/
     *    DIP(1811) /0.8377580410E+00/
     *    DEPTH(1811) /0.4182800000E+04/
     *    WIDTH(1811) /0.3127200000E+04/
      DATA STRIKE(1812) /0.1438151304E+01/
     *    HL(1812) /0.1495900000E+04/
     *    EQLAT(1812) /0.1108133802E+01/
     *    EQLON(1812) /0.2570345517E+01/
     *    SSLIP(1812) /-.1030000000E+00/
     *    DSLIP(1812) /-.2710000000E+01/
     *    DIP(1812) /0.8377580410E+00/
     *    DEPTH(1812) /0.4182800000E+04/
     *    WIDTH(1812) /0.3127200000E+04/
      DATA STRIKE(1813) /0.1439896633E+01/
     *    HL(1813) /0.1495900000E+04/
     *    EQLAT(1813) /0.1108195587E+01/
     *    EQLON(1813) /0.2569306348E+01/
     *    SSLIP(1813) /0.0000000000E+00/
     *    DSLIP(1813) /-.2280000000E+01/
     *    DIP(1813) /0.8377580410E+00/
     *    DEPTH(1813) /0.4182800000E+04/
     *    WIDTH(1813) /0.3127200000E+04/
      DATA STRIKE(1814) /0.1439896633E+01/
     *    HL(1814) /0.1495900000E+04/
     *    EQLAT(1814) /0.1108257022E+01/
     *    EQLON(1814) /0.2568267179E+01/
     *    SSLIP(1814) /0.0000000000E+00/
     *    DSLIP(1814) /-.1980000000E+01/
     *    DIP(1814) /0.8377580410E+00/
     *    DEPTH(1814) /0.4182800000E+04/
     *    WIDTH(1814) /0.3127200000E+04/
      DATA STRIKE(1815) /0.1441641962E+01/
     *    HL(1815) /0.1495900000E+04/
     *    EQLAT(1815) /0.1108317934E+01/
     *    EQLON(1815) /0.2567227661E+01/
     *    SSLIP(1815) /0.0000000000E+00/
     *    DSLIP(1815) /-.1960000000E+01/
     *    DIP(1815) /0.8377580410E+00/
     *    DEPTH(1815) /0.4182800000E+04/
     *    WIDTH(1815) /0.3127200000E+04/
      DATA STRIKE(1816) /0.1431169987E+01/
     *    HL(1816) /0.1495900000E+04/
     *    EQLAT(1816) /0.1107999761E+01/
     *    EQLON(1816) /0.2577716740E+01/
     *    SSLIP(1816) /-.4415000000E+01/
     *    DSLIP(1816) /-.6740000000E+01/
     *    DIP(1816) /0.8377580410E+00/
     *    DEPTH(1816) /0.6412300000E+04/
     *    WIDTH(1816) /0.3127200000E+04/
      DATA STRIKE(1817) /0.1432915316E+01/
     *    HL(1817) /0.1495900000E+04/
     *    EQLAT(1817) /0.1108064513E+01/
     *    EQLON(1817) /0.2576678793E+01/
     *    SSLIP(1817) /-.4479000000E+01/
     *    DSLIP(1817) /-.6580000000E+01/
     *    DIP(1817) /0.8377580410E+00/
     *    DEPTH(1817) /0.6412300000E+04/
     *    WIDTH(1817) /0.3127200000E+04/
      DATA STRIKE(1818) /0.1432915316E+01/
     *    HL(1818) /0.1495900000E+04/
     *    EQLAT(1818) /0.1108128915E+01/
     *    EQLON(1818) /0.2575640671E+01/
     *    SSLIP(1818) /-.4131000000E+01/
     *    DSLIP(1818) /-.5940000000E+01/
     *    DIP(1818) /0.8377580410E+00/
     *    DEPTH(1818) /0.6412300000E+04/
     *    WIDTH(1818) /0.3127200000E+04/
      DATA STRIKE(1819) /0.1434660645E+01/
     *    HL(1819) /0.1495900000E+04/
     *    EQLAT(1819) /0.1108192969E+01/
     *    EQLON(1819) /0.2574602375E+01/
     *    SSLIP(1819) /-.3427000000E+01/
     *    DSLIP(1819) /-.5160000000E+01/
     *    DIP(1819) /0.8377580410E+00/
     *    DEPTH(1819) /0.6412300000E+04/
     *    WIDTH(1819) /0.3127200000E+04/
      DATA STRIKE(1820) /0.1436405974E+01/
     *    HL(1820) /0.1495900000E+04/
     *    EQLAT(1820) /0.1108256499E+01/
     *    EQLON(1820) /0.2573563729E+01/
     *    SSLIP(1820) /-.2489000000E+01/
     *    DSLIP(1820) /-.4410000000E+01/
     *    DIP(1820) /0.8377580410E+00/
     *    DEPTH(1820) /0.6412300000E+04/
     *    WIDTH(1820) /0.3127200000E+04/
      DATA STRIKE(1821) /0.1436405974E+01/
     *    HL(1821) /0.1495900000E+04/
     *    EQLAT(1821) /0.1108319680E+01/
     *    EQLON(1821) /0.2572524909E+01/
     *    SSLIP(1821) /-.1510000000E+01/
     *    DSLIP(1821) /-.3750000000E+01/
     *    DIP(1821) /0.8377580410E+00/
     *    DEPTH(1821) /0.6412300000E+04/
     *    WIDTH(1821) /0.3127200000E+04/
      DATA STRIKE(1822) /0.1438151304E+01/
     *    HL(1822) /0.1495900000E+04/
     *    EQLAT(1822) /0.1108382337E+01/
     *    EQLON(1822) /0.2571485740E+01/
     *    SSLIP(1822) /-.6970000000E+00/
     *    DSLIP(1822) /-.3160000000E+01/
     *    DIP(1822) /0.8377580410E+00/
     *    DEPTH(1822) /0.6412300000E+04/
     *    WIDTH(1822) /0.3127200000E+04/
      DATA STRIKE(1823) /0.1438151304E+01/
     *    HL(1823) /0.1495900000E+04/
     *    EQLAT(1823) /0.1108444645E+01/
     *    EQLON(1823) /0.2570446222E+01/
     *    SSLIP(1823) /-.1950000000E+00/
     *    DSLIP(1823) /-.2630000000E+01/
     *    DIP(1823) /0.8377580410E+00/
     *    DEPTH(1823) /0.6412300000E+04/
     *    WIDTH(1823) /0.3127200000E+04/
      DATA STRIKE(1824) /0.1439896633E+01/
     *    HL(1824) /0.1495900000E+04/
     *    EQLAT(1824) /0.1108506430E+01/
     *    EQLON(1824) /0.2569406530E+01/
     *    SSLIP(1824) /-.1500000000E-01/
     *    DSLIP(1824) /-.2180000000E+01/
     *    DIP(1824) /0.8377580410E+00/
     *    DEPTH(1824) /0.6412300000E+04/
     *    WIDTH(1824) /0.3127200000E+04/
      DATA STRIKE(1825) /0.1439896633E+01/
     *    HL(1825) /0.1495900000E+04/
     *    EQLAT(1825) /0.1108567866E+01/
     *    EQLON(1825) /0.2568366662E+01/
     *    SSLIP(1825) /0.0000000000E+00/
     *    DSLIP(1825) /-.1880000000E+01/
     *    DIP(1825) /0.8377580410E+00/
     *    DEPTH(1825) /0.6412300000E+04/
     *    WIDTH(1825) /0.3127200000E+04/
      DATA STRIKE(1826) /0.1441641962E+01/
     *    HL(1826) /0.1495900000E+04/
     *    EQLAT(1826) /0.1108628778E+01/
     *    EQLON(1826) /0.2567326446E+01/
     *    SSLIP(1826) /0.0000000000E+00/
     *    DSLIP(1826) /-.1850000000E+01/
     *    DIP(1826) /0.8377580410E+00/
     *    DEPTH(1826) /0.6412300000E+04/
     *    WIDTH(1826) /0.3127200000E+04/
      DATA NUMEQ  /  29/
         
      END
